.htaccess.txt
admin
composer.json
composer.lock
core
download
extensions
image
index.php
install
license.txt
nginx.conf.txt
php.ini
resources
robots.txt
static_pages
storefront
system
task.php
task_cli.php
vendor