
SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Database: `abantecart144`
--

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]addresses`
--

CREATE TABLE `[[dbprefix]]addresses` (
  `address_id` int NOT NULL AUTO_INCREMENT,
  `customer_id` int NOT NULL,
  `company` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `firstname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `lastname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `address_1` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `address_2` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `postcode` varchar(10) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `city` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `country_id` int NOT NULL DEFAULT '0',
  `zone_id` int NOT NULL DEFAULT '0',
  `ext_fields` json DEFAULT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`address_id`),
  KEY `[[dbprefix]]addresses_idx` (`customer_id`,`country_id`,`zone_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=20 ;

--
-- Dumping data for table `[[dbprefix]]addresses`
--

INSERT INTO `[[dbprefix]]addresses` VALUES
(1, 2, '', 'Juliana', 'Davis', '9778 Golden Crescent', 'Apt 10', '85804-7365', 'Humansville', 223, 3616, NULL, '[[regtime]]', '[[regtime]]'),
(2, 3, '', 'Keely', 'Mccoy', '5071 Misty Pond Farm', 'Suite #101', '63406-9081', 'Bumble Bee', 223, 3648, NULL, '[[regtime]]', '[[regtime]]'),
(3, 4, 'BelfastCo', 'Zelda', 'Weiss', '6944 Sleepy Fawn Abbey', 'Suite #31', '86014-8121', 'Lawyers', 223, 3616, NULL, '[[regtime]]', '[[regtime]]'),
(4, 5, '', 'Gloria', 'Macias', '7590 Easy Robin Hollow', '', '73477-3842', 'Sandymush', 223, 3660, NULL, '[[regtime]]', '[[regtime]]'),
(5, 6, '', 'Bernard', 'Horne', '5607 Umber Branch Via', '', '86301-9785', 'Spook City', 223, 3616, NULL, '[[regtime]]', '[[regtime]]'),
(6, 7, '', 'James', 'Curtis', '6500 Arapahoe Road', '', '80303', 'Boulder', 223, 3634, NULL, '[[regtime]]', '[[regtime]]'),
(7, 8, '', 'Bruce', 'Rosarini', '61 Cumberland ST', '', '68624-2273', 'Skokie', 223, 3650, NULL, '[[regtime]]', '[[regtime]]'),
(8, 9, '', 'Carlos', 'Compton', '31 Capital Drive', '', '63142-0892', 'Fort Misery', 223, 3648, NULL, '[[regtime]]', '[[regtime]]'),
(9, 10, '', 'Garrison', 'Baxter', 'Eddie Hoffman Highway', '', '64034-2948', 'Shell Pile', 223, 3648, NULL, '[[regtime]]', '[[regtime]]'),
(10, 11, '', 'Anthony', 'Blair', '104 Main Street', '', '29181-8284', 'Gassaway', 223, 3666, NULL, '[[regtime]]', '[[regtime]]'),
(11, 12, '', 'Allen', 'Waters', '110 Shenandoah Avenue', '', '86565-1710', 'Honohina', 223, 3616, NULL, '[[regtime]]', '[[regtime]]'),
(12, 13, '', 'Tom', 'Kipling', '100 Main Str', '', '64034-2948', 'Shell Pile', 223, 3648, NULL, '[[regtime]]', '[[regtime]]'),
(13, 14, 'Eaton Stevenson Inc', 'Yuri', 'Howard', '22555 Jensen Ave', '', '93654', 'Reedley', 223, 3624, NULL, '[[regtime]]', '[[regtime]]'),
(14, 15, 'Day and Rivera Traders', 'Regan', 'Shields', '2355 Boulevard Bastien', '', 'G2B 1B3', 'Québec', 38, 612, NULL, '[[regtime]]', '[[regtime]]'),
(15, 16, '', 'Randall', 'Richards', '500 N Nebraska Ave', '', '33603', 'Tampa', 223, 3630, NULL, '[[regtime]]', '[[regtime]]'),
(16, 16, 'Guzman and Morin Inc', 'Mallory', 'Ballard', '2430 S French Ave', '', '32771', 'Sanford', 223, 3630, NULL, '[[regtime]]', '[[regtime]]'),
(17, 17, '', 'Michelle', 'Barnett', '3180 S Redwood Rd', '', '84119', 'West Valley City', 223, 3670, NULL, '[[regtime]]', '[[regtime]]'),
(18, 18, '', 'Elmer', 'West', '1433 Armand-Frappier', '', 'J3E 3R6', 'Sainte-Julie', 38, 612, NULL, '[[regtime]]', '[[regtime]]'),
(19, 18, '', 'Elmer', 'West', '291 Central Ave', '', '10606', 'White Plains', 223, 3657, NULL, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]ant_messages`
--

CREATE TABLE `[[dbprefix]]ant_messages` (
  `id` varchar(60) COLLATE utf8mb4_unicode_ci NOT NULL,
  `priority` int NOT NULL DEFAULT '0',
  `placeholder` varchar(128) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `start_date` timestamp NULL DEFAULT NULL,
  `end_date` timestamp NULL DEFAULT NULL,
  `viewed_date` timestamp NULL DEFAULT NULL,
  `viewed` int NOT NULL DEFAULT '0',
  `title` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `description` text COLLATE utf8mb4_unicode_ci,
  `html` longtext COLLATE utf8mb4_unicode_ci,
  `url` text COLLATE utf8mb4_unicode_ci,
  `language_code` varchar(2) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 'en',
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`,`language_code`),
  KEY `daterange_idx` (`start_date`,`end_date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]ant_messages`
--

INSERT INTO `[[dbprefix]]ant_messages` VALUES
('quick_start_offer1', 1, 'quick_start', '[[regtime]]', '2029-12-31 20:30:00', NULL, 0, 'Quick Start Wizzard modal content, Offer 1', '', '<div class="col-md-12">\n	<div class="text-center">\n		<a href="https://buy.avalara.com/signup?partner=abantecart&CampaignID=7010b0000013ZLp&" target="_ext_help">\n			<img width="900px" src="https://marketplace.abantecart.com/extensions/marketplace/storefront/view/default/images/avatax-trial-750x400.jpg" /></a>\n	</div>\n\n	<div class="text-center">\n		<div class="btn-group">\n			<a class="btn btn-white" href="https://buy.avalara.com/signup?partner=abantecart&CampaignID=7010b0000013ZLp&" target="_ext_help">\n				<i class="fa fa-arrow-right"></i> Learn More\n			</a>\n		</div>\n	</div>\n</div>', '', '*', '[[regtime]]'),
('quick_start_offer2', 1, 'quick_start', '[[regtime]]', '2029-12-31 20:30:00', NULL, 0, 'Quick Start Wizzard modal content, Offer 2', '', '<div class="col-md-12">\n	<div class="text-center">\n        <h1>Accept Payments from <br/>customers with Stripe.</h1>\n		<p>\n            <img alt="Stripe + AbanteCart" src="https://www.abantecart.com/resources/image/18/7f/9.webp"\n                 class="mcnImage"\n                 style="max-width:600px; padding-bottom: 0; display: inline !important; vertical-align: bottom; width:570px; align:middle;">\n		</p>\n	</div>\n\n	<div style="padding: 10px 60px 30px 60px">\n        <h1>Some Stripe benefits:</h1>\n		<p>\n            <label><b>Stripe supports a wide range of payment methods</b></label>\n			<br />\n            including cards, bank debits, bank redirects, Affirm, Klarna, ACH, MobilePay and more.\n		</p>\n\n		<p>\n			<label><b>Powerful Fraud Protection and Easy PCI Compliance</b></label>\n			<br />\n			Our robust tokenization technology simplifies PCI compliance requirements and our built-in fraud screening tool stops fraud in its tracks.\n		</p>\n\n		<p>\n			<label><b>White-Glove Customer Support</b></label>\n			<br />\n            Get one-on-one support every step of the way. Stripe''s Customer Support teams are always on hand to ensure\n            that you''re getting the most out of your integration, without any processing disruptions.\n		</p>\n\n		<p>\n			<label><b>Competitive Processing Rates</b></label>\n			<br />\n			Our extensive industry expertise and rate optimization technology allow us to offer you the lowest rates.\n		</p>\n	</div>\n\n	<div class="text-center">\n		<div class="btn-group">\n            <a class="btn btn-white" href="#admin#rt=extension/extensions/edit&extension=stripe" target="_blank">\n				<i class="fa fa-arrow-right"></i> Learn More\n			</a>\n		</div>\n	</div>\n</div>', '', '*', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]banners`
--

CREATE TABLE `[[dbprefix]]banners` (
  `banner_id` int NOT NULL AUTO_INCREMENT,
  `status` int NOT NULL DEFAULT '0',
  `banner_type` int NOT NULL DEFAULT '1',
  `banner_group_name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `start_date` timestamp NULL DEFAULT NULL,
  `end_date` timestamp NULL DEFAULT NULL,
  `blank` tinyint(1) NOT NULL DEFAULT '0',
  `target_url` text COLLATE utf8mb4_unicode_ci,
  `sort_order` int NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`banner_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=19 ;

--
-- Dumping data for table `[[dbprefix]]banners`
--

INSERT INTO `[[dbprefix]]banners` VALUES
(8, 1, 2, 'Main Page Banners', '[[regtime]]', NULL, 0, '', 1, '[[regtime]]', '[[regtime]]'),
(9, 1, 2, 'Main Page Banners', '[[regtime]]', NULL, 0, '', 2, '[[regtime]]', '[[regtime]]'),
(10, 1, 2, 'Main Page Banners', '[[regtime]]', NULL, 0, '', 3, '[[regtime]]', '[[regtime]]'),
(11, 1, 2, 'Main Page Banners', '[[regtime]]', NULL, 0, '', 4, '[[regtime]]', '[[regtime]]'),
(13, 1, 1, 'Main bottom banners', '[[regtime]]', NULL, 0, 'https://www.abantecart.com', 1, '[[regtime]]', '[[regtime]]'),
(14, 1, 1, 'Main bottom banners', '[[regtime]]', NULL, 0, 'https://www.abantecart.com', 2, '[[regtime]]', '[[regtime]]'),
(15, 1, 1, 'Main bottom banners', '[[regtime]]', NULL, 0, 'https://www.abantecart.com', 3, '[[regtime]]', '[[regtime]]'),
(16, 1, 1, 'Main bottom banners', '[[regtime]]', NULL, 0, 'https://www.abantecart.com', 4, '[[regtime]]', '[[regtime]]'),
(17, 1, 2, 'Main Page Banners', '[[regtime]]', NULL, 0, '', 5, '[[regtime]]', '[[regtime]]'),
(18, 1, 1, 'Main Page Banners', '[[regtime]]', NULL, 0, '', 6, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]banner_descriptions`
--

CREATE TABLE `[[dbprefix]]banner_descriptions` (
  `banner_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `description` longtext COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `meta` text COLLATE utf8mb4_unicode_ci COMMENT 'translatable',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`banner_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]banner_descriptions`
--

INSERT INTO `[[dbprefix]]banner_descriptions` VALUES
(8, 1, 'Main Banner 1', '&lt;p&gt;\r\n	&lt;img alt=&quot;&quot; class=&quot;wp1_3 slide1_bot&quot; src=&quot;storefront/view/default/image/banner_image_1.png&quot; width=&quot;600&quot; height=&quot;300&quot; /&gt; &lt;span class=&quot;txt1&quot;&gt;HTML5 Responsive Storefront to look great on&lt;/span&gt; &lt;span class=&quot;txt2&quot;&gt;ALL Screen Sizes&lt;/span&gt; &lt;span class=&quot;txt3 short&quot;&gt;Natively responsive template implemented with bootstrap library and HTML5. Will look good on most mobile devices and tablets.&lt;/span&gt; &lt;span class=&quot;txt4 txt4up&quot;&gt;&lt;a class=&quot;btn btn-wht&quot; href=&quot;&quot;&gt;Try on your device!&lt;/a&gt;&lt;/span&gt;&lt;/p&gt;\r\n', '', '[[regtime]]', '[[regtime]]'),
(9, 1, 'Main Banner 2', '&lt;p&gt;\r\n	&lt;img alt=&quot;&quot; class=&quot;wp1_3 wp1_left slide2_bot&quot; src=&quot;storefront/view/default/image/banner_image_2.png&quot; width=&quot;600&quot; height=&quot;300&quot; /&gt; &lt;span class=&quot;txt1 blue txt_right2&quot;&gt;Highly flexible layout on any page&lt;/span&gt; &lt;span class=&quot;txt2 blue txt_right2&quot;&gt;SEO Friendly&lt;/span&gt; &lt;span class=&quot;txt2 blue txt_right2&quot;&gt;Fast Loading&lt;/span&gt; &lt;span class=&quot;txt4 txt_right2 txt4up&quot;&gt;&lt;a class=&quot;btn btn-wht&quot; href=&quot;#&quot;&gt;Try Now!&lt;/a&gt;&lt;/span&gt;&lt;/p&gt;\r\n', '', '[[regtime]]', '[[regtime]]'),
(10, 1, 'Main Banner 3', '&lt;p&gt;\r\n	&lt;img alt=&quot;&quot; class=&quot;wp1_3 slide2_bot&quot; src=&quot;storefront/view/default/image/banner_image_3.png&quot; width=&quot;600&quot; height=&quot;300&quot; /&gt; &lt;span class=&quot;txt1&quot;&gt;Feature rich with smart UI&lt;/span&gt; &lt;span class=&quot;txt2&quot;&gt;Easy &amp;amp; fun to manage&lt;/span&gt; &lt;span class=&quot;txt3&quot;&gt;Feature reach shopping cart application right out of the box. Standard features allow to set up complete eCommerce site with all the tools needed to sell products online.&lt;/span&gt; &lt;span class=&quot;txt4&quot;&gt;&lt;a class=&quot;btn btn-wht&quot; href=&quot;#&quot;&gt;Install Now!&lt;/a&gt;&lt;/span&gt;&lt;/p&gt;\r\n', '', '[[regtime]]', '[[regtime]]'),
(11, 1, 'Main Banner 4', '&lt;p&gt;\r\n	&lt;img alt=&quot;&quot; class=&quot;wp1_3 slide3_bot&quot; src=&quot;storefront/view/default/image/banner_image_4.png&quot; width=&quot;600&quot; height=&quot;300&quot; /&gt; &lt;span class=&quot;txt1 blue&quot;&gt;Stay in control&lt;/span&gt; &lt;span class=&quot;txt2 blue&quot;&gt;Easy updates&lt;/span&gt; &lt;span class=&quot;txt3 short&quot;&gt;Upgrade right from admin. Backward supportability in upgrades and automatic backups. Easy extension download with one step installation.&lt;/span&gt; &lt;span class=&quot;txt4 txt4up&quot;&gt;&lt;a class=&quot;btn btn-wht&quot; href=&quot;#&quot;&gt;Get Yours!&lt;/a&gt;&lt;/span&gt;&lt;/p&gt;\r\n', '', '[[regtime]]', '[[regtime]]'),
(13, 1, 'banner1', '', '', '[[regtime]]', '[[regtime]]'),
(14, 1, 'banner2', '', '', '[[regtime]]', '[[regtime]]'),
(15, 1, 'banner3', '', '', '[[regtime]]', '[[regtime]]'),
(16, 1, 'banner4', '', '', '[[regtime]]', '[[regtime]]'),
(17, 1, 'Main Banner 5', '&lt;p&gt;\r\n	&lt;img alt=&quot;&quot; class=&quot;wp1_3 slide2_bot&quot; src=&quot;storefront/view/default/image/banner_image_5.png&quot; width=&quot;600&quot; height=&quot;300&quot; /&gt; &lt;span class=&quot;txt1&quot;&gt;Application and data security&lt;/span&gt; &lt;span class=&quot;txt2&quot;&gt;Secure Solution&lt;/span&gt; &lt;span class=&quot;txt3&quot;&gt;Very secure solution with up to date industry security practices and inline with PCI compliance. Customer information protection with data encryption&lt;/span&gt; &lt;span class=&quot;txt4&quot;&gt;&lt;a class=&quot;btn btn-wht&quot; href=&quot;#&quot;&gt;Install Now!&lt;/a&gt;&lt;/span&gt;&lt;/p&gt;\r\n', '', '[[regtime]]', '[[regtime]]'),
(18, 1, 'fallback', '', '', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]banner_stat`
--

CREATE TABLE `[[dbprefix]]banner_stat` (
  `rowid` int NOT NULL AUTO_INCREMENT,
  `banner_id` int NOT NULL,
  `type` int NOT NULL,
  `time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `store_id` int NOT NULL,
  `user_info` text COLLATE utf8mb4_unicode_ci,
  PRIMARY KEY (`rowid`),
  KEY `[[dbprefix]]banner_stat_idx` (`banner_id`,`type`,`time`,`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]blocks`
--

CREATE TABLE `[[dbprefix]]blocks` (
  `block_id` int NOT NULL AUTO_INCREMENT,
  `block_txt_id` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `controller` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`block_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=41 ;

--
-- Dumping data for table `[[dbprefix]]blocks`
--

INSERT INTO `[[dbprefix]]blocks` VALUES
(1, 'header', 'common/header', '[[regtime]]', '[[regtime]]'),
(2, 'header_bottom', 'common/header_bottom', '[[regtime]]', '[[regtime]]'),
(3, 'column_left', 'common/column_left', '[[regtime]]', '[[regtime]]'),
(4, 'content_top', 'common/content_top', '[[regtime]]', '[[regtime]]'),
(5, 'content_bottom', 'common/content_bottom', '[[regtime]]', '[[regtime]]'),
(6, 'column_right', 'common/column_right', '[[regtime]]', '[[regtime]]'),
(7, 'footer_top', 'common/footer_top', '[[regtime]]', '[[regtime]]'),
(8, 'footer', 'common/footer', '[[regtime]]', '[[regtime]]'),
(9, 'category', 'blocks/category', '[[regtime]]', '[[regtime]]'),
(10, 'manufacturer', 'blocks/manufacturer', '[[regtime]]', '[[regtime]]'),
(11, 'content', 'blocks/content', '[[regtime]]', '[[regtime]]'),
(12, 'latest', 'blocks/latest', '[[regtime]]', '[[regtime]]'),
(13, 'language', 'blocks/language', '[[regtime]]', '[[regtime]]'),
(14, 'currency', 'blocks/currency', '[[regtime]]', '[[regtime]]'),
(15, 'cart', 'blocks/cart', '[[regtime]]', '[[regtime]]'),
(16, 'order_summary', 'blocks/order_summary', '[[regtime]]', '[[regtime]]'),
(17, 'html_block', 'blocks/html_block', '[[regtime]]', '[[regtime]]'),
(18, 'bestsellers', 'blocks/bestseller', '[[regtime]]', '[[regtime]]'),
(19, 'featured', 'blocks/featured', '[[regtime]]', '[[regtime]]'),
(20, 'listing_block', 'blocks/listing_block', '[[regtime]]', '[[regtime]]'),
(21, 'donate', 'blocks/donate', '[[regtime]]', '[[regtime]]'),
(22, 'special', 'blocks/special', '[[regtime]]', '[[regtime]]'),
(23, 'banner_block', 'blocks/banner_block', '[[regtime]]', '[[regtime]]'),
(24, 'credit_cards', 'blocks/credit_cards', '[[regtime]]', '[[regtime]]'),
(25, 'newsletter_signup', 'blocks/newsletter_signup', '[[regtime]]', '[[regtime]]'),
(26, 'search', 'blocks/search', '[[regtime]]', '[[regtime]]'),
(27, 'menu', 'blocks/menu', '[[regtime]]', '[[regtime]]'),
(28, 'breadcrumbs', 'blocks/breadcrumbs', '[[regtime]]', '[[regtime]]'),
(29, 'account', 'blocks/account', '[[regtime]]', '[[regtime]]'),
(30, 'custom_form_block', 'blocks/custom_form_block', '[[regtime]]', '[[regtime]]'),
(31, 'customer', 'blocks/customer', '[[regtime]]', '[[regtime]]'),
(32, 'fast_checkout_cart_btn', 'blocks/fast_checkout_cart_btn', '[[regtime]]', '[[regtime]]'),
(33, 'fast_checkout_summary', 'blocks/fast_checkout_summary', '[[regtime]]', '[[regtime]]'),
(34, 'viewed_products', 'blocks/viewed_products', '[[regtime]]', '[[regtime]]'),
(35, 'new_content', 'blocks/new_content', '[[regtime]]', '[[regtime]]'),
(36, 'content_search', 'blocks/content_search', '[[regtime]]', '[[regtime]]'),
(37, 'store_hours', 'blocks/store_hours', '[[regtime]]', '[[regtime]]'),
(38, 'mega_menu_header', 'blocks/mega_menu', '[[regtime]]', '[[regtime]]'),
(39, 'category_slides', 'blocks/category_slides', '[[regtime]]', '[[regtime]]'),
(40, 'category_filter', 'blocks/category_filter', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]block_descriptions`
--

CREATE TABLE `[[dbprefix]]block_descriptions` (
  `block_description_id` int NOT NULL AUTO_INCREMENT,
  `custom_block_id` int NOT NULL,
  `language_id` int NOT NULL,
  `block_wrapper` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '0',
  `block_framed` tinyint(1) DEFAULT '0',
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  `content` longtext COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`block_description_id`,`custom_block_id`,`language_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=21 ;

--
-- Dumping data for table `[[dbprefix]]block_descriptions`
--

INSERT INTO `[[dbprefix]]block_descriptions` VALUES
(1, 1, 1, '0', 0, 'Social Icons', 'social_icons', '', '&lt;div class=&quot;social_icons nav navbar&quot;&gt; &lt;a class=&quot;nav-link m-3&quot; href=&quot;https://www.facebook.com/AbanteCart&quot; target=&quot;_blank&quot; title=&quot;Facebook&quot; &gt;&lt;i class=&quot; fa-brands fa-facebook fa-xl&quot; &gt;&lt;/i&gt;&lt;/a&gt;        &lt;a class=&quot;nav-link m-3&quot; href=&quot;https://twitter.com/abantecart&quot; target=&quot;_blank&quot; title=&quot;Twitter&quot;&gt;&lt;i class=&quot; fa-brands fa-x-twitter fa-xl&quot; &gt;&lt;/i&gt;&lt;/a&gt;        &lt;a class=&quot;nav-link m-3&quot;  href=&quot;#&quot; title=&quot;Linkedin&quot; &gt;&lt;i class=&quot;fa-brands fa-linkedin fa-xl&quot;&gt;&lt;/i&gt;&lt;/a&gt;        &lt;a class=&quot;nav-link m-3&quot;  href=&quot;#&quot; title=&quot;rss&quot; &gt;&lt;i class=&quot;fa-solid fa-square-rss fa-xl&quot;&gt;&lt;/i&gt;&lt;/a&gt;        &lt;a class=&quot;nav-link m-3&quot;  href=&quot;#&quot; target=&quot;_blank&quot; title=&quot;Skype&quot; &gt;&lt;i class=&quot;fa-brands fa-skype fa-xl&quot;&gt;&lt;/i&gt;&lt;/a&gt;        &lt;a class=&quot;nav-link m-3&quot;  href=&quot;#&quot; target=&quot;_blank&quot; title=&quot;Flickr&quot;&gt;&lt;i class=&quot;fa-brands fa-flickr fa-xl&quot;&gt;&lt;/i&gt;&lt;/a&gt;      &lt;/div&gt;', '[[regtime]]', '[[regtime]]'),
(2, 2, 1, 'blocks/html_block_footer.tpl', 1, 'About Us', 'About Us', '', '&lt;p class=&quot;small lh-lg&quot;&gt;AbanteCart is a free eCommerce solution for merchants to provide ability creating online business and sell products or services online. AbanteCart application is built and supported by experienced enthusiasts that are passionate about their work and contribution to rapidly evolving eCommerce industry. AbanteCart is more than just a shopping cart, it is rapidly growing eCommerce platform with many benefits.&lt;/p&gt;', '[[regtime]]', '[[regtime]]'),
(3, 3, 1, 'blocks/html_block_footer.tpl', 1, 'Contact us', 'Contact Us', '', '&lt;ul class=&quot;list-unstyled contact small&quot;&gt;   &lt;li class=&quot;mb-2&quot;&gt;&lt;i class=&quot;fa-solid fa-phone&quot;&gt;&lt;/i&gt;&lt;/i&gt; 123 456 7890,  123 456 7890&lt;/li&gt;    &lt;li class=&quot;mb-2&quot;&gt;&lt;i class=&quot;fa-solid fa-mobile-screen&quot;&gt;&lt;/i&gt;&lt;a class=&quot;text-decoration-none&quot;  href=&quot;tel:123 456 7890&quot;&gt; 123 456 7890&lt;/a&gt;,  123 456 78900&lt;/li&gt;    &lt;li class=&quot;mb-2&quot;&gt;&lt;i class=&quot;fa-solid fa-at&quot;&gt;&lt;/i&gt; help at abantecart.com&lt;/li&gt;&lt;/ul&gt;', '[[regtime]]', '[[regtime]]'),
(4, 4, 1, '0', 1, 'Testimonials', 'Testimonials', '', '&lt;div id=&quot;testimonial_sidebar&quot; class=&quot;carousel carousel-dark slide&quot; data-bs-ride=&quot;carousel&quot;&gt; &lt;div class=&quot;carousel-inner&quot;&gt;                   &lt;div class=&quot;carousel-item active&quot;&gt;                        &lt;div class=&quot;align-self-stretch small lh-lg&quot;&gt;                        &quot; I was working with many shopping carts, free and hosted for my clients. There is always something missing. In AbanteCart I find this gap to be much less. Interface is very easy to use and support is very responsive. This is considering its is free. Go AbanteCart go!&quot;&lt;br /&gt;                                    &lt;span class=&quot;pull-left orange&quot;&gt;By : TopShop on reviewcentre.com&lt;/span&gt;                        &lt;/div&gt;                    &lt;/div&gt;                    &lt;div class=&quot;carousel-item&quot;&gt;                        &lt;div class=&quot;align-self-stretch small lh-lg&quot;&gt;                        &quot; Without a doubt the best cart I have used. The title says it all - AbanteCart is undoubtedly the best I have used. I''m not an expert in site setup, so something this great looking and easy to use is absolutely perfect ... &quot;&lt;br /&gt;                                    &lt;span class=&quot;pull-left orange&quot;&gt;By : johnstenson80 on venturebeat.com&lt;/span&gt;                        &lt;/div&gt;                    &lt;/div&gt;                    &lt;div class=&quot;carousel-item&quot;&gt;                        &lt;div class=&quot;align-self-stretch small lh-lg&quot;&gt;                        &quot; Will not regret using this cart. All good is already mentioned, I want to add my experience with support. My problems with some configuration were resolved quick. Faster than paid shopping cart we had before.&quot;&lt;br /&gt;                                    &lt;span class=&quot;pull-left orange&quot;&gt;By : shopper23 at bestshoppingcartreviews.com&lt;/span&gt;                        &lt;/div&gt;                    &lt;/div&gt;                    &lt;div class=&quot;carousel-item&quot;&gt;                        &lt;div class=&quot;align-self-stretch small lh-lg&quot;&gt;                        &quot; Love the cart. I installed it a while back and use it since when. Some features a hidden, but fun to discover them.&quot;&lt;br /&gt;                                    &lt;span class=&quot;pull-left orange&quot;&gt;By : Liz Wattkins at shopping-cart-reviews.com&lt;/span&gt;                        &lt;/div&gt;                    &lt;/div&gt;                &lt;/div&gt;            &lt;/div&gt;', '[[regtime]]', '[[regtime]]'),
(5, 5, 1, '0', 0, 'Main Page Carousel', 'Main Page Carousel', '', '&lt;div id=&quot;mainPageSliderIndicators&quot; class=&quot;carousel carousel-dark slide bg-light&quot; data-bs-ride=&quot;carousel&quot;&gt;  &lt;div class=&quot;carousel-indicators&quot;&gt;  &lt;button type=&quot;button&quot; data-bs-target=&quot;#mainPageSliderIndicators&quot; data-bs-slide-to=&quot;0&quot; class=&quot;active&quot;  aria-current=&quot;true&quot; aria-label=&quot;Slide 1&quot;&gt;&lt;/button&gt;  &lt;button type=&quot;button&quot; data-bs-target=&quot;#mainPageSliderIndicators&quot; data-bs-slide-to=&quot;1&quot;  aria-label=&quot;Slide 2&quot;&gt;&lt;/button&gt;  &lt;button type=&quot;button&quot; data-bs-target=&quot;#mainPageSliderIndicators&quot; data-bs-slide-to=&quot;2&quot;  aria-label=&quot;Slide 3&quot;&gt;&lt;/button&gt;  &lt;button type=&quot;button&quot; data-bs-target=&quot;#mainPageSliderIndicators&quot; data-bs-slide-to=&quot;3&quot;  aria-label=&quot;Slide 4&quot;&gt;&lt;/button&gt;  &lt;/div&gt;  &lt;div class=&quot;carousel-inner&quot;&gt;  &lt;div class=&quot;carousel-item banner active&quot;&gt;  &lt;div class=&quot;d-flex flex-wrap flex-sm-nowrap justify-content-center align-items-center&quot;&gt;  &lt;div class=&quot;flex-item &quot;&gt;  &lt;img class=&quot;my-auto w-100&quot; src=&quot;image/Slide_600x300.jpeg&quot;&gt;  &lt;/div&gt;  &lt;div class=&quot;flex-item col-9 col-sm-3 m-5&quot;&gt;  &lt;h5&gt;HTML5 Responsive Storefront to look great on&lt;/h5&gt;  &lt;h5&gt;ALL Screen Sizes&lt;/h5&gt;  &lt;p&gt;Natively responsive template implemented with bootstrap library and HTML5. Will look good on most  mobile devices and tablets.&lt;/p&gt;  &lt;h3&gt;&lt;a href=&quot;#&quot; class=&quot;&quot;&gt; Try on your device!&lt;/a&gt;&lt;/h3&gt;  &lt;/div&gt;  &lt;/div&gt;  &lt;/div&gt;  &lt;div class=&quot;carousel-item banner&quot;&gt;  &lt;div class=&quot;d-flex flex-wrap flex-sm-nowrap justify-content-center align-items-center&quot;&gt;  &lt;div class=&quot;flex-item &quot;&gt;  &lt;img class=&quot;my-auto w-100&quot; src=&quot;image/Slide_600x300.jpeg&quot;&gt;  &lt;/div&gt;  &lt;div class=&quot;flex-item col-9 col-sm-3  m-5&quot;&gt;  &lt;h5&gt;Highly flexible layout on any page&lt;/h5&gt;  &lt;h5&gt;SEO Friendly&lt;/h5&gt;  &lt;p&gt;Fast Loading&lt;/p&gt;  &lt;h3&gt;&lt;a href=&quot;#&quot; class=&quot;&quot;&gt; Try Now!&lt;/a&gt;&lt;/h3&gt;  &lt;/div&gt;  &lt;/div&gt;  &lt;/div&gt;  &lt;div class=&quot;carousel-item banner&quot;&gt;  &lt;div class=&quot;d-flex flex-wrap flex-sm-nowrap justify-content-center align-items-center&quot;&gt;  &lt;div class=&quot;flex-item &quot;&gt;  &lt;img class=&quot;my-auto w-100&quot; src=&quot;image/Slide_600x300.jpeg&quot;&gt;  &lt;/div&gt;  &lt;div class=&quot;flex-item col-9 col-sm-3  m-5&quot;&gt;  &lt;h5&gt;Feature rich with smart UI&lt;/h5&gt;  &lt;h5&gt;Easy &amp;amp; fun to manage&lt;/h5&gt;  &lt;p&gt;Feature reach shopping cart application right out of the box. Standard features allow to set up  complete eCommerce site with all the tools needed to sell products online.&lt;/p&gt;  &lt;h3&gt;&lt;a href=&quot;#&quot; class=&quot;&quot;&gt;Install Now!&lt;/a&gt;&lt;/h3&gt;  &lt;/div&gt;  &lt;/div&gt;  &lt;/div&gt;  &lt;div class=&quot;carousel-item banner&quot;&gt;  &lt;div class=&quot;d-flex flex-wrap flex-sm-nowrap justify-content-center align-items-center&quot;&gt;  &lt;div class=&quot;flex-item &quot;&gt;  &lt;img class=&quot;my-auto w-100&quot; src=&quot;image/Slide_600x300.jpeg&quot;&gt;  &lt;/div&gt;  &lt;div class=&quot;flex-item col-9 col-sm-3  m-5&quot;&gt;  &lt;h5&gt;Stay in control&lt;/h5&gt;  &lt;h5&gt;Easy updates&lt;/h5&gt;  &lt;p&gt;Upgrade right from admin. Backward supportability in upgrades and automatic backups. Easy  extension download with one step installation.&lt;/p&gt;  &lt;h3&gt;&lt;a href=&quot;#&quot; class=&quot;&quot;&gt;Get Yours!&lt;/a&gt;&lt;/h3&gt;  &lt;/div&gt;  &lt;/div&gt;  &lt;/div&gt;  &lt;/div&gt;  &lt;button class=&quot;carousel-control-prev&quot; type=&quot;button&quot; data-bs-target=&quot;#mainPageSliderIndicators&quot; data-bs-slide=&quot;prev&quot;&gt;  &lt;span class=&quot;carousel-control-prev-icon&quot; aria-hidden=&quot;true&quot;&gt;&lt;/span&gt;  &lt;span class=&quot;visually-hidden&quot;&gt;Previous&lt;/span&gt;  &lt;/button&gt;  &lt;button class=&quot;carousel-control-next&quot; type=&quot;button&quot; data-bs-target=&quot;#mainPageSliderIndicators&quot; data-bs-slide=&quot;next&quot;&gt;  &lt;span class=&quot;carousel-control-next-icon&quot; aria-hidden=&quot;true&quot;&gt;&lt;/span&gt;  &lt;span class=&quot;visually-hidden&quot;&gt;Next&lt;/span&gt; &lt;/button&gt; &lt;/div&gt;', '[[regtime]]', '[[regtime]]'),
(6, 6, 1, '0', 0, 'Main Page Promo', 'Promo', '', '&lt;section class=&quot;d-flex flex-wrap justify-content-evenly border m-3&quot;&gt;	&lt;div class=&quot;d-flex flex-item align-items-center&quot;&gt;		&lt;div class=&quot;promo_icon fs-1 m-3&quot;&gt;&lt;i class=&quot;fa-solid fa-2xl fa-truck fs-1&quot;&gt;&lt;/i&gt;&lt;/div&gt;&lt;div class=&quot;promo_text&quot;&gt;&lt;h2&gt;Free shipping&lt;/h2&gt;All over in world over $200&lt;/div&gt;&lt;/div&gt;&lt;div class=&quot;d-flex flex-item align-items-center&quot;&gt;&lt;div class=&quot;promo_icon fs-1 m-3&quot;&gt;&lt;i class=&quot;fa-solid fa-2xl fa-money-bill-1 fs-1&quot;&gt;&lt;/i&gt;&lt;/div&gt;		&lt;div class=&quot;promo_text&quot;&gt;&lt;h2&gt;Easy Payment&lt;/h2&gt;Payment Gateway support&lt;/div&gt;&lt;/div&gt;&lt;div class=&quot;d-flex flex-item align-items-center&quot;&gt;		&lt;div class=&quot;promo_icon fs-1 m-3&quot;&gt;&lt;i class=&quot;fa-solid fa-2xl fa-clock fs-1&quot;&gt;&lt;/i&gt;&lt;/div&gt;&lt;div class=&quot;promo_text&quot;&gt;&lt;h2&gt;24hrs Shipping&lt;/h2&gt;For All US States&lt;/div&gt;&lt;/div&gt;&lt;div class=&quot;d-flex flex-item align-items-center&quot;&gt;&lt;div class=&quot;promo_icon fs-1 m-3&quot;&gt;&lt;i class=&quot;fa-solid fa-2xl fa-tags fs-1&quot;&gt;&lt;/i&gt;&lt;/div&gt;		&lt;div class=&quot;promo_text&quot;&gt;&lt;h2&gt;Large Variety&lt;/h2&gt;50,000  Products&lt;/div&gt;&lt;/div&gt;&lt;/section&gt;', '[[regtime]]', '[[regtime]]'),
(7, 7, 1, '0', 0, 'Main Page Banner Bottom', 'Bottom Banners', '', 'a:1:{s:17:""banner_group_name"";s:19:""Main bottom banners"";}', '[[regtime]]', '[[regtime]]'),
(8, 8, 1, 'blocks/listing_block/popular_brands_content_bottom.tpl', 0, 'Brands Scrolling List', 'Brands Scrolling List', '', 'a:1:{s:18:""listing_datasource"";s:20:""custom_manufacturers"";}', '[[regtime]]', '[[regtime]]'),
(9, 9, 1, 'blocks/html_block_footer.tpl', 0, 'Novator About Us', 'Novator About Us', 'Novator About Us', '&lt;div class=&quot;footer-abtus text-center text-md-start&quot;&gt;\n&lt;h3 class=&quot;h5 text-white mb-4&quot;&gt;\n  Where art and fashion fuse. Elevate your style with Balenciaga.&lt;/h3&gt;\n  &lt;ul class=&quot;list-inline&quot;&gt;\n    &lt;li class=&quot;list-inline-item&quot;&gt;&lt;a href=&quot;#&quot;&gt;&lt;i class=&quot;bi bi-layers&quot;&gt;&lt;/i&gt; Top Brands&lt;/a&gt;&lt;/li&gt;\n    &lt;li class=&quot;list-inline-item&quot;&gt;&lt;a href=&quot;#&quot;&gt;&lt;i class=&quot;bi bi-tag&quot;&gt;&lt;/i&gt; Discount&lt;/a&gt;&lt;/li&gt;\n  &lt;/ul&gt;\n  &lt;div class=&quot;social_icons&quot;&gt;\n    &lt;ul class=&quot;list-inline&quot;&gt;\n      &lt;li class=&quot;list-inline-item&quot;&gt;&lt;a href=&quot;https://www.facebook.com/AbanteCart&quot; target=&quot;_blank&quot; title=&quot;Facebook&quot; class=&quot;facebook&quot;&gt;&lt;i class=&quot;fa-brands fa-facebook-f&quot;&gt;&lt;/i&gt;&lt;/a&gt;&lt;/li&gt;\n      &lt;li class=&quot;list-inline-item&quot;&gt;&lt;a href=&quot;https://twitter.com/abantecart&quot; target=&quot;_blank&quot; title=&quot;Twitter&quot; class=&quot;twitter&quot;&gt;&lt;i class=&quot;fa-brands fa-x-twitter&quot;&gt;&lt;/i&gt;&lt;/a&gt;&lt;/li&gt;\n      &lt;li class=&quot;list-inline-item&quot;&gt;&lt;a href=&quot;#&quot; title=&quot;Linkedin&quot; class=&quot;linkedin&quot;&gt;&lt;i class=&quot;fa-brands fa-linkedin-in&quot;&gt;&lt;/i&gt;&lt;/a&gt;&lt;/li&gt;\n     &lt;/ul&gt;\n  &lt;/div&gt;\n&lt;/div&gt;', '[[regtime]]', '[[regtime]]'),
(10, 10, 1, '0', 0, 'Novator Footer link block main', 'Footer link block main', 'Footer link block main', '&lt;div class=&quot;footer-main-links row&quot;&gt;\n  &lt;div class=&quot;col-md-4&quot;&gt;\n  &lt;h3 class=&quot;h5 text-white text-start&quot;&gt;Product&lt;/h3&gt;\n  &lt;ul class=&quot;list-unstyled footer-link&quot;&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Smart&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Habits&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Tasks&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Calendar Sync&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Buffer Time&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Use Cases&lt;/a&gt;&lt;/li&gt;&lt;/ul&gt;\n  &lt;/div&gt;\n  &lt;div class=&quot;col-md-4&quot;&gt;\n  &lt;h3 class=&quot;h5 text-white text-start&quot;&gt;Product&lt;/h3&gt;\n  &lt;ul class=&quot;list-unstyled footer-link&quot;&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Smart&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Habits&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Tasks&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Calendar Sync&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Buffer Time&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Use Cases&lt;/a&gt;&lt;/li&gt;&lt;/ul&gt;\n  &lt;/div&gt;\n  &lt;div class=&quot;col-md-4&quot;&gt;\n  &lt;h3 class=&quot;h5 text-white text-start&quot;&gt;Product&lt;/h3&gt;\n  &lt;ul class=&quot;list-unstyled footer-link&quot;&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Smart&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Habits&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Tasks&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Calendar Sync&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Buffer Time&lt;/a&gt;&lt;/li&gt;&lt;li&gt;&lt;a href=&quot;#&quot; target=&quot;_blank&quot;&gt;Use Cases&lt;/a&gt;&lt;/li&gt;&lt;/ul&gt;\n  &lt;/div&gt;\n  &lt;/div&gt;', '[[regtime]]', '[[regtime]]'),
(11, 11, 1, 'blocks/html_block_footer.tpl', 0, 'Novator Contact us', 'Contact us', '', '&lt;div class=&quot;contactus-block text-center text-md-start&quot;&gt;\n&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/5.svg&quot; alt=&quot;images&quot; class=&quot;img-fluid h-auto&quot; width=&quot;350&quot; height=&quot;79&quot;&gt;&lt;p class=&quot;text-white&quot;&gt;1487 Rocky Horse Carrefour&lt;br&gt;Arlington, TX 16819&lt;/p&gt;&lt;h4 class=&quot;text-white&quot;&gt;&lt;i class=&quot;bi bi-telephone&quot;&gt;&lt;/i&gt; (444) 019 120 0401&lt;/h4&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-success d-inline-block&quot;&gt;Live Chat&lt;/a&gt; &lt;a href=&quot;#&quot; class=&quot;btn btn-outline-light d-inline-block&quot;&gt;Help Desk&lt;/a&gt;\n&lt;/div&gt;', '[[regtime]]', '[[regtime]]'),
(12, 12, 1, '0', 0, 'Novator Main Page Carousel', 'Novator Main Page Carousel', '', '&lt;section class=&quot;hero-slider-sec top-section&quot;&gt;\n    &lt;div id=&quot;carouselExample&quot; class=&quot;carousel slide carousel-dark&quot;&gt;\n      &lt;div class=&quot;carousel-inner&quot;&gt;\n        &lt;div class=&quot;carousel-item active&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7a/e.png&quot;\n            class=&quot;d-none d-lg-block w-100 h-auto&quot; alt=&quot;images&quot; width=&quot;1920&quot; height=&quot;750&quot;&gt; &lt;img\n            src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7a/f.png&quot; class=&quot;d-block d-lg-none w-100 h-auto&quot; alt=&quot;images&quot; width=&quot;1920&quot;\n            height=&quot;750&quot;&gt;\n          &lt;div class=&quot;carousel-caption d-none d-lg-flex&quot;&gt;\n            &lt;div class=&quot;container&quot;&gt;\n              &lt;div class=&quot;row&quot;&gt;\n                &lt;div class=&quot;col-md-5 text-start&quot;&gt;\n                  &lt;p class=&quot;h5&quot;&gt;Feature rich with smart UI&lt;/p&gt;\n                  &lt;h1 class=&quot;my-4 h2&quot;&gt;&lt;span class=&quot;text-primary&quot;&gt;Easy &amp; Fun&lt;/span&gt; To Manage&lt;/h1&gt;\n                  &lt;p class=&quot;mb-4&quot;&gt;Feature reach shopping cart application right out of the box. Standard features allow\n                    to set up complete eCommerce site with all the tools needed to sell products online.&lt;/p&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-outline-dark&quot;&gt;Install Now&lt;/a&gt;\n                &lt;/div&gt;\n              &lt;/div&gt;\n            &lt;/div&gt;\n          &lt;/div&gt;\n        &lt;/div&gt;\n        &lt;div class=&quot;carousel-item&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/0.png&quot; class=&quot;d-none d-lg-block w-100 h-auto&quot;\n            alt=&quot;images&quot; width=&quot;1920&quot; height=&quot;750&quot;&gt; &lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/1.png&quot;\n            class=&quot;d-block d-lg-none w-100 h-auto&quot; alt=&quot;images&quot; width=&quot;1920&quot; height=&quot;750&quot;&gt;\n          &lt;div class=&quot;carousel-caption d-none d-lg-flex&quot;&gt;\n            &lt;div class=&quot;container&quot;&gt;\n              &lt;div class=&quot;row&quot;&gt;\n                &lt;div class=&quot;col-md-5 text-start&quot;&gt;\n                  &lt;h1 class=&quot;mb-4&quot;&gt;All Screen Size&lt;/h1&gt;\n                  &lt;p class=&quot;mb-4&quot;&gt;Natively responsive template implemented with bootstrap library and HTML5. Will look\n                    good on most mobile devices and tablets.&lt;/p&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-outline-dark&quot;&gt;Try On Your\n                    Device&lt;/a&gt;\n                &lt;/div&gt;\n              &lt;/div&gt;\n            &lt;/div&gt;\n          &lt;/div&gt;\n        &lt;/div&gt;\n        &lt;div class=&quot;carousel-item&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/4.png&quot; class=&quot;d-none d-lg-block w-100 h-auto&quot;\n            alt=&quot;images&quot; width=&quot;1920&quot; height=&quot;750&quot;&gt; &lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/3.png&quot;\n            class=&quot;d-block d-lg-none w-100 h-auto&quot; alt=&quot;images&quot; width=&quot;1920&quot; height=&quot;750&quot;&gt;\n          &lt;div class=&quot;carousel-caption d-none d-lg-flex&quot;&gt;\n            &lt;div class=&quot;container&quot;&gt;\n              &lt;div class=&quot;row&quot;&gt;\n                &lt;div class=&quot;col-md-5 text-start&quot;&gt;\n                  &lt;h1 class=&quot;mb-4 h2 slide-3-title&quot;&gt;SEO Friendly&lt;/h1&gt;\n                  &lt;h1 class=&quot;mb-4 h2 slide-3-title&quot;&gt;Fast Loadnig&lt;/h1&gt;\n                  &lt;p class=&quot;mb-4 text-white&quot;&gt;Natively responsive template implemented with bootstrap library and HTML5.\n                    Will look good on most mobile devices and tablets.&lt;/p&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-outline-light&quot;&gt;Try On\n                    Your Device&lt;/a&gt;\n                &lt;/div&gt;\n              &lt;/div&gt;\n            &lt;/div&gt;\n          &lt;/div&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;&lt;button class=&quot;carousel-control-prev&quot; type=&quot;button&quot; data-bs-target=&quot;#carouselExample&quot;\n        data-bs-slide=&quot;prev&quot;&gt;&lt;span class=&quot;header-arrow rounded-end&quot;&gt;&lt;i class=&quot;bi bi-arrow-left&quot;&gt;&lt;/i&gt;&lt;/span&gt;&lt;/button&gt;\n      &lt;button class=&quot;carousel-control-next&quot; type=&quot;button&quot; data-bs-target=&quot;#carouselExample&quot; data-bs-slide=&quot;next&quot;&gt;&lt;span\n          class=&quot;header-arrow rounded-start&quot;&gt;&lt;i class=&quot;bi bi-arrow-right&quot;&gt;&lt;/i&gt;&lt;/span&gt;&lt;/button&gt;\n    &lt;/div&gt;\n  &lt;/section&gt;', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]block_descriptions` VALUES
(13, 13, 1, '0', 0, 'Novator Icon block', 'Promo', '', '&lt;section&gt;\n  &lt;div class=&quot;container&quot;&gt;\n    &lt;div class=&quot;row g-4&quot;&gt;\n      &lt;div class=&quot;col-sm-6 col-lg-3&quot;&gt;\n        &lt;div class=&quot;icon-block-card rounded-3 p-4&quot;&gt;\n          &lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot; width=&quot;50&quot; height=&quot;49&quot; viewBox=&quot;0 0 50 49&quot;\n            fill=&quot;none&quot;&gt;\n            &lt;g clip-path=&quot;url(#clip0_375_6590)&quot;&gt;\n              &lt;path\n                d=&quot;M46.0698 22.1421L44.8009 17.0665C45.1478 16.9928 45.4081 16.685 45.4081 16.3163V15.4979C45.4081 13.7211 43.9625 12.2756 42.1858 12.2756H36.4061V10.5876C36.4061 9.71322 35.6948 9.00195 34.8205 9.00195H5.35904C4.48469 9.00195 3.77343 9.71322 3.77343 10.5876V24.4999C3.77343 24.9236 4.11691 25.2672 4.54068 25.2672C4.96436 25.2672 5.30793 24.9237 5.30793 24.4999V10.5876C5.30793 10.5593 5.33081 10.5365 5.35904 10.5365H34.8204C34.8486 10.5365 34.8715 10.5593 34.8715 10.5876V24.5001C34.8715 24.9238 35.215 25.2674 35.6387 25.2674C36.0624 25.2674 36.406 24.9239 36.406 24.5001V23.6304H45.4565C45.4573 23.6304 45.4579 23.6306 45.4585 23.6306C45.4593 23.6306 45.46 23.6305 45.4607 23.6305C46.5743 23.6312 47.52 24.3622 47.8448 25.3695H45.4591C45.0354 25.3695 44.6919 25.713 44.6919 26.1367V27.7735C44.6919 29.099 45.7703 30.1774 47.0958 30.1774H47.9654V33.5532H45.9593C45.3003 31.6503 43.4914 30.2796 41.3672 30.2796C39.2431 30.2796 37.4341 31.6503 36.7752 33.5532H36.4058V27.7734C36.4058 27.3497 36.0623 27.0061 35.6385 27.0061C35.2149 27.0061 34.8713 27.3496 34.8713 27.7734V33.553H18.9532C18.2942 31.6501 16.4853 30.2794 14.3612 30.2794C12.237 30.2794 10.428 31.6501 9.76913 33.553H5.35904C5.33081 33.553 5.30793 33.5301 5.30793 33.5019V31.8139H8.63256C9.05624 31.8139 9.39982 31.4705 9.39982 31.0467C9.39982 30.6229 9.05634 30.2794 8.63256 30.2794H1.26725C0.843574 30.2794 0.5 30.6229 0.5 31.0467C0.5 31.4705 0.843478 31.8139 1.26725 31.8139H3.77352V33.5019C3.77352 34.3762 4.48479 35.0875 5.35913 35.0875H9.50346C9.50327 35.1045 9.50212 35.1214 9.50212 35.1386C9.50212 37.8179 11.682 39.9976 14.3612 39.9976C17.0404 39.9976 19.2202 37.8179 19.2202 35.1386C19.2202 35.1213 19.219 35.1045 19.2189 35.0875H36.5095C36.5093 35.1045 36.5082 35.1214 36.5082 35.1386C36.5082 37.8179 38.688 39.9976 41.3672 39.9976C44.0464 39.9976 46.2263 37.8179 46.2263 35.1386C46.2263 35.1213 46.2251 35.1045 46.2249 35.0875H48.7326C49.1563 35.0875 49.4999 34.744 49.4999 34.3202V26.1365C49.5 24.1161 48.0092 22.4373 46.0698 22.1421ZM36.4061 13.81H42.1858C43.1165 13.81 43.8737 14.5672 43.8737 15.4979V15.549H36.4061V13.81ZM36.4061 22.096V17.0834H43.2235L44.4766 22.096H36.4061ZM14.3612 38.4634C12.528 38.4634 11.0365 36.9721 11.0365 35.1388C11.0365 33.3055 12.528 31.8141 14.3612 31.8141C16.1944 31.8141 17.6858 33.3055 17.6858 35.1388C17.6858 36.9721 16.1944 38.4634 14.3612 38.4634ZM41.3674 38.4634C39.5342 38.4634 38.0428 36.9721 38.0428 35.1388C38.0428 33.3055 39.5342 31.8141 41.3674 31.8141C43.2006 31.8141 44.6921 33.3055 44.6921 35.1388C44.6921 36.9721 43.2006 38.4634 41.3674 38.4634ZM47.9656 28.6429H47.096C46.6166 28.6429 46.2265 28.2528 46.2265 27.7734V26.9038H47.9655V28.6429H47.9656Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M14.363 33.5532C13.4886 33.5532 12.7773 34.2645 12.7773 35.1388C12.7773 36.0132 13.4886 36.7244 14.363 36.7244C15.2373 36.7244 15.9486 36.0132 15.9486 35.1388C15.9486 34.2645 15.2373 33.5532 14.363 33.5532Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M41.3669 33.5532C40.4925 33.5532 39.7812 34.2645 39.7812 35.1388C39.7812 36.0132 40.4925 36.7244 41.3669 36.7244C42.2412 36.7244 42.9525 36.0132 42.9525 35.1388C42.9525 34.2645 42.2412 33.5532 41.3669 33.5532Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M32.3651 30.2798H20.9079C20.4842 30.2798 20.1406 30.6233 20.1406 31.047C20.1406 31.4708 20.4841 31.8143 20.9079 31.8143H32.3651C32.7887 31.8143 33.1323 31.4708 33.1323 31.047C33.1323 30.6233 32.7888 30.2798 32.3651 30.2798Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M12.7245 27.0063H2.90397C2.48029 27.0063 2.13672 27.3498 2.13672 27.7736C2.13672 28.1974 2.4802 28.5409 2.90397 28.5409H12.7245C13.1481 28.5409 13.4917 28.1974 13.4917 27.7736C13.4917 27.3498 13.1481 27.0063 12.7245 27.0063Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M27.181 16.5918C26.8814 16.2923 26.3955 16.2923 26.096 16.5919L19.2731 23.4147L15.7238 19.8654C15.4241 19.5657 14.9383 19.5657 14.6388 19.8654C14.3392 20.165 14.3392 20.6507 14.6388 20.9504L18.7307 25.0422C18.8805 25.1921 19.0768 25.2669 19.2731 25.2669C19.4694 25.2669 19.6659 25.1921 19.8156 25.0422L27.1809 17.6769C27.4805 17.3772 27.4805 16.8915 27.181 16.5918Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n            &lt;/g&gt;\n            &lt;defs&gt;\n              &lt;clipPath id=&quot;clip0_375_6590&quot;&gt;\n                &lt;rect width=&quot;49&quot; height=&quot;49&quot; fill=&quot;white&quot; transform=&quot;translate(0.5)&quot; /&gt;\n              &lt;/clipPath&gt;\n            &lt;/defs&gt;\n          &lt;/svg&gt;\n          &lt;h2 class=&quot;feature-title mt-4 mb-3 d-block&quot;&gt;Free Shipping&lt;/h2&gt;\n          &lt;p class=&quot;mb-0&quot;&gt;A commerce solution for growing digital brands&lt;/p&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n      &lt;div class=&quot;col-sm-6 col-lg-3&quot;&gt;\n        &lt;div class=&quot;icon-block-card rounded-3 p-4&quot;&gt;&lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot; width=&quot;50&quot; height=&quot;49&quot; viewBox=&quot;0 0 50 49&quot;\n            fill=&quot;none&quot;&gt;\n            &lt;g clip-path=&quot;url(#clip0_375_6613)&quot;&gt;\n              &lt;path\n                d=&quot;M38.3789 8.12346C38.4002 8.12501 38.4215 8.12656 38.4432 8.12656C38.48 8.12656 38.5169 8.12346 38.5529 8.11842C39.5177 8.13819 40.2899 8.92509 40.2911 9.88991C40.2911 10.3283 40.6465 10.6838 41.0849 10.6838C41.5234 10.6838 41.8788 10.3283 41.8788 9.88991C41.8769 8.31185 40.7783 6.9466 39.2371 6.60703V5.84417C39.2371 5.40575 38.8816 5.05029 38.4432 5.05029C38.0048 5.05029 37.6493 5.40575 37.6493 5.84417V6.64308C36.0197 7.07879 34.9654 8.6553 35.1851 10.3279C35.4049 12.0006 36.8307 13.2511 38.5176 13.2511C39.4972 13.2511 40.2911 14.0454 40.2911 15.0249C40.2911 16.0041 39.4972 16.7983 38.5176 16.7983C37.5381 16.7983 36.7442 16.0041 36.7442 15.0249C36.7442 14.5865 36.3888 14.231 35.9503 14.231C35.5119 14.231 35.1565 14.5865 35.1565 15.0249C35.1584 16.546 36.1802 17.8767 37.6493 18.2717V19.1416C37.6493 19.58 38.0048 19.9355 38.4432 19.9355C38.8816 19.9355 39.2371 19.58 39.2371 19.1416V18.3082C40.9136 17.9411 42.0443 16.3696 41.8594 14.6632C41.6749 12.9569 40.2341 11.6637 38.5176 11.6641C37.5652 11.6645 36.7826 10.9125 36.745 9.96085C36.7078 9.00921 37.4292 8.19789 38.3789 8.12385V8.12346Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M38.5617 1.16895C33.6779 1.16895 29.51 4.35569 27.9486 8.62277H8.24477C7.80829 8.62277 7.454 9.01622 7.45089 9.45231L7.26328 37.3015H1.64684C1.20842 37.3015 0.832031 37.619 0.832031 38.0582V41.5923C0.84211 44.9193 3.46252 47.6526 6.7861 47.803V47.8204H31.297V47.7971C31.4955 47.8045 31.5773 47.8204 31.7029 47.8204H31.7199C35.1598 47.815 37.9457 45.0248 37.9457 41.5849V23.7165C38.1442 23.7274 38.3543 23.7332 38.5597 23.7332C44.7747 23.7332 49.8322 18.666 49.8322 12.4507C49.8322 6.23572 44.777 1.16895 38.5617 1.16895ZM7.08807 46.2327H7.08303C4.51495 46.2292 2.43141 44.1526 2.41978 41.5841V38.8893H25.4422V41.5729C25.4433 43.2296 26.105 44.8178 27.2803 45.9857C27.3637 46.0691 27.4672 46.1334 27.5544 46.2327H7.08807ZM36.358 41.5841C36.3584 44.148 34.2826 46.2276 31.7192 46.2327H31.704C29.1301 46.228 27.0427 44.1472 27.0299 41.5737V38.0582C27.0365 37.8551 26.959 37.6586 26.8152 37.5151C26.6714 37.3717 26.4748 37.2946 26.2721 37.3015H8.85103L9.03322 10.2105H27.5079C27.3672 10.9373 27.2943 11.6754 27.2904 12.4154C27.2889 13.9803 27.6153 15.5277 28.2487 16.9585H20.7503C20.3115 16.9585 19.9564 17.3139 19.9564 17.7523C19.9564 18.1908 20.3115 18.5462 20.7503 18.5462H29.11C30.7477 21.1217 33.3658 22.9172 36.358 23.518V41.5841ZM38.5617 22.1458C33.2139 22.1458 28.8782 17.8105 28.8786 12.4623C28.8786 7.1141 33.2139 2.77879 38.5621 2.77879C43.9099 2.77879 48.2452 7.11449 48.2452 12.4623C48.2394 17.8078 43.9076 22.14 38.5617 22.1458Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M15.6542 22.2422C14.2529 22.2422 13.1133 23.3458 13.1133 24.7025C13.1133 26.0592 14.2529 27.1628 15.6542 27.1628C17.0555 27.1628 18.1956 26.0592 18.1956 24.7025C18.1956 23.3458 17.0555 22.2422 15.6542 22.2422ZM15.6542 25.5751C15.1282 25.5751 14.701 25.1836 14.701 24.7025C14.701 24.2211 15.1286 23.8299 15.6542 23.8299C16.1799 23.8299 16.6078 24.2215 16.6078 24.7025C16.6078 25.1836 16.1799 25.5751 15.6542 25.5751Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M19.957 24.6987C19.957 25.1371 20.3121 25.4925 20.7509 25.4925H31.3349C31.7733 25.4925 32.1288 25.1371 32.1288 24.6987C32.1288 24.2602 31.7733 23.9048 31.3349 23.9048H20.7509C20.3121 23.9048 19.957 24.2602 19.957 24.6987Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M15.6542 15.3408C14.2529 15.3408 13.1133 16.4448 13.1133 17.8015C13.1133 19.1582 14.2529 20.2618 15.6542 20.2618C17.0555 20.2618 18.1956 19.1582 18.1956 17.8015C18.1956 16.4448 17.0555 15.3408 15.6542 15.3408ZM15.6542 18.6741C15.1282 18.6741 14.701 18.2826 14.701 17.8015C14.701 17.3205 15.1286 16.9286 15.6542 16.9286C16.1799 16.9286 16.6078 17.3201 16.6078 17.8015C16.6078 18.2826 16.1799 18.6745 15.6542 18.6745V18.6741Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M15.6542 29.1421C14.2529 29.1421 13.1133 30.2457 13.1133 31.6024C13.1133 32.9591 14.2529 34.0627 15.6542 34.0627C17.0555 34.0627 18.1956 32.9591 18.1956 31.6024C18.1956 30.2457 17.0555 29.1421 15.6542 29.1421ZM15.6542 32.475C15.1282 32.475 14.701 32.0838 14.701 31.6024C14.701 31.1214 15.1286 30.7298 15.6542 30.7298C16.1799 30.7298 16.6078 31.1214 16.6078 31.6024C16.6078 32.0835 16.1799 32.475 15.6542 32.475Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M31.3349 30.8516H20.7509C20.3121 30.8516 19.957 31.207 19.957 31.6454C19.957 32.0839 20.3121 32.4393 20.7509 32.4393H31.3349C31.7733 32.4393 32.1288 32.0839 32.1288 31.6454C32.1288 31.207 31.7733 30.8516 31.3349 30.8516Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n            &lt;/g&gt;\n            &lt;defs&gt;\n              &lt;clipPath id=&quot;clip0_375_6613&quot;&gt;\n                &lt;rect width=&quot;49&quot; height=&quot;49&quot; fill=&quot;white&quot; transform=&quot;translate(0.832031)&quot; /&gt;\n              &lt;/clipPath&gt;\n            &lt;/defs&gt;\n          &lt;/svg&gt;\n          &lt;h2 class=&quot;feature-title mt-4 mb-3 d-block&quot;&gt;Free Shipping&lt;/h2&gt;\n          &lt;p class=&quot;mb-0&quot;&gt;A commerce solution for growing digital brands&lt;/p&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n      &lt;div class=&quot;col-sm-6 col-lg-3&quot;&gt;\n        &lt;div class=&quot;icon-block-card rounded-3 p-4&quot;&gt;&lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot; width=&quot;50&quot; height=&quot;49&quot; viewBox=&quot;0 0 50 49&quot;\n            fill=&quot;none&quot;&gt;\n            &lt;path\n              d=&quot;M2.39507 24.5033C2.39447 20.3202 3.57194 16.2215 5.79264 12.6764C8.01334 9.13141 11.1875 6.28344 14.9516 4.45865C18.7158 2.63385 22.9178 1.906 27.0764 2.35844C31.235 2.81088 35.1821 4.42531 38.4658 7.01688H35.0773C34.7838 7.01972 34.5032 7.13832 34.2967 7.34688C34.0901 7.55545 33.9742 7.83712 33.9742 8.13066C33.9742 8.42419 34.0901 8.70586 34.2967 8.91443C34.5032 9.12299 34.7838 9.24159 35.0773 9.24443H41.3778C41.6732 9.24443 41.9565 9.12708 42.1654 8.9182C42.3742 8.70932 42.4916 8.42601 42.4916 8.1306V1.82992C42.493 1.68275 42.4653 1.53675 42.4099 1.40037C42.3546 1.26399 42.2728 1.13993 42.1692 1.03536C42.0656 0.930787 41.9424 0.847776 41.8065 0.791125C41.6707 0.734474 41.525 0.705305 41.3778 0.705305C41.2306 0.705305 41.0849 0.734474 40.9491 0.791125C40.8132 0.847776 40.69 0.930787 40.5864 1.03536C40.4829 1.13993 40.401 1.26399 40.3457 1.40037C40.2904 1.53675 40.2626 1.68275 40.264 1.82992V5.60149C35.4074 1.59511 29.195 -0.388149 22.9153 0.0630496C16.6356 0.514248 10.7705 3.36528 6.53652 8.02483C2.30253 12.6844 0.0245208 18.7949 0.174974 25.089C0.325427 31.383 2.8928 37.3777 7.34459 41.8296C7.44757 41.935 7.57043 42.0189 7.70605 42.0765C7.84168 42.134 7.98738 42.1641 8.13472 42.165C8.28205 42.1658 8.42809 42.1374 8.56437 42.0814C8.70065 42.0254 8.82447 41.943 8.92866 41.8388C9.03284 41.7346 9.11531 41.6108 9.1713 41.4745C9.22729 41.3382 9.25569 41.1922 9.25484 41.0448C9.25399 40.8975 9.22392 40.7518 9.16636 40.6162C9.1088 40.4805 9.0249 40.3577 8.91953 40.2547C6.84455 38.191 5.19949 35.7363 4.07957 33.0325C2.95965 30.3288 2.3871 27.4298 2.39507 24.5033Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M14.9353 44.5466C14.3034 44.2393 13.678 43.8973 13.0768 43.5308C12.8247 43.3769 12.5218 43.3295 12.2347 43.3989C11.9476 43.4683 11.6998 43.649 11.5459 43.9011C11.392 44.1532 11.3446 44.4561 11.414 44.7432C11.4835 45.0303 11.6641 45.278 11.9162 45.4319C12.5781 45.836 13.2665 46.2118 13.9621 46.55C14.0936 46.6139 14.2365 46.6513 14.3825 46.66C14.5284 46.6687 14.6747 46.6486 14.8129 46.6008C14.9511 46.5529 15.0786 46.4784 15.188 46.3813C15.2974 46.2842 15.3866 46.1666 15.4505 46.035C15.5144 45.9035 15.5518 45.7606 15.5605 45.6146C15.5692 45.4687 15.5491 45.3224 15.5013 45.1842C15.4534 45.046 15.3789 44.9185 15.2818 44.8091C15.1847 44.6997 15.0671 44.6105 14.9355 44.5466H14.9353Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M44.7226 14.7893C44.7863 14.921 44.8754 15.0387 44.9847 15.136C45.0939 15.2332 45.2213 15.3079 45.3594 15.3559C45.4976 15.4039 45.6439 15.4242 45.7899 15.4157C45.9359 15.4071 46.0788 15.3699 46.2104 15.3062C46.3421 15.2424 46.4598 15.1534 46.5571 15.0441C46.6543 14.9348 46.729 14.8074 46.777 14.6693C46.825 14.5311 46.8453 14.3849 46.8368 14.2388C46.8282 14.0928 46.791 13.9499 46.7273 13.8183C46.3917 13.1249 46.0165 12.4365 45.6125 11.7718C45.5364 11.6468 45.4365 11.5381 45.3185 11.4517C45.2004 11.3653 45.0665 11.3031 44.9244 11.2685C44.6373 11.1985 44.3343 11.2455 44.0819 11.3991C43.8295 11.5526 43.6484 11.8001 43.5785 12.0872C43.5086 12.3742 43.5556 12.6773 43.7091 12.9296C44.0765 13.5339 44.4175 14.1596 44.7226 14.7893Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M27.3149 46.6232C26.6117 46.7067 25.9004 46.7564 25.2 46.7733C24.91 46.7844 24.6357 46.9083 24.4357 47.1186C24.2357 47.3289 24.1256 47.6089 24.129 47.8991C24.1324 48.1893 24.2489 48.4668 24.4538 48.6723C24.6586 48.8779 24.9357 48.9954 25.2259 48.9997C25.2345 48.9997 25.2438 48.9997 25.2525 48.9992C26.0225 48.9812 26.804 48.9261 27.5762 48.8349C27.8693 48.8 28.1365 48.6502 28.3192 48.4183C28.5019 48.1865 28.5851 47.8916 28.5505 47.5985C28.5159 47.3054 28.3664 47.0379 28.1348 46.855C27.9031 46.672 27.6083 46.5885 27.3152 46.6228L27.3149 46.6232Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M20.9759 46.4721C20.2831 46.3563 19.5864 46.2056 18.9056 46.0231C18.6201 45.9468 18.3161 45.9871 18.0603 46.135C17.8045 46.2828 17.618 46.5263 17.5417 46.8117C17.4654 47.0971 17.5056 47.4012 17.6535 47.657C17.8014 47.9127 18.0448 48.0993 18.3303 48.1756C19.0796 48.3757 19.8464 48.5416 20.6094 48.6688C20.7536 48.6929 20.9012 48.6883 21.0437 48.6553C21.1862 48.6224 21.3208 48.5616 21.4398 48.4767C21.5588 48.3917 21.66 48.2841 21.7374 48.16C21.8148 48.0359 21.8671 47.8978 21.8911 47.7536C21.9152 47.6093 21.9106 47.4617 21.8776 47.3192C21.8447 47.1767 21.7839 47.0421 21.699 46.9231C21.614 46.8041 21.5064 46.703 21.3823 46.6255C21.2582 46.5481 21.1201 46.4959 20.9759 46.4718V46.4721Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M48.0789 23.9666C47.7837 23.9595 47.4976 24.0698 47.2837 24.2734C47.0698 24.477 46.9454 24.7573 46.938 25.0525C46.9201 25.7568 46.869 26.468 46.7852 27.1674C46.7503 27.4607 46.8332 27.7559 47.0159 27.9881C47.1985 28.2203 47.4658 28.3704 47.7591 28.4056C47.8035 28.4106 47.8482 28.4131 47.8929 28.4132C48.1651 28.4128 48.4277 28.3128 48.6312 28.1319C48.8347 27.9511 48.9649 27.7021 48.9973 27.4318C49.0887 26.6634 49.1453 25.8819 49.1644 25.1081C49.1681 24.9618 49.143 24.8163 49.0904 24.6798C49.0379 24.5433 48.959 24.4184 48.8582 24.3124C48.7574 24.2064 48.6367 24.1213 48.503 24.062C48.3692 24.0027 48.2252 23.9703 48.0789 23.9666Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M44.6596 36.7062C44.4152 36.5405 44.115 36.4786 43.825 36.5339C43.5349 36.5893 43.2787 36.7574 43.1124 37.0015C42.7165 37.5839 42.2885 38.1544 41.8393 38.6965C41.7438 38.8089 41.6716 38.939 41.6268 39.0795C41.582 39.22 41.5656 39.368 41.5785 39.5148C41.5913 39.6617 41.6332 39.8046 41.7018 39.9351C41.7703 40.0657 41.864 40.1813 41.9776 40.2754C42.0912 40.3694 42.2223 40.4399 42.3633 40.4829C42.5044 40.5258 42.6526 40.5403 42.7993 40.5255C42.946 40.5108 43.0883 40.467 43.2179 40.3968C43.3476 40.3266 43.462 40.2313 43.5545 40.1165C44.0483 39.5205 44.5198 38.8934 44.9548 38.2529C45.037 38.1319 45.0945 37.996 45.1242 37.8528C45.1538 37.7096 45.1549 37.562 45.1275 37.4184C45.1001 37.2748 45.0447 37.138 44.9644 37.0158C44.8841 36.8936 44.7806 36.7884 44.6596 36.7062Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M46.1975 18.7573C46.378 19.4354 46.5281 20.1321 46.6439 20.8281C46.6871 21.0881 46.821 21.3244 47.0219 21.4949C47.2229 21.6655 47.4777 21.7593 47.7413 21.7597C47.8027 21.7595 47.864 21.7544 47.9245 21.7444C48.0689 21.7205 48.207 21.6684 48.3312 21.591C48.4554 21.5137 48.5631 21.4126 48.6481 21.2936C48.7332 21.1747 48.7941 21.0401 48.8271 20.8976C48.8602 20.7551 48.8649 20.6075 48.8409 20.4632C48.7141 19.6975 48.5485 18.9304 48.3501 18.1841C48.2741 17.8986 48.0878 17.6551 47.8322 17.507C47.5767 17.3589 47.2727 17.3184 46.9873 17.3944C46.7019 17.4705 46.4583 17.6567 46.3102 17.9123C46.1621 18.1679 46.1217 18.4719 46.1977 18.7573H46.1975Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M38.8439 41.6894C38.2995 42.1397 37.7291 42.5676 37.1489 42.9608C37.0278 43.0429 36.9241 43.148 36.8437 43.2701C36.7633 43.3922 36.7077 43.529 36.6801 43.6726C36.6526 43.8163 36.6535 43.9639 36.683 44.1071C36.7125 44.2504 36.7699 44.3864 36.852 44.5074C36.934 44.6285 37.0391 44.7322 37.1613 44.8126C37.2834 44.893 37.4202 44.9486 37.5638 44.9762C37.7074 45.0038 37.8551 45.0028 37.9983 44.9733C38.1415 44.9438 38.2775 44.8864 38.3986 44.8043C39.0371 44.372 39.6641 43.9016 40.2633 43.4068C40.491 43.2186 40.6347 42.9476 40.6626 42.6534C40.6906 42.3593 40.6005 42.0661 40.4123 41.8384C40.2241 41.6107 39.9531 41.467 39.659 41.4391C39.3648 41.4111 39.0716 41.5012 38.8439 41.6894Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M47.2844 30.5821C47.003 30.4927 46.6977 30.5186 46.4354 30.6541C46.1731 30.7896 45.9752 31.0236 45.8853 31.3048C45.6721 31.9731 45.4231 32.6405 45.1451 33.2892C45.0844 33.4241 45.0511 33.5697 45.0473 33.7176C45.0434 33.8654 45.0691 34.0126 45.1227 34.1504C45.1764 34.2883 45.257 34.4141 45.3598 34.5204C45.4626 34.6268 45.5856 34.7116 45.7215 34.7699C45.8575 34.8282 46.0037 34.8588 46.1516 34.86C46.2995 34.8612 46.4462 34.8329 46.583 34.7767C46.7199 34.7206 46.8442 34.6377 46.9487 34.533C47.0532 34.4283 47.1357 34.3038 47.1916 34.1669C47.4984 33.4528 47.7724 32.7171 48.0067 31.9813C48.0513 31.842 48.0679 31.6953 48.0557 31.5496C48.0435 31.4038 48.0026 31.2619 47.9356 31.132C47.8685 31.0021 47.7764 30.8866 47.6647 30.7922C47.553 30.6979 47.4238 30.6265 47.2844 30.5821Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M33.436 44.9884C32.7938 45.2635 32.126 45.5121 31.4511 45.7274C31.3118 45.7718 31.1826 45.8433 31.0709 45.9376C30.9591 46.032 30.8671 46.1474 30.8 46.2773C30.7329 46.4073 30.692 46.5491 30.6797 46.6949C30.6674 46.8406 30.684 46.9873 30.7284 47.1266C30.7728 47.266 30.8442 47.3952 30.9386 47.5069C31.033 47.6186 31.1484 47.7107 31.2783 47.7778C31.4083 47.8449 31.5501 47.8858 31.6959 47.8981C31.8416 47.9103 31.9883 47.8938 32.1276 47.8494C32.8699 47.6128 33.6052 47.3393 34.3127 47.0364C34.5842 46.9201 34.7985 46.7007 34.9083 46.4264C35.0181 46.1521 35.0145 45.8455 34.8981 45.5739C34.7818 45.3023 34.5624 45.088 34.2881 44.9782C34.0138 44.8684 33.7072 44.8721 33.4356 44.9884H33.436Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M15.2525 22.2278C15.2525 20.4024 14.0522 18.9398 12.1946 18.5013C11.1742 18.2596 10.1019 18.3709 9.1528 18.8172C8.20375 19.2634 7.43397 20.0182 6.96913 20.9582C6.83897 21.2222 6.81859 21.527 6.91244 21.806C7.00629 22.085 7.20675 22.3154 7.47001 22.4471C7.73327 22.5787 8.03793 22.6008 8.31742 22.5085C8.59692 22.4162 8.82852 22.2171 8.96163 21.9545C9.19941 21.4611 9.5994 21.0642 10.0947 20.8302C10.59 20.5962 11.1506 20.5394 11.6828 20.6692C11.9977 20.7435 13.0249 21.0757 13.0249 22.2278C13.0249 23.3894 11.6833 24.2853 10.2629 25.234C8.66353 26.3015 6.85156 27.5115 6.85156 29.5149C6.85156 29.8103 6.96891 30.0936 7.17778 30.3025C7.38665 30.5113 7.66994 30.6287 7.96533 30.6287H14.1387C14.2859 30.6301 14.4318 30.6024 14.5682 30.547C14.7046 30.4917 14.8286 30.4099 14.9332 30.3063C15.0378 30.2028 15.1208 30.0795 15.1774 29.9437C15.2341 29.8078 15.2632 29.6621 15.2632 29.515C15.2632 29.3678 15.2341 29.2221 15.1774 29.0863C15.1208 28.9504 15.0378 28.8272 14.9332 28.7236C14.8286 28.6201 14.7046 28.5382 14.5682 28.4829C14.4318 28.4276 14.2859 28.3998 14.1387 28.4013H9.72624C10.1929 27.9592 10.8524 27.5187 11.4996 27.0863C13.259 25.9117 15.2525 24.5804 15.2525 22.2278Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M25.7825 25.895C25.7825 25.5997 25.6652 25.3164 25.4563 25.1076C25.2474 24.8987 24.9641 24.7814 24.6688 24.7814H23.7638V18.8647C23.7638 18.634 23.6921 18.409 23.5588 18.2208C23.4254 18.0326 23.2369 17.8905 23.0193 17.814C22.8017 17.7375 22.5657 17.7305 22.3439 17.7938C22.1221 17.8572 21.9255 17.9879 21.7811 18.1678L16.1429 25.1985C16.0117 25.3623 15.9295 25.5598 15.9056 25.7683C15.8818 25.9768 15.9173 26.1877 16.0082 26.3769C16.099 26.5661 16.2414 26.7258 16.4189 26.8376C16.5965 26.9493 16.8021 27.0087 17.0119 27.0088H21.5364V30.1412C21.535 30.2883 21.5627 30.4343 21.6181 30.5707C21.6734 30.7071 21.7552 30.8311 21.8588 30.9357C21.9623 31.0402 22.0856 31.1233 22.2214 31.1799C22.3572 31.2366 22.5029 31.2657 22.6501 31.2657C22.7973 31.2657 22.943 31.2366 23.0788 31.1799C23.2147 31.1233 23.3379 31.0402 23.4415 30.9357C23.545 30.8311 23.6268 30.7071 23.6822 30.5707C23.7375 30.4343 23.7653 30.2883 23.7638 30.1412V27.0088H24.6688C24.9642 27.0088 25.2474 26.8915 25.4563 26.6826C25.6652 26.4737 25.7825 26.1904 25.7825 25.895ZM21.5364 24.7814H19.3333L21.5364 22.0335V24.7814Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M31.4866 17.1465C31.3431 17.1176 31.1954 17.1172 31.0518 17.1454C30.9082 17.1737 30.7716 17.23 30.6499 17.3112C30.5281 17.3923 30.4235 17.4967 30.3422 17.6184C30.2609 17.7401 30.2044 17.8766 30.176 18.0202L27.6701 30.5496C27.6121 30.8392 27.6716 31.14 27.8354 31.3858C27.9992 31.6316 28.2539 31.8022 28.5435 31.8602C28.6157 31.8746 28.6892 31.8819 28.7628 31.8819C29.02 31.8816 29.2692 31.7923 29.4681 31.6292C29.6669 31.466 29.8032 31.239 29.8537 30.9868L32.3596 18.4573C32.3884 18.3139 32.3886 18.1663 32.3603 18.0228C32.332 17.8793 32.2757 17.7428 32.1947 17.621C32.1136 17.4993 32.0093 17.3948 31.8878 17.3133C31.7663 17.2319 31.63 17.1752 31.4866 17.1465Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n            &lt;path\n              d=&quot;M37.2009 30.6296C37.4209 30.6294 37.6359 30.5642 37.8189 30.4422C38.0018 30.3202 38.1446 30.1468 38.2293 29.9438L42.4058 19.9202C42.4764 19.751 42.5041 19.5669 42.4865 19.3844C42.4689 19.2018 42.4065 19.0265 42.3048 18.8739C42.2031 18.7213 42.0653 18.5962 41.9036 18.5097C41.7419 18.4231 41.5613 18.3779 41.378 18.3779H35.7397C35.4462 18.3808 35.1657 18.4994 34.9591 18.7079C34.7526 18.9165 34.6367 19.1981 34.6367 19.4916C34.6367 19.7852 34.7526 20.0668 34.9591 20.2754C35.1657 20.4839 35.4462 20.6025 35.7397 20.6054H39.7074L36.1736 29.0872C36.1034 29.2564 36.0759 29.4404 36.0936 29.6228C36.1113 29.8052 36.1737 29.9804 36.2753 30.1329C36.3769 30.2854 36.5145 30.4106 36.6759 30.4973C36.8374 30.584 37.0177 30.6296 37.2009 30.63V30.6296Z&quot;\n              fill=&quot;currentcolor&quot; /&gt;\n          &lt;/svg&gt;\n          &lt;h2 class=&quot;feature-title mt-4 mb-3 d-block&quot;&gt;Free Shipping&lt;/h2&gt;\n          &lt;p class=&quot;mb-0&quot;&gt;A commerce solution for growing digital brands&lt;/p&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n      &lt;div class=&quot;col-sm-6 col-lg-3&quot;&gt;\n        &lt;div class=&quot;icon-block-card rounded-3 p-4&quot;&gt;&lt;svg xmlns=&quot;http://www.w3.org/2000/svg&quot; width=&quot;50&quot; height=&quot;49&quot; viewBox=&quot;0 0 50 49&quot;\n            fill=&quot;none&quot;&gt;\n            &lt;g clip-path=&quot;url(#clip0_375_6645)&quot;&gt;\n              &lt;path\n                d=&quot;M46.2339 21.2334C45.5117 21.2361 44.8109 21.478 44.2408 21.9212C43.6708 22.3645 43.2637 22.9842 43.0832 23.6834H38.0672V17.15C38.0649 16.5766 37.8594 16.0225 37.4874 15.5861C37.4784 15.5739 37.4686 15.5632 37.4588 15.5518C37.0654 15.0998 36.5189 14.809 35.9243 14.7351L38.3636 12.2958C39.0474 12.6985 39.8546 12.8381 40.6339 12.6884C41.4132 12.5386 42.1112 12.1098 42.597 11.4824C43.0829 10.8549 43.3232 10.0718 43.273 9.2798C43.2229 8.48782 42.8856 7.74131 42.3245 7.18016C41.7025 6.58572 40.8753 6.25398 40.0149 6.25398C39.1546 6.25398 38.3274 6.58572 37.7054 7.18016C37.1915 7.68969 36.8633 8.35681 36.7733 9.07486C36.6833 9.7929 36.8367 10.5204 37.2089 11.141L33.6458 14.7H25.8172V6.4174C26.587 6.21862 27.2579 5.74591 27.7042 5.08786C28.1504 4.4298 28.3413 3.63159 28.2412 2.84285C28.141 2.0541 27.7566 1.32896 27.16 0.803366C26.5634 0.277769 25.7956 -0.012207 25.0005 -0.012207C24.2054 -0.012207 23.4376 0.277769 22.8411 0.803366C22.2445 1.32896 21.8601 2.0541 21.7599 2.84285C21.6597 3.63159 21.8506 4.4298 22.2969 5.08786C22.7431 5.74591 23.414 6.21862 24.1839 6.4174V14.7H16.3553L12.7922 11.1369C13.1644 10.5163 13.3177 9.78882 13.2277 9.07077C13.1377 8.35273 12.8095 7.68561 12.2956 7.17608C11.6737 6.58163 10.8465 6.24989 9.9861 6.24989C9.12575 6.24989 8.29853 6.58163 7.67657 7.17608C7.11005 7.73579 6.76812 8.48358 6.71536 9.27821C6.6626 10.0728 6.90267 10.8593 7.39022 11.489C7.87777 12.1186 8.57904 12.548 9.36156 12.6959C10.1441 12.8438 10.9537 12.7 11.6374 12.2917L14.0768 14.7311C13.4821 14.8049 12.9357 15.0957 12.5423 15.5477C12.5325 15.5592 12.5227 15.5698 12.5137 15.582C12.1406 16.0194 11.9351 16.5751 11.9339 17.15V23.6834H6.91788C6.71911 22.9135 6.2464 22.2426 5.58835 21.7964C4.93029 21.3501 4.13208 21.1592 3.34333 21.2594C2.55459 21.3596 1.82945 21.744 1.30385 22.3406C0.778257 22.9372 0.488281 23.7049 0.488281 24.5C0.488281 25.2951 0.778257 26.0629 1.30385 26.6595C1.82945 27.2561 2.55459 27.6405 3.34333 27.7407C4.13208 27.8408 4.93029 27.6499 5.58835 27.2037C6.2464 26.7575 6.71911 26.0865 6.91788 25.3167H11.9339V31.85C11.9357 32.4449 12.1543 33.0187 12.5487 33.464C12.9432 33.9093 13.4865 34.1955 14.0768 34.269L11.6268 36.719C11.0022 36.3665 10.281 36.2239 9.56925 36.3121C8.85752 36.4003 8.19292 36.7147 7.6733 37.209C7.23571 37.6403 6.9282 38.1859 6.78586 38.7835C6.64352 39.3812 6.67209 40.0068 6.86831 40.5891C7.06453 41.1713 7.42049 41.6866 7.89557 42.0761C8.37064 42.4657 8.94568 42.7139 9.55504 42.7923C10.1644 42.8707 10.7835 42.7762 11.3417 42.5196C11.9 42.2629 12.3748 41.8545 12.712 41.341C13.0492 40.8274 13.2352 40.2294 13.2488 39.6151C13.2624 39.0009 13.1031 38.3952 12.7889 37.8672L16.3553 34.3H24.1839V42.5827C23.414 42.7814 22.7431 43.2542 22.2969 43.9122C21.8506 44.5703 21.6597 45.3685 21.7599 46.1572C21.8601 46.946 22.2445 47.6711 22.8411 48.1967C23.4376 48.7223 24.2054 49.0123 25.0005 49.0123C25.7956 49.0123 26.5634 48.7223 27.16 48.1967C27.7566 47.6711 28.141 46.946 28.2412 46.1572C28.3413 45.3685 28.1504 44.5703 27.7042 43.9122C27.2579 43.2542 26.587 42.7814 25.8172 42.5827V34.3H33.6458L37.2089 37.8631C36.9006 38.389 36.7458 38.9907 36.7623 39.6C36.7787 40.2093 36.9656 40.8018 37.3018 41.3103C37.638 41.8187 38.11 42.2227 38.6642 42.4765C39.2184 42.7302 39.8327 42.8234 40.4373 42.7456C41.0418 42.6679 41.6125 42.4221 42.0844 42.0364C42.5564 41.6506 42.9107 41.1403 43.1072 40.5633C43.3038 39.9863 43.3346 39.3658 43.1962 38.7721C43.0579 38.1785 42.7559 37.6356 42.3245 37.2049C41.8049 36.7106 41.1403 36.3962 40.4285 36.308C39.7168 36.2198 38.9956 36.3624 38.371 36.7149L35.921 34.2649C36.5112 34.1922 37.0547 33.9069 37.4497 33.4624C37.8448 33.0179 38.0643 32.4447 38.0672 31.85V25.3167H43.0832C43.2369 25.9068 43.5531 26.4419 43.9958 26.8614C44.4384 27.2808 44.9898 27.5677 45.5873 27.6895C46.1848 27.8113 46.8045 27.7632 47.376 27.5505C47.9475 27.3378 48.4479 26.9692 48.8205 26.4864C49.193 26.0036 49.4227 25.426 49.4834 24.8193C49.5442 24.2125 49.4336 23.6009 49.1642 23.0538C48.8948 22.5067 48.4775 22.0461 47.9595 21.7243C47.4415 21.4026 46.8437 21.2325 46.2339 21.2334ZM23.3672 3.2667C23.3672 2.94365 23.463 2.62787 23.6425 2.35926C23.8219 2.09066 24.077 1.88132 24.3755 1.75769C24.6739 1.63407 25.0023 1.60172 25.3192 1.66475C25.636 1.72777 25.927 1.88333 26.1555 2.11175C26.3839 2.34018 26.5394 2.63121 26.6025 2.94805C26.6655 3.26488 26.6331 3.59329 26.5095 3.89175C26.3859 4.1902 26.1766 4.44529 25.908 4.62476C25.6394 4.80424 25.3236 4.90003 25.0005 4.90003C24.5673 4.90003 24.1519 4.72795 23.8456 4.42164C23.5393 4.11533 23.3672 3.69988 23.3672 3.2667ZM3.76718 26.1334C3.44414 26.1334 3.12835 26.0376 2.85975 25.8581C2.59115 25.6786 2.3818 25.4235 2.25818 25.1251C2.13456 24.8266 2.10221 24.4982 2.16524 24.1814C2.22826 23.8645 2.38382 23.5735 2.61224 23.3451C2.84067 23.1167 3.1317 22.9611 3.44854 22.8981C3.76537 22.8351 4.09378 22.8674 4.39223 22.991C4.69069 23.1146 4.94578 23.324 5.12525 23.5926C5.30472 23.8612 5.40052 24.177 5.40052 24.5C5.40052 24.9332 5.22844 25.3487 4.92213 25.655C4.61582 25.9613 4.20037 26.1334 3.76718 26.1334ZM26.6339 45.7334C26.6339 46.0564 26.5381 46.3722 26.3586 46.6408C26.1791 46.9094 25.924 47.1187 25.6256 47.2424C25.3271 47.366 24.9987 47.3983 24.6819 47.3353C24.365 47.2723 24.074 47.1167 23.8456 46.8883C23.6172 46.6599 23.4616 46.3688 23.3986 46.052C23.3356 45.7352 23.3679 45.4068 23.4915 45.1083C23.6151 44.8099 23.8245 44.5548 24.0931 44.3753C24.3617 44.1958 24.6775 44.1 25.0005 44.1C25.4337 44.1 25.8492 44.2721 26.1555 44.5784C26.4618 44.8847 26.6339 45.3002 26.6339 45.7334ZM31.5339 30.2167V32.6667H18.4672V30.2167C18.4672 29.5669 18.2091 28.9438 17.7496 28.4843C17.2901 28.0248 16.667 27.7667 16.0172 27.7667H13.5672V18.5808L16.2385 23.5878C16.5166 24.1105 16.9318 24.5477 17.4396 24.8522C17.9473 25.1568 18.5284 25.3174 19.1205 25.3167H20.1005C20.3171 25.3167 20.5248 25.2307 20.678 25.0775C20.8311 24.9243 20.9172 24.7166 20.9172 24.5C20.9172 24.2834 20.8311 24.0757 20.678 23.9226C20.5248 23.7694 20.3171 23.6834 20.1005 23.6834H19.1205C18.8243 23.6835 18.5336 23.6032 18.2795 23.4508C18.0255 23.2985 17.8177 23.0799 17.6783 22.8185L14.2352 16.3668C14.2835 16.3507 14.3333 16.3394 14.3839 16.3334H35.6172C35.6676 16.3384 35.7174 16.3485 35.7658 16.3636L32.3211 22.8193C32.1818 23.0803 31.9741 23.2986 31.7204 23.4507C31.4667 23.6029 31.1764 23.6833 30.8805 23.6834H29.9005C29.6839 23.6834 29.4762 23.7694 29.3231 23.9226C29.1699 24.0757 29.0839 24.2834 29.0839 24.5C29.0839 24.7166 29.1699 24.9243 29.3231 25.0775C29.4762 25.2307 29.6839 25.3167 29.9005 25.3167H30.8805C31.4727 25.3176 32.0538 25.1571 32.5616 24.8525C33.0694 24.5479 33.4846 24.1107 33.7625 23.5878L36.4339 18.58V27.7667H33.9839C33.3341 27.7667 32.7109 28.0248 32.2514 28.4843C31.792 28.9438 31.5339 29.5669 31.5339 30.2167ZM38.8602 8.33003C39.0119 8.17833 39.192 8.05799 39.3902 7.9759C39.5884 7.8938 39.8008 7.85154 40.0154 7.85154C40.2299 7.85154 40.4423 7.8938 40.6405 7.9759C40.8387 8.05799 41.0188 8.17833 41.1705 8.33003C41.3222 8.48173 41.4426 8.66182 41.5247 8.86003C41.6068 9.05823 41.649 9.27067 41.649 9.4852C41.649 9.69974 41.6068 9.91218 41.5247 10.1104C41.4426 10.3086 41.3222 10.4887 41.1705 10.6404C40.8595 10.9375 40.4459 11.1033 40.0158 11.1033C39.5856 11.1033 39.172 10.9375 38.861 10.6404C38.5548 10.3341 38.3828 9.91871 38.3828 9.48561C38.3828 9.05251 38.5548 8.63714 38.861 8.33085L38.8602 8.33003ZM8.83052 10.6404C8.60204 10.412 8.44643 10.1209 8.38337 9.80409C8.32031 9.48724 8.35263 9.15881 8.47623 8.86033C8.59984 8.56185 8.80919 8.30673 9.0778 8.12723C9.34641 7.94774 9.66222 7.85193 9.98529 7.85193C10.3083 7.85193 10.6242 7.94774 10.8928 8.12723C11.1614 8.30673 11.3707 8.56185 11.4943 8.86033C11.6179 9.15881 11.6503 9.48724 11.5872 9.80409C11.5241 10.1209 11.3685 10.412 11.1401 10.6404C10.829 10.9375 10.4154 11.1033 9.98529 11.1033C9.55514 11.1033 9.14155 10.9375 8.83052 10.6404ZM13.5672 31.85V29.4H16.0172C16.2338 29.4 16.4415 29.4861 16.5947 29.6392C16.7478 29.7924 16.8339 30.0001 16.8339 30.2167V32.6667H14.3839C14.1673 32.6667 13.9595 32.5807 13.8064 32.4275C13.6532 32.2743 13.5672 32.0666 13.5672 31.85ZM11.1409 40.67C10.8298 40.9672 10.4162 41.133 9.9861 41.133C9.55596 41.133 9.14236 40.9672 8.83134 40.67C8.60286 40.4416 8.44725 40.1506 8.38419 39.8337C8.32113 39.5169 8.35344 39.1885 8.47705 38.89C8.60066 38.5915 8.81001 38.3364 9.07862 38.1569C9.34723 37.9774 9.66304 37.8816 9.9861 37.8816C10.3092 37.8816 10.625 37.9774 10.8936 38.1569C11.1622 38.3364 11.3715 38.5915 11.4952 38.89C11.6188 39.1885 11.6511 39.5169 11.588 39.8337C11.525 40.1506 11.3693 40.4416 11.1409 40.67ZM40.0149 37.8819C40.338 37.8818 40.6538 37.9776 40.9225 38.157C41.1912 38.3364 41.4006 38.5914 41.5243 38.8899C41.648 39.1883 41.6804 39.5168 41.6174 39.8336C41.5544 40.1505 41.3989 40.4416 41.1705 40.67C40.8595 40.9672 40.4459 41.133 40.0158 41.133C39.5856 41.133 39.172 40.9672 38.861 40.67C38.6326 40.4416 38.4771 40.1506 38.4141 39.8338C38.3511 39.517 38.3835 39.1887 38.5071 38.8903C38.6307 38.5919 38.84 38.3368 39.1085 38.1573C39.377 37.9778 39.6928 37.882 40.0158 37.8819H40.0149ZM35.6172 32.6667H33.1672V30.2167C33.1672 30.0001 33.2532 29.7924 33.4064 29.6392C33.5595 29.4861 33.7673 29.4 33.9839 29.4H36.4339V31.85C36.4339 32.0666 36.3478 32.2743 36.1947 32.4275C36.0415 32.5807 35.8338 32.6667 35.6172 32.6667ZM46.2339 26.1334C45.9108 26.1334 45.595 26.0376 45.3264 25.8581C45.0578 25.6786 44.8485 25.4235 44.7249 25.1251C44.6012 24.8266 44.5689 24.4982 44.6319 24.1814C44.6949 23.8645 44.8505 23.5735 45.0789 23.3451C45.3073 23.1167 45.5984 22.9611 45.9152 22.8981C46.232 22.8351 46.5605 22.8674 46.8589 22.991C47.1574 23.1146 47.4125 23.324 47.5919 23.5926C47.7714 23.8612 47.8672 24.177 47.8672 24.5C47.8672 24.9332 47.6951 25.3487 47.3888 25.655C47.0825 25.9613 46.667 26.1334 46.2339 26.1334Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n              &lt;path\n                d=&quot;M24.9997 23.6834C24.8564 23.6833 24.7156 23.6454 24.5916 23.5737C24.4675 23.5019 24.3645 23.3988 24.2929 23.2746C24.2214 23.1504 24.1837 23.0096 24.1838 22.8663C24.1839 22.7229 24.2217 22.5822 24.2934 22.4581C24.3652 22.334 24.4683 22.231 24.5924 22.1594C24.7166 22.0877 24.8574 22.0501 25.0007 22.0501C25.144 22.0501 25.2848 22.0879 25.4089 22.1596C25.533 22.2312 25.6361 22.3343 25.7078 22.4584C25.8195 22.639 25.9971 22.769 26.203 22.8208C26.4089 22.8726 26.6269 22.8421 26.8108 22.7359C26.9946 22.6297 27.1299 22.4561 27.1879 22.2518C27.2459 22.0475 27.222 21.8287 27.1214 21.6418C26.8257 21.1446 26.3633 20.7684 25.8164 20.5801V20.4168C25.8164 20.2002 25.7303 19.9924 25.5772 19.8393C25.424 19.6861 25.2163 19.6001 24.9997 19.6001C24.7831 19.6001 24.5754 19.6861 24.4222 19.8393C24.2691 19.9924 24.183 20.2002 24.183 20.4168V20.567C23.6386 20.7588 23.1796 21.1371 22.8873 21.6348C22.595 22.1326 22.4883 22.7178 22.5861 23.2867C22.684 23.8556 22.9799 24.3715 23.4217 24.7431C23.8635 25.1146 24.4225 25.3179 24.9997 25.3168C25.143 25.3169 25.2838 25.3548 25.4078 25.4265C25.5319 25.4983 25.6349 25.6014 25.7065 25.7256C25.778 25.8498 25.8157 25.9906 25.8156 26.1339C25.8155 26.2773 25.7777 26.418 25.706 26.5421C25.6342 26.6662 25.5311 26.7692 25.407 26.8408C25.2828 26.9124 25.142 26.9501 24.9987 26.9501C24.8554 26.9501 24.7146 26.9123 24.5905 26.8406C24.4664 26.769 24.3633 26.6659 24.2917 26.5418C24.1799 26.3612 24.0023 26.2312 23.7964 26.1794C23.5905 26.1276 23.3725 26.1581 23.1886 26.2643C23.0048 26.3705 22.8695 26.5441 22.8115 26.7484C22.7535 26.9526 22.7774 27.1715 22.878 27.3584C23.1741 27.8559 23.6371 28.2321 24.1847 28.4201V28.5834C24.1847 28.8 24.2707 29.0077 24.4239 29.1609C24.577 29.3141 24.7847 29.4001 25.0013 29.4001C25.2179 29.4001 25.4257 29.3141 25.5788 29.1609C25.732 29.0077 25.818 28.8 25.818 28.5834V28.4332C26.3626 28.2414 26.8217 27.8629 27.114 27.365C27.4062 26.867 27.5128 26.2817 27.4148 25.7127C27.3167 25.1437 27.0205 24.6278 26.5784 24.2563C26.1364 23.8849 25.5771 23.6819 24.9997 23.6834Z&quot;\n                fill=&quot;currentcolor&quot; /&gt;\n            &lt;/g&gt;\n            &lt;defs&gt;\n              &lt;clipPath id=&quot;clip0_375_6645&quot;&gt;\n                &lt;rect width=&quot;49&quot; height=&quot;49&quot; fill=&quot;white&quot; transform=&quot;translate(0.5)&quot; /&gt;\n              &lt;/clipPath&gt;\n            &lt;/defs&gt;\n          &lt;/svg&gt;\n          &lt;h2 class=&quot;feature-title mt-4 mb-3 d-block&quot;&gt;Free Shipping&lt;/h2&gt;\n          &lt;p class=&quot;mb-0&quot;&gt;A commerce solution for growing digital brands&lt;/p&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n    &lt;/div&gt;\n  &lt;/div&gt;\n&lt;/section&gt;', '[[regtime]]', '[[regtime]]'),
(14, 14, 1, '0', 0, 'Novator Featured Banner', 'Featured Banner 1', 'Featured Banner2', '&lt;section&gt;\n&lt;div class=&quot;container&quot;&gt;\n  &lt;div class=&quot;row sec-heading-block justify-content-center text-center&quot;&gt;\n    &lt;div class=&quot;col-xl-8&quot;&gt;\n      &lt;h2&gt;Featured Banner&lt;/h2&gt;\n    &lt;/div&gt;\n  &lt;/div&gt;\n  &lt;div class=&quot;row g-4&quot;&gt;\n    &lt;div class=&quot;col-md-4&quot;&gt;\n      &lt;div class=&quot;banner-card&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7a/7.png&quot; alt=&quot;images&quot;\n          class=&quot;img-fluid w-100 h-auto&quot; width=&quot;100&quot; height=&quot;100&quot;&gt;\n        &lt;div class=&quot;banner-overlay&quot;&gt;\n          &lt;h2 class=&quot;banner-title text-white&quot;&gt;Hawaiian Shirts&lt;/h2&gt;&lt;span class=&quot;banner-text text-white&quot;&gt;Dress up in\n            summer vibe&lt;/span&gt;\n          &lt;h3 class=&quot;banner-sales text-white&quot;&gt;UPTO 50% OFF&lt;/h3&gt;\n          &lt;div class=&quot;banner-arrow text-white&quot;&gt;&lt;i class=&quot;bi bi-arrow-down&quot;&gt;&lt;/i&gt;&lt;/div&gt;&lt;a href=&quot;#&quot;\n            class=&quot;btn btn-outline-light&quot;&gt;SHOP NOW&lt;/a&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n    &lt;/div&gt;\n    &lt;div class=&quot;col-md-4&quot;&gt;\n      &lt;div class=&quot;banner-card&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7a/8.png&quot; alt=&quot;images&quot;\n          class=&quot;img-fluid w-100 h-auto&quot; width=&quot;100&quot; height=&quot;100&quot;&gt;\n        &lt;div class=&quot;banner-overlay right text-end&quot;&gt;\n          &lt;h2 class=&quot;banner-title text-white&quot;&gt;Printed T-Shirt&lt;/h2&gt;&lt;span class=&quot;banner-text text-white&quot;&gt;New Designs\n            Every Week&lt;/span&gt;\n          &lt;h3 class=&quot;banner-sales text-white&quot;&gt;UPTO 40% OFF&lt;/h3&gt;\n          &lt;div class=&quot;banner-arrow text-white&quot;&gt;&lt;i class=&quot;bi bi-arrow-down&quot;&gt;&lt;/i&gt;&lt;/div&gt;&lt;a href=&quot;#&quot;\n            class=&quot;btn btn-outline-light&quot;&gt;SHOP NOW&lt;/a&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n    &lt;/div&gt;\n    &lt;div class=&quot;col-md-4&quot;&gt;\n      &lt;div class=&quot;banner-card&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7a/9.png&quot; alt=&quot;images&quot;\n          class=&quot;img-fluid w-100 h-auto&quot; width=&quot;100&quot; height=&quot;100&quot;&gt;\n        &lt;div class=&quot;banner-overlay right&quot;&gt;\n          &lt;h2 class=&quot;banner-title&quot;&gt;Cargo Joggers&lt;/h2&gt;&lt;span class=&quot;banner-text&quot;&gt;Move with style &amp; comfort&lt;/span&gt;\n          &lt;h3 class=&quot;banner-sales&quot;&gt;UPTO 50% OFF&lt;/h3&gt;\n          &lt;div class=&quot;banner-arrow&quot;&gt;&lt;i class=&quot;bi bi-arrow-down&quot;&gt;&lt;/i&gt;&lt;/div&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-outline-dark&quot;&gt;SHOP\n            NOW&lt;/a&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n    &lt;/div&gt;\n    &lt;div class=&quot;col-md-6&quot;&gt;\n      &lt;div class=&quot;banner-card&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7a/a.png&quot; alt=&quot;images&quot;\n          class=&quot;img-fluid w-100 h-auto&quot; width=&quot;100&quot; height=&quot;100&quot;&gt;\n        &lt;div class=&quot;banner-overlay right big&quot;&gt;\n          &lt;h2 class=&quot;banner-title&quot;&gt;Urban Shirts&lt;/h2&gt;&lt;span class=&quot;banner-text&quot;&gt;Live In Confort&lt;/span&gt;\n          &lt;h3 class=&quot;banner-sales&quot;&gt;FLAT 60% OFF&lt;/h3&gt;\n          &lt;div class=&quot;banner-arrow&quot;&gt;&lt;i class=&quot;bi bi-arrow-down&quot;&gt;&lt;/i&gt;&lt;/div&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-outline-dark&quot;&gt;SHOP\n            NOW&lt;/a&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n    &lt;/div&gt;\n    &lt;div class=&quot;col-md-6&quot;&gt;\n      &lt;div class=&quot;banner-card&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7a/b.png&quot; alt=&quot;images&quot;\n          class=&quot;img-fluid w-100 h-auto&quot; width=&quot;100&quot; height=&quot;100&quot;&gt;\n        &lt;div class=&quot;banner-overlay right big&quot;&gt;\n          &lt;h2 class=&quot;banner-title&quot;&gt;Oversized T-Shirts&lt;/h2&gt;&lt;span class=&quot;banner-text&quot;&gt;Street Style Icon&lt;/span&gt;\n          &lt;h3 class=&quot;banner-sales&quot;&gt;FLAT 60% OFF&lt;/h3&gt;\n          &lt;div class=&quot;banner-arrow&quot;&gt;&lt;i class=&quot;bi bi-arrow-down&quot;&gt;&lt;/i&gt;&lt;/div&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-outline-dark&quot;&gt;SHOP\n            NOW&lt;/a&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n    &lt;/div&gt;\n  &lt;/div&gt;\n&lt;/div&gt;\n&lt;/section&gt;', '[[regtime]]', '[[regtime]]'),
(15, 15, 1, '0', 0, 'Novator Making Commerce', 'Making Commerce', 'Making Commerce', '&lt;section class=&quot;cta position-relative&quot;&gt;\n  &lt;div class=&quot;cta-data&quot;&gt;\n    &lt;div class=&quot;container&quot;&gt;\n      &lt;div class=&quot;row g-4&quot;&gt;\n        &lt;div class=&quot;col-lg-6&quot;&gt;\n          &lt;div class=&quot;cta-content&quot;&gt;\n          &lt;h2 class=&quot;text-white&quot;&gt;Making Commerce&lt;br&gt;Better for Everyone&lt;/h2&gt;\n          &lt;div class=&quot;cta-price text-white&quot;&gt;&lt;small class=&quot;me-2&quot;&gt;Start From&lt;/small&gt; $56&lt;/div&gt;&lt;br&gt;&lt;a href=&quot;#&quot;\n            class=&quot;cta-btn btn btn-warning&quot;&gt;Try Now&lt;/a&gt;\n          &lt;/div&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n    &lt;/div&gt;\n  &lt;/div&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7a/c.png&quot; alt=&quot;images&quot; class=&quot;w-100 h-auto img-fluid d-none d-lg-block&quot;\n    width=&quot;1920&quot; height=&quot;612&quot;&gt; &lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7a/d.png&quot; alt=&quot;images&quot;\n    class=&quot;w-100 h-auto img-fluid d-block d-lg-none&quot; width=&quot;1920&quot; height=&quot;612&quot;&gt;\n&lt;/section&gt;', '[[regtime]]', '[[regtime]]'),
(16, 16, 1, '0', 0, 'Novator See Our Most Featured Product', 'See Our Most Featured Product', '', '&lt;section class=&quot;pt-0&quot;&gt;\n    &lt;div class=&quot;container&quot;&gt;\n      &lt;div class=&quot;row title justify-content-center text-center&quot;&gt;\n        &lt;div class=&quot;col-12&quot;&gt;\n          &lt;h2&gt;See Our Most Featured Product&lt;/h2&gt;\n        &lt;/div&gt;\n        &lt;div class=&quot;col-12 text-center mt-4&quot;&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-warning&quot;&gt;Get Started&lt;/a&gt;&lt;/div&gt;\n      &lt;/div&gt;\n    &lt;/div&gt;\n  &lt;/section&gt;', '[[regtime]]', '[[regtime]]'),
(17, 17, 1, 'blocks/listing_block/popular_brands_content_bottom.tpl', 1, 'Novator Brands Scrolling List', 'Brands Scrolling List', 'Brands Scrolling ListBrands Scrolling List', 'a:2:{s:18:"listing_datasource";s:33:"catalog_category_getmanufacturers";s:5:"limit";s:0:"";}', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]block_descriptions` VALUES
(18, 18, 1, '0', 0, 'Novator Testimonials', 'Novator Testimonials', '', '&lt;section class=&quot;comment-section&quot;&gt;\n    &lt;div class=&quot;container&quot;&gt;\n      &lt;div class=&quot;row title justify-content-center sec-heading-block&quot;&gt;\n        &lt;div class=&quot;col-xl-8&quot;&gt;\n          &lt;h2 class=&quot;text-center&quot;&gt;What Our Clients Say About Us&lt;/h2&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n      &lt;div class=&quot;comment-carousel owl-carousel owl-theme&quot;&gt;\n        &lt;div class=&quot;item&quot;&gt;\n          &lt;div class=&quot;card comment-card&quot;&gt;\n            &lt;div class=&quot;row g-0 align-items-center&quot;&gt;\n              &lt;div class=&quot;col-4&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/6.png&quot; class=&quot;img-fluid rounded-start&quot;\n                  alt=&quot;images&quot;&gt;&lt;/div&gt;\n              &lt;div class=&quot;col-8&quot;&gt;\n                &lt;div class=&quot;card-body&quot;&gt;&lt;span&gt;On reviewcentre.com&lt;/span&gt;\n                  &lt;h3 class=&quot;h4&quot;&gt;Lorem ipsum it amet, consectetur adipiscing elit.&lt;/h3&gt;\n                  &lt;p class=&quot;text-muted&quot;&gt;&quot; I was working with many shopping carts, free and hosted for my clients. There\n                    is always something missing. In abantecart I find this gap to be much less. Interface is very easy\n                    to use and support is very responsive. This is considering its is free. Go abantecart go!&quot;&lt;/p&gt;\n                  &lt;p class=&quot;text-primary mb-0&quot;&gt;TopShop&lt;/p&gt;\n                &lt;/div&gt;\n              &lt;/div&gt;\n            &lt;/div&gt;\n          &lt;/div&gt;\n        &lt;/div&gt;\n        &lt;div class=&quot;item&quot;&gt;\n          &lt;div class=&quot;card comment-card&quot;&gt;\n            &lt;div class=&quot;row g-0 align-items-center&quot;&gt;\n              &lt;div class=&quot;col-4&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/7.png&quot; class=&quot;img-fluid rounded-start&quot;\n                  alt=&quot;images&quot;&gt;&lt;/div&gt;\n              &lt;div class=&quot;col-8&quot;&gt;\n                &lt;div class=&quot;card-body&quot;&gt;&lt;span&gt;On reviewcentre.com&lt;/span&gt;\n                  &lt;h3 class=&quot;h4&quot;&gt;Lorem ipsum it amet, consectetur adipiscing elit.&lt;/h3&gt;\n                  &lt;p class=&quot;text-muted&quot;&gt;&quot; I was working with many shopping carts, free and hosted for my clients. There\n                    is always something missing. In abantecart I find this gap to be much less. Interface is very easy\n                    to use and support is very responsive. This is considering its is free. Go abantecart go!&quot;&lt;/p&gt;\n                  &lt;p class=&quot;text-primary mb-0&quot;&gt;TopShop&lt;/p&gt;\n                &lt;/div&gt;\n              &lt;/div&gt;\n            &lt;/div&gt;\n          &lt;/div&gt;\n        &lt;/div&gt;\n        &lt;div class=&quot;item&quot;&gt;\n          &lt;div class=&quot;card comment-card&quot;&gt;\n            &lt;div class=&quot;row g-0 align-items-center&quot;&gt;\n              &lt;div class=&quot;col-4&quot;&gt;&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/8.png&quot; class=&quot;img-fluid rounded-start&quot;\n                  alt=&quot;images&quot;&gt;&lt;/div&gt;\n              &lt;div class=&quot;col-8&quot;&gt;\n                &lt;div class=&quot;card-body&quot;&gt;&lt;span&gt;On reviewcentre.com&lt;/span&gt;\n                  &lt;h3 class=&quot;h4&quot;&gt;Lorem ipsum it amet, consectetur adipiscing elit.&lt;/h3&gt;\n                  &lt;p class=&quot;text-muted&quot;&gt;&quot; I was working with many shopping carts, free and hosted for my clients. There\n                    is always something missing. In abantecart I find this gap to be much less. Interface is very easy\n                    to use and support is very responsive. This is considering its is free. Go abantecart go!&quot;&lt;/p&gt;\n                  &lt;p class=&quot;text-primary mb-0&quot;&gt;TopShop&lt;/p&gt;\n                &lt;/div&gt;\n              &lt;/div&gt;\n            &lt;/div&gt;\n          &lt;/div&gt;\n        &lt;/div&gt;\n      &lt;/div&gt;\n    &lt;/div&gt;\n  &lt;/section&gt;\n&lt;script&gt;\n$(document).ready(function () {\n      var owl = $(''.comment-carousel'');\n      owl.owlCarousel({\n        loop: true,\n        margin: 24,\n        navText: [''&lt;i class=&quot;bi bi-chevron-left&quot;&gt;&lt;/i&gt;'', ''&lt;i class=&quot;bi bi-chevron-right&quot;&gt;&lt;/i&gt;''],\n        nav: true,\n        center: true,\n        autoWidth: true,\n        items: 1.8\n      });\n    });\n&lt;/script&gt;', '[[regtime]]', '[[regtime]]'),
(19, 19, 1, '0', 0, 'Novator Left banner 1', 'Left banner 1', '', '&lt;div class=&quot;left-right-banner card p-0 border-0&quot;&gt;\n&lt;a href=&quot;#&quot;&gt;\n  &lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/a.jpg&quot; class=&quot;img-fluid&quot;&gt;\n&lt;/a&gt;\n&lt;/div&gt;', '[[regtime]]', '[[regtime]]'),
(20, 20, 1, '0', 0, 'Novator Left banner 2', 'Left banner 2', '', '&lt;div class=&quot;left-right-banner card p-0 border-0&quot;&gt;\n&lt;a href=&quot;#&quot;&gt;\n&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/b.jpg&quot; class=&quot;img-fluid&quot;&gt;\n&lt;/a&gt;\n&lt;/div&gt;', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]block_layouts`
--

CREATE TABLE `[[dbprefix]]block_layouts` (
  `instance_id` int NOT NULL AUTO_INCREMENT,
  `layout_id` int NOT NULL DEFAULT '0',
  `block_id` int NOT NULL DEFAULT '0',
  `custom_block_id` int NOT NULL DEFAULT '0',
  `parent_instance_id` int NOT NULL DEFAULT '0',
  `position` smallint NOT NULL DEFAULT '0',
  `status` smallint NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`instance_id`),
  UNIQUE KEY `[[dbprefix]]block_layouts_idx` (`instance_id`,`layout_id`,`block_id`,`parent_instance_id`,`custom_block_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=887 ;

--
-- Dumping data for table `[[dbprefix]]block_layouts`
--

INSERT INTO `[[dbprefix]]block_layouts` VALUES
(1, 1, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(2, 1, 15, 0, 1, 10, 1, '[[regtime]]', '[[regtime]]'),
(3, 1, 31, 0, 1, 20, 1, '[[regtime]]', '[[regtime]]'),
(4, 1, 27, 0, 1, 30, 1, '[[regtime]]', '[[regtime]]'),
(5, 1, 26, 0, 1, 40, 1, '[[regtime]]', '[[regtime]]'),
(6, 1, 13, 0, 1, 50, 1, '[[regtime]]', '[[regtime]]'),
(7, 1, 14, 0, 1, 60, 1, '[[regtime]]', '[[regtime]]'),
(8, 1, 17, 1, 1, 70, 1, '[[regtime]]', '[[regtime]]'),
(9, 1, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(10, 1, 9, 0, 9, 10, 1, '[[regtime]]', '[[regtime]]'),
(11, 1, 28, 0, 9, 20, 1, '[[regtime]]', '[[regtime]]'),
(12, 1, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(13, 1, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(14, 1, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(15, 1, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(16, 1, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(17, 1, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(18, 1, 17, 2, 17, 10, 1, '[[regtime]]', '[[regtime]]'),
(19, 1, 17, 3, 17, 20, 1, '[[regtime]]', '[[regtime]]'),
(20, 1, 17, 4, 17, 30, 1, '[[regtime]]', '[[regtime]]'),
(21, 1, 25, 0, 17, 40, 1, '[[regtime]]', '[[regtime]]'),
(22, 1, 11, 0, 17, 50, 1, '[[regtime]]', '[[regtime]]'),
(23, 1, 17, 1, 17, 60, 1, '[[regtime]]', '[[regtime]]'),
(24, 1, 24, 0, 17, 70, 1, '[[regtime]]', '[[regtime]]'),
(25, 1, 21, 0, 17, 80, 1, '[[regtime]]', '[[regtime]]'),
(26, 2, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(27, 2, 15, 0, 26, 10, 1, '[[regtime]]', '[[regtime]]'),
(28, 2, 31, 0, 26, 20, 1, '[[regtime]]', '[[regtime]]'),
(29, 2, 27, 0, 26, 30, 1, '[[regtime]]', '[[regtime]]'),
(30, 2, 26, 0, 26, 40, 1, '[[regtime]]', '[[regtime]]'),
(31, 2, 13, 0, 26, 50, 1, '[[regtime]]', '[[regtime]]'),
(32, 2, 14, 0, 26, 60, 1, '[[regtime]]', '[[regtime]]'),
(33, 2, 17, 1, 26, 70, 1, '[[regtime]]', '[[regtime]]'),
(34, 2, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(35, 2, 9, 0, 34, 10, 1, '[[regtime]]', '[[regtime]]'),
(36, 2, 17, 5, 34, 20, 1, '[[regtime]]', '[[regtime]]'),
(37, 2, 17, 6, 34, 30, 1, '[[regtime]]', '[[regtime]]'),
(38, 2, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(39, 2, 12, 0, 38, 10, 1, '[[regtime]]', '[[regtime]]'),
(40, 2, 4, 0, 0, 40, 0, '[[regtime]]', '[[regtime]]'),
(41, 2, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(42, 2, 19, 0, 41, 10, 1, '[[regtime]]', '[[regtime]]'),
(43, 2, 12, 0, 41, 20, 1, '[[regtime]]', '[[regtime]]'),
(44, 2, 18, 0, 41, 30, 1, '[[regtime]]', '[[regtime]]'),
(45, 2, 22, 0, 41, 40, 1, '[[regtime]]', '[[regtime]]'),
(46, 2, 6, 0, 0, 60, 0, '[[regtime]]', '[[regtime]]'),
(47, 2, 12, 0, 46, 10, 1, '[[regtime]]', '[[regtime]]'),
(48, 2, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(49, 2, 23, 7, 48, 10, 1, '[[regtime]]', '[[regtime]]'),
(50, 2, 20, 8, 48, 20, 1, '[[regtime]]', '[[regtime]]'),
(51, 2, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(52, 2, 17, 2, 51, 10, 1, '[[regtime]]', '[[regtime]]'),
(53, 2, 17, 3, 51, 20, 1, '[[regtime]]', '[[regtime]]'),
(54, 2, 17, 4, 51, 30, 1, '[[regtime]]', '[[regtime]]'),
(55, 2, 25, 0, 51, 40, 1, '[[regtime]]', '[[regtime]]'),
(56, 2, 11, 0, 51, 50, 1, '[[regtime]]', '[[regtime]]'),
(57, 2, 17, 1, 51, 60, 1, '[[regtime]]', '[[regtime]]'),
(58, 2, 24, 0, 51, 70, 1, '[[regtime]]', '[[regtime]]'),
(59, 2, 21, 0, 51, 80, 1, '[[regtime]]', '[[regtime]]'),
(60, 3, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(61, 3, 15, 0, 60, 10, 1, '[[regtime]]', '[[regtime]]'),
(62, 3, 31, 0, 60, 20, 1, '[[regtime]]', '[[regtime]]'),
(63, 3, 27, 0, 60, 30, 1, '[[regtime]]', '[[regtime]]'),
(64, 3, 26, 0, 60, 40, 1, '[[regtime]]', '[[regtime]]'),
(65, 3, 13, 0, 60, 50, 1, '[[regtime]]', '[[regtime]]'),
(66, 3, 14, 0, 60, 60, 1, '[[regtime]]', '[[regtime]]'),
(67, 3, 17, 1, 60, 70, 1, '[[regtime]]', '[[regtime]]'),
(68, 3, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(69, 3, 9, 0, 68, 10, 1, '[[regtime]]', '[[regtime]]'),
(70, 3, 28, 0, 68, 20, 1, '[[regtime]]', '[[regtime]]'),
(71, 3, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(72, 3, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(73, 3, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(74, 3, 6, 0, 0, 60, 0, '[[regtime]]', '[[regtime]]'),
(75, 3, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(76, 3, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(77, 3, 17, 2, 76, 10, 1, '[[regtime]]', '[[regtime]]'),
(78, 3, 17, 3, 76, 20, 1, '[[regtime]]', '[[regtime]]'),
(79, 3, 17, 4, 76, 30, 1, '[[regtime]]', '[[regtime]]'),
(80, 3, 25, 0, 76, 40, 1, '[[regtime]]', '[[regtime]]'),
(81, 3, 11, 0, 76, 50, 1, '[[regtime]]', '[[regtime]]'),
(82, 3, 17, 1, 76, 60, 1, '[[regtime]]', '[[regtime]]'),
(83, 3, 24, 0, 76, 70, 1, '[[regtime]]', '[[regtime]]'),
(84, 3, 21, 0, 76, 80, 1, '[[regtime]]', '[[regtime]]'),
(85, 4, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(86, 4, 15, 0, 85, 10, 1, '[[regtime]]', '[[regtime]]'),
(87, 4, 31, 0, 85, 20, 1, '[[regtime]]', '[[regtime]]'),
(88, 4, 27, 0, 85, 30, 1, '[[regtime]]', '[[regtime]]'),
(89, 4, 26, 0, 85, 40, 1, '[[regtime]]', '[[regtime]]'),
(90, 4, 13, 0, 85, 50, 1, '[[regtime]]', '[[regtime]]'),
(91, 4, 14, 0, 85, 60, 1, '[[regtime]]', '[[regtime]]'),
(92, 4, 17, 1, 85, 70, 1, '[[regtime]]', '[[regtime]]'),
(93, 4, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(94, 4, 9, 0, 93, 10, 1, '[[regtime]]', '[[regtime]]'),
(95, 4, 28, 0, 93, 20, 1, '[[regtime]]', '[[regtime]]'),
(96, 4, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(97, 4, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(98, 4, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(99, 4, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(100, 4, 37, 0, 99, 10, 1, '[[regtime]]', '[[regtime]]'),
(101, 4, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(102, 4, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(103, 4, 17, 2, 102, 10, 1, '[[regtime]]', '[[regtime]]'),
(104, 4, 17, 3, 102, 20, 1, '[[regtime]]', '[[regtime]]'),
(105, 4, 17, 4, 102, 30, 1, '[[regtime]]', '[[regtime]]'),
(106, 4, 25, 0, 102, 40, 1, '[[regtime]]', '[[regtime]]'),
(107, 4, 11, 0, 102, 50, 1, '[[regtime]]', '[[regtime]]'),
(108, 4, 17, 1, 102, 60, 1, '[[regtime]]', '[[regtime]]'),
(109, 4, 24, 0, 102, 70, 1, '[[regtime]]', '[[regtime]]'),
(110, 4, 21, 0, 102, 80, 1, '[[regtime]]', '[[regtime]]'),
(111, 5, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(112, 5, 15, 0, 111, 10, 1, '[[regtime]]', '[[regtime]]'),
(113, 5, 31, 0, 111, 20, 1, '[[regtime]]', '[[regtime]]'),
(114, 5, 27, 0, 111, 30, 1, '[[regtime]]', '[[regtime]]'),
(115, 5, 26, 0, 111, 40, 1, '[[regtime]]', '[[regtime]]'),
(116, 5, 13, 0, 111, 50, 1, '[[regtime]]', '[[regtime]]'),
(117, 5, 14, 0, 111, 60, 1, '[[regtime]]', '[[regtime]]'),
(118, 5, 17, 1, 111, 70, 1, '[[regtime]]', '[[regtime]]'),
(119, 5, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(120, 5, 9, 0, 119, 10, 1, '[[regtime]]', '[[regtime]]'),
(121, 5, 28, 0, 119, 20, 1, '[[regtime]]', '[[regtime]]'),
(122, 5, 3, 0, 0, 30, 1, '[[regtime]]', '[[regtime]]'),
(123, 5, 12, 0, 122, 10, 1, '[[regtime]]', '[[regtime]]'),
(124, 5, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(125, 5, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(126, 5, 6, 0, 0, 60, 0, '[[regtime]]', '[[regtime]]'),
(127, 5, 7, 0, 0, 70, 0, '[[regtime]]', '[[regtime]]'),
(128, 5, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(129, 5, 17, 2, 128, 10, 1, '[[regtime]]', '[[regtime]]'),
(130, 5, 17, 3, 128, 20, 1, '[[regtime]]', '[[regtime]]'),
(131, 5, 17, 4, 128, 30, 1, '[[regtime]]', '[[regtime]]'),
(132, 5, 25, 0, 128, 40, 1, '[[regtime]]', '[[regtime]]'),
(133, 5, 11, 0, 128, 50, 1, '[[regtime]]', '[[regtime]]'),
(134, 5, 17, 1, 128, 60, 1, '[[regtime]]', '[[regtime]]'),
(135, 5, 24, 0, 128, 70, 1, '[[regtime]]', '[[regtime]]'),
(136, 5, 21, 0, 128, 80, 1, '[[regtime]]', '[[regtime]]'),
(137, 6, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(138, 6, 15, 0, 137, 10, 1, '[[regtime]]', '[[regtime]]'),
(139, 6, 31, 0, 137, 20, 1, '[[regtime]]', '[[regtime]]'),
(140, 6, 27, 0, 137, 30, 1, '[[regtime]]', '[[regtime]]'),
(141, 6, 26, 0, 137, 40, 1, '[[regtime]]', '[[regtime]]'),
(142, 6, 13, 0, 137, 50, 1, '[[regtime]]', '[[regtime]]'),
(143, 6, 14, 0, 137, 60, 1, '[[regtime]]', '[[regtime]]'),
(144, 6, 17, 1, 137, 70, 1, '[[regtime]]', '[[regtime]]'),
(145, 6, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(146, 6, 9, 0, 145, 10, 1, '[[regtime]]', '[[regtime]]'),
(147, 6, 28, 0, 145, 20, 1, '[[regtime]]', '[[regtime]]'),
(148, 6, 3, 0, 0, 30, 1, '[[regtime]]', '[[regtime]]'),
(149, 6, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(150, 6, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(151, 6, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(152, 6, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(153, 6, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(154, 6, 17, 2, 153, 10, 1, '[[regtime]]', '[[regtime]]'),
(155, 6, 17, 3, 153, 20, 1, '[[regtime]]', '[[regtime]]'),
(156, 6, 17, 4, 153, 30, 1, '[[regtime]]', '[[regtime]]'),
(157, 6, 25, 0, 153, 40, 1, '[[regtime]]', '[[regtime]]'),
(158, 6, 11, 0, 153, 50, 1, '[[regtime]]', '[[regtime]]'),
(159, 6, 17, 1, 153, 60, 1, '[[regtime]]', '[[regtime]]'),
(160, 6, 24, 0, 153, 70, 1, '[[regtime]]', '[[regtime]]'),
(161, 6, 21, 0, 153, 80, 1, '[[regtime]]', '[[regtime]]'),
(162, 7, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(163, 7, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(164, 7, 3, 0, 0, 30, 1, '[[regtime]]', '[[regtime]]'),
(165, 7, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(166, 7, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(167, 7, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(168, 7, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(169, 7, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(170, 8, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(171, 8, 15, 0, 170, 10, 1, '[[regtime]]', '[[regtime]]'),
(172, 8, 31, 0, 170, 20, 1, '[[regtime]]', '[[regtime]]'),
(173, 8, 27, 0, 170, 30, 1, '[[regtime]]', '[[regtime]]'),
(174, 8, 26, 0, 170, 40, 1, '[[regtime]]', '[[regtime]]'),
(175, 8, 13, 0, 170, 50, 1, '[[regtime]]', '[[regtime]]'),
(176, 8, 14, 0, 170, 60, 1, '[[regtime]]', '[[regtime]]'),
(177, 8, 17, 1, 170, 70, 1, '[[regtime]]', '[[regtime]]'),
(178, 8, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(179, 8, 9, 0, 178, 10, 1, '[[regtime]]', '[[regtime]]'),
(180, 8, 28, 0, 178, 20, 1, '[[regtime]]', '[[regtime]]'),
(181, 8, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(182, 8, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(183, 8, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(184, 8, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(185, 8, 29, 0, 184, 10, 1, '[[regtime]]', '[[regtime]]'),
(186, 8, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(187, 8, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(188, 8, 17, 2, 187, 10, 1, '[[regtime]]', '[[regtime]]'),
(189, 8, 17, 3, 187, 20, 1, '[[regtime]]', '[[regtime]]'),
(190, 8, 17, 4, 187, 30, 1, '[[regtime]]', '[[regtime]]'),
(191, 8, 25, 0, 187, 40, 1, '[[regtime]]', '[[regtime]]'),
(192, 8, 11, 0, 187, 50, 1, '[[regtime]]', '[[regtime]]'),
(193, 8, 17, 1, 187, 60, 1, '[[regtime]]', '[[regtime]]'),
(194, 8, 24, 0, 187, 70, 1, '[[regtime]]', '[[regtime]]'),
(195, 8, 21, 0, 187, 80, 1, '[[regtime]]', '[[regtime]]'),
(196, 9, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(197, 9, 15, 0, 196, 10, 1, '[[regtime]]', '[[regtime]]'),
(198, 9, 31, 0, 196, 20, 1, '[[regtime]]', '[[regtime]]'),
(199, 9, 27, 0, 196, 30, 1, '[[regtime]]', '[[regtime]]'),
(200, 9, 26, 0, 196, 40, 1, '[[regtime]]', '[[regtime]]'),
(201, 9, 13, 0, 196, 50, 1, '[[regtime]]', '[[regtime]]'),
(202, 9, 14, 0, 196, 60, 1, '[[regtime]]', '[[regtime]]'),
(203, 9, 17, 1, 196, 70, 1, '[[regtime]]', '[[regtime]]'),
(204, 9, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(205, 9, 9, 0, 204, 10, 1, '[[regtime]]', '[[regtime]]'),
(206, 9, 28, 0, 204, 20, 1, '[[regtime]]', '[[regtime]]'),
(207, 9, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(208, 9, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(209, 9, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(210, 9, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(211, 9, 29, 0, 210, 10, 1, '[[regtime]]', '[[regtime]]'),
(212, 9, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(213, 9, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(214, 9, 17, 2, 213, 10, 1, '[[regtime]]', '[[regtime]]'),
(215, 9, 17, 3, 213, 20, 1, '[[regtime]]', '[[regtime]]'),
(216, 9, 17, 4, 213, 30, 1, '[[regtime]]', '[[regtime]]'),
(217, 9, 25, 0, 213, 40, 1, '[[regtime]]', '[[regtime]]'),
(218, 9, 11, 0, 213, 50, 1, '[[regtime]]', '[[regtime]]'),
(219, 9, 17, 1, 213, 60, 1, '[[regtime]]', '[[regtime]]'),
(220, 9, 24, 0, 213, 70, 1, '[[regtime]]', '[[regtime]]'),
(221, 9, 21, 0, 213, 80, 1, '[[regtime]]', '[[regtime]]'),
(222, 10, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(223, 10, 15, 0, 222, 10, 1, '[[regtime]]', '[[regtime]]'),
(224, 10, 31, 0, 222, 20, 1, '[[regtime]]', '[[regtime]]'),
(225, 10, 27, 0, 222, 30, 1, '[[regtime]]', '[[regtime]]'),
(226, 10, 26, 0, 222, 40, 1, '[[regtime]]', '[[regtime]]'),
(227, 10, 13, 0, 222, 50, 1, '[[regtime]]', '[[regtime]]'),
(228, 10, 14, 0, 222, 60, 1, '[[regtime]]', '[[regtime]]'),
(229, 10, 17, 1, 222, 70, 1, '[[regtime]]', '[[regtime]]'),
(230, 10, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(231, 10, 9, 0, 230, 10, 1, '[[regtime]]', '[[regtime]]'),
(232, 10, 28, 0, 230, 20, 1, '[[regtime]]', '[[regtime]]'),
(233, 10, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(234, 10, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(235, 10, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(236, 10, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(237, 10, 29, 0, 236, 10, 1, '[[regtime]]', '[[regtime]]'),
(238, 10, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(239, 10, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(240, 10, 17, 2, 239, 10, 1, '[[regtime]]', '[[regtime]]'),
(241, 10, 17, 3, 239, 20, 1, '[[regtime]]', '[[regtime]]'),
(242, 10, 17, 4, 239, 30, 1, '[[regtime]]', '[[regtime]]'),
(243, 10, 25, 0, 239, 40, 1, '[[regtime]]', '[[regtime]]'),
(244, 10, 11, 0, 239, 50, 1, '[[regtime]]', '[[regtime]]'),
(245, 10, 17, 1, 239, 60, 1, '[[regtime]]', '[[regtime]]'),
(246, 10, 24, 0, 239, 70, 1, '[[regtime]]', '[[regtime]]'),
(247, 10, 21, 0, 239, 80, 1, '[[regtime]]', '[[regtime]]'),
(248, 11, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(249, 11, 15, 0, 248, 10, 1, '[[regtime]]', '[[regtime]]'),
(250, 11, 31, 0, 248, 20, 1, '[[regtime]]', '[[regtime]]'),
(251, 11, 27, 0, 248, 30, 1, '[[regtime]]', '[[regtime]]'),
(252, 11, 26, 0, 248, 40, 1, '[[regtime]]', '[[regtime]]'),
(253, 11, 13, 0, 248, 50, 1, '[[regtime]]', '[[regtime]]'),
(254, 11, 14, 0, 248, 60, 1, '[[regtime]]', '[[regtime]]'),
(255, 11, 17, 1, 248, 70, 1, '[[regtime]]', '[[regtime]]'),
(256, 11, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(257, 11, 9, 0, 256, 10, 1, '[[regtime]]', '[[regtime]]'),
(258, 11, 28, 0, 256, 20, 1, '[[regtime]]', '[[regtime]]'),
(259, 11, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(260, 11, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(261, 11, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(262, 11, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(263, 11, 29, 0, 262, 10, 1, '[[regtime]]', '[[regtime]]'),
(264, 11, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(265, 11, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(266, 11, 17, 2, 265, 10, 1, '[[regtime]]', '[[regtime]]'),
(267, 11, 17, 3, 265, 20, 1, '[[regtime]]', '[[regtime]]'),
(268, 11, 17, 4, 265, 30, 1, '[[regtime]]', '[[regtime]]'),
(269, 11, 25, 0, 265, 40, 1, '[[regtime]]', '[[regtime]]'),
(270, 11, 11, 0, 265, 50, 1, '[[regtime]]', '[[regtime]]'),
(271, 11, 17, 1, 265, 60, 1, '[[regtime]]', '[[regtime]]'),
(272, 11, 24, 0, 265, 70, 1, '[[regtime]]', '[[regtime]]'),
(273, 11, 21, 0, 265, 80, 1, '[[regtime]]', '[[regtime]]'),
(274, 12, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(275, 12, 15, 0, 274, 10, 1, '[[regtime]]', '[[regtime]]'),
(276, 12, 31, 0, 274, 20, 1, '[[regtime]]', '[[regtime]]'),
(277, 12, 27, 0, 274, 30, 1, '[[regtime]]', '[[regtime]]'),
(278, 12, 26, 0, 274, 40, 1, '[[regtime]]', '[[regtime]]'),
(279, 12, 13, 0, 274, 50, 1, '[[regtime]]', '[[regtime]]'),
(280, 12, 14, 0, 274, 60, 1, '[[regtime]]', '[[regtime]]'),
(281, 12, 17, 1, 274, 70, 1, '[[regtime]]', '[[regtime]]'),
(282, 12, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(283, 12, 9, 0, 282, 10, 1, '[[regtime]]', '[[regtime]]'),
(284, 12, 28, 0, 282, 20, 1, '[[regtime]]', '[[regtime]]'),
(285, 12, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(286, 12, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(287, 12, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(288, 12, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(289, 12, 29, 0, 288, 10, 1, '[[regtime]]', '[[regtime]]'),
(290, 12, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(291, 12, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(292, 12, 17, 2, 291, 10, 1, '[[regtime]]', '[[regtime]]'),
(293, 12, 17, 3, 291, 20, 1, '[[regtime]]', '[[regtime]]'),
(294, 12, 17, 4, 291, 30, 1, '[[regtime]]', '[[regtime]]'),
(295, 12, 25, 0, 291, 40, 1, '[[regtime]]', '[[regtime]]'),
(296, 12, 11, 0, 291, 50, 1, '[[regtime]]', '[[regtime]]'),
(297, 12, 17, 1, 291, 60, 1, '[[regtime]]', '[[regtime]]'),
(298, 12, 24, 0, 291, 70, 1, '[[regtime]]', '[[regtime]]'),
(299, 12, 21, 0, 291, 80, 1, '[[regtime]]', '[[regtime]]'),
(300, 13, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(301, 13, 15, 0, 300, 10, 1, '[[regtime]]', '[[regtime]]'),
(302, 13, 31, 0, 300, 20, 1, '[[regtime]]', '[[regtime]]'),
(303, 13, 27, 0, 300, 30, 1, '[[regtime]]', '[[regtime]]'),
(304, 13, 26, 0, 300, 40, 1, '[[regtime]]', '[[regtime]]'),
(305, 13, 13, 0, 300, 50, 1, '[[regtime]]', '[[regtime]]'),
(306, 13, 14, 0, 300, 60, 1, '[[regtime]]', '[[regtime]]'),
(307, 13, 17, 1, 300, 70, 1, '[[regtime]]', '[[regtime]]'),
(308, 13, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(309, 13, 9, 0, 308, 10, 1, '[[regtime]]', '[[regtime]]'),
(310, 13, 28, 0, 308, 20, 1, '[[regtime]]', '[[regtime]]'),
(311, 13, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(312, 13, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(313, 13, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(314, 13, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(315, 13, 29, 0, 314, 10, 1, '[[regtime]]', '[[regtime]]'),
(316, 13, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(317, 13, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(318, 13, 17, 2, 317, 10, 1, '[[regtime]]', '[[regtime]]'),
(319, 13, 17, 3, 317, 20, 1, '[[regtime]]', '[[regtime]]'),
(320, 13, 17, 4, 317, 30, 1, '[[regtime]]', '[[regtime]]'),
(321, 13, 25, 0, 317, 40, 1, '[[regtime]]', '[[regtime]]'),
(322, 13, 11, 0, 317, 50, 1, '[[regtime]]', '[[regtime]]'),
(323, 13, 17, 1, 317, 60, 1, '[[regtime]]', '[[regtime]]'),
(324, 13, 24, 0, 317, 70, 1, '[[regtime]]', '[[regtime]]'),
(325, 13, 21, 0, 317, 80, 1, '[[regtime]]', '[[regtime]]'),
(326, 14, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(327, 14, 15, 0, 326, 10, 1, '[[regtime]]', '[[regtime]]'),
(328, 14, 31, 0, 326, 20, 1, '[[regtime]]', '[[regtime]]'),
(329, 14, 27, 0, 326, 30, 1, '[[regtime]]', '[[regtime]]'),
(330, 14, 26, 0, 326, 40, 1, '[[regtime]]', '[[regtime]]'),
(331, 14, 13, 0, 326, 50, 1, '[[regtime]]', '[[regtime]]'),
(332, 14, 14, 0, 326, 60, 1, '[[regtime]]', '[[regtime]]'),
(333, 14, 17, 1, 326, 70, 1, '[[regtime]]', '[[regtime]]'),
(334, 14, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(335, 14, 9, 0, 334, 10, 1, '[[regtime]]', '[[regtime]]'),
(336, 14, 28, 0, 334, 20, 1, '[[regtime]]', '[[regtime]]'),
(337, 14, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(338, 14, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(339, 14, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(340, 14, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(341, 14, 29, 0, 340, 10, 1, '[[regtime]]', '[[regtime]]'),
(342, 14, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(343, 14, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(344, 14, 17, 2, 343, 10, 1, '[[regtime]]', '[[regtime]]'),
(345, 14, 17, 3, 343, 20, 1, '[[regtime]]', '[[regtime]]'),
(346, 14, 17, 4, 343, 30, 1, '[[regtime]]', '[[regtime]]'),
(347, 14, 25, 0, 343, 40, 1, '[[regtime]]', '[[regtime]]'),
(348, 14, 11, 0, 343, 50, 1, '[[regtime]]', '[[regtime]]'),
(349, 14, 17, 1, 343, 60, 1, '[[regtime]]', '[[regtime]]'),
(350, 14, 24, 0, 343, 70, 1, '[[regtime]]', '[[regtime]]'),
(351, 14, 21, 0, 343, 80, 1, '[[regtime]]', '[[regtime]]'),
(352, 15, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(353, 15, 15, 0, 352, 10, 1, '[[regtime]]', '[[regtime]]'),
(354, 15, 31, 0, 352, 20, 1, '[[regtime]]', '[[regtime]]'),
(355, 15, 27, 0, 352, 30, 1, '[[regtime]]', '[[regtime]]'),
(356, 15, 26, 0, 352, 40, 1, '[[regtime]]', '[[regtime]]'),
(357, 15, 13, 0, 352, 50, 1, '[[regtime]]', '[[regtime]]'),
(358, 15, 14, 0, 352, 60, 1, '[[regtime]]', '[[regtime]]'),
(359, 15, 17, 1, 352, 70, 1, '[[regtime]]', '[[regtime]]'),
(360, 15, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(361, 15, 9, 0, 360, 10, 1, '[[regtime]]', '[[regtime]]'),
(362, 15, 28, 0, 360, 20, 1, '[[regtime]]', '[[regtime]]'),
(363, 15, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(364, 15, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(365, 15, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(366, 15, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(367, 15, 29, 0, 366, 10, 1, '[[regtime]]', '[[regtime]]'),
(368, 15, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(369, 15, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(370, 15, 17, 2, 369, 10, 1, '[[regtime]]', '[[regtime]]'),
(371, 15, 17, 3, 369, 20, 1, '[[regtime]]', '[[regtime]]'),
(372, 15, 17, 4, 369, 30, 1, '[[regtime]]', '[[regtime]]'),
(373, 15, 25, 0, 369, 40, 1, '[[regtime]]', '[[regtime]]'),
(374, 15, 11, 0, 369, 50, 1, '[[regtime]]', '[[regtime]]'),
(375, 15, 17, 1, 369, 60, 1, '[[regtime]]', '[[regtime]]'),
(376, 15, 24, 0, 369, 70, 1, '[[regtime]]', '[[regtime]]'),
(377, 15, 21, 0, 369, 80, 1, '[[regtime]]', '[[regtime]]'),
(378, 16, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(379, 16, 15, 0, 378, 10, 1, '[[regtime]]', '[[regtime]]'),
(380, 16, 31, 0, 378, 20, 1, '[[regtime]]', '[[regtime]]'),
(381, 16, 27, 0, 378, 30, 1, '[[regtime]]', '[[regtime]]'),
(382, 16, 26, 0, 378, 40, 1, '[[regtime]]', '[[regtime]]'),
(383, 16, 13, 0, 378, 50, 1, '[[regtime]]', '[[regtime]]'),
(384, 16, 14, 0, 378, 60, 1, '[[regtime]]', '[[regtime]]'),
(385, 16, 17, 1, 378, 70, 1, '[[regtime]]', '[[regtime]]'),
(386, 16, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(387, 16, 9, 0, 386, 10, 1, '[[regtime]]', '[[regtime]]'),
(388, 16, 28, 0, 386, 20, 1, '[[regtime]]', '[[regtime]]'),
(389, 16, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(390, 16, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(391, 16, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(392, 16, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(393, 16, 29, 0, 392, 10, 1, '[[regtime]]', '[[regtime]]'),
(394, 16, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(395, 16, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(396, 16, 17, 2, 395, 10, 1, '[[regtime]]', '[[regtime]]'),
(397, 16, 17, 3, 395, 20, 1, '[[regtime]]', '[[regtime]]'),
(398, 16, 17, 4, 395, 30, 1, '[[regtime]]', '[[regtime]]'),
(399, 16, 25, 0, 395, 40, 1, '[[regtime]]', '[[regtime]]'),
(400, 16, 11, 0, 395, 50, 1, '[[regtime]]', '[[regtime]]'),
(401, 16, 17, 1, 395, 60, 1, '[[regtime]]', '[[regtime]]'),
(402, 16, 24, 0, 395, 70, 1, '[[regtime]]', '[[regtime]]'),
(403, 16, 21, 0, 395, 80, 1, '[[regtime]]', '[[regtime]]'),
(404, 17, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(405, 17, 15, 0, 404, 10, 1, '[[regtime]]', '[[regtime]]'),
(406, 17, 31, 0, 404, 20, 1, '[[regtime]]', '[[regtime]]'),
(407, 17, 27, 0, 404, 30, 1, '[[regtime]]', '[[regtime]]'),
(408, 17, 26, 0, 404, 40, 1, '[[regtime]]', '[[regtime]]'),
(409, 17, 13, 0, 404, 50, 1, '[[regtime]]', '[[regtime]]'),
(410, 17, 14, 0, 404, 60, 1, '[[regtime]]', '[[regtime]]'),
(411, 17, 17, 1, 404, 70, 1, '[[regtime]]', '[[regtime]]'),
(412, 17, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(413, 17, 9, 0, 412, 10, 1, '[[regtime]]', '[[regtime]]'),
(414, 17, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(415, 17, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(416, 17, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(417, 17, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(418, 17, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(419, 17, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(420, 17, 11, 0, 419, 50, 1, '[[regtime]]', '[[regtime]]'),
(421, 17, 24, 0, 419, 70, 1, '[[regtime]]', '[[regtime]]'),
(422, 17, 21, 0, 419, 80, 1, '[[regtime]]', '[[regtime]]'),
(423, 18, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(424, 18, 32, 0, 423, 40, 1, '[[regtime]]', '[[regtime]]'),
(425, 18, 2, 0, 0, 20, 0, '[[regtime]]', '[[regtime]]'),
(426, 18, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(427, 18, 4, 0, 0, 40, 0, '[[regtime]]', '[[regtime]]'),
(428, 18, 5, 0, 0, 50, 0, '[[regtime]]', '[[regtime]]'),
(429, 18, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(430, 18, 33, 0, 429, 10, 1, '[[regtime]]', '[[regtime]]'),
(431, 18, 7, 0, 0, 70, 0, '[[regtime]]', '[[regtime]]'),
(432, 18, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(433, 19, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(434, 19, 2, 0, 0, 20, 0, '[[regtime]]', '[[regtime]]'),
(435, 19, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(436, 19, 4, 0, 0, 40, 0, '[[regtime]]', '[[regtime]]'),
(437, 19, 5, 0, 0, 50, 0, '[[regtime]]', '[[regtime]]'),
(438, 19, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(439, 19, 7, 0, 0, 70, 0, '[[regtime]]', '[[regtime]]'),
(440, 19, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(441, 20, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(442, 20, 15, 0, 441, 10, 1, '[[regtime]]', '[[regtime]]'),
(443, 20, 31, 0, 441, 20, 1, '[[regtime]]', '[[regtime]]'),
(444, 20, 27, 0, 441, 30, 1, '[[regtime]]', '[[regtime]]'),
(445, 20, 26, 0, 441, 40, 1, '[[regtime]]', '[[regtime]]'),
(446, 20, 13, 0, 441, 50, 1, '[[regtime]]', '[[regtime]]'),
(447, 20, 14, 0, 441, 60, 1, '[[regtime]]', '[[regtime]]'),
(448, 20, 17, 1, 441, 70, 1, '[[regtime]]', '[[regtime]]'),
(449, 20, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(450, 20, 9, 0, 449, 10, 1, '[[regtime]]', '[[regtime]]'),
(451, 20, 28, 0, 449, 20, 1, '[[regtime]]', '[[regtime]]'),
(452, 20, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(453, 20, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(454, 20, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(455, 20, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(456, 20, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(457, 20, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(458, 20, 17, 2, 457, 10, 1, '[[regtime]]', '[[regtime]]'),
(459, 20, 17, 3, 457, 20, 1, '[[regtime]]', '[[regtime]]'),
(460, 20, 17, 4, 457, 30, 1, '[[regtime]]', '[[regtime]]'),
(461, 20, 25, 0, 457, 40, 1, '[[regtime]]', '[[regtime]]'),
(462, 20, 11, 0, 457, 50, 1, '[[regtime]]', '[[regtime]]'),
(463, 20, 17, 1, 457, 60, 1, '[[regtime]]', '[[regtime]]'),
(464, 20, 24, 0, 457, 70, 1, '[[regtime]]', '[[regtime]]'),
(465, 20, 21, 0, 457, 80, 1, '[[regtime]]', '[[regtime]]'),
(466, 21, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(467, 21, 26, 0, 466, 10, 1, '[[regtime]]', '[[regtime]]'),
(468, 21, 13, 0, 466, 20, 1, '[[regtime]]', '[[regtime]]'),
(469, 21, 14, 0, 466, 30, 1, '[[regtime]]', '[[regtime]]'),
(470, 21, 15, 0, 466, 40, 1, '[[regtime]]', '[[regtime]]'),
(471, 21, 31, 0, 466, 50, 1, '[[regtime]]', '[[regtime]]'),
(472, 21, 38, 0, 466, 60, 1, '[[regtime]]', '[[regtime]]'),
(473, 21, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(474, 21, 38, 0, 473, 10, 1, '[[regtime]]', '[[regtime]]'),
(475, 21, 28, 0, 473, 20, 1, '[[regtime]]', '[[regtime]]'),
(476, 21, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(477, 21, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(478, 21, 11, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(479, 21, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(480, 21, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(481, 21, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(482, 21, 25, 0, 481, 10, 1, '[[regtime]]', '[[regtime]]'),
(483, 21, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(484, 21, 17, 9, 483, 10, 1, '[[regtime]]', '[[regtime]]'),
(485, 21, 17, 10, 483, 20, 1, '[[regtime]]', '[[regtime]]'),
(486, 21, 17, 11, 483, 30, 1, '[[regtime]]', '[[regtime]]'),
(487, 21, 11, 0, 483, 40, 1, '[[regtime]]', '[[regtime]]'),
(488, 22, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(489, 22, 26, 0, 488, 10, 1, '[[regtime]]', '[[regtime]]'),
(490, 22, 13, 0, 488, 20, 1, '[[regtime]]', '[[regtime]]'),
(491, 22, 14, 0, 488, 30, 1, '[[regtime]]', '[[regtime]]'),
(492, 22, 15, 0, 488, 40, 1, '[[regtime]]', '[[regtime]]'),
(493, 22, 31, 0, 488, 50, 1, '[[regtime]]', '[[regtime]]'),
(494, 22, 38, 0, 488, 60, 1, '[[regtime]]', '[[regtime]]'),
(495, 22, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(496, 22, 38, 0, 495, 10, 1, '[[regtime]]', '[[regtime]]'),
(497, 22, 17, 12, 495, 20, 1, '[[regtime]]', '[[regtime]]'),
(498, 22, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(499, 22, 4, 0, 0, 40, 0, '[[regtime]]', '[[regtime]]'),
(500, 22, 11, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(501, 22, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(502, 22, 17, 13, 501, 10, 1, '[[regtime]]', '[[regtime]]'),
(503, 22, 12, 0, 501, 20, 1, '[[regtime]]', '[[regtime]]'),
(504, 22, 19, 0, 501, 30, 1, '[[regtime]]', '[[regtime]]'),
(505, 22, 17, 14, 501, 40, 1, '[[regtime]]', '[[regtime]]'),
(506, 22, 18, 0, 501, 50, 1, '[[regtime]]', '[[regtime]]'),
(507, 22, 22, 0, 501, 60, 1, '[[regtime]]', '[[regtime]]'),
(508, 22, 17, 15, 501, 70, 1, '[[regtime]]', '[[regtime]]'),
(509, 22, 17, 16, 501, 80, 1, '[[regtime]]', '[[regtime]]'),
(510, 22, 20, 17, 501, 90, 1, '[[regtime]]', '[[regtime]]'),
(511, 22, 17, 18, 501, 100, 1, '[[regtime]]', '[[regtime]]'),
(512, 22, 6, 0, 0, 60, 0, '[[regtime]]', '[[regtime]]'),
(513, 22, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(514, 22, 25, 0, 513, 10, 1, '[[regtime]]', '[[regtime]]'),
(515, 22, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(516, 22, 17, 9, 515, 10, 1, '[[regtime]]', '[[regtime]]'),
(517, 22, 17, 10, 515, 20, 1, '[[regtime]]', '[[regtime]]'),
(518, 22, 17, 11, 515, 30, 1, '[[regtime]]', '[[regtime]]'),
(519, 22, 11, 0, 515, 40, 1, '[[regtime]]', '[[regtime]]'),
(520, 23, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(521, 23, 26, 0, 520, 10, 1, '[[regtime]]', '[[regtime]]'),
(522, 23, 13, 0, 520, 20, 1, '[[regtime]]', '[[regtime]]'),
(523, 23, 14, 0, 520, 30, 1, '[[regtime]]', '[[regtime]]'),
(524, 23, 15, 0, 520, 40, 1, '[[regtime]]', '[[regtime]]'),
(525, 23, 31, 0, 520, 50, 1, '[[regtime]]', '[[regtime]]'),
(526, 23, 38, 0, 520, 60, 1, '[[regtime]]', '[[regtime]]'),
(527, 23, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(528, 23, 38, 0, 527, 10, 1, '[[regtime]]', '[[regtime]]'),
(529, 23, 28, 0, 527, 20, 1, '[[regtime]]', '[[regtime]]'),
(530, 23, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(531, 23, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(532, 23, 11, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(533, 23, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(534, 23, 6, 0, 0, 60, 0, '[[regtime]]', '[[regtime]]'),
(535, 23, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(536, 23, 25, 0, 535, 10, 1, '[[regtime]]', '[[regtime]]'),
(537, 23, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(538, 23, 17, 9, 537, 10, 1, '[[regtime]]', '[[regtime]]'),
(539, 23, 17, 10, 537, 20, 1, '[[regtime]]', '[[regtime]]'),
(540, 23, 17, 11, 537, 30, 1, '[[regtime]]', '[[regtime]]'),
(541, 23, 11, 0, 537, 40, 1, '[[regtime]]', '[[regtime]]'),
(542, 24, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(543, 24, 26, 0, 542, 10, 1, '[[regtime]]', '[[regtime]]'),
(544, 24, 13, 0, 542, 20, 1, '[[regtime]]', '[[regtime]]'),
(545, 24, 14, 0, 542, 30, 1, '[[regtime]]', '[[regtime]]'),
(546, 24, 15, 0, 542, 40, 1, '[[regtime]]', '[[regtime]]'),
(547, 24, 31, 0, 542, 50, 1, '[[regtime]]', '[[regtime]]'),
(548, 24, 38, 0, 542, 60, 1, '[[regtime]]', '[[regtime]]'),
(549, 24, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(550, 24, 38, 0, 549, 10, 1, '[[regtime]]', '[[regtime]]'),
(551, 24, 28, 0, 549, 20, 1, '[[regtime]]', '[[regtime]]'),
(552, 24, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(553, 24, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(554, 24, 11, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(555, 24, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(556, 24, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(557, 24, 37, 0, 556, 10, 1, '[[regtime]]', '[[regtime]]'),
(558, 24, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(559, 24, 25, 0, 558, 10, 1, '[[regtime]]', '[[regtime]]'),
(560, 24, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(561, 24, 17, 9, 560, 10, 1, '[[regtime]]', '[[regtime]]'),
(562, 24, 17, 10, 560, 20, 1, '[[regtime]]', '[[regtime]]'),
(563, 24, 17, 11, 560, 30, 1, '[[regtime]]', '[[regtime]]'),
(564, 24, 11, 0, 560, 40, 1, '[[regtime]]', '[[regtime]]'),
(565, 25, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(566, 25, 26, 0, 565, 10, 1, '[[regtime]]', '[[regtime]]'),
(567, 25, 13, 0, 565, 20, 1, '[[regtime]]', '[[regtime]]'),
(568, 25, 14, 0, 565, 30, 1, '[[regtime]]', '[[regtime]]'),
(569, 25, 15, 0, 565, 40, 1, '[[regtime]]', '[[regtime]]'),
(570, 25, 31, 0, 565, 50, 1, '[[regtime]]', '[[regtime]]'),
(571, 25, 38, 0, 565, 60, 1, '[[regtime]]', '[[regtime]]'),
(572, 25, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(573, 25, 38, 0, 572, 10, 1, '[[regtime]]', '[[regtime]]'),
(574, 25, 28, 0, 572, 20, 1, '[[regtime]]', '[[regtime]]'),
(575, 25, 3, 0, 0, 30, 1, '[[regtime]]', '[[regtime]]'),
(576, 25, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(577, 25, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(578, 25, 34, 0, 577, 10, 1, '[[regtime]]', '[[regtime]]'),
(579, 25, 6, 0, 0, 60, 0, '[[regtime]]', '[[regtime]]'),
(580, 25, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(581, 25, 25, 0, 580, 10, 1, '[[regtime]]', '[[regtime]]'),
(582, 25, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(583, 25, 17, 9, 582, 10, 1, '[[regtime]]', '[[regtime]]'),
(584, 25, 17, 10, 582, 20, 1, '[[regtime]]', '[[regtime]]'),
(585, 25, 17, 11, 582, 30, 1, '[[regtime]]', '[[regtime]]'),
(586, 25, 11, 0, 582, 40, 1, '[[regtime]]', '[[regtime]]'),
(587, 26, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(588, 26, 26, 0, 587, 10, 1, '[[regtime]]', '[[regtime]]'),
(589, 26, 13, 0, 587, 20, 1, '[[regtime]]', '[[regtime]]'),
(590, 26, 14, 0, 587, 30, 1, '[[regtime]]', '[[regtime]]'),
(591, 26, 15, 0, 587, 40, 1, '[[regtime]]', '[[regtime]]'),
(592, 26, 31, 0, 587, 50, 1, '[[regtime]]', '[[regtime]]'),
(593, 26, 38, 0, 587, 60, 1, '[[regtime]]', '[[regtime]]'),
(594, 26, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(595, 26, 38, 0, 594, 10, 1, '[[regtime]]', '[[regtime]]'),
(596, 26, 39, 0, 594, 20, 1, '[[regtime]]', '[[regtime]]'),
(597, 26, 28, 0, 594, 30, 1, '[[regtime]]', '[[regtime]]'),
(598, 26, 3, 0, 0, 30, 1, '[[regtime]]', '[[regtime]]'),
(599, 26, 40, 0, 598, 10, 1, '[[regtime]]', '[[regtime]]'),
(600, 26, 17, 19, 598, 20, 1, '[[regtime]]', '[[regtime]]'),
(601, 26, 17, 20, 598, 30, 1, '[[regtime]]', '[[regtime]]'),
(602, 26, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(603, 26, 11, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(604, 26, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(605, 26, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(606, 26, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(607, 26, 25, 0, 606, 10, 1, '[[regtime]]', '[[regtime]]'),
(608, 26, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(609, 26, 17, 9, 608, 10, 1, '[[regtime]]', '[[regtime]]'),
(610, 26, 17, 10, 608, 20, 1, '[[regtime]]', '[[regtime]]'),
(611, 26, 17, 11, 608, 30, 1, '[[regtime]]', '[[regtime]]'),
(612, 26, 11, 0, 608, 40, 1, '[[regtime]]', '[[regtime]]'),
(613, 27, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(614, 27, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(615, 27, 3, 0, 0, 30, 1, '[[regtime]]', '[[regtime]]'),
(616, 27, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(617, 27, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(618, 27, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(619, 27, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(620, 27, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(621, 28, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(622, 28, 26, 0, 621, 10, 1, '[[regtime]]', '[[regtime]]'),
(623, 28, 13, 0, 621, 20, 1, '[[regtime]]', '[[regtime]]'),
(624, 28, 14, 0, 621, 30, 1, '[[regtime]]', '[[regtime]]'),
(625, 28, 15, 0, 621, 40, 1, '[[regtime]]', '[[regtime]]'),
(626, 28, 31, 0, 621, 50, 1, '[[regtime]]', '[[regtime]]'),
(627, 28, 38, 0, 621, 60, 1, '[[regtime]]', '[[regtime]]'),
(628, 28, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(629, 28, 38, 0, 628, 10, 1, '[[regtime]]', '[[regtime]]'),
(630, 28, 28, 0, 628, 20, 1, '[[regtime]]', '[[regtime]]'),
(631, 28, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(632, 28, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(633, 28, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(634, 28, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(635, 28, 29, 0, 634, 10, 1, '[[regtime]]', '[[regtime]]'),
(636, 28, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(637, 28, 25, 0, 636, 10, 1, '[[regtime]]', '[[regtime]]'),
(638, 28, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(639, 28, 17, 9, 638, 10, 1, '[[regtime]]', '[[regtime]]'),
(640, 28, 17, 10, 638, 20, 1, '[[regtime]]', '[[regtime]]'),
(641, 28, 17, 11, 638, 30, 1, '[[regtime]]', '[[regtime]]'),
(642, 28, 11, 0, 638, 40, 1, '[[regtime]]', '[[regtime]]'),
(643, 29, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(644, 29, 26, 0, 643, 10, 1, '[[regtime]]', '[[regtime]]'),
(645, 29, 13, 0, 643, 20, 1, '[[regtime]]', '[[regtime]]'),
(646, 29, 14, 0, 643, 30, 1, '[[regtime]]', '[[regtime]]'),
(647, 29, 15, 0, 643, 40, 1, '[[regtime]]', '[[regtime]]'),
(648, 29, 31, 0, 643, 50, 1, '[[regtime]]', '[[regtime]]'),
(649, 29, 38, 0, 643, 60, 1, '[[regtime]]', '[[regtime]]'),
(650, 29, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(651, 29, 38, 0, 650, 10, 1, '[[regtime]]', '[[regtime]]'),
(652, 29, 28, 0, 650, 20, 1, '[[regtime]]', '[[regtime]]'),
(653, 29, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(654, 29, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(655, 29, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(656, 29, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(657, 29, 29, 0, 656, 10, 1, '[[regtime]]', '[[regtime]]'),
(658, 29, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(659, 29, 25, 0, 658, 10, 1, '[[regtime]]', '[[regtime]]'),
(660, 29, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(661, 29, 17, 9, 660, 10, 1, '[[regtime]]', '[[regtime]]'),
(662, 29, 17, 10, 660, 20, 1, '[[regtime]]', '[[regtime]]'),
(663, 29, 17, 11, 660, 30, 1, '[[regtime]]', '[[regtime]]'),
(664, 29, 11, 0, 660, 40, 1, '[[regtime]]', '[[regtime]]'),
(665, 30, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(666, 30, 26, 0, 665, 10, 1, '[[regtime]]', '[[regtime]]'),
(667, 30, 13, 0, 665, 20, 1, '[[regtime]]', '[[regtime]]'),
(668, 30, 14, 0, 665, 30, 1, '[[regtime]]', '[[regtime]]'),
(669, 30, 15, 0, 665, 40, 1, '[[regtime]]', '[[regtime]]'),
(670, 30, 31, 0, 665, 50, 1, '[[regtime]]', '[[regtime]]'),
(671, 30, 38, 0, 665, 60, 1, '[[regtime]]', '[[regtime]]'),
(672, 30, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(673, 30, 38, 0, 672, 10, 1, '[[regtime]]', '[[regtime]]'),
(674, 30, 28, 0, 672, 20, 1, '[[regtime]]', '[[regtime]]'),
(675, 30, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(676, 30, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(677, 30, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(678, 30, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(679, 30, 29, 0, 678, 10, 1, '[[regtime]]', '[[regtime]]'),
(680, 30, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(681, 30, 25, 0, 680, 10, 1, '[[regtime]]', '[[regtime]]'),
(682, 30, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(683, 30, 17, 9, 682, 10, 1, '[[regtime]]', '[[regtime]]'),
(684, 30, 17, 10, 682, 20, 1, '[[regtime]]', '[[regtime]]'),
(685, 30, 17, 11, 682, 30, 1, '[[regtime]]', '[[regtime]]'),
(686, 30, 11, 0, 682, 40, 1, '[[regtime]]', '[[regtime]]'),
(687, 31, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(688, 31, 26, 0, 687, 10, 1, '[[regtime]]', '[[regtime]]'),
(689, 31, 13, 0, 687, 20, 1, '[[regtime]]', '[[regtime]]'),
(690, 31, 14, 0, 687, 30, 1, '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]block_layouts` VALUES
(691, 31, 15, 0, 687, 40, 1, '[[regtime]]', '[[regtime]]'),
(692, 31, 31, 0, 687, 50, 1, '[[regtime]]', '[[regtime]]'),
(693, 31, 38, 0, 687, 60, 1, '[[regtime]]', '[[regtime]]'),
(694, 31, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(695, 31, 38, 0, 694, 10, 1, '[[regtime]]', '[[regtime]]'),
(696, 31, 28, 0, 694, 20, 1, '[[regtime]]', '[[regtime]]'),
(697, 31, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(698, 31, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(699, 31, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(700, 31, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(701, 31, 29, 0, 700, 10, 1, '[[regtime]]', '[[regtime]]'),
(702, 31, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(703, 31, 25, 0, 702, 10, 1, '[[regtime]]', '[[regtime]]'),
(704, 31, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(705, 31, 17, 9, 704, 10, 1, '[[regtime]]', '[[regtime]]'),
(706, 31, 17, 10, 704, 20, 1, '[[regtime]]', '[[regtime]]'),
(707, 31, 17, 11, 704, 30, 1, '[[regtime]]', '[[regtime]]'),
(708, 31, 11, 0, 704, 40, 1, '[[regtime]]', '[[regtime]]'),
(709, 32, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(710, 32, 26, 0, 709, 10, 1, '[[regtime]]', '[[regtime]]'),
(711, 32, 13, 0, 709, 20, 1, '[[regtime]]', '[[regtime]]'),
(712, 32, 14, 0, 709, 30, 1, '[[regtime]]', '[[regtime]]'),
(713, 32, 15, 0, 709, 40, 1, '[[regtime]]', '[[regtime]]'),
(714, 32, 31, 0, 709, 50, 1, '[[regtime]]', '[[regtime]]'),
(715, 32, 38, 0, 709, 60, 1, '[[regtime]]', '[[regtime]]'),
(716, 32, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(717, 32, 38, 0, 716, 10, 1, '[[regtime]]', '[[regtime]]'),
(718, 32, 28, 0, 716, 20, 1, '[[regtime]]', '[[regtime]]'),
(719, 32, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(720, 32, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(721, 32, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(722, 32, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(723, 32, 29, 0, 722, 10, 1, '[[regtime]]', '[[regtime]]'),
(724, 32, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(725, 32, 25, 0, 724, 10, 1, '[[regtime]]', '[[regtime]]'),
(726, 32, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(727, 32, 17, 9, 726, 10, 1, '[[regtime]]', '[[regtime]]'),
(728, 32, 17, 10, 726, 20, 1, '[[regtime]]', '[[regtime]]'),
(729, 32, 17, 11, 726, 30, 1, '[[regtime]]', '[[regtime]]'),
(730, 32, 11, 0, 726, 40, 1, '[[regtime]]', '[[regtime]]'),
(731, 33, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(732, 33, 26, 0, 731, 10, 1, '[[regtime]]', '[[regtime]]'),
(733, 33, 13, 0, 731, 20, 1, '[[regtime]]', '[[regtime]]'),
(734, 33, 14, 0, 731, 30, 1, '[[regtime]]', '[[regtime]]'),
(735, 33, 15, 0, 731, 40, 1, '[[regtime]]', '[[regtime]]'),
(736, 33, 31, 0, 731, 50, 1, '[[regtime]]', '[[regtime]]'),
(737, 33, 38, 0, 731, 60, 1, '[[regtime]]', '[[regtime]]'),
(738, 33, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(739, 33, 38, 0, 738, 10, 1, '[[regtime]]', '[[regtime]]'),
(740, 33, 28, 0, 738, 20, 1, '[[regtime]]', '[[regtime]]'),
(741, 33, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(742, 33, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(743, 33, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(744, 33, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(745, 33, 29, 0, 744, 10, 1, '[[regtime]]', '[[regtime]]'),
(746, 33, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(747, 33, 25, 0, 746, 10, 1, '[[regtime]]', '[[regtime]]'),
(748, 33, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(749, 33, 17, 9, 748, 10, 1, '[[regtime]]', '[[regtime]]'),
(750, 33, 17, 10, 748, 20, 1, '[[regtime]]', '[[regtime]]'),
(751, 33, 17, 11, 748, 30, 1, '[[regtime]]', '[[regtime]]'),
(752, 33, 11, 0, 748, 40, 1, '[[regtime]]', '[[regtime]]'),
(753, 34, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(754, 34, 26, 0, 753, 10, 1, '[[regtime]]', '[[regtime]]'),
(755, 34, 13, 0, 753, 20, 1, '[[regtime]]', '[[regtime]]'),
(756, 34, 14, 0, 753, 30, 1, '[[regtime]]', '[[regtime]]'),
(757, 34, 15, 0, 753, 40, 1, '[[regtime]]', '[[regtime]]'),
(758, 34, 31, 0, 753, 50, 1, '[[regtime]]', '[[regtime]]'),
(759, 34, 38, 0, 753, 60, 1, '[[regtime]]', '[[regtime]]'),
(760, 34, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(761, 34, 38, 0, 760, 10, 1, '[[regtime]]', '[[regtime]]'),
(762, 34, 28, 0, 760, 20, 1, '[[regtime]]', '[[regtime]]'),
(763, 34, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(764, 34, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(765, 34, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(766, 34, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(767, 34, 29, 0, 766, 10, 1, '[[regtime]]', '[[regtime]]'),
(768, 34, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(769, 34, 25, 0, 768, 10, 1, '[[regtime]]', '[[regtime]]'),
(770, 34, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(771, 34, 17, 9, 770, 10, 1, '[[regtime]]', '[[regtime]]'),
(772, 34, 17, 10, 770, 20, 1, '[[regtime]]', '[[regtime]]'),
(773, 34, 17, 11, 770, 30, 1, '[[regtime]]', '[[regtime]]'),
(774, 34, 11, 0, 770, 40, 1, '[[regtime]]', '[[regtime]]'),
(775, 35, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(776, 35, 26, 0, 775, 10, 1, '[[regtime]]', '[[regtime]]'),
(777, 35, 13, 0, 775, 20, 1, '[[regtime]]', '[[regtime]]'),
(778, 35, 14, 0, 775, 30, 1, '[[regtime]]', '[[regtime]]'),
(779, 35, 15, 0, 775, 40, 1, '[[regtime]]', '[[regtime]]'),
(780, 35, 31, 0, 775, 50, 1, '[[regtime]]', '[[regtime]]'),
(781, 35, 38, 0, 775, 60, 1, '[[regtime]]', '[[regtime]]'),
(782, 35, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(783, 35, 38, 0, 782, 10, 1, '[[regtime]]', '[[regtime]]'),
(784, 35, 28, 0, 782, 20, 1, '[[regtime]]', '[[regtime]]'),
(785, 35, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(786, 35, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(787, 35, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(788, 35, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(789, 35, 29, 0, 788, 10, 1, '[[regtime]]', '[[regtime]]'),
(790, 35, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(791, 35, 25, 0, 790, 10, 1, '[[regtime]]', '[[regtime]]'),
(792, 35, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(793, 35, 17, 9, 792, 10, 1, '[[regtime]]', '[[regtime]]'),
(794, 35, 17, 10, 792, 20, 1, '[[regtime]]', '[[regtime]]'),
(795, 35, 17, 11, 792, 30, 1, '[[regtime]]', '[[regtime]]'),
(796, 35, 11, 0, 792, 40, 1, '[[regtime]]', '[[regtime]]'),
(797, 36, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(798, 36, 26, 0, 797, 10, 1, '[[regtime]]', '[[regtime]]'),
(799, 36, 13, 0, 797, 20, 1, '[[regtime]]', '[[regtime]]'),
(800, 36, 14, 0, 797, 30, 1, '[[regtime]]', '[[regtime]]'),
(801, 36, 15, 0, 797, 40, 1, '[[regtime]]', '[[regtime]]'),
(802, 36, 31, 0, 797, 50, 1, '[[regtime]]', '[[regtime]]'),
(803, 36, 38, 0, 797, 60, 1, '[[regtime]]', '[[regtime]]'),
(804, 36, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(805, 36, 38, 0, 804, 10, 1, '[[regtime]]', '[[regtime]]'),
(806, 36, 28, 0, 804, 20, 1, '[[regtime]]', '[[regtime]]'),
(807, 36, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(808, 36, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(809, 36, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(810, 36, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(811, 36, 29, 0, 810, 10, 1, '[[regtime]]', '[[regtime]]'),
(812, 36, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(813, 36, 25, 0, 812, 10, 1, '[[regtime]]', '[[regtime]]'),
(814, 36, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(815, 36, 17, 9, 814, 10, 1, '[[regtime]]', '[[regtime]]'),
(816, 36, 17, 10, 814, 20, 1, '[[regtime]]', '[[regtime]]'),
(817, 36, 17, 11, 814, 30, 1, '[[regtime]]', '[[regtime]]'),
(818, 36, 11, 0, 814, 40, 1, '[[regtime]]', '[[regtime]]'),
(819, 37, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(820, 37, 26, 0, 819, 10, 1, '[[regtime]]', '[[regtime]]'),
(821, 37, 13, 0, 819, 20, 1, '[[regtime]]', '[[regtime]]'),
(822, 37, 14, 0, 819, 30, 1, '[[regtime]]', '[[regtime]]'),
(823, 37, 15, 0, 819, 40, 1, '[[regtime]]', '[[regtime]]'),
(824, 37, 31, 0, 819, 50, 1, '[[regtime]]', '[[regtime]]'),
(825, 37, 38, 0, 819, 60, 1, '[[regtime]]', '[[regtime]]'),
(826, 37, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(827, 37, 38, 0, 826, 10, 1, '[[regtime]]', '[[regtime]]'),
(828, 37, 28, 0, 826, 20, 1, '[[regtime]]', '[[regtime]]'),
(829, 37, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(830, 37, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(831, 37, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(832, 37, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(833, 37, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(834, 37, 25, 0, 833, 10, 1, '[[regtime]]', '[[regtime]]'),
(835, 37, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(836, 37, 17, 9, 835, 10, 1, '[[regtime]]', '[[regtime]]'),
(837, 37, 17, 10, 835, 20, 1, '[[regtime]]', '[[regtime]]'),
(838, 37, 17, 11, 835, 30, 1, '[[regtime]]', '[[regtime]]'),
(839, 37, 11, 0, 835, 40, 1, '[[regtime]]', '[[regtime]]'),
(840, 38, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(841, 38, 32, 0, 840, 40, 1, '[[regtime]]', '[[regtime]]'),
(842, 38, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(843, 38, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(844, 38, 4, 0, 0, 40, 0, '[[regtime]]', '[[regtime]]'),
(845, 38, 5, 0, 0, 50, 0, '[[regtime]]', '[[regtime]]'),
(846, 38, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(847, 38, 33, 0, 846, 10, 1, '[[regtime]]', '[[regtime]]'),
(848, 38, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(849, 38, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(850, 39, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(851, 39, 26, 0, 850, 10, 1, '[[regtime]]', '[[regtime]]'),
(852, 39, 13, 0, 850, 20, 1, '[[regtime]]', '[[regtime]]'),
(853, 39, 14, 0, 850, 30, 1, '[[regtime]]', '[[regtime]]'),
(854, 39, 15, 0, 850, 40, 1, '[[regtime]]', '[[regtime]]'),
(855, 39, 31, 0, 850, 50, 1, '[[regtime]]', '[[regtime]]'),
(856, 39, 38, 0, 850, 60, 1, '[[regtime]]', '[[regtime]]'),
(857, 39, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(858, 39, 38, 0, 857, 10, 1, '[[regtime]]', '[[regtime]]'),
(859, 39, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(860, 39, 4, 0, 0, 40, 0, '[[regtime]]', '[[regtime]]'),
(861, 39, 5, 0, 0, 50, 0, '[[regtime]]', '[[regtime]]'),
(862, 39, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(863, 39, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(864, 39, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(865, 40, 1, 0, 0, 10, 1, '[[regtime]]', '[[regtime]]'),
(866, 40, 26, 0, 865, 10, 1, '[[regtime]]', '[[regtime]]'),
(867, 40, 13, 0, 865, 20, 1, '[[regtime]]', '[[regtime]]'),
(868, 40, 14, 0, 865, 30, 1, '[[regtime]]', '[[regtime]]'),
(869, 40, 15, 0, 865, 40, 1, '[[regtime]]', '[[regtime]]'),
(870, 40, 31, 0, 865, 50, 1, '[[regtime]]', '[[regtime]]'),
(871, 40, 38, 0, 865, 60, 1, '[[regtime]]', '[[regtime]]'),
(872, 40, 2, 0, 0, 20, 1, '[[regtime]]', '[[regtime]]'),
(873, 40, 38, 0, 872, 10, 1, '[[regtime]]', '[[regtime]]'),
(874, 40, 28, 0, 872, 20, 1, '[[regtime]]', '[[regtime]]'),
(875, 40, 3, 0, 0, 30, 0, '[[regtime]]', '[[regtime]]'),
(876, 40, 4, 0, 0, 40, 1, '[[regtime]]', '[[regtime]]'),
(877, 40, 11, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(878, 40, 5, 0, 0, 50, 1, '[[regtime]]', '[[regtime]]'),
(879, 40, 6, 0, 0, 60, 1, '[[regtime]]', '[[regtime]]'),
(880, 40, 7, 0, 0, 70, 1, '[[regtime]]', '[[regtime]]'),
(881, 40, 25, 0, 880, 10, 1, '[[regtime]]', '[[regtime]]'),
(882, 40, 8, 0, 0, 80, 1, '[[regtime]]', '[[regtime]]'),
(883, 40, 17, 9, 882, 10, 1, '[[regtime]]', '[[regtime]]'),
(884, 40, 17, 10, 882, 20, 1, '[[regtime]]', '[[regtime]]'),
(885, 40, 17, 11, 882, 30, 1, '[[regtime]]', '[[regtime]]'),
(886, 40, 11, 0, 882, 40, 1, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]block_templates`
--

CREATE TABLE `[[dbprefix]]block_templates` (
  `block_id` int NOT NULL AUTO_INCREMENT,
  `parent_block_id` int NOT NULL DEFAULT '0',
  `template` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`block_id`,`parent_block_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=41 ;

--
-- Dumping data for table `[[dbprefix]]block_templates`
--

INSERT INTO `[[dbprefix]]block_templates` VALUES
(9, 1, 'blocks/category_top.tpl', '[[regtime]]', '[[regtime]]'),
(9, 2, 'blocks/category_top.tpl', '[[regtime]]', '[[regtime]]'),
(9, 3, 'blocks/category.tpl', '[[regtime]]', '[[regtime]]'),
(9, 6, 'blocks/category.tpl', '[[regtime]]', '[[regtime]]'),
(9, 7, 'blocks/category_bottom.tpl', '[[regtime]]', '[[regtime]]'),
(9, 8, 'blocks/category_bottom.tpl', '[[regtime]]', '[[regtime]]'),
(10, 3, 'blocks/manufacturer.tpl', '[[regtime]]', '[[regtime]]'),
(10, 6, 'blocks/manufacturer.tpl', '[[regtime]]', '[[regtime]]'),
(11, 1, 'blocks/content_header.tpl', '[[regtime]]', '[[regtime]]'),
(11, 3, 'blocks/content.tpl', '[[regtime]]', '[[regtime]]'),
(11, 6, 'blocks/content.tpl', '[[regtime]]', '[[regtime]]'),
(11, 8, 'blocks/content_footer.tpl', '[[regtime]]', '[[regtime]]'),
(12, 3, 'blocks/latest.tpl', '[[regtime]]', '[[regtime]]'),
(12, 4, 'blocks/latest_home.tpl', '[[regtime]]', '[[regtime]]'),
(12, 5, 'blocks/latest_home.tpl', '[[regtime]]', '[[regtime]]'),
(12, 6, 'blocks/latest.tpl', '[[regtime]]', '[[regtime]]'),
(13, 1, 'blocks/language.tpl', '[[regtime]]', '[[regtime]]'),
(14, 1, 'blocks/currency.tpl', '[[regtime]]', '[[regtime]]'),
(15, 1, 'blocks/cart_top.tpl', '[[regtime]]', '[[regtime]]'),
(15, 6, 'blocks/cart.tpl', '[[regtime]]', '[[regtime]]'),
(16, 6, 'blocks/order_summary.tpl', '[[regtime]]', '[[regtime]]'),
(17, 1, 'blocks/html_block_header.tpl', '[[regtime]]', '[[regtime]]'),
(17, 2, 'blocks/html_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(17, 3, 'blocks/html_block.tpl', '[[regtime]]', '[[regtime]]'),
(17, 4, 'blocks/html_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(17, 5, 'blocks/html_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(17, 6, 'blocks/html_block.tpl', '[[regtime]]', '[[regtime]]'),
(17, 7, 'blocks/html_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(17, 8, 'blocks/html_block_footer.tpl', '[[regtime]]', '[[regtime]]'),
(18, 3, 'blocks/bestseller.tpl', '[[regtime]]', '[[regtime]]'),
(18, 5, 'blocks/bestseller_home.tpl', '[[regtime]]', '[[regtime]]'),
(18, 6, 'blocks/bestseller.tpl', '[[regtime]]', '[[regtime]]'),
(19, 3, 'blocks/featured.tpl', '[[regtime]]', '[[regtime]]'),
(19, 5, 'blocks/featured_home.tpl', '[[regtime]]', '[[regtime]]'),
(19, 6, 'blocks/featured.tpl', '[[regtime]]', '[[regtime]]'),
(20, 1, 'blocks/listing_block_header.tpl', '[[regtime]]', '[[regtime]]'),
(20, 2, 'blocks/listing_block_header_bottom.tpl', '[[regtime]]', '[[regtime]]'),
(20, 3, 'blocks/listing_block_column_left.tpl', '[[regtime]]', '[[regtime]]'),
(20, 4, 'blocks/listing_block_content_top.tpl', '[[regtime]]', '[[regtime]]'),
(20, 5, 'blocks/listing_block_content_bottom.tpl', '[[regtime]]', '[[regtime]]'),
(20, 6, 'blocks/listing_block_column_right.tpl', '[[regtime]]', '[[regtime]]'),
(20, 7, 'blocks/listing_block_footer_top.tpl', '[[regtime]]', '[[regtime]]'),
(20, 8, 'blocks/listing_block_footer.tpl', '[[regtime]]', '[[regtime]]'),
(21, 8, 'blocks/donate.tpl', '[[regtime]]', '[[regtime]]'),
(22, 3, 'blocks/special.tpl', '[[regtime]]', '[[regtime]]'),
(22, 5, 'blocks/special_home.tpl', '[[regtime]]', '[[regtime]]'),
(22, 6, 'blocks/special.tpl', '[[regtime]]', '[[regtime]]'),
(23, 1, 'blocks/banner_block_header.tpl', '[[regtime]]', '[[regtime]]'),
(23, 2, 'blocks/banner_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(23, 3, 'blocks/banner_block.tpl', '[[regtime]]', '[[regtime]]'),
(23, 4, 'blocks/banner_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(23, 5, 'blocks/banner_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(23, 6, 'blocks/banner_block.tpl', '[[regtime]]', '[[regtime]]'),
(23, 7, 'blocks/banner_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(23, 8, 'blocks/banner_block_header.tpl', '[[regtime]]', '[[regtime]]'),
(24, 8, 'blocks/credit_cards.tpl', '[[regtime]]', '[[regtime]]'),
(25, 1, 'blocks/newsletter_signup_header.tpl', '[[regtime]]', '[[regtime]]'),
(25, 2, 'blocks/newsletter_signup_header_bottom.tpl', '[[regtime]]', '[[regtime]]'),
(25, 3, 'blocks/newsletter_signup_column_left.tpl', '[[regtime]]', '[[regtime]]'),
(25, 4, 'blocks/newsletter_signup_content_top.tpl', '[[regtime]]', '[[regtime]]'),
(25, 5, 'blocks/newsletter_signup_content_bottom.tpl', '[[regtime]]', '[[regtime]]'),
(25, 6, 'blocks/newsletter_signup_column_right.tpl', '[[regtime]]', '[[regtime]]'),
(25, 7, 'blocks/newsletter_signup_footer_top.tpl', '[[regtime]]', '[[regtime]]'),
(25, 8, 'blocks/newsletter_signup_footer.tpl', '[[regtime]]', '[[regtime]]'),
(26, 1, 'blocks/search_top.tpl', '[[regtime]]', '[[regtime]]'),
(26, 2, 'blocks/search_top.tpl', '[[regtime]]', '[[regtime]]'),
(26, 3, 'blocks/search.tpl', '[[regtime]]', '[[regtime]]'),
(26, 6, 'blocks/search.tpl', '[[regtime]]', '[[regtime]]'),
(27, 1, 'blocks/menu_top.tpl', '[[regtime]]', '[[regtime]]'),
(27, 2, 'blocks/menu.tpl', '[[regtime]]', '[[regtime]]'),
(27, 3, 'blocks/menu.tpl', '[[regtime]]', '[[regtime]]'),
(27, 6, 'blocks/menu.tpl', '[[regtime]]', '[[regtime]]'),
(27, 8, 'blocks/menu_bottom.tpl', '[[regtime]]', '[[regtime]]'),
(28, 2, 'blocks/breadcrumbs.tpl', '[[regtime]]', '[[regtime]]'),
(29, 3, 'blocks/account.tpl', '[[regtime]]', '[[regtime]]'),
(29, 6, 'blocks/account.tpl', '[[regtime]]', '[[regtime]]'),
(30, 1, 'blocks/custom_form_block_header.tpl', '[[regtime]]', '[[regtime]]'),
(30, 2, 'blocks/custom_form_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(30, 3, 'blocks/custom_form_block.tpl', '[[regtime]]', '[[regtime]]'),
(30, 4, 'blocks/custom_form_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(30, 5, 'blocks/custom_form_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(30, 6, 'blocks/custom_form_block.tpl', '[[regtime]]', '[[regtime]]'),
(30, 7, 'blocks/custom_form_block_content.tpl', '[[regtime]]', '[[regtime]]'),
(30, 8, 'blocks/custom_form_block_header.tpl', '[[regtime]]', '[[regtime]]'),
(31, 1, 'blocks/customer.tpl', '[[regtime]]', '[[regtime]]'),
(32, 1, 'blocks/fast_checkout_cart_btn.tpl', '[[regtime]]', '[[regtime]]'),
(33, 6, 'blocks/fast_checkout_summary.tpl', '[[regtime]]', '[[regtime]]'),
(34, 1, 'blocks/viewed_block_column_header.tpl', '[[regtime]]', '[[regtime]]'),
(34, 2, 'blocks/viewed_block_column_header_bottom.tpl', '[[regtime]]', '[[regtime]]'),
(34, 3, 'blocks/viewed_block_column_left.tpl', '[[regtime]]', '[[regtime]]'),
(34, 4, 'blocks/viewed_block_column_content_top.tpl', '[[regtime]]', '[[regtime]]'),
(34, 5, 'blocks/viewed_block_column_footer_top.tpl', '[[regtime]]', '[[regtime]]'),
(34, 6, 'blocks/viewed_block_column_right.tpl', '[[regtime]]', '[[regtime]]'),
(34, 7, 'blocks/viewed_block_column_footer_top.tpl', '[[regtime]]', '[[regtime]]'),
(34, 8, 'blocks/viewed_block_column_footer.tpl', '[[regtime]]', '[[regtime]]'),
(35, 3, 'blocks/new_content.tpl', '[[regtime]]', '[[regtime]]'),
(35, 6, 'blocks/new_content.tpl', '[[regtime]]', '[[regtime]]'),
(36, 1, 'blocks/content_search.tpl', '[[regtime]]', '[[regtime]]'),
(36, 2, 'blocks/content_search.tpl', '[[regtime]]', '[[regtime]]'),
(36, 3, 'blocks/content_search.tpl', '[[regtime]]', '[[regtime]]'),
(36, 4, 'blocks/content_search.tpl', '[[regtime]]', '[[regtime]]'),
(36, 5, 'blocks/content_search.tpl', '[[regtime]]', '[[regtime]]'),
(36, 6, 'blocks/content_search.tpl', '[[regtime]]', '[[regtime]]'),
(37, 3, 'blocks/store_hours.tpl', '[[regtime]]', '[[regtime]]'),
(37, 6, 'blocks/store_hours.tpl', '[[regtime]]', '[[regtime]]'),
(38, 1, 'blocks/mega_menu_header.tpl', '[[regtime]]', '[[regtime]]'),
(38, 2, 'blocks/mega_menu_header_bottom.tpl', '[[regtime]]', '[[regtime]]'),
(39, 2, 'blocks/category_slides.tpl', '[[regtime]]', '[[regtime]]'),
(40, 3, 'blocks/category_filter.tpl', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]categories`
--

CREATE TABLE `[[dbprefix]]categories` (
  `category_id` int NOT NULL AUTO_INCREMENT,
  `parent_id` int NOT NULL DEFAULT '0',
  `sort_order` int NOT NULL DEFAULT '0',
  `status` int NOT NULL DEFAULT '1',
  `supplier_code` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `supplier_id` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`category_id`),
  UNIQUE KEY `[[dbprefix]]categories_supplier_idx` (`supplier_code`,`supplier_id`),
  KEY `[[dbprefix]]categories_idx` (`category_id`,`parent_id`,`status`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=71 ;

--
-- Dumping data for table `[[dbprefix]]categories`
--

INSERT INTO `[[dbprefix]]categories` VALUES
(36, 0, 1, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(37, 36, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(38, 36, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(39, 36, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(40, 36, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(41, 36, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(42, 36, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(43, 0, 2, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(44, 43, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(45, 43, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(46, 43, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(47, 43, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(48, 43, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(49, 0, 3, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(50, 49, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(51, 49, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(52, 0, 98, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(53, 52, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(54, 52, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(58, 0, 4, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(59, 58, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(60, 58, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(61, 58, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(62, 58, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(63, 58, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(64, 0, 99, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(65, 0, 100, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(66, 65, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(67, 65, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(68, 0, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(69, 68, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(70, 68, 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]categories_to_stores`
--

CREATE TABLE `[[dbprefix]]categories_to_stores` (
  `category_id` int NOT NULL,
  `store_id` int NOT NULL,
  PRIMARY KEY (`category_id`,`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]categories_to_stores`
--

INSERT INTO `[[dbprefix]]categories_to_stores` VALUES
(36, 0),
(37, 0),
(38, 0),
(39, 0),
(40, 0),
(41, 0),
(42, 0),
(43, 0),
(44, 0),
(45, 0),
(46, 0),
(47, 0),
(48, 0),
(49, 0),
(50, 0),
(51, 0),
(52, 0),
(53, 0),
(54, 0),
(58, 0),
(59, 0),
(60, 0),
(61, 0),
(62, 0),
(63, 0),
(64, 0),
(65, 0),
(66, 0),
(67, 0),
(68, 0),
(69, 0),
(70, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]category_descriptions`
--

CREATE TABLE `[[dbprefix]]category_descriptions` (
  `category_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  `meta_keywords` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `meta_description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `description` longtext COLLATE utf8mb4_unicode_ci COMMENT 'translatable',
  PRIMARY KEY (`category_id`,`language_id`),
  KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]category_descriptions`
--

INSERT INTO `[[dbprefix]]category_descriptions` VALUES
(36, 1, 'Makeup', 'Makeup', '', '&lt;p&gt;\r\n	All your makeup needs, from foundation to eye shadow in hundreds of different assortments and colors.&lt;/p&gt;\r\n'),
(37, 1, 'Value Sets', 'value sets makeup', '', ''),
(38, 1, 'Face', '', '', ''),
(39, 1, 'Eyes', '', '', ''),
(40, 1, 'Cheeks', '', '', ''),
(41, 1, 'Lips', '', '', ''),
(42, 1, 'Nails', '', '', ''),
(43, 1, 'Skincare', '', '', '&lt;p&gt;\r\n	Products from award-winning skin care brands&lt;/p&gt;\r\n'),
(44, 1, 'Sun', '', '', ''),
(45, 1, 'Gift Ideas &amp; Sets', '', '', ''),
(46, 1, 'Facial', '', '', '&lt;p&gt;\r\n	Find face skin care solutions&lt;/p&gt;\r\n'),
(47, 1, 'Eye Care', '', '', ''),
(48, 1, 'Hands &amp; Nails', '', '', '&lt;p&gt;\r\n	Keep your hands looking fresh&lt;/p&gt;\r\n'),
(49, 1, 'Fragrance', '', '', '&lt;p&gt;\r\n	Looking for a new scent? Check out our fragrance&lt;/p&gt;\r\n'),
(50, 1, 'Women', '', '', '&lt;p&gt;\r\n	Fragrance for Women&lt;/p&gt;\r\n'),
(51, 1, 'Men', '', '', ''),
(52, 1, 'Hair Care', '', '', '&lt;p&gt;\r\n	The widest range of premium hair products&lt;/p&gt;\r\n'),
(53, 1, 'Shampoo', '', '', ''),
(54, 1, 'Conditioner', '', '', ''),
(58, 1, 'Men', '', '', ''),
(59, 1, 'Fragrance Sets', '', '', ''),
(60, 1, 'Skincare', '', '', ''),
(61, 1, 'Pre-Shave &amp; Shaving', '', '', ''),
(62, 1, 'Post-Shave &amp; Moisturizers', '', '', ''),
(63, 1, 'Body &amp; Shower', '', '', ''),
(64, 1, 'Bath &amp; Body', '', '', ''),
(65, 1, 'Books', '', '', 'Find the Items You&amp;#39;d Like to read'),
(66, 1, 'Audio CD', '', '', ''),
(67, 1, 'Paperback', '', '', ''),
(68, 1, 'Apparel &amp; accessories', '', '', ''),
(69, 1, 'Shoes', '', '', ''),
(70, 1, 'T-shirts', '', '', 'Shop men&amp;#39;s T-shirts');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]collections`
--

CREATE TABLE `[[dbprefix]]collections` (
  `id` int NOT NULL AUTO_INCREMENT,
  `status` tinyint NOT NULL DEFAULT '0',
  `name` varchar(255) CHARACTER SET utf8mb3 COLLATE utf8mb3_bin DEFAULT NULL,
  `description` text CHARACTER SET utf8mb3 COLLATE utf8mb3_bin,
  `conditions` text CHARACTER SET utf8mb3 COLLATE utf8mb3_bin,
  `store_id` int NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]collection_descriptions`
--

CREATE TABLE `[[dbprefix]]collection_descriptions` (
  `id` int NOT NULL AUTO_INCREMENT,
  `collection_id` int NOT NULL,
  `language_id` int NOT NULL,
  `title` varchar(255) CHARACTER SET utf8mb3 COLLATE utf8mb3_bin DEFAULT NULL,
  `meta_keywords` text CHARACTER SET utf8mb3 COLLATE utf8mb3_bin,
  `meta_description` text CHARACTER SET utf8mb3 COLLATE utf8mb3_bin,
  PRIMARY KEY (`id`),
  UNIQUE KEY `collection_language_idx` (`collection_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]contents`
--

CREATE TABLE `[[dbprefix]]contents` (
  `content_id` int NOT NULL AUTO_INCREMENT,
  `parent_content_id` int NOT NULL DEFAULT '0',
  `sort_order` int NOT NULL DEFAULT '0',
  `status` int NOT NULL DEFAULT '0',
  `content_bar` int NOT NULL DEFAULT '0',
  `show_title` int DEFAULT '1',
  `author` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `icon_rl_id` int DEFAULT NULL,
  `publish_date` timestamp NULL DEFAULT NULL,
  `expire_date` timestamp NULL DEFAULT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`content_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=5 ;

--
-- Dumping data for table `[[dbprefix]]contents`
--

INSERT INTO `[[dbprefix]]contents` VALUES
(1, 0, 1, 1, 0, 1, '', NULL, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(2, 0, 2, 1, 0, 1, '', NULL, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(3, 0, 3, 1, 0, 1, '', NULL, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(4, 0, 4, 1, 0, 1, '', NULL, NULL, NULL, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]contents_to_stores`
--

CREATE TABLE `[[dbprefix]]contents_to_stores` (
  `content_id` int NOT NULL,
  `store_id` int NOT NULL,
  PRIMARY KEY (`content_id`,`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]contents_to_stores`
--

INSERT INTO `[[dbprefix]]contents_to_stores` VALUES
(1, 0),
(2, 0),
(3, 0),
(4, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]content_descriptions`
--

CREATE TABLE `[[dbprefix]]content_descriptions` (
  `content_id` int NOT NULL DEFAULT '0',
  `language_id` int NOT NULL,
  `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  `meta_keywords` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `meta_description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `content` longtext COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`content_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]content_descriptions`
--

INSERT INTO `[[dbprefix]]content_descriptions` VALUES
(1, 1, 'About Us', 'some description', '', '', 'text about your store', '[[regtime]]', '[[regtime]]'),
(2, 1, 'Privacy Policy', 'some description', '', '', 'some text about privacy policy', '[[regtime]]', '[[regtime]]'),
(3, 1, 'Return Policy', 'some description', '', '', 'some text about return policy', '[[regtime]]', '[[regtime]]'),
(4, 1, 'Shipping', 'some description', '', '', 'some text about shipping', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]content_tags`
--

CREATE TABLE `[[dbprefix]]content_tags` (
  `content_id` int NOT NULL,
  `tag` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `language_id` int NOT NULL,
  PRIMARY KEY (`content_id`,`tag`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]countries`
--

CREATE TABLE `[[dbprefix]]countries` (
  `country_id` int NOT NULL AUTO_INCREMENT,
  `iso_code_2` varchar(2) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `iso_code_3` varchar(3) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `address_format` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `status` int NOT NULL DEFAULT '1',
  `sort_order` int NOT NULL DEFAULT '0',
  PRIMARY KEY (`country_id`),
  KEY `[[dbprefix]]countries_idx` (`iso_code_2`,`iso_code_3`,`status`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=244 ;

--
-- Dumping data for table `[[dbprefix]]countries`
--

INSERT INTO `[[dbprefix]]countries` VALUES
(1, 'AF', 'AFG', '', 1, 0),
(2, 'AL', 'ALB', '', 1, 0),
(3, 'DZ', 'DZA', '', 1, 0),
(4, 'AS', 'ASM', '', 1, 0),
(5, 'AD', 'AND', '', 1, 0),
(6, 'AO', 'AGO', '', 1, 0),
(7, 'AI', 'AIA', '', 1, 0),
(8, 'AQ', 'ATA', '', 1, 0),
(9, 'AG', 'ATG', '', 1, 0),
(10, 'AR', 'ARG', '', 1, 0),
(11, 'AM', 'ARM', '', 1, 0),
(12, 'AW', 'ABW', '', 1, 0),
(13, 'AU', 'AUS', '', 1, 0),
(14, 'AT', 'AUT', '', 1, 0),
(15, 'AZ', 'AZE', '', 1, 0),
(16, 'BS', 'BHS', '', 1, 0),
(17, 'BH', 'BHR', '', 1, 0),
(18, 'BD', 'BGD', '', 1, 0),
(19, 'BB', 'BRB', '', 1, 0),
(20, 'BY', 'BLR', '', 1, 0),
(21, 'BE', 'BEL', '', 1, 0),
(22, 'BZ', 'BLZ', '', 1, 0),
(23, 'BJ', 'BEN', '', 1, 0),
(24, 'BM', 'BMU', '', 1, 0),
(25, 'BT', 'BTN', '', 1, 0),
(26, 'BO', 'BOL', '', 1, 0),
(27, 'BA', 'BIH', '', 1, 0),
(28, 'BW', 'BWA', '', 1, 0),
(29, 'BV', 'BVT', '', 1, 0),
(30, 'BR', 'BRA', '', 1, 0),
(31, 'IO', 'IOT', '', 1, 0),
(32, 'BN', 'BRN', '', 1, 0),
(33, 'BG', 'BGR', '', 1, 0),
(34, 'BF', 'BFA', '', 1, 0),
(35, 'BI', 'BDI', '', 1, 0),
(36, 'KH', 'KHM', '', 1, 0),
(37, 'CM', 'CMR', '', 1, 0),
(38, 'CA', 'CAN', '', 1, 0),
(39, 'CV', 'CPV', '', 1, 0),
(40, 'KY', 'CYM', '', 1, 0),
(41, 'CF', 'CAF', '', 1, 0),
(42, 'TD', 'TCD', '', 1, 0),
(43, 'CL', 'CHL', '', 1, 0),
(44, 'CN', 'CHN', '', 1, 0),
(45, 'CX', 'CXR', '', 1, 0),
(46, 'CC', 'CCK', '', 1, 0),
(47, 'CO', 'COL', '', 1, 0),
(48, 'KM', 'COM', '', 1, 0),
(49, 'CG', 'COG', '', 1, 0),
(50, 'CK', 'COK', '', 1, 0),
(51, 'CR', 'CRI', '', 1, 0),
(52, 'CI', 'CIV', '', 1, 0),
(53, 'HR', 'HRV', '', 1, 0),
(54, 'CU', 'CUB', '', 1, 0),
(55, 'CY', 'CYP', '', 1, 0),
(56, 'CZ', 'CZE', '', 1, 0),
(57, 'DK', 'DNK', '', 1, 0),
(58, 'DJ', 'DJI', '', 1, 0),
(59, 'DM', 'DMA', '', 1, 0),
(60, 'DO', 'DOM', '', 1, 0),
(61, 'TL', 'TLS', '', 1, 0),
(62, 'EC', 'ECU', '', 1, 0),
(63, 'EG', 'EGY', '', 1, 0),
(64, 'SV', 'SLV', '', 1, 0),
(65, 'GQ', 'GNQ', '', 1, 0),
(66, 'ER', 'ERI', '', 1, 0),
(67, 'EE', 'EST', '', 1, 0),
(68, 'ET', 'ETH', '', 1, 0),
(69, 'FK', 'FLK', '', 1, 0),
(70, 'FO', 'FRO', '', 1, 0),
(71, 'FJ', 'FJI', '', 1, 0),
(72, 'FI', 'FIN', '', 1, 0),
(73, 'FR', 'FRA', '', 1, 0),
(74, 'FX', 'FXX', '', 1, 0),
(75, 'GF', 'GUF', '', 1, 0),
(76, 'PF', 'PYF', '', 1, 0),
(77, 'TF', 'ATF', '', 1, 0),
(78, 'GA', 'GAB', '', 1, 0),
(79, 'GM', 'GMB', '', 1, 0),
(80, 'GE', 'GEO', '', 1, 0),
(81, 'DE', 'DEU', '', 1, 0),
(82, 'GH', 'GHA', '', 1, 0),
(83, 'GI', 'GIB', '', 1, 0),
(84, 'GR', 'GRC', '', 1, 0),
(85, 'GL', 'GRL', '', 1, 0),
(86, 'GD', 'GRD', '', 1, 0),
(87, 'GP', 'GLP', '', 1, 0),
(88, 'GU', 'GUM', '', 1, 0),
(89, 'GT', 'GTM', '', 1, 0),
(90, 'GN', 'GIN', '', 1, 0),
(91, 'GW', 'GNB', '', 1, 0),
(92, 'GY', 'GUY', '', 1, 0),
(93, 'HT', 'HTI', '', 1, 0),
(94, 'HM', 'HMD', '', 1, 0),
(95, 'HN', 'HND', '', 1, 0),
(96, 'HK', 'HKG', '', 1, 0),
(97, 'HU', 'HUN', '', 1, 0),
(98, 'IS', 'ISL', '', 1, 0),
(99, 'IN', 'IND', '', 1, 0),
(100, 'ID', 'IDN', '', 1, 0),
(101, 'IR', 'IRN', '', 1, 0),
(102, 'IQ', 'IRQ', '', 1, 0),
(103, 'IE', 'IRL', '', 1, 0),
(104, 'IL', 'ISR', '', 1, 0),
(105, 'IT', 'ITA', '', 1, 0),
(106, 'JM', 'JAM', '', 1, 0),
(107, 'JP', 'JPN', '', 1, 0),
(108, 'JO', 'JOR', '', 1, 0),
(109, 'KZ', 'KAZ', '', 1, 0),
(110, 'KE', 'KEN', '', 1, 0),
(111, 'KI', 'KIR', '', 1, 0),
(112, 'KP', 'PRK', '', 1, 0),
(113, 'KR', 'KOR', '', 1, 0),
(114, 'KW', 'KWT', '', 1, 0),
(115, 'KG', 'KGZ', '', 1, 0),
(116, 'LA', 'LAO', '', 1, 0),
(117, 'LV', 'LVA', '', 1, 0),
(118, 'LB', 'LBN', '', 1, 0),
(119, 'LS', 'LSO', '', 1, 0),
(120, 'LR', 'LBR', '', 1, 0),
(121, 'LY', 'LBY', '', 1, 0),
(122, 'LI', 'LIE', '', 1, 0),
(123, 'LT', 'LTU', '', 1, 0),
(124, 'LU', 'LUX', '', 1, 0),
(125, 'MO', 'MAC', '', 1, 0),
(126, 'MK', 'MKD', '', 1, 0),
(127, 'MG', 'MDG', '', 1, 0),
(128, 'MW', 'MWI', '', 1, 0),
(129, 'MY', 'MYS', '', 1, 0),
(130, 'MV', 'MDV', '', 1, 0),
(131, 'ML', 'MLI', '', 1, 0),
(132, 'MT', 'MLT', '', 1, 0),
(133, 'MH', 'MHL', '', 1, 0),
(134, 'MQ', 'MTQ', '', 1, 0),
(135, 'MR', 'MRT', '', 1, 0),
(136, 'MU', 'MUS', '', 1, 0),
(137, 'YT', 'MYT', '', 1, 0),
(138, 'MX', 'MEX', '', 1, 0),
(139, 'FM', 'FSM', '', 1, 0),
(140, 'MD', 'MDA', '', 1, 0),
(141, 'MC', 'MCO', '', 1, 0),
(142, 'MN', 'MNG', '', 1, 0),
(143, 'MS', 'MSR', '', 1, 0),
(144, 'MA', 'MAR', '', 1, 0),
(145, 'MZ', 'MOZ', '', 1, 0),
(146, 'MM', 'MMR', '', 1, 0),
(147, 'NA', 'NAM', '', 1, 0),
(148, 'NR', 'NRU', '', 1, 0),
(149, 'NP', 'NPL', '', 1, 0),
(150, 'NL', 'NLD', '', 1, 0),
(151, 'AN', 'ANT', '', 1, 0),
(152, 'NC', 'NCL', '', 1, 0),
(153, 'NZ', 'NZL', '', 1, 0),
(154, 'NI', 'NIC', '', 1, 0),
(155, 'NE', 'NER', '', 1, 0),
(156, 'NG', 'NGA', '', 1, 0),
(157, 'NU', 'NIU', '', 1, 0),
(158, 'NF', 'NFK', '', 1, 0),
(159, 'MP', 'MNP', '', 1, 0),
(160, 'NO', 'NOR', '', 1, 0),
(161, 'OM', 'OMN', '', 1, 0),
(162, 'PK', 'PAK', '', 1, 0),
(163, 'PW', 'PLW', '', 1, 0),
(164, 'PA', 'PAN', '', 1, 0),
(165, 'PG', 'PNG', '', 1, 0),
(166, 'PY', 'PRY', '', 1, 0),
(167, 'PE', 'PER', '', 1, 0),
(168, 'PH', 'PHL', '', 1, 0),
(169, 'PN', 'PCN', '', 1, 0),
(170, 'PL', 'POL', '', 1, 0),
(171, 'PT', 'PRT', '', 1, 0),
(172, 'PR', 'PRI', '', 1, 0),
(173, 'QA', 'QAT', '', 1, 0),
(174, 'RE', 'REU', '', 1, 0),
(175, 'RO', 'ROM', '', 1, 0),
(176, 'RU', 'RUS', '', 1, 0),
(177, 'RW', 'RWA', '', 1, 0),
(178, 'KN', 'KNA', '', 1, 0),
(179, 'LC', 'LCA', '', 1, 0),
(180, 'VC', 'VCT', '', 1, 0),
(181, 'WS', 'WSM', '', 1, 0),
(182, 'SM', 'SMR', '', 1, 0),
(183, 'ST', 'STP', '', 1, 0),
(184, 'SA', 'SAU', '', 1, 0),
(185, 'SN', 'SEN', '', 1, 0),
(186, 'SC', 'SYC', '', 1, 0),
(187, 'SL', 'SLE', '', 1, 0),
(188, 'SG', 'SGP', '', 1, 0),
(189, 'SK', 'SVK', '', 1, 0),
(190, 'SI', 'SVN', '', 1, 0),
(191, 'SB', 'SLB', '', 1, 0),
(192, 'SO', 'SOM', '', 1, 0),
(193, 'ZA', 'ZAF', '', 1, 0),
(194, 'GS', 'SGS', '', 1, 0),
(195, 'ES', 'ESP', '', 1, 0),
(196, 'LK', 'LKA', '', 1, 0),
(197, 'SH', 'SHN', '', 1, 0),
(198, 'PM', 'SPM', '', 1, 0),
(199, 'SD', 'SDN', '', 1, 0),
(200, 'SR', 'SUR', '', 1, 0),
(201, 'SJ', 'SJM', '', 1, 0),
(202, 'SZ', 'SWZ', '', 1, 0),
(203, 'SE', 'SWE', '', 1, 0),
(204, 'CH', 'CHE', '', 1, 0),
(205, 'SY', 'SYR', '', 1, 0),
(206, 'TW', 'TWN', '', 1, 0),
(207, 'TJ', 'TJK', '', 1, 0),
(208, 'TZ', 'TZA', '', 1, 0),
(209, 'TH', 'THA', '', 1, 0),
(210, 'TG', 'TGO', '', 1, 0),
(211, 'TK', 'TKL', '', 1, 0),
(212, 'TO', 'TON', '', 1, 0),
(213, 'TT', 'TTO', '', 1, 0),
(214, 'TN', 'TUN', '', 1, 0),
(215, 'TR', 'TUR', '', 1, 0),
(216, 'TM', 'TKM', '', 1, 0),
(217, 'TC', 'TCA', '', 1, 0),
(218, 'TV', 'TUV', '', 1, 0),
(219, 'UG', 'UGA', '', 1, 0),
(220, 'UA', 'UKR', '', 1, 0),
(221, 'AE', 'ARE', '', 1, 0),
(222, 'GB', 'GBR', '', 1, 0),
(223, 'US', 'USA', '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 1, 0),
(224, 'UM', 'UMI', '', 1, 0),
(225, 'UY', 'URY', '', 1, 0),
(226, 'UZ', 'UZB', '', 1, 0),
(227, 'VU', 'VUT', '', 1, 0),
(228, 'VA', 'VAT', '', 1, 0),
(229, 'VE', 'VEN', '', 1, 0),
(230, 'VN', 'VNM', '', 1, 0),
(231, 'VG', 'VGB', '', 1, 0),
(232, 'VI', 'VIR', '', 1, 0),
(233, 'WF', 'WLF', '', 1, 0),
(234, 'EH', 'ESH', '', 1, 0),
(235, 'YE', 'YEM', '', 1, 0),
(236, 'ME', 'MNE', '', 1, 0),
(237, 'CW', 'CUW', '', 1, 0),
(238, 'ZM', 'ZMB', '', 1, 0),
(239, 'ZW', 'ZWE', '', 1, 0),
(240, 'GB', 'NIR', '', 1, 0),
(241, 'RS', 'SRB', '', 1, 0),
(242, 'XK', 'XXK', '', 1, 0),
(243, 'SS', 'RSS', '', 1, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]country_descriptions`
--

CREATE TABLE `[[dbprefix]]country_descriptions` (
  `country_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`country_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]country_descriptions`
--

INSERT INTO `[[dbprefix]]country_descriptions` VALUES
(1, 1, 'Afghanistan'),
(2, 1, 'Albania'),
(3, 1, 'Algeria'),
(4, 1, 'American Samoa'),
(5, 1, 'Andorra'),
(6, 1, 'Angola'),
(7, 1, 'Anguilla'),
(8, 1, 'Antarctica'),
(9, 1, 'Antigua and Barbuda'),
(10, 1, 'Argentina'),
(11, 1, 'Armenia'),
(12, 1, 'Aruba'),
(13, 1, 'Australia'),
(14, 1, 'Austria'),
(15, 1, 'Azerbaijan'),
(16, 1, 'Bahamas'),
(17, 1, 'Bahrain'),
(18, 1, 'Bangladesh'),
(19, 1, 'Barbados'),
(20, 1, 'Belarus'),
(21, 1, 'Belgium'),
(22, 1, 'Belize'),
(23, 1, 'Benin'),
(24, 1, 'Bermuda'),
(25, 1, 'Bhutan'),
(26, 1, 'Bolivia'),
(27, 1, 'Bosnia and Herzegowina'),
(28, 1, 'Botswana'),
(29, 1, 'Bouvet Island'),
(30, 1, 'Brazil'),
(31, 1, 'British Indian Ocean Territory'),
(32, 1, 'Brunei Darussalam'),
(33, 1, 'Bulgaria'),
(34, 1, 'Burkina Faso'),
(35, 1, 'Burundi'),
(36, 1, 'Cambodia'),
(37, 1, 'Cameroon'),
(38, 1, 'Canada'),
(39, 1, 'Cabo Verde'),
(40, 1, 'Cayman Islands'),
(41, 1, 'Central African Republic'),
(42, 1, 'Chad'),
(43, 1, 'Chile'),
(44, 1, 'China'),
(45, 1, 'Christmas Island'),
(46, 1, 'Cocos (Keeling) Islands'),
(47, 1, 'Colombia'),
(48, 1, 'Comoros'),
(49, 1, 'Congo'),
(50, 1, 'Cook Islands'),
(51, 1, 'Costa Rica'),
(52, 1, 'Côte d''Ivoire'),
(53, 1, 'Croatia'),
(54, 1, 'Cuba'),
(55, 1, 'Cyprus'),
(56, 1, 'Czech Republic'),
(57, 1, 'Denmark'),
(58, 1, 'Djibouti'),
(59, 1, 'Dominica'),
(60, 1, 'Dominican Republic'),
(61, 1, 'Timor-Leste'),
(62, 1, 'Ecuador'),
(63, 1, 'Egypt'),
(64, 1, 'El Salvador'),
(65, 1, 'Equatorial Guinea'),
(66, 1, 'Eritrea'),
(67, 1, 'Estonia'),
(68, 1, 'Ethiopia'),
(69, 1, 'Falkland Islands (Malvinas)'),
(70, 1, 'Faroe Islands'),
(71, 1, 'Fiji'),
(72, 1, 'Finland'),
(73, 1, 'France'),
(74, 1, 'France, Metropolitan'),
(75, 1, 'French Guiana'),
(76, 1, 'French Polynesia'),
(77, 1, 'French Southern Territories'),
(78, 1, 'Gabon'),
(79, 1, 'Gambia'),
(80, 1, 'Georgia'),
(81, 1, 'Germany'),
(82, 1, 'Ghana'),
(83, 1, 'Gibraltar'),
(84, 1, 'Greece'),
(85, 1, 'Greenland'),
(86, 1, 'Grenada'),
(87, 1, 'Guadeloupe'),
(88, 1, 'Guam'),
(89, 1, 'Guatemala'),
(90, 1, 'Guinea'),
(91, 1, 'Guinea-bissau'),
(92, 1, 'Guyana'),
(93, 1, 'Haiti'),
(94, 1, 'Heard and Mc Donald Islands'),
(95, 1, 'Honduras'),
(96, 1, 'Hong Kong'),
(97, 1, 'Hungary'),
(98, 1, 'Iceland'),
(99, 1, 'India'),
(100, 1, 'Indonesia'),
(101, 1, 'Iran (Islamic Republic of)'),
(102, 1, 'Iraq'),
(103, 1, 'Ireland'),
(104, 1, 'Israel'),
(105, 1, 'Italy'),
(106, 1, 'Jamaica'),
(107, 1, 'Japan'),
(108, 1, 'Jordan'),
(109, 1, 'Kazakhstan'),
(110, 1, 'Kenya'),
(111, 1, 'Kiribati'),
(112, 1, 'North Korea'),
(113, 1, 'Korea, Republic of'),
(114, 1, 'Kuwait'),
(115, 1, 'Kyrgyzstan'),
(116, 1, 'Lao People''s Democratic Republic'),
(117, 1, 'Latvia'),
(118, 1, 'Lebanon'),
(119, 1, 'Lesotho'),
(120, 1, 'Liberia'),
(121, 1, 'Libyan Arab Jamahiriya'),
(122, 1, 'Liechtenstein'),
(123, 1, 'Lithuania'),
(124, 1, 'Luxembourg'),
(125, 1, 'Macau'),
(126, 1, 'North Macedonia'),
(127, 1, 'Madagascar'),
(128, 1, 'Malawi'),
(129, 1, 'Malaysia'),
(130, 1, 'Maldives'),
(131, 1, 'Mali'),
(132, 1, 'Malta'),
(133, 1, 'Marshall Islands'),
(134, 1, 'Martinique'),
(135, 1, 'Mauritania'),
(136, 1, 'Mauritius'),
(137, 1, 'Mayotte'),
(138, 1, 'Mexico'),
(139, 1, 'Micronesia, Federated States of'),
(140, 1, 'Moldova, Republic of'),
(141, 1, 'Monaco'),
(142, 1, 'Mongolia'),
(143, 1, 'Montserrat'),
(144, 1, 'Morocco'),
(145, 1, 'Mozambique'),
(146, 1, 'Myanmar'),
(147, 1, 'Namibia'),
(148, 1, 'Nauru'),
(149, 1, 'Nepal'),
(150, 1, 'Netherlands'),
(151, 1, 'Netherlands Antilles'),
(152, 1, 'New Caledonia'),
(153, 1, 'New Zealand'),
(154, 1, 'Nicaragua'),
(155, 1, 'Niger'),
(156, 1, 'Nigeria'),
(157, 1, 'Niue'),
(158, 1, 'Norfolk Island'),
(159, 1, 'Northern Mariana Islands'),
(160, 1, 'Norway'),
(161, 1, 'Oman'),
(162, 1, 'Pakistan'),
(163, 1, 'Palau'),
(164, 1, 'Panama'),
(165, 1, 'Papua New Guinea'),
(166, 1, 'Paraguay'),
(167, 1, 'Peru'),
(168, 1, 'Philippines'),
(169, 1, 'Pitcairn'),
(170, 1, 'Poland'),
(171, 1, 'Portugal'),
(172, 1, 'Puerto Rico'),
(173, 1, 'Qatar'),
(174, 1, 'Reunion'),
(175, 1, 'Romania'),
(176, 1, 'Russia'),
(177, 1, 'Rwanda'),
(178, 1, 'Saint Kitts and Nevis'),
(179, 1, 'Saint Lucia'),
(180, 1, 'Saint Vincent and the Grenadines'),
(181, 1, 'Samoa'),
(182, 1, 'San Marino'),
(183, 1, 'Sao Tome and Principe'),
(184, 1, 'Saudi Arabia'),
(185, 1, 'Senegal'),
(186, 1, 'Seychelles'),
(187, 1, 'Sierra Leone'),
(188, 1, 'Singapore'),
(189, 1, 'Slovak Republic'),
(190, 1, 'Slovenia'),
(191, 1, 'Solomon Islands'),
(192, 1, 'Somalia'),
(193, 1, 'South Africa'),
(194, 1, 'South Georgia &amp; South Sandwich Islands'),
(195, 1, 'Spain'),
(196, 1, 'Sri Lanka'),
(197, 1, 'St. Helena'),
(198, 1, 'St. Pierre and Miquelon'),
(199, 1, 'Sudan'),
(200, 1, 'Suriname'),
(201, 1, 'Svalbard and Jan Mayen Islands'),
(202, 1, 'Eswatini'),
(203, 1, 'Sweden'),
(204, 1, 'Switzerland'),
(205, 1, 'Syrian Arab Republic'),
(206, 1, 'Taiwan'),
(207, 1, 'Tajikistan'),
(208, 1, 'Tanzania, United Republic of'),
(209, 1, 'Thailand'),
(210, 1, 'Togo'),
(211, 1, 'Tokelau'),
(212, 1, 'Tonga'),
(213, 1, 'Trinidad and Tobago'),
(214, 1, 'Tunisia'),
(215, 1, 'Turkey'),
(216, 1, 'Turkmenistan'),
(217, 1, 'Turks and Caicos Islands'),
(218, 1, 'Tuvalu'),
(219, 1, 'Uganda'),
(220, 1, 'Ukraine'),
(221, 1, 'United Arab Emirates'),
(222, 1, 'United Kingdom'),
(223, 1, 'United States'),
(224, 1, 'United States Minor Outlying Islands'),
(225, 1, 'Uruguay'),
(226, 1, 'Uzbekistan'),
(227, 1, 'Vanuatu'),
(228, 1, 'Vatican City State (Holy See)'),
(229, 1, 'Venezuela'),
(230, 1, 'Viet Nam'),
(231, 1, 'Virgin Islands (British)'),
(232, 1, 'Virgin Islands (U.S.)'),
(233, 1, 'Wallis and Futuna Islands'),
(234, 1, 'Western Sahara'),
(235, 1, 'Yemen'),
(236, 1, 'Montenegro'),
(237, 1, 'Curaçao'),
(238, 1, 'Zambia'),
(239, 1, 'Zimbabwe'),
(240, 1, 'Northern Ireland'),
(241, 1, 'Serbia'),
(242, 1, 'Kosovo'),
(243, 1, 'South Sudan');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]coupons`
--

CREATE TABLE `[[dbprefix]]coupons` (
  `coupon_id` int NOT NULL AUTO_INCREMENT,
  `code` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `type` char(1) COLLATE utf8mb4_unicode_ci NOT NULL,
  `discount` decimal(15,4) NOT NULL,
  `logged` int NOT NULL,
  `shipping` int NOT NULL,
  `total` decimal(15,4) NOT NULL,
  `date_start` date DEFAULT NULL,
  `date_end` date DEFAULT NULL,
  `uses_total` int NOT NULL,
  `uses_customer` varchar(11) COLLATE utf8mb4_unicode_ci NOT NULL,
  `status` int NOT NULL,
  `condition_rule` enum('OR','AND') COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 'OR',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`coupon_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=7 ;

--
-- Dumping data for table `[[dbprefix]]coupons`
--

INSERT INTO `[[dbprefix]]coupons` VALUES
(4, '2222', 'P', '10.0000', 0, 0, '0.0000', '2021-01-01', '2022-01-01', 30, '3', 0, 'OR', '[[regtime]]', '[[regtime]]'),
(5, '3333', 'P', '0.0000', 0, 1, '100.0000', '2021-01-01', '2022-01-01', 40, '1', 0, 'OR', '[[regtime]]', '[[regtime]]'),
(6, '1111', 'F', '10.0000', 0, 0, '10.0000', '2021-01-01', '2022-01-01', 100, '2', 0, 'OR', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]coupons_categories`
--

CREATE TABLE `[[dbprefix]]coupons_categories` (
  `coupon_category_id` int NOT NULL AUTO_INCREMENT,
  `coupon_id` int NOT NULL,
  `category_id` int NOT NULL,
  PRIMARY KEY (`coupon_category_id`),
  KEY `[[dbprefix]]coupons_categories_idx` (`coupon_id`,`category_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]coupons_products`
--

CREATE TABLE `[[dbprefix]]coupons_products` (
  `coupon_product_id` int NOT NULL AUTO_INCREMENT,
  `coupon_id` int NOT NULL,
  `product_id` int NOT NULL,
  PRIMARY KEY (`coupon_product_id`),
  KEY `[[dbprefix]]coupons_products_idx` (`coupon_id`,`product_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=11 ;

--
-- Dumping data for table `[[dbprefix]]coupons_products`
--

INSERT INTO `[[dbprefix]]coupons_products` VALUES
(10, 6, 68);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]coupon_descriptions`
--

CREATE TABLE `[[dbprefix]]coupon_descriptions` (
  `coupon_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `description` text COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`coupon_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]coupon_descriptions`
--

INSERT INTO `[[dbprefix]]coupon_descriptions` VALUES
(4, 1, 'Coupon (-10%)', '10% Discount'),
(5, 1, 'Coupon (Free Shipping)', 'Free Shipping'),
(6, 1, 'Coupon (-10.00)', 'Fixed Amount Discount');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]currencies`
--

CREATE TABLE `[[dbprefix]]currencies` (
  `currency_id` int NOT NULL AUTO_INCREMENT,
  `title` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `code` varchar(3) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `symbol_left` varchar(12) COLLATE utf8mb4_unicode_ci NOT NULL,
  `symbol_right` varchar(12) COLLATE utf8mb4_unicode_ci NOT NULL,
  `decimal_place` char(1) COLLATE utf8mb4_unicode_ci NOT NULL,
  `value` decimal(15,8) NOT NULL,
  `status` int NOT NULL,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`currency_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]currencies`
--

INSERT INTO `[[dbprefix]]currencies` VALUES
(1, 'US Dollar', 'USD', '$', '', '2', '1.00000000', 1, '2011-06-20 15:30:00'),
(2, 'Euro', 'EUR', '', '€', '2', '0.93850000', 1, '2011-06-20 15:30:00'),
(3, 'Pound Sterling', 'GBP', '£', '', '2', '0.79330000', 1, '2011-06-20 15:30:00');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]customers`
--

CREATE TABLE `[[dbprefix]]customers` (
  `customer_id` int NOT NULL AUTO_INCREMENT,
  `store_id` int NOT NULL DEFAULT '0',
  `firstname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `lastname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `loginname` varchar(96) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `email` varchar(96) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `telephone` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `fax` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `sms` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'mobile phone number',
  `salt` varchar(8) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `password` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `cart` longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  `wishlist` longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  `newsletter` int NOT NULL DEFAULT '0',
  `address_id` int NOT NULL DEFAULT '0',
  `status` int NOT NULL,
  `approved` int NOT NULL DEFAULT '0',
  `customer_group_id` int NOT NULL,
  `ip` varchar(50) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '0',
  `data` text COLLATE utf8mb4_unicode_ci,
  `ext_fields` json DEFAULT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `last_login` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`customer_id`),
  UNIQUE KEY `customers_loginname` (`loginname`),
  KEY `[[dbprefix]]customers_idx` (`store_id`,`address_id`,`customer_group_id`),
  FULLTEXT KEY `[[dbprefix]]customers_name_idx` (`firstname`,`lastname`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=19 ;

--
-- Dumping data for table `[[dbprefix]]customers`
--

INSERT INTO `[[dbprefix]]customers` VALUES
(2, 0, 'Juliana', 'Davis', 'julidavis@abantecart.com', 'julidavis@abantecart.com', '(602) 141-7191', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 1, 1, 1, 1, '109.104.166.98', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(3, 0, 'Keely', 'Mccoy', 'keelymccoy@abantecart.com', 'keelymccoy@abantecart.com', '(602) 916-1822', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 2, 1, 1, 1, '109.104.166.98', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(4, 0, 'Zelda', 'Weiss', 'zeldaweiss@abantecart.com', 'zeldaweiss@abantecart.com', '(539) 838-9210', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 3, 1, 1, 1, '109.104.166.138', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(5, 0, 'Gloria', 'Macias', 'gloriamacias@abantecart.com', 'gloriamacias@abantecart.com', '(573) 500-2105', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 4, 1, 1, 1, '109.104.166.98', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(6, 0, 'Bernard', 'Horne', 'bernardhorne@abantecart.com', 'bernardhorne@abantecart.com', '(573) 500-2105', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 5, 1, 1, 1, '109.104.166.138', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(7, 0, 'James', 'Curtis', 'jamescurtis@abantecart.com', 'jamescurtis@abantecart.com', '(602) 916-1822', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 6, 1, 1, 1, '109.104.166.138', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(8, 0, 'Bruce', 'Rosarini', 'brucerosarini@abantecart.com', 'brucerosarini@abantecart.com', '(539) 838-9210', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 7, 1, 1, 1, '109.104.166.98', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(9, 0, 'Carlos', 'Compton', 'carloscmpton@abantecart.com', 'carloscmpton@abantecart.com', '(928) 205-0511', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 8, 1, 1, 1, '109.104.166.98', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(10, 0, 'Garrison', 'Baxter', 'garrisonbaxter@abantecart.com', 'garrisonbaxter@abantecart.com', '(803) 189-5001', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 9, 1, 1, 1, '109.104.166.138', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(11, 0, 'Anthony', 'Blair', 'anthonyblair@abantecart.com', 'anthonyblair@abantecart.com', '(402) 456-6398', '', '', '', '6b006ba67f3c172e146991a2ad46d865', 'a:0:{}', NULL, 0, 10, 1, 1, 1, '171.98.12.12', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(12, 0, 'Allen', 'Waters', 'allenwaters', 'allenwaters@abantecart.com', '(417) 280-7406', '', '', 'vkmQqxNw', 'e9aa1fed0f5c85e84ef9c9e8860c2732326e790b', 'a:0:{}', NULL, 0, 11, 1, 1, 1, '77.111.246.147', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(13, 0, 'Brock', 'Wheeler', 'michael', 'cotan@abantecart.com', '12893654499', '', '', 'QqHpW6DV', '189212083ca9de5f584e624b7a7c256af90fdcfb', 'a:0:{}', 'a:2:{i:108;i:1552911485;i:111;i:1552911579;}', 1, 12, 1, 1, 1, '77.111.246.167', NULL, NULL, '[[regtime]]', '[[regtime]]', NULL),
(14, 0, 'Yuri', 'Howard', 'howard566', 'howardinc@abantecart.com', '16943733146', '', '', '1IVINJ6A', '9980a6c101c48ba14277e5fcc7277fed31a8eb34', 'a:0:{}', NULL, 1, 13, 1, 1, 1, '77.111.247.7', 'N;', NULL, '[[regtime]]', '[[regtime]]', NULL),
(15, 0, 'Regan', 'Shields', 'RiaGardner', 'ricuvif@abantecart.com', '+1 (267) 125-5153', '', '', 'QaPiKdCR', '30a96d6489cc8089d2f66f1b3407334cfd5a5490', 'a:0:{}', NULL, 1, 14, 1, 1, 1, '23.129.64.106', 'N;', NULL, '[[regtime]]', '[[regtime]]', NULL),
(16, 0, 'Randall', 'Richards', 'randallri', 'randallri@abantecart.com', '17887737896', '', '', 'KGtkpKGm', '0664a4c600337892f120b53b81de10646e68ee91', 'a:1:{s:7:"store_0";a:1:{i:96;a:2:{s:3:"qty";i:2;s:7:"options";a:0:{}}}}', NULL, 0, 15, 1, 1, 1, '77.111.247.7', 'N;', NULL, '[[regtime]]', '[[regtime]]', NULL),
(17, 0, 'Michelle', 'Barnett', 'mbarnett', 'mbarnett@abantecart.com', '1 469 537-8505', '', '', 'XlUAn9uJ', 'f47de9ec3628658a74e781634caf9a76b1153ee6', NULL, NULL, 0, 17, 1, 1, 1, '', 'N;', NULL, '[[regtime]]', '[[regtime]]', NULL),
(18, 0, 'Elmer', 'West', 'X6QDsfu', 'elmer@abantecart.com', ' 1 (128) 392-8036', '', '', 'qkN3jME3', 'c05a1acf9a9c189533b8ce63db274a61e91e622b', 'a:1:{s:7:"store_0";a:103:{s:36:"115:5cba4f750e02abb06a5be0f06e274666";a:2:{s:3:"qty";i:1;s:7:"options";a:2:{i:342;s:3:"743";i:404;s:5:"gfddf";}}s:36:"115:2dc647c8b17b4ccecaa5d92effd9eeaf";a:2:{s:3:"qty";i:1;s:7:"options";a:2:{i:342;s:3:"744";i:404;s:3:"111";}}s:36:"115:28180855290c8c9c44737b328b571ee9";a:2:{s:3:"qty";i:4;s:7:"options";a:2:{i:342;s:3:"745";i:404;s:9:"456765787";}}i:131;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:165;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:164;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:162;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:163;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:161;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:139;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:160;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:138;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:36:"156:2b07b4d10632c7bff4bec4a101046faf";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:399;s:3:"874";}}s:36:"155:32c2e9da9b2f2345237b87451d60b84f";a:2:{s:3:"qty";i:3;s:7:"options";a:1:{i:398;s:3:"872";}}s:36:"157:6aa8e2c1dfc6e034560f3800d4917829";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:400;s:3:"876";}}s:36:"158:28e3af117692f4201fce21ecf6f8f53e";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:401;s:3:"878";}}s:36:"159:f270abbebd3fa32849aff306271123bd";a:2:{s:3:"qty";i:3;s:7:"options";a:1:{i:402;s:3:"881";}}s:36:"125:7235a986e40dfd6fb4368d6a51082723";a:2:{s:3:"qty";i:2;s:7:"options";a:1:{i:391;s:3:"859";}}s:36:"151:34ce24453dc79bf18967dc5f8c97c9be";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:394;s:3:"864";}}s:36:"152:d809b4aa4e2031d806f660abb4cb76ee";a:2:{s:3:"qty";i:3;s:7:"options";a:1:{i:395;s:3:"866";}}i:153;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:150;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:36:"145:d7e2147856134d399fef21f5974a6744";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:385;s:3:"847";}}s:36:"146:9d00b12a8a9ac34b003d9709f9f464c8";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:386;s:3:"849";}}s:36:"147:9c9d41ffab356d49888814b4f2b1f0cb";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:387;s:3:"851";}}s:36:"148:3e5982fcb6350355bfd7f527c9abbf4e";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:388;s:3:"853";}}s:36:"142:7898ea06f08354d9c870e3d345befef7";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:382;s:3:"841";}}s:36:"134:a9223e83409daad197efa7c3d8ad2ee4";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:373;s:3:"824";}}s:35:"53:ee705d4ae7846adb2c3e17d441a1009f";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:318;s:3:"652";}}s:35:"53:b1a0e11451071a263d5a530074cc3395";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:318;s:3:"653";}}i:52;a:2:{s:3:"qty";i:2;s:7:"options";a:0:{}}i:51;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:75;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:74;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:73;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:70;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:71;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:72;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:35:"69:eeeca3bfc8100dde326e86957e9a6530";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:317;s:3:"650";}}s:35:"63:65aa2de1a315740513d57700a595f6d2";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:316;s:3:"647";}}s:35:"63:f0ee771e76731e5a0413b4f15a14db41";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:316;s:3:"648";}}s:35:"63:545f48ecb97d7a1628419cf271302198";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:316;s:3:"649";}}s:35:"64:4a6352b281fa824da3c09c488b9da5a3";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:314;s:3:"642";}}s:35:"64:9f00c3e9cebe257a0d8aeac09dc4b5dd";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:314;s:3:"643";}}i:67;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:35:"61:eba0f047e459bb4a3056b25508e12b9f";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:308;s:3:"625";}}s:35:"61:858452a6f2d2951133d15d1c13277acb";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:308;s:3:"626";}}i:62;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:35:"60:5f8b507b181a05057d93220c99c1cf26";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:307;s:3:"622";}}i:93;a:2:{s:3:"qty";i:2;s:7:"options";a:0:{}}s:35:"59:440e65f322af942e2214c72e03177c2b";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:305;s:3:"615";}}s:35:"59:620a58973de6c7c5954c4ed2d88a0228";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:305;s:3:"616";}}s:35:"57:ae3056fceb4dfd9d0296b09777d3f229";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:304;s:3:"612";}}s:35:"57:370ad88f62136118f7ac72feacabfae1";a:2:{s:3:"qty";i:2;s:7:"options";a:1:{i:304;s:3:"613";}}s:35:"56:dada7bc1947940f2c55366451914de9a";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:319;s:3:"654";}}s:35:"55:5f15b4a30882c43681dba854ace7334e";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:306;s:3:"618";}}s:35:"55:e8db34041472435dcc7f2a7d608a09ac";a:2:{s:3:"qty";i:4;s:7:"options";a:1:{i:306;s:3:"619";}}s:36:"120:fa80aa5a6a63e55338799d7f2ada7e12";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:349;s:3:"773";}}s:36:"105:0d06b1d274719b783849b8fefbaf4786";a:2:{s:3:"qty";i:1;s:7:"options";a:2:{i:335;a:2:{i:0;s:3:"721";i:1;s:3:"722";}i:337;s:3:"723";}}s:36:"105:75cbcc99bfb333369498a06b77a02682";a:2:{s:3:"qty";i:1;s:7:"options";a:3:{i:335;a:2:{i:0;s:3:"720";i:1;s:3:"722";}i:337;s:3:"724";i:336;s:3:"yes";}}s:36:"106:6496c6289f0eaf2ff7bdb209576b4d46";a:2:{s:3:"qty";i:1;s:7:"options";a:2:{i:338;s:3:"731";i:339;s:3:"yes";}}s:36:"109:3e6f80443cbce01f9ae3e21da5f0ab14";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:340;s:3:"yes";}}s:36:"110:da0d1fb831ac71d6b13f1e60a75bf992";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:341;s:3:"738";}}i:113;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:114;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:36:"117:85a002586a2ea99ca83b9f6b7352a3ca";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:346;s:3:"756";}}s:36:"117:c392653d989af6c2fb05fa89d0ad4da9";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:346;s:3:"758";}}s:36:"117:2dfbe5bb56eaed33caefedd299af3dbf";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:346;s:3:"759";}}s:36:"116:d00a62f8ad226fbfdfbb2e2455d6eb83";a:2:{s:3:"qty";i:1;s:7:"options";a:2:{i:344;a:1:{i:0;s:3:"748";}i:345;s:3:"754";}}s:36:"116:f5346da9d272626f5fdb5d376f8a8eb3";a:2:{s:3:"qty";i:10;s:7:"options";a:2:{i:344;a:1:{i:0;s:3:"751";}i:345;s:3:"752";}}s:35:"78:2f6b2458b37e05cdff085ad39dcb080c";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:320;s:3:"660";}}i:79;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:76;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:86;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:88;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:87;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:35:"90:13993f688a965eb6fac5df1f1bd03309";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:326;s:3:"676";}}s:35:"89:a45ab41d0bddba8ea847d7b3f42c19d0";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:324;s:3:"672";}}i:92;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:94;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:91;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:95;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:96;a:2:{s:3:"qty";i:2;s:7:"options";a:0:{}}s:35:"99:728efcff89e7bc9a7cab157a7b6b46f5";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:327;s:3:"678";}}i:103;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:97;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:98;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:36:"104:e74c6dd4ec8eacd20e2e54a1544b48df";a:2:{s:3:"qty";i:1;s:7:"options";a:2:{i:331;s:3:"713";i:332;s:1:"1";}}s:36:"102:c1d1ba48cdfdc495ed98f22b80419edb";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:330;s:3:"690";}}s:36:"101:77ddff2eb7368bc15959e015aeb4ee93";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:329;s:3:"687";}}i:77;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:36:"119:26a4a29af72e9fa902217e00730cfec7";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:348;s:3:"769";}}i:50;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:65;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:66;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:68;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}i:58;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:36:"123:2b2351e536ad293222b586fbf65d778f";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:353;s:3:"781";}}s:36:"122:e072997ce78a3aea542fef3375d40e20";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:352;s:3:"778";}}s:35:"80:d8601ba52a1351d969c41c14fd8dd827";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:321;s:3:"663";}}i:82;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}s:35:"84:3e0d468e2ae6d6615ed68b4e0e9ece75";a:2:{s:3:"qty";i:1;s:7:"options";a:1:{i:322;s:3:"666";}}i:83;a:2:{s:3:"qty";i:1;s:7:"options";a:0:{}}}}', NULL, 0, 18, 1, 1, 1, '77.111.246.40', 'N;', NULL, '[[regtime]]', '[[regtime]]', NULL);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]customer_groups`
--

CREATE TABLE `[[dbprefix]]customer_groups` (
  `customer_group_id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL,
  `tax_exempt` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`customer_group_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]customer_groups`
--

INSERT INTO `[[dbprefix]]customer_groups` VALUES
(1, 'Default', 0),
(2, 'Wholesalers', 1),
(3, 'Newsletter Subscribers', 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]customer_notifications`
--

CREATE TABLE `[[dbprefix]]customer_notifications` (
  `customer_id` int NOT NULL,
  `sendpoint` varchar(255) NOT NULL,
  `protocol` varchar(30) NOT NULL,
  `status` int NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`customer_id`,`sendpoint`,`protocol`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]customer_sessions`
--

CREATE TABLE `[[dbprefix]]customer_sessions` (
  `customer_id` int NOT NULL AUTO_INCREMENT,
  `session_id` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `ip` varchar(50) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `last_active` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`customer_id`,`session_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]customer_transactions`
--

CREATE TABLE `[[dbprefix]]customer_transactions` (
  `customer_transaction_id` int NOT NULL AUTO_INCREMENT,
  `customer_id` int NOT NULL DEFAULT '0',
  `order_id` int NOT NULL DEFAULT '0',
  `created_by` int NOT NULL COMMENT 'user_id for admin, customer_id for storefront section',
  `section` smallint NOT NULL DEFAULT '0' COMMENT '1 - admin, 0 - customer',
  `credit` decimal(15,4) DEFAULT '0.0000',
  `debit` decimal(15,4) DEFAULT '0.0000',
  `transaction_type` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'text type of transaction',
  `comment` text COLLATE utf8mb4_unicode_ci COMMENT 'comment for internal use',
  `description` text COLLATE utf8mb4_unicode_ci COMMENT 'text for customer',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`customer_transaction_id`),
  KEY `[[dbprefix]]customer_transactions_idx` (`customer_id`,`order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]custom_blocks`
--

CREATE TABLE `[[dbprefix]]custom_blocks` (
  `custom_block_id` int NOT NULL AUTO_INCREMENT,
  `block_id` int NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`custom_block_id`,`block_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=21 ;

--
-- Dumping data for table `[[dbprefix]]custom_blocks`
--

INSERT INTO `[[dbprefix]]custom_blocks` VALUES
(1, 17, '[[regtime]]', '[[regtime]]'),
(2, 17, '[[regtime]]', '[[regtime]]'),
(3, 17, '[[regtime]]', '[[regtime]]'),
(4, 17, '[[regtime]]', '[[regtime]]'),
(5, 17, '[[regtime]]', '[[regtime]]'),
(6, 17, '[[regtime]]', '[[regtime]]'),
(7, 23, '[[regtime]]', '[[regtime]]'),
(8, 20, '[[regtime]]', '[[regtime]]'),
(9, 17, '[[regtime]]', '[[regtime]]'),
(10, 17, '[[regtime]]', '[[regtime]]'),
(11, 17, '[[regtime]]', '[[regtime]]'),
(12, 17, '[[regtime]]', '[[regtime]]'),
(13, 17, '[[regtime]]', '[[regtime]]'),
(14, 17, '[[regtime]]', '[[regtime]]'),
(15, 17, '[[regtime]]', '[[regtime]]'),
(16, 17, '[[regtime]]', '[[regtime]]'),
(17, 20, '[[regtime]]', '[[regtime]]'),
(18, 17, '[[regtime]]', '[[regtime]]'),
(19, 17, '[[regtime]]', '[[regtime]]'),
(20, 17, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]custom_lists`
--

CREATE TABLE `[[dbprefix]]custom_lists` (
  `rowid` int NOT NULL AUTO_INCREMENT,
  `custom_block_id` int NOT NULL,
  `data_type` varchar(70) COLLATE utf8mb4_unicode_ci NOT NULL,
  `id` int NOT NULL,
  `store_id` int DEFAULT NULL,
  `sort_order` int NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`rowid`),
  KEY `[[dbprefix]]custom_block_id_list_idx` (`custom_block_id`,`store_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=11 ;

--
-- Dumping data for table `[[dbprefix]]custom_lists`
--

INSERT INTO `[[dbprefix]]custom_lists` VALUES
(1, 12, 'manufacturer_id', 12, 0, 0, '[[regtime]]', '[[regtime]]'),
(2, 12, 'manufacturer_id', 14, 0, 0, '[[regtime]]', '[[regtime]]'),
(3, 12, 'manufacturer_id', 13, 0, 0, '[[regtime]]', '[[regtime]]'),
(4, 12, 'manufacturer_id', 18, 0, 0, '[[regtime]]', '[[regtime]]'),
(5, 12, 'manufacturer_id', 19, 0, 0, '[[regtime]]', '[[regtime]]'),
(6, 12, 'manufacturer_id', 20, 0, 0, '[[regtime]]', '[[regtime]]'),
(7, 12, 'manufacturer_id', 15, 0, 0, '[[regtime]]', '[[regtime]]'),
(8, 12, 'manufacturer_id', 11, 0, 0, '[[regtime]]', '[[regtime]]'),
(9, 12, 'manufacturer_id', 17, 0, 0, '[[regtime]]', '[[regtime]]'),
(10, 12, 'manufacturer_id', 16, 0, 0, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]datasets`
--

CREATE TABLE `[[dbprefix]]datasets` (
  `dataset_id` int NOT NULL AUTO_INCREMENT,
  `dataset_name` varchar(255) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci NOT NULL,
  `dataset_key` varchar(255) CHARACTER SET utf8mb3 COLLATE utf8mb3_general_ci DEFAULT '',
  PRIMARY KEY (`dataset_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=6 ;

--
-- Dumping data for table `[[dbprefix]]datasets`
--

INSERT INTO `[[dbprefix]]datasets` VALUES
(1, 'menu', 'storefront'),
(2, 'menu', 'admin'),
(3, 'menu', 'storefront_description'),
(4, 'install_upgrade_history', 'admin'),
(5, 'file_uploads', 'admin');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]dataset_column_properties`
--

CREATE TABLE `[[dbprefix]]dataset_column_properties` (
  `rowid` int NOT NULL AUTO_INCREMENT,
  `dataset_column_id` int NOT NULL,
  `dataset_column_property_name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `dataset_column_property_value` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  PRIMARY KEY (`rowid`),
  KEY `dataset_column_properties_idx` (`dataset_column_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]dataset_definition`
--

CREATE TABLE `[[dbprefix]]dataset_definition` (
  `dataset_id` int NOT NULL,
  `dataset_column_id` int NOT NULL AUTO_INCREMENT,
  `dataset_column_name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `dataset_column_type` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  `dataset_column_sort_order` int NOT NULL DEFAULT '0',
  PRIMARY KEY (`dataset_column_id`),
  KEY `dataset_definition_idx` (`dataset_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=41 ;

--
-- Dumping data for table `[[dbprefix]]dataset_definition`
--

INSERT INTO `[[dbprefix]]dataset_definition` VALUES
(1, 1, 'item_id', 'varchar', 1),
(1, 2, 'item_icon', 'varchar', 2),
(1, 3, 'item_url', 'varchar', 3),
(1, 4, 'parent_id', 'varchar', 4),
(1, 5, 'sort_order', 'integer', 5),
(1, 6, 'item_type', 'varchar', 6),
(1, 7, 'item_icon_rl_id', 'integer', 7),
(1, 8, 'settings', 'text', 8),
(2, 10, 'item_id', 'varchar', 1),
(2, 11, 'item_text', 'varchar', 2),
(2, 12, 'item_url', 'varchar', 3),
(2, 13, 'parent_id', 'varchar', 4),
(2, 14, 'sort_order', 'integer', 5),
(2, 15, 'item_type', 'varchar', 6),
(3, 16, 'item_id', 'varchar', 1),
(3, 17, 'item_text', 'varchar', 2),
(3, 18, 'language_id', 'integer', 3),
(4, 20, 'date_added', 'timestamp', 1),
(4, 21, 'name', 'varchar', 2),
(4, 22, 'version', 'varchar', 3),
(4, 23, 'backup_file', 'varchar', 4),
(4, 24, 'backup_date', 'timestamp', 5),
(4, 25, 'type', 'varchar', 6),
(4, 26, 'user', 'varchar', 7),
(5, 30, 'date_added', 'timestamp', 1),
(5, 31, 'name', 'varchar', 2),
(5, 32, 'type', 'varchar', 3),
(5, 33, 'section', 'varchar', 4),
(5, 34, 'section_id', 'integer', 5),
(5, 35, 'path', 'varchar', 6),
(2, 40, 'item_icon_rl_id', 'varchar', 7);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]dataset_properties`
--

CREATE TABLE `[[dbprefix]]dataset_properties` (
  `rowid` int NOT NULL AUTO_INCREMENT,
  `dataset_id` int NOT NULL,
  `dataset_property_name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `dataset_property_value` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  PRIMARY KEY (`rowid`),
  KEY `dataset_property_idx` (`dataset_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]dataset_properties`
--

INSERT INTO `[[dbprefix]]dataset_properties` VALUES
(1, 1, 'controller', 'design/menu'),
(2, 4, 'controller', 'tool/install_upgrade_history'),
(3, 5, 'controller', 'tool/files');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]dataset_values`
--

CREATE TABLE `[[dbprefix]]dataset_values` (
  `dataset_column_id` int NOT NULL,
  `value_integer` int DEFAULT NULL,
  `value_float` float DEFAULT NULL,
  `value_varchar` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `value_text` text COLLATE utf8mb4_unicode_ci,
  `value_timestamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `value_boolean` tinyint(1) DEFAULT NULL,
  `value_sort_order` int NOT NULL AUTO_INCREMENT,
  `row_id` int unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`value_sort_order`),
  KEY `dataset_values_idx` (`value_integer`,`value_float`,`value_varchar`,`value_boolean`,`row_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=766 ;

--
-- Dumping data for table `[[dbprefix]]dataset_values`
--

INSERT INTO `[[dbprefix]]dataset_values` VALUES
(1, NULL, NULL, 'home', NULL, '[[regtime]]', NULL, 1, 1),
(1, NULL, NULL, 'login', NULL, '[[regtime]]', NULL, 2, 2),
(1, NULL, NULL, 'logout', NULL, '[[regtime]]', NULL, 3, 3),
(1, NULL, NULL, 'account', NULL, '[[regtime]]', NULL, 4, 4),
(1, NULL, NULL, 'cart', NULL, '[[regtime]]', NULL, 5, 5),
(1, NULL, NULL, 'checkout', NULL, '[[regtime]]', NULL, 6, 6),
(1, NULL, NULL, 'specials', NULL, '[[regtime]]', NULL, 7, 7),
(1, NULL, NULL, 'order', NULL, '[[regtime]]', NULL, 8, 8),
(2, NULL, NULL, '', NULL, '[[regtime]]', NULL, 9, 1),
(2, NULL, NULL, '', NULL, '[[regtime]]', NULL, 10, 2),
(2, NULL, NULL, '', NULL, '[[regtime]]', NULL, 11, 3),
(2, NULL, NULL, '', NULL, '[[regtime]]', NULL, 12, 4),
(2, NULL, NULL, '', NULL, '[[regtime]]', NULL, 13, 5),
(2, NULL, NULL, '', NULL, '[[regtime]]', NULL, 14, 6),
(2, NULL, NULL, '', NULL, '[[regtime]]', NULL, 15, 7),
(2, NULL, NULL, '', NULL, '[[regtime]]', NULL, 16, 8),
(3, NULL, NULL, 'index/home', NULL, '[[regtime]]', NULL, 17, 1),
(3, NULL, NULL, 'account/login', NULL, '[[regtime]]', NULL, 18, 2),
(3, NULL, NULL, 'account/logout', NULL, '[[regtime]]', NULL, 19, 3),
(3, NULL, NULL, 'account/account', NULL, '[[regtime]]', NULL, 20, 4),
(3, NULL, NULL, 'checkout/cart', NULL, '[[regtime]]', NULL, 21, 5),
(3, NULL, NULL, 'checkout/fast_checkout', NULL, '[[regtime]]', NULL, 22, 6),
(3, NULL, NULL, 'product/special', NULL, '[[regtime]]', NULL, 23, 7),
(3, NULL, NULL, 'account/order_details', NULL, '[[regtime]]', NULL, 24, 8),
(4, NULL, NULL, '', NULL, '[[regtime]]', NULL, 25, 1),
(4, NULL, NULL, 'account', NULL, '[[regtime]]', NULL, 26, 2),
(4, NULL, NULL, 'account', NULL, '[[regtime]]', NULL, 27, 3),
(4, NULL, NULL, '', NULL, '[[regtime]]', NULL, 28, 4),
(4, NULL, NULL, '', NULL, '[[regtime]]', NULL, 29, 5),
(4, NULL, NULL, '', NULL, '[[regtime]]', NULL, 30, 6),
(4, NULL, NULL, '', NULL, '[[regtime]]', NULL, 31, 7),
(4, NULL, NULL, 'account', NULL, '[[regtime]]', NULL, 32, 8),
(5, 10, NULL, NULL, NULL, '[[regtime]]', NULL, 33, 1),
(5, 11, NULL, NULL, NULL, '[[regtime]]', NULL, 34, 2),
(5, 12, NULL, NULL, NULL, '[[regtime]]', NULL, 35, 3),
(5, 20, NULL, NULL, NULL, '[[regtime]]', NULL, 36, 4),
(5, 30, NULL, NULL, NULL, '[[regtime]]', NULL, 37, 5),
(5, 50, NULL, NULL, NULL, '[[regtime]]', NULL, 38, 6),
(5, 60, NULL, NULL, NULL, '[[regtime]]', NULL, 39, 7),
(5, 13, NULL, NULL, NULL, '[[regtime]]', NULL, 40, 8),
(6, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 41, 1),
(6, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 42, 2),
(6, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 43, 3),
(6, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 44, 4),
(6, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 45, 5),
(6, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 46, 6),
(6, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 47, 7),
(6, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 48, 8),
(7, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 49, 1),
(7, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 50, 2),
(7, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 51, 3),
(7, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 52, 4),
(7, 250, NULL, NULL, NULL, '[[regtime]]', NULL, 53, 5),
(7, 282, NULL, NULL, NULL, '[[regtime]]', NULL, 54, 6),
(7, 244, NULL, NULL, NULL, '[[regtime]]', NULL, 55, 7),
(7, 266, NULL, NULL, NULL, '[[regtime]]', NULL, 56, 8),
(8, NULL, NULL, NULL, 'a:3:{s:6:"status";s:1:"1";s:16:"include_children";s:1:"0";s:6:"target";s:5:"_self";}', '[[regtime]]', NULL, 57, 1),
(8, NULL, NULL, NULL, 'a:3:{s:6:"status";s:1:"1";s:16:"include_children";s:1:"0";s:6:"target";s:5:"_self";}', '[[regtime]]', NULL, 58, 2),
(8, NULL, NULL, NULL, 'a:3:{s:6:"status";s:1:"1";s:16:"include_children";s:1:"0";s:6:"target";s:5:"_self";}', '[[regtime]]', NULL, 59, 3),
(8, NULL, NULL, NULL, 'a:3:{s:6:"status";s:1:"1";s:16:"include_children";s:1:"0";s:6:"target";s:5:"_self";}', '[[regtime]]', NULL, 60, 4),
(8, NULL, NULL, NULL, 'a:3:{s:6:"status";s:1:"1";s:16:"include_children";s:1:"0";s:6:"target";s:5:"_self";}', '[[regtime]]', NULL, 61, 5),
(8, NULL, NULL, NULL, 'a:3:{s:6:"status";s:1:"1";s:16:"include_children";s:1:"0";s:6:"target";s:5:"_self";}', '[[regtime]]', NULL, 62, 6),
(8, NULL, NULL, NULL, 'a:3:{s:6:"status";s:1:"1";s:16:"include_children";s:1:"0";s:6:"target";s:5:"_self";}', '[[regtime]]', NULL, 63, 7),
(8, NULL, NULL, NULL, 'a:3:{s:6:"status";s:1:"1";s:16:"include_children";s:1:"0";s:6:"target";s:5:"_self";}', '[[regtime]]', NULL, 64, 8),
(10, NULL, NULL, 'catalog', NULL, '[[regtime]]', NULL, 65, 1),
(10, NULL, NULL, 'sale', NULL, '[[regtime]]', NULL, 66, 2),
(10, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 67, 3),
(10, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 68, 4),
(10, NULL, NULL, 'system', NULL, '[[regtime]]', NULL, 69, 5),
(10, NULL, NULL, 'reports', NULL, '[[regtime]]', NULL, 70, 6),
(10, NULL, NULL, 'help', NULL, '[[regtime]]', NULL, 71, 7),
(11, NULL, NULL, 'text_catalog', NULL, '[[regtime]]', NULL, 72, 1),
(11, NULL, NULL, 'text_sale', NULL, '[[regtime]]', NULL, 73, 2),
(11, NULL, NULL, 'text_design', NULL, '[[regtime]]', NULL, 74, 3),
(11, NULL, NULL, 'text_extension', NULL, '[[regtime]]', NULL, 75, 4),
(11, NULL, NULL, 'text_system', NULL, '[[regtime]]', NULL, 76, 5),
(11, NULL, NULL, 'text_reports', NULL, '[[regtime]]', NULL, 77, 6),
(11, NULL, NULL, 'text_help', NULL, '[[regtime]]', NULL, 78, 7),
(12, NULL, NULL, 'catalog/category', NULL, '[[regtime]]', NULL, 79, 1),
(12, NULL, NULL, 'sale/order', NULL, '[[regtime]]', NULL, 80, 2),
(12, NULL, NULL, 'design/template', NULL, '[[regtime]]', NULL, 81, 3),
(12, NULL, NULL, 'extension/extensions/extensions', NULL, '[[regtime]]', NULL, 82, 4),
(12, NULL, NULL, 'setting/setting', NULL, '[[regtime]]', NULL, 83, 5),
(12, NULL, NULL, 'report/sale/orders', NULL, '[[regtime]]', NULL, 84, 6),
(12, NULL, NULL, '', NULL, '[[regtime]]', NULL, 85, 7),
(13, NULL, NULL, '', NULL, '[[regtime]]', NULL, 86, 1),
(13, NULL, NULL, '', NULL, '[[regtime]]', NULL, 87, 2),
(13, NULL, NULL, '', NULL, '[[regtime]]', NULL, 88, 3),
(13, NULL, NULL, '', NULL, '[[regtime]]', NULL, 89, 4),
(13, NULL, NULL, '', NULL, '[[regtime]]', NULL, 90, 5),
(13, NULL, NULL, '', NULL, '[[regtime]]', NULL, 91, 6),
(13, NULL, NULL, '', NULL, '[[regtime]]', NULL, 92, 7),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 93, 1),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 94, 2),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 95, 3),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 96, 4),
(14, 5, NULL, NULL, NULL, '[[regtime]]', NULL, 97, 5),
(14, 6, NULL, NULL, NULL, '[[regtime]]', NULL, 98, 6),
(14, 7, NULL, NULL, NULL, '[[regtime]]', NULL, 99, 7),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 100, 1),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 101, 2),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 102, 3),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 103, 4),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 104, 5),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 105, 6),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 106, 7),
(40, NULL, NULL, '200', NULL, '[[regtime]]', NULL, 107, 1),
(40, NULL, NULL, '201', NULL, '[[regtime]]', NULL, 108, 2),
(40, NULL, NULL, '202', NULL, '[[regtime]]', NULL, 109, 3),
(40, NULL, NULL, '203', NULL, '[[regtime]]', NULL, 110, 4),
(40, NULL, NULL, '204', NULL, '[[regtime]]', NULL, 111, 5),
(40, NULL, NULL, '205', NULL, '[[regtime]]', NULL, 112, 6),
(40, NULL, NULL, '206', NULL, '[[regtime]]', NULL, 113, 7),
(10, NULL, NULL, 'category', NULL, '[[regtime]]', NULL, 114, 11),
(10, NULL, NULL, 'product', NULL, '[[regtime]]', NULL, 115, 12),
(10, NULL, NULL, 'manufacturer', NULL, '[[regtime]]', NULL, 116, 13),
(10, NULL, NULL, 'download', NULL, '[[regtime]]', NULL, 117, 14),
(10, NULL, NULL, 'review', NULL, '[[regtime]]', NULL, 118, 15),
(10, NULL, NULL, 'attributes', NULL, '[[regtime]]', NULL, 119, 16),
(10, NULL, NULL, 'collections', NULL, '[[regtime]]', NULL, 120, 17),
(10, NULL, NULL, 'rl_manager', NULL, '[[regtime]]', NULL, 121, 220),
(11, NULL, NULL, 'text_category', NULL, '[[regtime]]', NULL, 122, 11),
(11, NULL, NULL, 'text_product', NULL, '[[regtime]]', NULL, 123, 12),
(11, NULL, NULL, 'text_manufacturer', NULL, '[[regtime]]', NULL, 124, 13),
(11, NULL, NULL, 'text_download', NULL, '[[regtime]]', NULL, 125, 14),
(11, NULL, NULL, 'text_review', NULL, '[[regtime]]', NULL, 126, 15),
(11, NULL, NULL, 'text_attribute', NULL, '[[regtime]]', NULL, 127, 16),
(11, NULL, NULL, 'text_collection', NULL, '[[regtime]]', NULL, 128, 17),
(11, NULL, NULL, 'text_rl_manager', NULL, '[[regtime]]', NULL, 129, 220),
(12, NULL, NULL, 'catalog/category', NULL, '[[regtime]]', NULL, 130, 11),
(12, NULL, NULL, 'catalog/product', NULL, '[[regtime]]', NULL, 131, 12),
(12, NULL, NULL, 'catalog/manufacturer', NULL, '[[regtime]]', NULL, 132, 13),
(12, NULL, NULL, 'catalog/download', NULL, '[[regtime]]', NULL, 133, 14),
(12, NULL, NULL, 'catalog/review', NULL, '[[regtime]]', NULL, 134, 15),
(12, NULL, NULL, 'catalog/attribute', NULL, '[[regtime]]', NULL, 135, 16),
(12, NULL, NULL, 'catalog/collections', NULL, '[[regtime]]', NULL, 136, 17),
(12, NULL, NULL, 'tool/rl_manager', NULL, '[[regtime]]', NULL, 137, 220),
(13, NULL, NULL, 'catalog', NULL, '[[regtime]]', NULL, 138, 11),
(13, NULL, NULL, 'catalog', NULL, '[[regtime]]', NULL, 139, 12),
(13, NULL, NULL, 'catalog', NULL, '[[regtime]]', NULL, 140, 13),
(13, NULL, NULL, 'catalog', NULL, '[[regtime]]', NULL, 141, 14),
(13, NULL, NULL, 'catalog', NULL, '[[regtime]]', NULL, 142, 15),
(13, NULL, NULL, 'catalog', NULL, '[[regtime]]', NULL, 143, 16),
(13, NULL, NULL, 'catalog', NULL, '[[regtime]]', NULL, 144, 17),
(13, NULL, NULL, 'catalog', NULL, '[[regtime]]', NULL, 145, 220),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 146, 11),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 147, 12),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 148, 13),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 149, 14),
(14, 5, NULL, NULL, NULL, '[[regtime]]', NULL, 150, 15),
(14, 6, NULL, NULL, NULL, '[[regtime]]', NULL, 151, 16),
(14, 8, NULL, NULL, NULL, '[[regtime]]', NULL, 152, 17),
(14, 7, NULL, NULL, NULL, '[[regtime]]', NULL, 153, 220),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 154, 11),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 155, 12),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 156, 13),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 157, 14),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 158, 15),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 159, 16),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 160, 17),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 161, 220),
(40, NULL, NULL, '207', NULL, '[[regtime]]', NULL, 162, 11),
(40, NULL, NULL, '208', NULL, '[[regtime]]', NULL, 163, 12),
(40, NULL, NULL, '209', NULL, '[[regtime]]', NULL, 164, 13),
(40, NULL, NULL, '210', NULL, '[[regtime]]', NULL, 165, 14),
(40, NULL, NULL, '211', NULL, '[[regtime]]', NULL, 166, 15),
(40, NULL, NULL, '212', NULL, '[[regtime]]', NULL, 167, 16),
(40, NULL, NULL, '279', NULL, '[[regtime]]', NULL, 168, 17),
(40, NULL, NULL, '277', NULL, '[[regtime]]', NULL, 169, 220),
(10, NULL, NULL, 'extensions', NULL, '[[regtime]]', NULL, 170, 31),
(10, NULL, NULL, 'shipping', NULL, '[[regtime]]', NULL, 171, 32),
(10, NULL, NULL, 'payment', NULL, '[[regtime]]', NULL, 172, 33),
(10, NULL, NULL, 'templates', NULL, '[[regtime]]', NULL, 173, 34),
(10, NULL, NULL, 'languages', NULL, '[[regtime]]', NULL, 174, 35),
(10, NULL, NULL, 'taxes', NULL, '[[regtime]]', NULL, 175, 36),
(10, NULL, NULL, 'total', NULL, '[[regtime]]', NULL, 176, 37),
(10, NULL, NULL, 'add_extension', NULL, '[[regtime]]', NULL, 177, 38),
(10, NULL, NULL, 'extensions_stores', NULL, '[[regtime]]', NULL, 178, 39),
(11, NULL, NULL, 'text_extensions', NULL, '[[regtime]]', NULL, 179, 31),
(11, NULL, NULL, 'text_shipping', NULL, '[[regtime]]', NULL, 180, 32),
(11, NULL, NULL, 'text_payment', NULL, '[[regtime]]', NULL, 181, 33),
(11, NULL, NULL, 'text_templates', NULL, '[[regtime]]', NULL, 182, 34),
(11, NULL, NULL, 'text_language', NULL, '[[regtime]]', NULL, 183, 35),
(11, NULL, NULL, 'text_taxes', NULL, '[[regtime]]', NULL, 184, 36),
(11, NULL, NULL, 'text_total', NULL, '[[regtime]]', NULL, 185, 37),
(11, NULL, NULL, 'text_add_extension', NULL, '[[regtime]]', NULL, 186, 38),
(11, NULL, NULL, 'text_extensions_store', NULL, '[[regtime]]', NULL, 187, 39),
(12, NULL, NULL, 'extension/extensions/extensions', NULL, '[[regtime]]', NULL, 188, 31),
(12, NULL, NULL, 'extension/extensions/shipping', NULL, '[[regtime]]', NULL, 189, 32),
(12, NULL, NULL, 'extension/extensions/payment', NULL, '[[regtime]]', NULL, 190, 33),
(12, NULL, NULL, 'extension/extensions/template', NULL, '[[regtime]]', NULL, 191, 34),
(12, NULL, NULL, 'extension/extensions/language', NULL, '[[regtime]]', NULL, 192, 35),
(12, NULL, NULL, 'extension/extensions/tax', NULL, '[[regtime]]', NULL, 193, 36),
(12, NULL, NULL, 'extension/total', NULL, '[[regtime]]', NULL, 194, 37),
(12, NULL, NULL, 'tool/package_installer', NULL, '[[regtime]]', NULL, 195, 38),
(12, NULL, NULL, 'extension/extensions_store', NULL, '[[regtime]]', NULL, 196, 39),
(13, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 197, 31),
(13, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 198, 32),
(13, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 199, 33),
(13, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 200, 34),
(13, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 201, 35),
(13, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 202, 36),
(13, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 203, 37),
(13, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 204, 38),
(13, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 205, 39),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 206, 31),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 207, 32),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 208, 33),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 209, 34),
(14, 5, NULL, NULL, NULL, '[[regtime]]', NULL, 210, 35),
(14, 6, NULL, NULL, NULL, '[[regtime]]', NULL, 211, 36),
(14, 7, NULL, NULL, NULL, '[[regtime]]', NULL, 212, 37),
(14, 8, NULL, NULL, NULL, '[[regtime]]', NULL, 213, 38),
(14, 9, NULL, NULL, NULL, '[[regtime]]', NULL, 214, 39),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 215, 31),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 216, 32),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 217, 33),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 218, 34),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 219, 35),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 220, 36),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 221, 37),
(40, NULL, NULL, '213', NULL, '[[regtime]]', NULL, 222, 31),
(40, NULL, NULL, '214', NULL, '[[regtime]]', NULL, 223, 32),
(40, NULL, NULL, '260', NULL, '[[regtime]]', NULL, 224, 33),
(40, NULL, NULL, '216', NULL, '[[regtime]]', NULL, 225, 34),
(40, NULL, NULL, '217', NULL, '[[regtime]]', NULL, 226, 35),
(40, NULL, NULL, '215', NULL, '[[regtime]]', NULL, 227, 36),
(40, NULL, NULL, '218', NULL, '[[regtime]]', NULL, 228, 37),
(40, NULL, NULL, '219', NULL, '[[regtime]]', NULL, 229, 38),
(40, NULL, NULL, '220', NULL, '[[regtime]]', NULL, 230, 39),
(10, NULL, NULL, 'order', NULL, '[[regtime]]', NULL, 231, 51),
(10, NULL, NULL, 'customer', NULL, '[[regtime]]', NULL, 232, 52),
(10, NULL, NULL, 'customer_group', NULL, '[[regtime]]', NULL, 233, 53),
(10, NULL, NULL, 'coupon', NULL, '[[regtime]]', NULL, 234, 54),
(10, NULL, NULL, 'contact', NULL, '[[regtime]]', NULL, 235, 55),
(11, NULL, NULL, 'text_order', NULL, '[[regtime]]', NULL, 236, 51),
(11, NULL, NULL, 'text_customer', NULL, '[[regtime]]', NULL, 237, 52),
(11, NULL, NULL, 'text_customer_group', NULL, '[[regtime]]', NULL, 238, 53),
(11, NULL, NULL, 'text_coupon', NULL, '[[regtime]]', NULL, 239, 54),
(11, NULL, NULL, 'text_contact', NULL, '[[regtime]]', NULL, 240, 55),
(12, NULL, NULL, 'sale/order', NULL, '[[regtime]]', NULL, 241, 51),
(12, NULL, NULL, 'sale/customer', NULL, '[[regtime]]', NULL, 242, 52),
(12, NULL, NULL, 'sale/customer_group', NULL, '[[regtime]]', NULL, 243, 53),
(12, NULL, NULL, 'sale/coupon', NULL, '[[regtime]]', NULL, 244, 54),
(12, NULL, NULL, 'sale/contact', NULL, '[[regtime]]', NULL, 245, 55),
(13, NULL, NULL, 'sale', NULL, '[[regtime]]', NULL, 246, 51),
(13, NULL, NULL, 'sale', NULL, '[[regtime]]', NULL, 247, 52),
(13, NULL, NULL, 'sale', NULL, '[[regtime]]', NULL, 248, 53),
(13, NULL, NULL, 'sale', NULL, '[[regtime]]', NULL, 249, 54),
(13, NULL, NULL, 'sale', NULL, '[[regtime]]', NULL, 250, 55),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 251, 51),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 252, 52),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 253, 53),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 254, 54),
(14, 5, NULL, NULL, NULL, '[[regtime]]', NULL, 255, 55),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 256, 51),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 257, 52),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 258, 53),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 259, 54),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 260, 55),
(40, NULL, NULL, '221', NULL, '[[regtime]]', NULL, 261, 51),
(40, NULL, NULL, '222', NULL, '[[regtime]]', NULL, 262, 52),
(40, NULL, NULL, '223', NULL, '[[regtime]]', NULL, 263, 53),
(40, NULL, NULL, '224', NULL, '[[regtime]]', NULL, 264, 54),
(40, NULL, NULL, '225', NULL, '[[regtime]]', NULL, 265, 55),
(10, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 266, 71),
(10, NULL, NULL, 'users', NULL, '[[regtime]]', NULL, 267, 72),
(10, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 268, 73),
(10, NULL, NULL, 'data', NULL, '[[regtime]]', NULL, 269, 74),
(10, NULL, NULL, 'updater', NULL, '[[regtime]]', NULL, 270, 77),
(10, NULL, NULL, 'cache', NULL, '[[regtime]]', NULL, 271, 78),
(10, NULL, NULL, 'messages', NULL, '[[regtime]]', NULL, 272, 79),
(10, NULL, NULL, 'logs', NULL, '[[regtime]]', NULL, 273, 80),
(11, NULL, NULL, 'text_setting', NULL, '[[regtime]]', NULL, 274, 71),
(11, NULL, NULL, 'text_users', NULL, '[[regtime]]', NULL, 275, 72),
(11, NULL, NULL, 'text_localisation', NULL, '[[regtime]]', NULL, 276, 73),
(11, NULL, NULL, 'text_data', NULL, '[[regtime]]', NULL, 277, 74),
(11, NULL, NULL, 'text_updater', NULL, '[[regtime]]', NULL, 278, 77),
(11, NULL, NULL, 'text_cache', NULL, '[[regtime]]', NULL, 279, 78),
(11, NULL, NULL, 'text_messages', NULL, '[[regtime]]', NULL, 280, 79),
(11, NULL, NULL, 'text_logs', NULL, '[[regtime]]', NULL, 281, 80),
(12, NULL, NULL, 'setting/setting', NULL, '[[regtime]]', NULL, 282, 71),
(12, NULL, NULL, '', NULL, '[[regtime]]', NULL, 283, 72),
(12, NULL, NULL, '', NULL, '[[regtime]]', NULL, 284, 73),
(12, NULL, NULL, '', NULL, '[[regtime]]', NULL, 285, 74),
(12, NULL, NULL, 'tool/updater', NULL, '[[regtime]]', NULL, 286, 77),
(12, NULL, NULL, 'tool/cache', NULL, '[[regtime]]', NULL, 287, 78),
(12, NULL, NULL, 'tool/message_manager', NULL, '[[regtime]]', NULL, 288, 79),
(12, NULL, NULL, '', NULL, '[[regtime]]', NULL, 289, 80),
(13, NULL, NULL, 'system', NULL, '[[regtime]]', NULL, 290, 71),
(13, NULL, NULL, 'system', NULL, '[[regtime]]', NULL, 291, 72),
(13, NULL, NULL, 'system', NULL, '[[regtime]]', NULL, 292, 73),
(13, NULL, NULL, 'system', NULL, '[[regtime]]', NULL, 293, 74),
(13, NULL, NULL, 'system', NULL, '[[regtime]]', NULL, 294, 77),
(13, NULL, NULL, 'system', NULL, '[[regtime]]', NULL, 295, 78),
(13, NULL, NULL, 'system', NULL, '[[regtime]]', NULL, 296, 79),
(13, NULL, NULL, 'system', NULL, '[[regtime]]', NULL, 297, 80),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 298, 71),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 299, 72),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 300, 73),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 301, 74),
(14, 7, NULL, NULL, NULL, '[[regtime]]', NULL, 302, 77),
(14, 8, NULL, NULL, NULL, '[[regtime]]', NULL, 303, 78),
(14, 9, NULL, NULL, NULL, '[[regtime]]', NULL, 304, 79),
(14, 10, NULL, NULL, NULL, '[[regtime]]', NULL, 305, 80),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 306, 71),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 307, 72),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 308, 73),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 309, 74),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 310, 77),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 311, 78),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 312, 79),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 313, 80),
(40, NULL, NULL, '226', NULL, '[[regtime]]', NULL, 314, 71),
(40, NULL, NULL, '227', NULL, '[[regtime]]', NULL, 315, 72),
(40, NULL, NULL, '228', NULL, '[[regtime]]', NULL, 316, 73),
(40, NULL, NULL, '229', NULL, '[[regtime]]', NULL, 317, 74),
(40, NULL, NULL, '230', NULL, '[[regtime]]', NULL, 318, 77),
(40, NULL, NULL, '231', NULL, '[[regtime]]', NULL, 319, 78),
(40, NULL, NULL, '232', NULL, '[[regtime]]', NULL, 320, 79),
(40, NULL, NULL, '233', NULL, '[[regtime]]', NULL, 321, 80),
(10, NULL, NULL, 'report_sale', NULL, '[[regtime]]', NULL, 322, 91),
(10, NULL, NULL, 'report_customer', NULL, '[[regtime]]', NULL, 323, 92),
(10, NULL, NULL, 'report_product', NULL, '[[regtime]]', NULL, 324, 93),
(10, NULL, NULL, 'report_analytics', NULL, '[[regtime]]', NULL, 325, 221),
(10, NULL, NULL, 'banner_manager_stat', NULL, '[[regtime]]', NULL, 326, 94),
(11, NULL, NULL, 'text_report_sale', NULL, '[[regtime]]', NULL, 327, 91),
(11, NULL, NULL, 'text_customer', NULL, '[[regtime]]', NULL, 328, 92),
(11, NULL, NULL, 'text_product', NULL, '[[regtime]]', NULL, 329, 93),
(11, NULL, NULL, 'text_analytics', NULL, '[[regtime]]', NULL, 330, 221),
(11, NULL, NULL, 'banner_manager_name_stat', NULL, '[[regtime]]', NULL, 331, 94),
(12, NULL, NULL, 'report/sale/orders', NULL, '[[regtime]]', NULL, 332, 91),
(12, NULL, NULL, 'report/customer/online', NULL, '[[regtime]]', NULL, 333, 92),
(12, NULL, NULL, '', NULL, '[[regtime]]', NULL, 334, 93),
(12, NULL, NULL, '', NULL, '[[regtime]]', NULL, 335, 221),
(12, NULL, NULL, 'extension/banner_manager_stat', NULL, '[[regtime]]', NULL, 336, 94),
(13, NULL, NULL, 'reports', NULL, '[[regtime]]', NULL, 337, 91),
(13, NULL, NULL, 'reports', NULL, '[[regtime]]', NULL, 338, 92),
(13, NULL, NULL, 'reports', NULL, '[[regtime]]', NULL, 339, 93),
(13, NULL, NULL, 'reports', NULL, '[[regtime]]', NULL, 340, 221),
(13, NULL, NULL, 'reports', NULL, '[[regtime]]', NULL, 341, 94),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 342, 91),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 343, 92),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 344, 93),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 345, 221),
(14, 5, NULL, NULL, NULL, '[[regtime]]', NULL, 346, 94),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 347, 91),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 348, 92),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 349, 93),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 350, 221),
(15, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 351, 94),
(40, NULL, NULL, '234', NULL, '[[regtime]]', NULL, 352, 91),
(40, NULL, NULL, '222', NULL, '[[regtime]]', NULL, 353, 92),
(40, NULL, NULL, '208', NULL, '[[regtime]]', NULL, 354, 93),
(40, NULL, NULL, '234', NULL, '[[regtime]]', NULL, 355, 221),
(40, NULL, NULL, '237', NULL, '[[regtime]]', NULL, 356, 94),
(10, NULL, NULL, 'abantecart', NULL, '[[regtime]]', NULL, 357, 111),
(10, NULL, NULL, 'documentation', NULL, '[[regtime]]', NULL, 358, 112),
(10, NULL, NULL, 'support', NULL, '[[regtime]]', NULL, 359, 113),
(10, NULL, NULL, 'marketplace', NULL, '[[regtime]]', NULL, 360, 114),
(11, NULL, NULL, 'text_abantecart', NULL, '[[regtime]]', NULL, 361, 111),
(11, NULL, NULL, 'text_documentation', NULL, '[[regtime]]', NULL, 362, 112),
(11, NULL, NULL, 'text_support', NULL, '[[regtime]]', NULL, 363, 113),
(11, NULL, NULL, 'text_extensions_store', NULL, '[[regtime]]', NULL, 364, 114),
(12, NULL, NULL, 'window.open(''https://www.abantecart.com'');', NULL, '[[regtime]]', NULL, 365, 111),
(12, NULL, NULL, 'window.open(''https://docs.abantecart.com'');', NULL, '[[regtime]]', NULL, 366, 112),
(12, NULL, NULL, 'window.open(''https://forum.abantecart.com'');', NULL, '[[regtime]]', NULL, 367, 113),
(12, NULL, NULL, 'window.open(''https://marketplace.abantecart.com'');', NULL, '[[regtime]]', NULL, 368, 114),
(13, NULL, NULL, 'help', NULL, '[[regtime]]', NULL, 369, 111),
(13, NULL, NULL, 'help', NULL, '[[regtime]]', NULL, 370, 112),
(13, NULL, NULL, 'help', NULL, '[[regtime]]', NULL, 371, 113),
(13, NULL, NULL, 'help', NULL, '[[regtime]]', NULL, 372, 114),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 373, 111),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 374, 112),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 375, 113),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 376, 114),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 377, 111),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 378, 112),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 379, 113),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 380, 114),
(40, NULL, NULL, '238', NULL, '[[regtime]]', NULL, 381, 111),
(40, NULL, NULL, '239', NULL, '[[regtime]]', NULL, 382, 112),
(40, NULL, NULL, '240', NULL, '[[regtime]]', NULL, 383, 113),
(40, NULL, NULL, '203', NULL, '[[regtime]]', NULL, 384, 114),
(10, NULL, NULL, 'template', NULL, '[[regtime]]', NULL, 385, 131),
(10, NULL, NULL, 'layout', NULL, '[[regtime]]', NULL, 386, 132),
(10, NULL, NULL, 'blocks', NULL, '[[regtime]]', NULL, 387, 133),
(10, NULL, NULL, 'menu', NULL, '[[regtime]]', NULL, 388, 134),
(10, NULL, NULL, 'content', NULL, '[[regtime]]', NULL, 389, 135),
(10, NULL, NULL, 'banner_manager', NULL, '[[regtime]]', NULL, 390, 136),
(10, NULL, NULL, 'forms_manager', NULL, '[[regtime]]', NULL, 391, 200),
(10, NULL, NULL, 'email_templates', NULL, '[[regtime]]', NULL, 392, 137),
(11, NULL, NULL, 'text_templates', NULL, '[[regtime]]', NULL, 393, 131),
(11, NULL, NULL, 'text_layout', NULL, '[[regtime]]', NULL, 394, 132),
(11, NULL, NULL, 'text_blocks', NULL, '[[regtime]]', NULL, 395, 133),
(11, NULL, NULL, 'text_menu', NULL, '[[regtime]]', NULL, 396, 134),
(11, NULL, NULL, 'text_content', NULL, '[[regtime]]', NULL, 397, 135),
(11, NULL, NULL, 'banner_manager_name', NULL, '[[regtime]]', NULL, 398, 136),
(11, NULL, NULL, 'forms_manager_name', NULL, '[[regtime]]', NULL, 399, 200),
(11, NULL, NULL, 'email_templates', NULL, '[[regtime]]', NULL, 400, 137),
(12, NULL, NULL, 'design/template', NULL, '[[regtime]]', NULL, 401, 131),
(12, NULL, NULL, 'design/layout', NULL, '[[regtime]]', NULL, 402, 132),
(12, NULL, NULL, 'design/blocks', NULL, '[[regtime]]', NULL, 403, 133),
(12, NULL, NULL, 'design/menu', NULL, '[[regtime]]', NULL, 404, 134),
(12, NULL, NULL, 'design/content', NULL, '[[regtime]]', NULL, 405, 135),
(12, NULL, NULL, 'extension/banner_manager', NULL, '[[regtime]]', NULL, 406, 136),
(12, NULL, NULL, 'design/email_templates', NULL, '[[regtime]]', NULL, 407, 137),
(12, NULL, NULL, 'tool/forms_manager', NULL, '[[regtime]]', NULL, 408, 200),
(13, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 409, 131),
(13, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 410, 132),
(13, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 411, 133),
(13, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 412, 134),
(13, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 413, 135),
(13, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 414, 136),
(13, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 415, 137),
(13, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 416, 200),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 417, 131),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 418, 132),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 419, 133),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 420, 134),
(14, 5, NULL, NULL, NULL, '[[regtime]]', NULL, 421, 135),
(14, 6, NULL, NULL, NULL, '[[regtime]]', NULL, 422, 136),
(14, 8, NULL, NULL, NULL, '[[regtime]]', NULL, 423, 137),
(14, 7, NULL, NULL, NULL, '[[regtime]]', NULL, 424, 200),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 425, 131),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 426, 132),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 427, 133),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 428, 134),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 429, 135),
(15, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 430, 136),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 431, 137),
(15, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 432, 200),
(40, NULL, NULL, '241', NULL, '[[regtime]]', NULL, 433, 131),
(40, NULL, NULL, '242', NULL, '[[regtime]]', NULL, 434, 132),
(40, NULL, NULL, '243', NULL, '[[regtime]]', NULL, 435, 133),
(40, NULL, NULL, '244', NULL, '[[regtime]]', NULL, 436, 134),
(40, NULL, NULL, '245', NULL, '[[regtime]]', NULL, 437, 135),
(40, NULL, NULL, '246', NULL, '[[regtime]]', NULL, 438, 136),
(40, NULL, NULL, '280', NULL, '[[regtime]]', NULL, 439, 137),
(40, NULL, NULL, '248', NULL, '[[regtime]]', NULL, 440, 200),
(10, NULL, NULL, 'all_settings', NULL, '[[regtime]]', NULL, 441, 191),
(10, NULL, NULL, 'settings_details', NULL, '[[regtime]]', NULL, 442, 192),
(10, NULL, NULL, 'settings_general', NULL, '[[regtime]]', NULL, 443, 193),
(10, NULL, NULL, 'settings_checkout', NULL, '[[regtime]]', NULL, 444, 194),
(10, NULL, NULL, 'settings_appearance', NULL, '[[regtime]]', NULL, 445, 195),
(10, NULL, NULL, 'settings_mail', NULL, '[[regtime]]', NULL, 446, 196),
(10, NULL, NULL, 'settings_im', NULL, '[[regtime]]', NULL, 447, 219),
(10, NULL, NULL, 'settings_api', NULL, '[[regtime]]', NULL, 448, 197),
(10, NULL, NULL, 'settings_system', NULL, '[[regtime]]', NULL, 449, 198),
(10, NULL, NULL, 'settings_newstore', NULL, '[[regtime]]', NULL, 450, 199),
(11, NULL, NULL, 'text_all_settings', NULL, '[[regtime]]', NULL, 451, 191),
(11, NULL, NULL, 'text_settings_details', NULL, '[[regtime]]', NULL, 452, 192),
(11, NULL, NULL, 'text_settings_general', NULL, '[[regtime]]', NULL, 453, 193),
(11, NULL, NULL, 'text_settings_checkout', NULL, '[[regtime]]', NULL, 454, 194),
(11, NULL, NULL, 'text_settings_appearance', NULL, '[[regtime]]', NULL, 455, 195),
(11, NULL, NULL, 'text_settings_mail', NULL, '[[regtime]]', NULL, 456, 196),
(11, NULL, NULL, 'text_settings_im', NULL, '[[regtime]]', NULL, 457, 219),
(11, NULL, NULL, 'text_settings_api', NULL, '[[regtime]]', NULL, 458, 197),
(11, NULL, NULL, 'text_settings_system', NULL, '[[regtime]]', NULL, 459, 198),
(11, NULL, NULL, 'text_settings_newstore', NULL, '[[regtime]]', NULL, 460, 199),
(12, NULL, NULL, 'setting/setting/all', NULL, '[[regtime]]', NULL, 461, 191),
(12, NULL, NULL, 'setting/setting/details', NULL, '[[regtime]]', NULL, 462, 192),
(12, NULL, NULL, 'setting/setting/general', NULL, '[[regtime]]', NULL, 463, 193),
(12, NULL, NULL, 'setting/setting/checkout', NULL, '[[regtime]]', NULL, 464, 194),
(12, NULL, NULL, 'setting/setting/appearance', NULL, '[[regtime]]', NULL, 465, 195),
(12, NULL, NULL, 'setting/setting/mail', NULL, '[[regtime]]', NULL, 466, 196),
(12, NULL, NULL, 'setting/setting/im', NULL, '[[regtime]]', NULL, 467, 219),
(12, NULL, NULL, 'setting/setting/api', NULL, '[[regtime]]', NULL, 468, 197),
(12, NULL, NULL, 'setting/setting/system', NULL, '[[regtime]]', NULL, 469, 198),
(12, NULL, NULL, 'setting/store/insert', NULL, '[[regtime]]', NULL, 470, 199),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 471, 191),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 472, 192),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 473, 193),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 474, 194),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 475, 195),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 476, 196),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 477, 219),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 478, 197),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 479, 198),
(13, NULL, NULL, 'setting', NULL, '[[regtime]]', NULL, 480, 199),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 481, 191),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 482, 192),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 483, 193),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 484, 194),
(14, 5, NULL, NULL, NULL, '[[regtime]]', NULL, 485, 195),
(14, 6, NULL, NULL, NULL, '[[regtime]]', NULL, 486, 196),
(14, 7, NULL, NULL, NULL, '[[regtime]]', NULL, 487, 219),
(14, 8, NULL, NULL, NULL, '[[regtime]]', NULL, 488, 197),
(14, 9, NULL, NULL, NULL, '[[regtime]]', NULL, 489, 198),
(14, 10, NULL, NULL, NULL, '[[regtime]]', NULL, 490, 199),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 491, 191),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 492, 192),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 493, 193),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 494, 194),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 495, 195),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 496, 196),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 497, 219),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 498, 197),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 499, 198),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 500, 199),
(40, NULL, NULL, '247', NULL, '[[regtime]]', NULL, 501, 191),
(40, NULL, NULL, '248', NULL, '[[regtime]]', NULL, 502, 192),
(40, NULL, NULL, '249', NULL, '[[regtime]]', NULL, 503, 193),
(40, NULL, NULL, '250', NULL, '[[regtime]]', NULL, 504, 194),
(40, NULL, NULL, '251', NULL, '[[regtime]]', NULL, 505, 195),
(40, NULL, NULL, '252', NULL, '[[regtime]]', NULL, 506, 196),
(40, NULL, NULL, '276', NULL, '[[regtime]]', NULL, 507, 219),
(40, NULL, NULL, '253', NULL, '[[regtime]]', NULL, 508, 197),
(40, NULL, NULL, '254', NULL, '[[regtime]]', NULL, 509, 198),
(40, NULL, NULL, '255', NULL, '[[regtime]]', NULL, 510, 199),
(10, NULL, NULL, 'user', NULL, '[[regtime]]', NULL, 511, 151),
(10, NULL, NULL, 'permission', NULL, '[[regtime]]', NULL, 512, 152),
(11, NULL, NULL, 'text_user', NULL, '[[regtime]]', NULL, 513, 151),
(11, NULL, NULL, 'text_user_group', NULL, '[[regtime]]', NULL, 514, 152),
(12, NULL, NULL, 'user/user', NULL, '[[regtime]]', NULL, 515, 151),
(12, NULL, NULL, 'user/user_permission', NULL, '[[regtime]]', NULL, 516, 152),
(13, NULL, NULL, 'users', NULL, '[[regtime]]', NULL, 517, 151),
(13, NULL, NULL, 'users', NULL, '[[regtime]]', NULL, 518, 152),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 519, 151),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 520, 152),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 521, 151),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 522, 152),
(40, NULL, NULL, '256', NULL, '[[regtime]]', NULL, 523, 151),
(40, NULL, NULL, '257', NULL, '[[regtime]]', NULL, 524, 152),
(10, NULL, NULL, 'language', NULL, '[[regtime]]', NULL, 525, 171),
(10, NULL, NULL, 'language_definitions', NULL, '[[regtime]]', NULL, 526, 172),
(10, NULL, NULL, 'currency', NULL, '[[regtime]]', NULL, 527, 173),
(10, NULL, NULL, 'stockstatus', NULL, '[[regtime]]', NULL, 528, 174),
(10, NULL, NULL, 'orderstatus', NULL, '[[regtime]]', NULL, 529, 175),
(10, NULL, NULL, 'country', NULL, '[[regtime]]', NULL, 530, 176),
(10, NULL, NULL, 'zone', NULL, '[[regtime]]', NULL, 531, 177),
(10, NULL, NULL, 'location', NULL, '[[regtime]]', NULL, 532, 178),
(10, NULL, NULL, 'taxclass', NULL, '[[regtime]]', NULL, 533, 179),
(10, NULL, NULL, 'lengthclass', NULL, '[[regtime]]', NULL, 534, 180),
(10, NULL, NULL, 'weightclass', NULL, '[[regtime]]', NULL, 535, 181),
(11, NULL, NULL, 'text_language', NULL, '[[regtime]]', NULL, 536, 171),
(11, NULL, NULL, 'text_language_definitions', NULL, '[[regtime]]', NULL, 537, 172),
(11, NULL, NULL, 'text_currency', NULL, '[[regtime]]', NULL, 538, 173),
(11, NULL, NULL, 'text_stock_status', NULL, '[[regtime]]', NULL, 539, 174),
(11, NULL, NULL, 'text_order_status', NULL, '[[regtime]]', NULL, 540, 175),
(11, NULL, NULL, 'text_country', NULL, '[[regtime]]', NULL, 541, 176),
(11, NULL, NULL, 'text_zone', NULL, '[[regtime]]', NULL, 542, 177),
(11, NULL, NULL, 'text_location', NULL, '[[regtime]]', NULL, 543, 178),
(11, NULL, NULL, 'text_tax_class', NULL, '[[regtime]]', NULL, 544, 179),
(11, NULL, NULL, 'text_length_class', NULL, '[[regtime]]', NULL, 545, 180),
(11, NULL, NULL, 'text_weight_class', NULL, '[[regtime]]', NULL, 546, 181),
(12, NULL, NULL, 'localisation/language', NULL, '[[regtime]]', NULL, 547, 171),
(12, NULL, NULL, 'localisation/language_definitions', NULL, '[[regtime]]', NULL, 548, 172),
(12, NULL, NULL, 'localisation/currency', NULL, '[[regtime]]', NULL, 549, 173),
(12, NULL, NULL, 'localisation/stock_status', NULL, '[[regtime]]', NULL, 550, 174),
(12, NULL, NULL, 'localisation/order_status', NULL, '[[regtime]]', NULL, 551, 175),
(12, NULL, NULL, 'localisation/country', NULL, '[[regtime]]', NULL, 552, 176),
(12, NULL, NULL, 'localisation/zone', NULL, '[[regtime]]', NULL, 553, 177),
(12, NULL, NULL, 'localisation/location', NULL, '[[regtime]]', NULL, 554, 178),
(12, NULL, NULL, 'localisation/tax_class', NULL, '[[regtime]]', NULL, 555, 179),
(12, NULL, NULL, 'localisation/length_class', NULL, '[[regtime]]', NULL, 556, 180),
(12, NULL, NULL, 'localisation/weight_class', NULL, '[[regtime]]', NULL, 557, 181),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 558, 171),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 559, 172),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 560, 173),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 561, 174),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 562, 175),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 563, 176),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 564, 177),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 565, 178),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 566, 179),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 567, 180),
(13, NULL, NULL, 'localisation', NULL, '[[regtime]]', NULL, 568, 181),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 569, 171),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 570, 172),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 571, 173),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 572, 174),
(14, 5, NULL, NULL, NULL, '[[regtime]]', NULL, 573, 175),
(14, 6, NULL, NULL, NULL, '[[regtime]]', NULL, 574, 176),
(14, 7, NULL, NULL, NULL, '[[regtime]]', NULL, 575, 177),
(14, 8, NULL, NULL, NULL, '[[regtime]]', NULL, 576, 178),
(14, 9, NULL, NULL, NULL, '[[regtime]]', NULL, 577, 179),
(14, 10, NULL, NULL, NULL, '[[regtime]]', NULL, 578, 180),
(14, 11, NULL, NULL, NULL, '[[regtime]]', NULL, 579, 181),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 580, 171),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 581, 172),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 582, 173),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 583, 174),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 584, 175),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 585, 176),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 586, 177),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 587, 178),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 588, 179),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 589, 180),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 590, 181),
(40, NULL, NULL, '258', NULL, '[[regtime]]', NULL, 591, 171),
(40, NULL, NULL, '259', NULL, '[[regtime]]', NULL, 592, 172),
(40, NULL, NULL, '260', NULL, '[[regtime]]', NULL, 593, 173),
(40, NULL, NULL, '261', NULL, '[[regtime]]', NULL, 594, 174),
(40, NULL, NULL, '262', NULL, '[[regtime]]', NULL, 595, 175),
(40, NULL, NULL, '263', NULL, '[[regtime]]', NULL, 596, 176),
(40, NULL, NULL, '264', NULL, '[[regtime]]', NULL, 597, 177),
(40, NULL, NULL, '265', NULL, '[[regtime]]', NULL, 598, 178),
(40, NULL, NULL, '266', NULL, '[[regtime]]', NULL, 599, 179),
(40, NULL, NULL, '267', NULL, '[[regtime]]', NULL, 600, 180),
(40, NULL, NULL, '268', NULL, '[[regtime]]', NULL, 601, 181),
(10, NULL, NULL, 'backup', NULL, '[[regtime]]', NULL, 602, 183),
(10, NULL, NULL, 'migrate', NULL, '[[regtime]]', NULL, 603, 184),
(10, NULL, NULL, 'datasets', NULL, '[[regtime]]', NULL, 604, 185),
(10, NULL, NULL, 'import_export', NULL, '[[regtime]]', NULL, 605, 182),
(10, NULL, NULL, 'file_uploads', NULL, '[[regtime]]', NULL, 606, 188),
(11, NULL, NULL, 'text_backup', NULL, '[[regtime]]', NULL, 607, 183),
(11, NULL, NULL, 'text_migrate', NULL, '[[regtime]]', NULL, 608, 184),
(11, NULL, NULL, 'text_datasets_manager', NULL, '[[regtime]]', NULL, 609, 185),
(11, NULL, NULL, 'text_import_export', NULL, '[[regtime]]', NULL, 610, 182),
(11, NULL, NULL, 'text_file_uploads', NULL, '[[regtime]]', NULL, 611, 188),
(12, NULL, NULL, 'tool/backup', NULL, '[[regtime]]', NULL, 612, 183),
(12, NULL, NULL, 'tool/migration/step_one', NULL, '[[regtime]]', NULL, 613, 184),
(12, NULL, NULL, 'tool/datasets_manager', NULL, '[[regtime]]', NULL, 614, 185),
(12, NULL, NULL, 'tool/import_export', NULL, '[[regtime]]', NULL, 615, 182),
(12, NULL, NULL, 'tool/files', NULL, '[[regtime]]', NULL, 616, 188),
(13, NULL, NULL, 'data', NULL, '[[regtime]]', NULL, 617, 183),
(13, NULL, NULL, 'data', NULL, '[[regtime]]', NULL, 618, 184),
(13, NULL, NULL, 'data', NULL, '[[regtime]]', NULL, 619, 185),
(13, NULL, NULL, 'data', NULL, '[[regtime]]', NULL, 620, 182),
(13, NULL, NULL, 'data', NULL, '[[regtime]]', NULL, 621, 188),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 622, 183),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 623, 184),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 624, 185),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 625, 182),
(14, 5, NULL, NULL, NULL, '[[regtime]]', NULL, 626, 188),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 627, 183),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 628, 184),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 629, 185),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 630, 182),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 631, 188),
(40, NULL, NULL, '269', NULL, '[[regtime]]', NULL, 632, 183),
(40, NULL, NULL, '270', NULL, '[[regtime]]', NULL, 633, 184),
(40, NULL, NULL, '271', NULL, '[[regtime]]', NULL, 634, 185),
(40, NULL, NULL, '272', NULL, '[[regtime]]', NULL, 635, 182),
(40, NULL, NULL, '273', NULL, '[[regtime]]', NULL, 636, 188),
(10, NULL, NULL, 'installlog', NULL, '[[regtime]]', NULL, 637, 186),
(10, NULL, NULL, 'error_log', NULL, '[[regtime]]', NULL, 638, 187),
(10, NULL, NULL, 'task', NULL, '[[regtime]]', NULL, 639, 189),
(11, NULL, NULL, 'text_install_upgrade_history', NULL, '[[regtime]]', NULL, 640, 186),
(11, NULL, NULL, 'text_error_log', NULL, '[[regtime]]', NULL, 641, 187),
(11, NULL, NULL, 'text_tasks', NULL, '[[regtime]]', NULL, 642, 189),
(12, NULL, NULL, 'tool/install_upgrade_history', NULL, '[[regtime]]', NULL, 643, 186),
(12, NULL, NULL, 'tool/error_log', NULL, '[[regtime]]', NULL, 644, 187),
(12, NULL, NULL, 'tool/task', NULL, '[[regtime]]', NULL, 645, 189),
(13, NULL, NULL, 'logs', NULL, '[[regtime]]', NULL, 646, 186),
(13, NULL, NULL, 'logs', NULL, '[[regtime]]', NULL, 647, 187),
(13, NULL, NULL, 'logs', NULL, '[[regtime]]', NULL, 648, 189),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 649, 186),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 650, 187),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 651, 189),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 652, 186),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 653, 187),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 654, 189),
(40, NULL, NULL, '274', NULL, '[[regtime]]', NULL, 655, 186),
(40, NULL, NULL, '275', NULL, '[[regtime]]', NULL, 656, 187),
(40, NULL, NULL, '254', NULL, '[[regtime]]', NULL, 657, 189),
(10, NULL, NULL, 'report_sale_orders', NULL, '[[regtime]]', NULL, 658, 210),
(10, NULL, NULL, 'report_sale_tax', NULL, '[[regtime]]', NULL, 659, 211),
(10, NULL, NULL, 'report_sale_shipping', NULL, '[[regtime]]', NULL, 660, 212),
(10, NULL, NULL, 'report_sale_coupon', NULL, '[[regtime]]', NULL, 661, 213),
(11, NULL, NULL, 'text_order', NULL, '[[regtime]]', NULL, 662, 210),
(11, NULL, NULL, 'text_tax', NULL, '[[regtime]]', NULL, 663, 211),
(11, NULL, NULL, 'text_shipping', NULL, '[[regtime]]', NULL, 664, 212),
(11, NULL, NULL, 'text_discount', NULL, '[[regtime]]', NULL, 665, 213),
(12, NULL, NULL, 'report/sale/orders', NULL, '[[regtime]]', NULL, 666, 210),
(12, NULL, NULL, 'report/sale/taxes', NULL, '[[regtime]]', NULL, 667, 211),
(12, NULL, NULL, 'report/sale/shipping', NULL, '[[regtime]]', NULL, 668, 212),
(12, NULL, NULL, 'report/sale/coupons', NULL, '[[regtime]]', NULL, 669, 213),
(13, NULL, NULL, 'report_sale', NULL, '[[regtime]]', NULL, 670, 210),
(13, NULL, NULL, 'report_sale', NULL, '[[regtime]]', NULL, 671, 211),
(13, NULL, NULL, 'report_sale', NULL, '[[regtime]]', NULL, 672, 212),
(13, NULL, NULL, 'report_sale', NULL, '[[regtime]]', NULL, 673, 213),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 674, 210),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 675, 211),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 676, 212),
(14, 4, NULL, NULL, NULL, '[[regtime]]', NULL, 677, 213),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 678, 210),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 679, 211),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 680, 212),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 681, 213),
(40, NULL, NULL, '221', NULL, '[[regtime]]', NULL, 682, 210),
(40, NULL, NULL, '266', NULL, '[[regtime]]', NULL, 683, 211),
(40, NULL, NULL, '214', NULL, '[[regtime]]', NULL, 684, 212),
(40, NULL, NULL, '224', NULL, '[[regtime]]', NULL, 685, 213),
(10, NULL, NULL, 'report_customer_online', NULL, '[[regtime]]', NULL, 686, 214);
INSERT INTO `[[dbprefix]]dataset_values` VALUES
(10, NULL, NULL, 'report_customer_order', NULL, '[[regtime]]', NULL, 687, 215),
(10, NULL, NULL, 'report_customer_transactions', NULL, '[[regtime]]', NULL, 688, 216),
(11, NULL, NULL, 'text_online', NULL, '[[regtime]]', NULL, 689, 214),
(11, NULL, NULL, 'text_order', NULL, '[[regtime]]', NULL, 690, 215),
(11, NULL, NULL, 'text_balance_history', NULL, '[[regtime]]', NULL, 691, 216),
(12, NULL, NULL, 'report/customer/online', NULL, '[[regtime]]', NULL, 692, 214),
(12, NULL, NULL, 'report/customer/orders', NULL, '[[regtime]]', NULL, 693, 215),
(12, NULL, NULL, 'report/customer/transactions', NULL, '[[regtime]]', NULL, 694, 216),
(13, NULL, NULL, 'report_customer', NULL, '[[regtime]]', NULL, 695, 214),
(13, NULL, NULL, 'report_customer', NULL, '[[regtime]]', NULL, 696, 215),
(13, NULL, NULL, 'report_customer', NULL, '[[regtime]]', NULL, 697, 216),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 698, 214),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 699, 215),
(14, 3, NULL, NULL, NULL, '[[regtime]]', NULL, 700, 216),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 701, 214),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 702, 215),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 703, 216),
(40, NULL, NULL, '222', NULL, '[[regtime]]', NULL, 704, 214),
(40, NULL, NULL, '221', NULL, '[[regtime]]', NULL, 705, 215),
(40, NULL, NULL, '260', NULL, '[[regtime]]', NULL, 706, 216),
(10, NULL, NULL, 'report_product_viewed', NULL, '[[regtime]]', NULL, 707, 217),
(10, NULL, NULL, 'report_product_purchased', NULL, '[[regtime]]', NULL, 708, 218),
(11, NULL, NULL, 'text_report_viewed', NULL, '[[regtime]]', NULL, 709, 217),
(11, NULL, NULL, 'text_report_purchased', NULL, '[[regtime]]', NULL, 710, 218),
(12, NULL, NULL, 'report/viewed', NULL, '[[regtime]]', NULL, 711, 217),
(12, NULL, NULL, 'report/purchased', NULL, '[[regtime]]', NULL, 712, 218),
(13, NULL, NULL, 'report_product', NULL, '[[regtime]]', NULL, 713, 217),
(13, NULL, NULL, 'report_product', NULL, '[[regtime]]', NULL, 714, 218),
(14, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 715, 217),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 716, 218),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 717, 217),
(15, NULL, NULL, 'core', NULL, '[[regtime]]', NULL, 718, 218),
(40, NULL, NULL, '235', NULL, '[[regtime]]', NULL, 719, 217),
(40, NULL, NULL, '236', NULL, '[[regtime]]', NULL, 720, 218),
(16, NULL, NULL, 'home', NULL, '[[regtime]]', NULL, 721, 1),
(16, NULL, NULL, 'login', NULL, '[[regtime]]', NULL, 722, 2),
(16, NULL, NULL, 'logout', NULL, '[[regtime]]', NULL, 723, 3),
(16, NULL, NULL, 'account', NULL, '[[regtime]]', NULL, 724, 4),
(16, NULL, NULL, 'cart', NULL, '[[regtime]]', NULL, 725, 5),
(16, NULL, NULL, 'checkout', NULL, '[[regtime]]', NULL, 726, 6),
(16, NULL, NULL, 'specials', NULL, '[[regtime]]', NULL, 727, 14),
(16, NULL, NULL, 'order', NULL, '[[regtime]]', NULL, 728, 15),
(17, NULL, NULL, 'Home', NULL, '[[regtime]]', NULL, 729, 1),
(17, NULL, NULL, 'Login', NULL, '[[regtime]]', NULL, 730, 2),
(17, NULL, NULL, 'Logout', NULL, '[[regtime]]', NULL, 731, 3),
(17, NULL, NULL, 'Account', NULL, '[[regtime]]', NULL, 732, 4),
(17, NULL, NULL, 'Cart', NULL, '[[regtime]]', NULL, 733, 5),
(17, NULL, NULL, 'Checkout', NULL, '[[regtime]]', NULL, 734, 6),
(17, NULL, NULL, 'Specials', NULL, '[[regtime]]', NULL, 735, 14),
(17, NULL, NULL, 'Check Your Order', NULL, '[[regtime]]', NULL, 736, 15),
(18, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 737, 1),
(18, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 738, 2),
(18, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 739, 3),
(18, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 740, 4),
(18, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 741, 5),
(18, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 742, 6),
(18, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 743, 14),
(18, 1, NULL, NULL, NULL, '[[regtime]]', NULL, 744, 15),
(20, NULL, NULL, NULL, NULL, '[[regtime]]', NULL, 745, 1),
(21, NULL, NULL, 'AbanteCart', NULL, '[[regtime]]', NULL, 746, 1),
(22, NULL, NULL, '1.4.4', NULL, '[[regtime]]', NULL, 747, 1),
(23, NULL, NULL, '', NULL, '[[regtime]]', NULL, 748, 1),
(24, NULL, NULL, '', NULL, '[[regtime]]', NULL, 749, 1),
(25, NULL, NULL, 'install', NULL, '[[regtime]]', NULL, 750, 1),
(26, NULL, NULL, 'admin', NULL, '[[regtime]]', NULL, 751, 1),
(20, NULL, NULL, NULL, NULL, '[[regtime_yest]]', NULL, 752, 2),
(21, NULL, NULL, 'novator', NULL, '[[regtime]]', NULL, 753, 2),
(22, NULL, NULL, '', NULL, '[[regtime]]', NULL, 754, 2),
(23, NULL, NULL, '', NULL, '[[regtime]]', NULL, 755, 2),
(24, NULL, NULL, NULL, NULL, '0000-00-00 00:00:00', NULL, 756, 2),
(25, NULL, NULL, 'install', NULL, '[[regtime]]', NULL, 757, 2),
(26, NULL, NULL, 'install', NULL, '[[regtime]]', NULL, 758, 2),
(10, NULL, NULL, 'page_builder', NULL, '[[regtime]]', NULL, 759, 222),
(13, NULL, NULL, 'design', NULL, '[[regtime]]', NULL, 760, 222),
(11, NULL, NULL, 'page_builder_name', NULL, '[[regtime]]', NULL, 761, 222),
(12, NULL, NULL, 'design/page_builder', NULL, '[[regtime]]', NULL, 762, 222),
(40, NULL, NULL, '100263', NULL, '[[regtime]]', NULL, 763, 222),
(15, NULL, NULL, 'extension', NULL, '[[regtime]]', NULL, 764, 222),
(14, 2, NULL, NULL, NULL, '[[regtime]]', NULL, 765, 222);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]downloads`
--

CREATE TABLE `[[dbprefix]]downloads` (
  `download_id` int NOT NULL AUTO_INCREMENT,
  `filename` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `mask` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `max_downloads` int DEFAULT NULL,
  `expire_days` int DEFAULT NULL,
  `sort_order` int NOT NULL,
  `activate` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  `activate_order_status_id` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `shared` int NOT NULL DEFAULT '0',
  `status` int NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`download_id`),
  KEY `[[dbprefix]]downloads_idx` (`activate_order_status_id`,`shared`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=7 ;

--
-- Dumping data for table `[[dbprefix]]downloads`
--

INSERT INTO `[[dbprefix]]downloads` VALUES
(1, '100196', 'audio-cd.mp3', 50, NULL, 2, 'order_status', 'a:1:{i:0;s:1:"5";}', 0, 1, '[[regtime]]', '[[regtime]]'),
(2, '100197', 'sample.mp3', NULL, NULL, 1, 'before_order', 'a:1:{i:0;s:0:"";}', 0, 1, '[[regtime]]', '[[regtime]]'),
(5, 'download/18/79/f.pdf', 'size-fit-guide-print.pdf', NULL, NULL, 0, 'before_order', 'a:1:{i:0;s:0:"";}', 1, 1, '[[regtime]]', '[[regtime]]'),
(6, '100261', 'file-sample_150kB.pdf', NULL, NULL, 0, 'immediately', '0', 0, 1, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]download_attribute_values`
--

CREATE TABLE `[[dbprefix]]download_attribute_values` (
  `download_attribute_id` int NOT NULL AUTO_INCREMENT,
  `attribute_id` int NOT NULL,
  `download_id` int NOT NULL,
  `attribute_value_ids` text COLLATE utf8mb4_unicode_ci,
  PRIMARY KEY (`download_attribute_id`),
  KEY `[[dbprefix]]download_attribute_values_idx` (`attribute_id`,`download_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]download_descriptions`
--

CREATE TABLE `[[dbprefix]]download_descriptions` (
  `download_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  PRIMARY KEY (`download_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]download_descriptions`
--

INSERT INTO `[[dbprefix]]download_descriptions` VALUES
(1, 1, 'Audio CD1'),
(2, 1, 'audio sample mp3'),
(5, 1, 'Find your fit'),
(6, 1, 'Sample PDF');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]email_templates`
--

CREATE TABLE `[[dbprefix]]email_templates` (
  `id` int NOT NULL AUTO_INCREMENT,
  `status` tinyint(1) NOT NULL,
  `text_id` varchar(255) CHARACTER SET utf8mb3 COLLATE utf8mb3_unicode_ci NOT NULL,
  `language_id` int NOT NULL,
  `headers` varchar(255) CHARACTER SET utf8mb3 COLLATE utf8mb3_unicode_ci NOT NULL,
  `subject` varchar(255) CHARACTER SET utf8mb3 COLLATE utf8mb3_unicode_ci NOT NULL COMMENT 'translatable',
  `html_body` text CHARACTER SET utf8mb3 COLLATE utf8mb3_unicode_ci NOT NULL COMMENT 'translatable',
  `text_body` text CHARACTER SET utf8mb3 COLLATE utf8mb3_unicode_ci NOT NULL COMMENT 'translatable',
  `allowed_placeholders` text CHARACTER SET utf8mb3 COLLATE utf8mb3_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `date_deleted` timestamp NULL DEFAULT NULL,
  `store_id` int NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `email_templates_text_id_idx` (`text_id`,`language_id`,`store_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=26 ;

--
-- Dumping data for table `[[dbprefix]]email_templates`
--

INSERT INTO `[[dbprefix]]email_templates` VALUES
(1, 1, 'storefront_reset_password_link', 1, '', '{{store_name}} - Password reset', 'A password reset was requested from {{store_name}}&lt;br /&gt;\r\nTo reset your password click link below:&lt;br /&gt;\r\n&lt;a href="{{ reset_link }}"&gt;{{ reset_link }}&lt;/a &gt;\r\n&lt;br /&gt;&lt;br /&gt;\r\n{{{ text_project_label }}}', 'A password reset was requested from {{store_name}} \r\nTo reset your password click link below:\r\n{{ reset_link }}\r\n\r\n\r\n{{{ text_project_label }}}', 'store_name, reset_link, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(2, 1, 'storefront_welcome_email_activated', 1, '', 'Welcome, {{store_name}}', '&lt;html&gt;\r\n	&lt;head&gt;\r\n		&lt;meta http-equiv=&quot;Content-Type&quot; content=&quot;text/html; charset=utf-8&quot;&gt;\r\n	&lt;/head&gt;\r\n	&lt;body&gt;\r\n		&lt;table style=&quot;font-family: Verdana,sans-serif; font-size: 11px; color: #374953; width: 600px;&quot;&gt;\r\n			&lt;tr&gt;\r\n				&lt;td class=&quot;align_left&quot;&gt;\r\n				&lt;a href=&quot;{{ store_url }}&quot; title=&quot;{{ store_name }}&quot;&gt;\r\n						{{# logo_uri}}\r\n				&lt;img src=&quot;{{ logo_uri }}&quot; alt=&quot;{{store_name}}&quot; style=&quot;border: none;&quot;&gt;\r\n                                                 {{/ logo_uri}}\r\n                                                 {{^ logo_uri}}\r\n                                                       {{# logo_html}}\r\n                                                        {{logo_html}}\r\n                                                       {{/ logo_html}}\r\n                                                 {{/ logo_uri}}\r\n					&lt;/a&gt;\r\n				&lt;/td&gt;\r\n			&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n		&lt;td&gt;Welcome and thank you for registering at {{ store_name }}&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;\r\n                          Your account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:&lt;br/&gt;\r\n&lt;a href=&quot;{{ login_url }}&quot;&gt;{{ login_url }}&lt;/a&gt;&lt;br/&gt;\r\nOnce you logging in, you will be able to access, your wishlist, order history, printing invoices and editing your account information.\r\n	&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;\r\n					Thank you.&lt;br/&gt;\r\n                                        {{ store_name }}\r\n&lt;br/&gt;&lt;br/&gt;\r\n{{{ text_project_label }}}\r\n		&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n		&lt;/table&gt;\r\n	&lt;/body&gt;\r\n&lt;/html&gt;', 'Welcome and thank you for registering at {{ store_name }}\r\n\r\nYour account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:\r\n{{ login_url }}\r\n\r\nOnce you logging in, you will be able to access, your wishlist, order history, printing invoices and editing your account information.\r\n\r\nThank you.\r\n{{ store_name }}\r\n{{{ text_project_label }}}', 'store_name, login_url, store_url, logo_html, logo_uri, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(3, 1, 'storefront_welcome_email_approval', 1, '', 'Welcome, {{store_name}}', '&lt;html&gt;\r\n	&lt;head&gt;\r\n		&lt;meta http-equiv=&quot;Content-Type&quot; content=&quot;text/html; charset=utf-8&quot;&gt;\r\n	&lt;/head&gt;\r\n	&lt;body&gt;\r\n		&lt;table style=&quot;font-family: Verdana,sans-serif; font-size: 11px; color: #374953; width: 600px;&quot;&gt;\r\n			&lt;tr&gt;\r\n				&lt;td class=&quot;align_left&quot;&gt;\r\n					&lt;a href=&quot;{{ store_url }}&quot; title=&quot;{{ store_name }}&quot;&gt;\r\n				{{#logo_uri}}\r\n				&lt;img src=&quot;{{ logo_uri }}&quot; alt=&quot;{{store_name}}&quot; style=&quot;border: none;&quot;&gt;\r\n                                                 {{/logo_uri}}\r\n                                                 {{^logo_uri}}\r\n                                                       {{#logo_html}}\r\n                                                        {{logo_html}}\r\n                                                       {{/logo_html}}\r\n                                                 {{/logo_uri}}\r\n					&lt;/a&gt;\r\n				&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;Welcome and thank you for registering at {{ store_name }}&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;\r\n                          Your account must be approved before you can login. Once approved you can log in by using your email address and password by visiting our website or at the following URL:&lt;br/&gt;\r\n&lt;a href=&quot;{{ login_url }}&quot;&gt;{{ login_url }}&lt;/a&gt;&lt;br/&gt;\r\nOnce you logging in, you will be able to access, your wishlist, order history, printing invoices and editing your account information.\r\n		&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;\r\n					Thank you.&lt;br/&gt;\r\n                                        {{ store_name }}\r\n&lt;br/&gt;&lt;br/&gt;\r\n{{{ text_project_label }}}\r\n		&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n		&lt;/table&gt;\r\n	&lt;/body&gt;\r\n&lt;/html&gt;', 'Welcome and thank you for registering at {{ store_name }}\r\n\r\nYour account must be approved before you can login. Once approved you can log in by using your email address and password by visiting our website or at the following URL:\r\n{{ login_url }}\r\n\r\nOnce you logging in, you will be able to access, your wishlist, order history, printing invoices and editing your account information.\r\n\r\nThank you.\r\n{{ store_name }}\r\n{{{ text_project_label }}}', 'store_name, login_url, store_url, logo_html, logo_uri, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(4, 1, 'storefront_send_activate_link', 1, '', '{{store_name}} - Thank you for registering', '&lt;html&gt;\r\n	&lt;head&gt;\r\n		&lt;meta http-equiv=&quot;Content-Type&quot; content=&quot;text/html; charset=utf-8&quot;&gt;\r\n	&lt;/head&gt;\r\n	&lt;body&gt;\r\n		&lt;table style=&quot;font-family: Verdana,sans-serif; font-size: 11px; color: #374953; width: 600px;&quot;&gt;\r\n			&lt;tr&gt;\r\n				&lt;td class=&quot;align_left&quot;&gt;\r\n					&lt;a href=&quot;{{ store_url }}&quot; title=&quot;{{ store_name }}&quot;&gt;\r\n					{{#logo_uri}}\r\n							&lt;img src=&quot;{{ logo_uri }}&quot; alt=&quot;{{store_name}}&quot; style=&quot;border: none;&quot;&gt;\r\n                                                 {{/logo_uri}}\r\n                                                 {{^logo_uri}}\r\n                                                       {{#logo_html}}\r\n                                                        {{logo_html}}\r\n                                                       {{/logo_html}}\r\n                                                 {{/logo_uri}}\r\n					&lt;/a&gt;\r\n			&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n		&lt;td&gt;Welcome and thank you for registering at {{ store_name }}&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;\r\n                          Before we can activate your account one last step must be taken to complete your registration.&lt;br/&gt;\r\nYou must complete this last step to become a registered member. Please click the following link to activate your account:&lt;br/&gt;\r\n{{{ activate_url }}}&lt;br/&gt;\r\n\r\n				&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n		&lt;td&gt;\r\n					Thank you.&lt;br/&gt;\r\n                                        {{ store_name }}\r\n&lt;br/&gt;\r\n&lt;br/&gt;\r\n{{{ text_project_label }}}\r\n			 	&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n		&lt;/table&gt;\r\n	&lt;/body&gt;\r\n&lt;/html&gt;', 'Welcome and thank you for registering at {{ store_name }}!\r\n\r\nBefore we can activate your account one last step must be taken to complete your registration.\r\nYou must complete this last step to become a registered member. Please click the following link to activate your account\r\n{{ activate_url }}\r\n\r\nThank you,\r\n{{ store_name }}\r\n\r\n{{{ text_project_label }}}', 'store_name, activate_url, logo_uri, logo_html, store_url, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(5, 1, 'storefront_reset_password_notify', 1, '', '{{store_name}} - Password reset', 'Your password was successfully reset on {{store_name}}\r\n&lt;br/&gt;\r\n{{{ text_project_label }}}', 'Your password was successfully reset on {{store_name}}\r\n\r\n{{{ text_project_label }}}', 'store_name, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(6, 1, 'storefront_send_login_name', 1, '', '{{store_name}} - Login name reminder', 'Login name reminder was requested from {{store_name}} &lt;br/&gt;\r\n&lt;br/&gt;\r\nYour login name is: {{ login_name }}\r\n\r\n&lt;br/&gt;\r\n{{store_name}} \r\n&lt;br/&gt;\r\n&lt;br/&gt;\r\n{{{ text_project_label }}}', 'Login name reminder was requested from {{store_name}} \r\n\r\nYour login name is: {{ login_name }}\r\n\r\n{{store_name}} \r\n\r\n{{{ text_project_label }}}', 'store_name, login_name, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(7, 1, 'storefront_order_confirm', 1, '', '{{store_name}} - Order {{ order_id }}', '&lt;html&gt;\r\n&lt;head&gt;\r\n	&lt;meta http-equiv=&quot;Content-Type&quot; content=&quot;text/html; charset=utf-8&quot;&gt;\r\n	&lt;title&gt; {{store_name}} - Order {{ order_id }} &lt;/title&gt;\r\n&lt;/head&gt;\r\n&lt;body&gt;\r\n&lt;table style=&quot;font-family: Verdana,sans-serif; font-size: 11px; color: #374953; width: 600px;&quot;&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;\r\n					&lt;a href=&quot;{{ store_url }}&quot; title=&quot;{{ store_name }}&quot;&gt;\r\n						{{# logo_uri}}\r\n			&lt;img src=&quot;{{ logo_uri }}&quot; alt=&quot;{{store_name}}&quot; style=&quot;border: none;&quot;&gt;\r\n                                                 {{/ logo_uri}}\r\n                                                 {{^ logo_uri}}\r\n                                                       {{# logo_html}}\r\n                                                        {{logo_html}}\r\n                                                       {{/ logo_html}}\r\n                                                 {{/ logo_uri}}\r\n					&lt;/a&gt;\r\n				&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;Thank you for your interest in {{store_name}} products. Your order has been received and will be processed after payment is confirmed.&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;\r\n		    style=&quot;background-color: #069; color:#FFF; font-size: 12px; font-weight: bold; padding: 0.5em 1em;&quot;&gt;Order Details&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;Order ID: &lt;span\r\n					style=&quot;color: #069; font-weight: bold;&quot;&gt;{{ order_id }}&lt;/span&gt;&lt;br/&gt;\r\n			Date Ordered: {{ date_added }}&lt;br&gt;\r\n			Payment Method: &lt;strong&gt;{{ payment_method }}&lt;/strong&gt;&lt;br/&gt;\r\n			Shipping Method: &lt;strong&gt;{{ shipping_method }}&lt;/strong&gt;&lt;br/&gt;\r\n			&lt;br/&gt;\r\n			Email: &lt;strong&gt;{{ customer_email }}&lt;/strong&gt;&lt;br/&gt;\r\n			Telephone: &lt;strong&gt;{{ customer_telephone }}&lt;/strong&gt;&lt;br/&gt;\r\n                         {{# customer_mobile_phone }}\r\n                            Telephone: &lt;strong&gt;{{ customer_mobile_phone }}&lt;/strong&gt;&lt;br/&gt;\r\n                         {{/ customer_mobile_phone }}\r\n		         {{# customer_fax }}\r\n                            Fax: &lt;strong&gt;{{ customer_fax }}&lt;/strong&gt;&lt;br/&gt;\r\n                         {{/ customer_fax }}\r\n                         IP Address:&lt;strong&gt;{{ customer_ip }}&lt;/strong&gt;\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;\r\n			&lt;table style=&quot;width: 100%; font-family: Verdana,sans-serif; font-size: 11px; color: #FFFFFF;&quot;&gt;\r\n				&lt;tr style=&quot;background-color: #CCCCCC; text-transform: uppercase;&quot;&gt;\r\n		&lt;th style=&quot;text-align: left; padding: 0.3em;&quot;&gt;Shipping Address&lt;/th&gt;\r\n					&lt;th style=&quot;text-align: left; padding: 0.3em;&quot;&gt;Payment Address&lt;/th&gt;\r\n				&lt;/tr&gt;\r\n				&lt;tr&gt;\r\n					&lt;td style=&quot;padding: 0.3em; background-color: #EEEEEE; color: #000;&quot;&gt;\r\n{{# shipping_data }}\r\n{{ firstname }} {{lastname}} &lt;br/&gt;\r\n{{# company }}\r\n{{{ company }}} &lt;br/&gt; \r\n{{/ company }}\r\n{{# address_1 }}\r\n{{{ address_1 }}} &lt;br/&gt; \r\n{{/ address_1 }}\r\n{{# address_2 }}\r\n{{{ address_2 }}} &lt;br/&gt; \r\n{{/ address_2 }}\r\n{{{ city }}} {{{ postcode }}} &lt;br/&gt; \r\n{{# zone }}\r\n{{{ zone }}} &lt;br/&gt; \r\n{{/ zone }}\r\n{{{ country }}}\r\n{{/ shipping_data }}\r\n&lt;/td&gt;\r\n&lt;td style=&quot;padding: 0.3em; background-color: #EEEEEE; color: #000;&quot;&gt;\r\n{{# payment_data }}\r\n{{ firstname }} {{lastname}} &lt;br/&gt;\r\n{{# company }}\r\n{{{ company }}} &lt;br/&gt; \r\n{{/ company }}\r\n{{# address_1 }}\r\n{{{ address_1 }}} &lt;br/&gt; \r\n{{/ address_1 }}\r\n{{# address_2 }}\r\n{{{ address_2 }}} &lt;br/&gt; \r\n{{/ address_2 }}\r\n{{{ city }}} {{{ postcode }}} &lt;br/&gt; \r\n{{# zone }}\r\n{{{ zone }}} &lt;br/&gt; \r\n{{/ zone }}\r\n{{{ country }}}\r\n{{/ payment_data }}\r\n&lt;/td&gt;\r\n				&lt;/tr&gt;\r\n			&lt;/table&gt;\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;\r\n			&lt;table style=&quot;width: 100%; font-family: Verdana,sans-serif; font-size: 11px; color: #000000;&quot;&gt;\r\n				&lt;tr style=&quot;background-color: #CCCCCC;&quot;&gt;\r\n					&lt;th style=&quot;width: 40%; padding: 0.3em; color: #FFFFFF;&quot;&gt;Product&lt;/th&gt;\r\n					&lt;th class=&quot;align_left&quot; style=&quot;color: #FFFFFF;&quot;&gt;Model&lt;/th&gt;\r\n&lt;th class=&quot;align_right&quot;\r\n		    style=&quot;width: 10%; padding: 0.3em; color: #FFFFFF;&quot;&gt;Price&lt;/th&gt;\r\n					&lt;th class=&quot;align_right&quot;\r\n					    style=&quot;width: 15%; padding: 0.3em; color: #FFFFFF;&quot;&gt;Quantity&lt;/th&gt;\r\n					&lt;th class=&quot;align_right&quot;\r\n	    style=&quot;width: 20%; padding: 0.3em; color: #FFFFFF;&quot;&gt;Total&lt;/th&gt;\r\n				&lt;/tr&gt;\r\n				{{# products }}\r\n					&lt;tr style=&quot;background-color: #EEEEEE; text-align: center;&quot;&gt;\r\n						&lt;td class=&quot;align_left&quot; style=&quot;text-align: left;&quot;&gt;{{ name }}\r\n	{{# option }}\r\n								&lt;br/&gt;\r\n								&amp;nbsp;&amp;nbsp;- {{ name}} {{ value }} \r\n	{{/ option }}\r\n						&lt;td class=&quot;align_left&quot;&gt; {{ model }} &lt;/td&gt;\r\n						&lt;td class=&quot;align_right&quot;&gt; {{ price }} &lt;/td&gt;\r\n						&lt;td class=&quot;align_right&quot;&gt; {{ quantity }} &lt;/td&gt;\r\n						&lt;td class=&quot;align_right&quot;&gt; {{ total }}&lt;/td&gt;\r\n					&lt;/tr&gt;\r\n                                {{/ products }}\r\n                                         {{# totals }}\r\n			&lt;tr style=&quot;text-align: right;&quot;&gt;\r\n						&lt;td colspan=&quot;3&quot;&gt;&amp;nbsp;&lt;/td&gt;\r\n						&lt;td style=&quot;background-color: #EEEEEE; font-weight: bold; padding: 0.3em;&quot;&gt;{{ title }} &lt;/td&gt;\r\n						&lt;td style=&quot;background-color: #EEEEEE; padding: 0.3em;&quot;&gt; {{ text }}&lt;/td&gt;\r\n					&lt;/tr&gt;\r\n                                         {{/ totals }}\r\n			&lt;/table&gt;\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;\r\n		    style=&quot;background-color: #069; color: #FFF; font-size: 12px; font-weight: bold; padding: 0.5em 1em;&quot;&gt;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n {{# comment }}\r\n	&lt;tr&gt;\r\n&lt;td class=&quot;align_left&quot;\r\n			    style=&quot;background-color: #069; color: #FFF; font-size: 12px; font-weight: bold; padding: 0.5em 1em;&quot;&gt;The comments for your order are:&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td class=&quot;align_left&quot;&gt; {{{ comment }}} &lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n {{/ comment }}\r\n {{# invoice }}\r\n		&lt;tr&gt;\r\n			&lt;td class=&quot;align_left&quot;\r\n			    style=&quot;background-color: #069; color: #FFF; font-size: 12px; font-weight: bold; padding: 0.5em 1em;&quot;&gt;To view your order click on the link below:&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;&lt;a href=&quot;{{ invoice }}&quot;&gt; {{ invoice }}&lt;/a&gt;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n{{/ invoice }}\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_center&quot;\r\n		    style=&quot;font-size: 10px; border-top: 1px solid #069; text-decoration: none; color: #374953;&quot;&gt;\r\n			&lt;a href=&quot;{{ store_url }}&quot;\r\n			   style=&quot;color: #069; font-weight: bold; text-decoration: none;&quot;&gt;{{ store_name }}&lt;/a&gt;\r\n{{{ text_project_label }}}\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n&lt;/table&gt;\r\n&lt;/body&gt;\r\n&lt;/html&gt;\r\n', 'Thank you for your interest in {{store_name}} products. Your order has been received and will be processed after payment is confirmed.\r\n\r\nOrder Details\r\n\r\nOrder ID: {{ order_id }}\r\nDate Ordered: {{ date_added }}\r\nPayment Method: {{ payment_method }}\r\nShipping Method: {{ shipping_method }}\r\n\r\nEmail: {{ customer_email }}\r\nTelephone: {{ customer_telephone }}\r\n{{# customer_mobile_phone }}\r\nTelephone: {{ customer_mobile_phone }}\r\n{{/ customer_mobile_phone }}\r\n{{# customer_fax }}\r\nFax: {{ customer_fax }}\r\n{{/ customer_fax }}\r\nIP Address: {{ customer_ip }}\r\n\r\n{{# shipping_data }}\r\nShipping Address:\r\n{{{ firstname }}} {{{lastname}}}\r\n{{{ company }}} \r\n{{{ address_1 }}} \r\n{{{ address_2 }}}\r\n{{{ city }}} {{{ postcode }}}\r\n{{{ zone }}}\r\n{{{ country }}}\r\n{{/ shipping_data }}\r\n\r\n{{# payment_data }}\r\nPayment Address:\r\n{{{ firstname }}} {{{lastname}}}\r\n{{{ company }}} \r\n{{{ address_1 }}} \r\n{{{ address_2 }}}\r\n{{{ city }}} {{{ postcode }}}\r\n{{{ zone }}}\r\n{{{ country }}}\r\n{{/ payment_data }}\r\n\r\n\r\nProduct                                                 Model                             Price                  Quantity              Total\r\n{{# products }}\r\n					\r\n{{ name }}                                               {{ model }}                       {{ price }}            {{ quantity }}        {{ total }}\r\n   {{# option }}\r\n    - {{ name}} {{ value }} \r\n   {{/ option }}\r\n\r\n\r\n{{/ products }}\r\n{{# totals }}\r\n  {{ title }}  {{ text }}\r\n{{/ totals }}\r\n\r\n\r\n{{# comment }}\r\n	The comments for your order are:\r\n {{{ comment }}} \r\n{{/ comment }}\r\n\r\n{{# invoice }}\r\nTo view your order click on the link below:\r\n{{ invoice }}\r\n{{/ invoice }}\r\n\r\n{{ store_name }}\r\n{{ text_project_label }}', 'store_name, order_id, store_url, logo_uri, logo_html, date_added, payment_method, shipping_method, customer_email, customer_telephone, customer_mobile_phone, customer_fax, customer_ip, shipping_data, payment_data, products, totals, comment, invoice,  text_project_label, ', '[[regtime]]', '[[regtime]]', NULL, 0),
(8, 1, 'storefront_order_confirm_admin_notify', 1, '', '{{store_name}} - Order {{ order_id }}', '&lt;html&gt;\r\n&lt;head&gt;\r\n	&lt;meta http-equiv=&quot;Content-Type&quot; content=&quot;text/html; charset=utf-8&quot;&gt;\r\n	&lt;title&gt; {{store_name}} - Order {{ order_id }} &lt;/title&gt;\r\n&lt;/head&gt;\r\n&lt;body&gt;\r\n&lt;table style=&quot;font-family: Verdana,sans-serif; font-size: 11px; color: #374953; width: 600px;&quot;&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;\r\n				&lt;a href=&quot;{{ store_url }}&quot; title=&quot;{{ store_name }}&quot;&gt;\r\n						{{# logo_uri}}\r\n				&lt;img src=&quot;{{ logo_uri }}&quot; alt=&quot;{{store_name}}&quot; style=&quot;border: none;&quot;&gt;\r\n                                                 {{/ logo_uri}}\r\n                                                 {{^ logo_uri}}\r\n                                                       {{# logo_html}}\r\n                                                        {{logo_html}}\r\n                                                       {{/ logo_html}}\r\n                                                 {{/ logo_uri}}\r\n					&lt;/a&gt;\r\n				&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;You have received an order.&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;\r\n		    style=&quot;background-color: #069; color:#FFF; font-size: 12px; font-weight: bold; padding: 0.5em 1em;&quot;&gt;Order Details&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;Order ID: &lt;span\r\n			style=&quot;color: #069; font-weight: bold;&quot;&gt;{{ order_id }}&lt;/span&gt;&lt;br/&gt;\r\n			Date Ordered: {{ date_added }}&lt;br&gt;\r\n			Payment Method: &lt;strong&gt;{{ payment_method }}&lt;/strong&gt;&lt;br/&gt;\r\n			Shipping Method: &lt;strong&gt;{{ shipping_method }}&lt;/strong&gt;&lt;br/&gt;\r\n			&lt;br/&gt;\r\n			Email: &lt;strong&gt;{{ customer_email }}&lt;/strong&gt;&lt;br/&gt;\r\n			Telephone: &lt;strong&gt;{{ customer_telephone }}&lt;/strong&gt;&lt;br/&gt;\r\n                         {{# customer_mobile_phone }}\r\n                            Telephone: &lt;strong&gt;{{ customer_mobile_phone }}&lt;/strong&gt;&lt;br/&gt;\r\n                         {{/ customer_mobile_phone }}\r\n		         {{# customer_fax }}\r\n                            Fax: &lt;strong&gt;{{ customer_fax }}&lt;/strong&gt;&lt;br/&gt;\r\n                         {{/ customer_fax }}\r\n                         IP Address:&lt;strong&gt;{{ customer_ip }}&lt;/strong&gt;\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;\r\n			&lt;table style=&quot;width: 100%; font-family: Verdana,sans-serif; font-size: 11px; color: #FFFFFF;&quot;&gt;\r\n		&lt;tr style=&quot;background-color: #CCCCCC; text-transform: uppercase;&quot;&gt;\r\n					&lt;th style=&quot;text-align: left; padding: 0.3em;&quot;&gt;Shipping Address&lt;/th&gt;\r\n		&lt;th style=&quot;text-align: left; padding: 0.3em;&quot;&gt;Payment Address&lt;/th&gt;\r\n				&lt;/tr&gt;\r\n				&lt;tr&gt;\r\n					&lt;td style=&quot;padding: 0.3em; background-color: #EEEEEE; color: #000;&quot;&gt;\r\n{{# shipping_data }}\r\n{{ firstname }} {{lastname}} &lt;br/&gt;\r\n{{# company }}\r\n{{{ company }}} &lt;br/&gt; \r\n{{/ company }}\r\n{{# address_1 }}\r\n{{{ address_1 }}} &lt;br/&gt; \r\n{{/ address_1 }}\r\n{{# address_2 }}\r\n{{{ address_2 }}} &lt;br/&gt; \r\n{{/ address_2 }}\r\n{{{ city }}} {{{ postcode }}} &lt;br/&gt; \r\n{{# zone }}\r\n{{{ zone }}} &lt;br/&gt; \r\n{{/ zone }}\r\n{{{ country }}}\r\n{{/ shipping_data }}\r\n&lt;/td&gt;\r\n					&lt;td style=&quot;padding: 0.3em; background-color: #EEEEEE; color: #000;&quot;&gt;\r\n{{# payment_data }}\r\n{{ firstname }} {{lastname}} &lt;br/&gt;\r\n{{# company }}\r\n{{{ company }}} &lt;br/&gt; \r\n{{/ company }}\r\n{{# address_1 }}\r\n{{{ address_1 }}} &lt;br/&gt; \r\n{{/ address_1 }}\r\n{{# address_2 }}\r\n{{{ address_2 }}} &lt;br/&gt; \r\n{{/ address_2 }}\r\n{{{ city }}} {{{ postcode }}} &lt;br/&gt; \r\n{{# zone }}\r\n{{{ zone }}} &lt;br/&gt; \r\n{{/ zone }}\r\n{{{ country }}}\r\n{{/ payment_data }}\r\n&lt;/td&gt;\r\n				&lt;/tr&gt;\r\n			&lt;/table&gt;\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;\r\n			&lt;table style=&quot;width: 100%; font-family: Verdana,sans-serif; font-size: 11px; color: #000000;&quot;&gt;\r\n				&lt;tr style=&quot;background-color: #CCCCCC;&quot;&gt;\r\n					&lt;th style=&quot;width: 40%; padding: 0.3em; color: #FFFFFF;&quot;&gt;Product&lt;/th&gt;\r\n					&lt;th class=&quot;align_left&quot; style=&quot;color: #FFFFFF;&quot;&gt;Model&lt;/th&gt;\r\n					&lt;th class=&quot;align_right&quot;\r\n		    style=&quot;width: 10%; padding: 0.3em; color: #FFFFFF;&quot;&gt;Price&lt;/th&gt;\r\n					&lt;th class=&quot;align_right&quot;\r\n					    style=&quot;width: 15%; padding: 0.3em; color: #FFFFFF;&quot;&gt;Quantity&lt;/th&gt;\r\n					&lt;th class=&quot;align_right&quot;\r\n					    style=&quot;width: 20%; padding: 0.3em; color: #FFFFFF;&quot;&gt;Total&lt;/th&gt;\r\n				&lt;/tr&gt;\r\n				{{# products }}\r\n					&lt;tr style=&quot;background-color: #EEEEEE; text-align: center;&quot;&gt;\r\n						&lt;td class=&quot;align_left&quot; style=&quot;text-align: left;&quot;&gt;{{ name }}\r\n					{{# option }}\r\n			&lt;br/&gt;\r\n								&amp;nbsp;&amp;nbsp;- {{ name}} {{ value }} \r\n	{{/ option }}\r\n						&lt;td class=&quot;align_left&quot;&gt; {{ model }} &lt;/td&gt;\r\n						&lt;td class=&quot;align_right&quot;&gt; {{ price }} &lt;/td&gt;\r\n						&lt;td class=&quot;align_right&quot;&gt; {{ quantity }} &lt;/td&gt;\r\n						&lt;td class=&quot;align_right&quot;&gt; {{ total }}&lt;/td&gt;\r\n					&lt;/tr&gt;\r\n                                {{/ products }}\r\n                                         {{# totals }}\r\n			&lt;tr style=&quot;text-align: right;&quot;&gt;\r\n						&lt;td colspan=&quot;3&quot;&gt;&amp;nbsp;&lt;/td&gt;\r\n						&lt;td style=&quot;background-color: #EEEEEE; font-weight: bold; padding: 0.3em;&quot;&gt;{{ title }} &lt;/td&gt;\r\n					&lt;td style=&quot;background-color: #EEEEEE; padding: 0.3em;&quot;&gt; {{ text }}&lt;/td&gt;\r\n					&lt;/tr&gt;\r\n                                         {{/ totals }}\r\n		&lt;/table&gt;\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;\r\n		    style=&quot;background-color: #069; color: #FFF; font-size: 12px; font-weight: bold; padding: 0.5em 1em;&quot;&gt;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n {{# comment }}\r\n	&lt;tr&gt;\r\n			&lt;td class=&quot;align_left&quot;\r\n			    style=&quot;background-color: #069; color: #FFF; font-size: 12px; font-weight: bold; padding: 0.5em 1em;&quot;&gt;The comments for your order are:&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td class=&quot;align_left&quot;&gt; {{{ comment }}} &lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n {{/ comment }}\r\n {{# invoice }}\r\n		&lt;tr&gt;\r\n			&lt;td class=&quot;align_left&quot;\r\n			    style=&quot;background-color: #069; color: #FFF; font-size: 12px; font-weight: bold; padding: 0.5em 1em;&quot;&gt;To view your order click on the link below:&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n&lt;td class=&quot;align_left&quot;&gt;&lt;a href=&quot;{{ invoice }}&quot;&gt; {{ invoice }}&lt;/a&gt;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr&gt;\r\n			&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n{{/ invoice }}\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_center&quot;\r\n		    style=&quot;font-size: 10px; border-top: 1px solid #069; text-decoration: none; color: #374953;&quot;&gt;\r\n			&lt;a href=&quot;{{ store_url }}&quot;\r\n			   style=&quot;color: #069; font-weight: bold; text-decoration: none;&quot;&gt;{{ store_name }}&lt;/a&gt;\r\n{{{ text_project_label }}}\r\n	&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n&lt;/table&gt;\r\n&lt;/body&gt;\r\n&lt;/html&gt;\r\n', 'You have received an order.\r\n\r\nOrder Details\r\n\r\nOrder ID: {{ order_id }}\r\nDate Ordered: {{ date_added }}\r\nPayment Method: {{ payment_method }}\r\nShipping Method: {{ shipping_method }}\r\n\r\nEmail: {{ customer_email }}\r\nTelephone: {{ customer_telephone }}\r\n{{# customer_mobile_phone }}\r\nTelephone: {{ customer_mobile_phone }}\r\n{{/ customer_mobile_phone }}\r\n{{# customer_fax }}\r\nFax: {{ customer_fax }}\r\n{{/ customer_fax }}\r\nIP Address: {{ customer_ip }}\r\n\r\n{{# shipping_data }}\r\nShipping Address:\r\n{{{ firstname }}} {{{lastname}}}\r\n{{{ company }}}\r\n{{{ address_1 }}} \r\n{{{ address_2 }}}\r\n{{{ city }}} {{{ postcode }}}\r\n{{{ zone }}}\r\n{{{ country }}}\r\n{{/ shipping_data }}\r\n\r\n{{# payment_data }}\r\nPayment Address:\r\n{{{ firstname }}} {{{lastname}}} \r\n{{{ company }}}\r\n{{{ address_1 }}}\r\n{{{ address_2 }}}\r\n{{{ city }}} {{{ postcode }}}\r\n{{{ zone }}}\r\n{{{ country }}}\r\n{{/ payment_data }}\r\n\r\n\r\nProduct                                                 Model                             Price                  Quantity              Total\r\n{{# products }}\r\n					\r\n{{ name }}                                               {{ model }}                       {{ price }}            {{ quantity }}        {{ total }}\r\n   {{# option }}\r\n    - {{ name}} {{ value }} \r\n   {{/ option }}\r\n\r\n\r\n{{/ products }}\r\n{{# totals }}\r\n  {{ title }}  {{ text }}\r\n{{/ totals }}\r\n\r\n\r\n{{# comment }}\r\n	The comments for your order are:\r\n {{{ comment }}} \r\n{{/ comment }}\r\n\r\n{{# invoice }}\r\nTo view your order click on the link below:\r\n{{ invoice }}\r\n{{/ invoice }}\r\n\r\n{{ store_name }}\r\n{{ text_project_label }}', 'store_name, order_id, store_url, logo_uri, logo_html, date_added, payment_method, shipping_method, customer_email, customer_telephone, customer_mobile_phone, customer_fax, customer_ip, shipping_data, payment_data, products, totals, comment, invoice,  text_project_label, order_total', '[[regtime]]', '[[regtime]]', NULL, 0),
(11, 1, 'admin_order_status_notify', 1, '', '{{ store_name }} - Order Update {{ order_id }}', 'Order:  {{ order_id }} &lt;br/&gt;\r\nDate added: {{ order_date_added }} &lt;br/&gt;\r\nOrder status: {{ order_status }} &lt;br/&gt;\r\nInvoice: {{ invoice }}&lt;br/&gt;\r\n&lt;br/&gt;\r\n\r\nComment:&lt;br/&gt;\r\n{{{ comment }}}&lt;br/&gt;\r\n\r\n&lt;br/&gt;\r\n\r\nPlease reply to this email if you have any questions.\r\n', 'Order:  {{ order_id }} \r\nDate added: {{ order_date_added }} \r\nOrder status: {{ order_status }} \r\nInvoice: {{ invoice }}\r\n\r\nComment:\r\n{{{ comment }}}\r\n\r\nPlease reply to this email if you have any questions.\r\n', 'store_name, order_id, order_date_added, order_status, invoice, comment', '[[regtime]]', '[[regtime]]', NULL, 0),
(12, 1, 'admin_new_transaction_notify', 1, '', 'New transaction has been posted to your {{store_name}} account', 'New transaction has been posted to your {{ store_name }} account in the amount of {{ amount }}. For more details, login to {{ store_name }} account', 'New transaction has been posted to your {{ store_name }} account in the amount of {{ amount }}. For more details, login to {{ store_name }} account', 'store_name, amount, transactions_url', '[[regtime]]', '[[regtime]]', NULL, 0),
(13, 1, 'admin_approval_email', 1, '', '{{ store_name}} - Your Account has been activated!', '&lt;a href="{{ store_url }}" title="{{ store_name }}"&gt;\r\n						{{# logo_uri}}\r\n				&lt;img src="{{ logo_uri }}" alt="{{store_name}}" style="border: none;"&gt;\r\n                                                 {{/ logo_uri}}\r\n                                                 {{^ logo_uri}}\r\n                                                       {{# logo_html}}\r\n                                                        {{logo_html}}\r\n                                                       {{/ logo_html}}\r\n                                                 {{/ logo_uri}}\r\n					&lt;/a&gt;\r\n\r\nWelcome and thank you for registering at {{ store_name }} &lt;br/&gt;\r\nYour account has now been created and you can log in by using your email address and password by visiting our website or at the following URL: &lt;br/&gt;\r\n{{ store_url }}&lt;br/&gt;\r\n&lt;br/&gt;\r\n\r\nOnce you logging in, you will be able to access, your wishlist, order history, printing invoices and editing your account information.&lt;br/&gt;\r\n&lt;br/&gt;\r\nThank you,&lt;br/&gt;\r\n {{ store_name}} &lt;br/&gt;\r\n\r\n{{ text_project_label }}', 'Welcome and thank you for registering at {{ store_name }} \r\nYour account has now been created and you can log in by using your email address and password by visiting our website or at the following URL: \r\n{{ store_url }}\r\n\r\nOnce you logging in, you will be able to access, your wishlist, order history, printing invoices and editing your account information.\r\n\r\nThank you,\r\n {{ store_name}} \r\n\r\n{{text_project_label}}', 'store_name, store_url, text_project_label, logo_uri, logo_html', '[[regtime]]', '[[regtime]]', NULL, 0),
(14, 1, 'storefront_password_reset_notify', 1, '', '{{store_name}} Notification', 'Your password has been updated! If you did not do any changes, please contact site owner&lt;br/&gt;', 'Your password has been updated! If you did not do any changes, please contact site owner', 'store_name, loginname, customer_id, firstname, lastname', '[[regtime]]', '[[regtime]]', NULL, 0),
(15, 1, 'storefront_customer_account_update', 1, '', '{{store_name}} Account update notification', 'Your account has been updated! If you did not do any changes, please contact site owner ', ' Your account has been updated! If you did not do any changes, please contact site owner ', 'store_name, firstname, lastname, telephone, fax, email, loginname, customer_id, old_loginname, old_email', '[[regtime]]', '[[regtime]]', NULL, 0),
(16, 1, 'storefront_contact_us_mail', 1, '', 'Enquiry from {{ first_name }}', '&lt;html&gt;\r\n&lt;head&gt;\r\n	&lt;meta http-equiv=&quot;Content-Type&quot; content=&quot;text/html; charset=utf-8&quot;&gt;\r\n	&lt;title&gt;{{ title }}&lt;/title&gt;\r\n&lt;/head&gt;\r\n&lt;body&gt;\r\n&lt;table style=&quot;font-family: Verdana,sans-serif; font-size: 11px; color: #374953; width: 600px;&quot;&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;&gt;\r\n			&lt;a href=&quot;{{ store_url }}&quot; title=&quot;{{ store_name }}&quot;&gt;\r\n				{{# logo_uri }}\r\n					&lt;img src=&quot;{{ logo_uri }}&quot; alt=&quot;{{ store_name }}&quot; style=&quot;border: none;&quot;&gt;\r\n				{{/ logo_uri }}\r\n				{{# logo_html }}\r\n					{{ logo_html }}\r\n				{{/ logo_html }}				 \r\n			&lt;/a&gt;\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;\r\n		    style=&quot;background-color: #069; color:#FFF; font-size: 12px; font-weight: bold; padding: 0.5em 1em;&quot;&gt;{{ entry_enquiry }}&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_left&quot;\r\n		    style=&quot; font-size: 12px; padding: 0.5em 1em;&quot;&gt;{{{ enquiry }}}&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;\r\n			&lt;table style=&quot;width: 100%; font-family: Verdana,sans-serif; font-size: 11px; color: #FFFFFF;&quot;&gt;\r\n				{{# tpl_form_fields }}\r\n				&lt;tr&gt;\r\n				&lt;td style=&quot;padding: 0.3em; background-color: #EEEEEE; color: #000;&quot;&gt;{{ name }}&lt;/td&gt;\r\n					&lt;td style=&quot;padding: 0.3em; background-color: #EEEEEE; color: #000;&quot;&gt;{{ value }}&lt;/td&gt;\r\n				&lt;/tr&gt;\r\n				{{/ tpl_form_fields }}\r\n			&lt;/table&gt;\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n	&lt;tr&gt;\r\n		&lt;td class=&quot;align_center&quot;\r\n		    style=&quot;font-size: 10px; border-top: 1px solid #069; text-decoration: none; color: #374953;&quot;&gt;\r\n			&lt;a href=&quot;{{ store_url }}&quot;\r\n			   style=&quot;color: #069; font-weight: bold; text-decoration: none;&quot;&gt;{{ store_name }}&lt;/a&gt;&lt;br&gt;\r\n{{{ text_project_label }}}\r\n		&lt;/td&gt;\r\n	&lt;/tr&gt;\r\n&lt;/table&gt;\r\n&lt;/body&gt;\r\n&lt;/html&gt;\r\n', '{{ store_name }}\r\n\r\n{{ entry_enquiry }}\r\n{{{ enquiry }}}\r\n\r\n\r\n{{# tpl_form_fields }}\r\n{{ name }}  {{ value }}\r\n{{/ tpl_form_fields }}\r\n\r\n{{{ text_project_label }}}', 'first_name, title, store_url, store_name, logo_uri, logo_html, entry_enquiry, enquiry, tpl_form_fields, form_fields, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(17, 1, 'storefront_contact_us_mail_admin_notify', 1, '', 'New enquiry from customer', ' You have got new enquiry from customer ({{first_name}}, {{email}})!', ' You have got new enquiry from customer ({{first_name}}, {{email}})! ', 'first_name, email', '[[regtime]]', '[[regtime]]', NULL, 0),
(18, 1, 'storefront_new_customer_admin_notify', 1, '', ' New Customer {{ firstname }} {{ lastname }} has been registered!', ' New Customer {{ firstname }} {{ lastname }}  has been registered!', ' New Customer {{ firstname }} {{ lastname }}  has been registered!', 'firstname, lastname', '[[regtime]]', '[[regtime]]', NULL, 0),
(19, 1, 'storefront_new_subscriber_admin_notify', 1, '', ' New Subscriber {{ firstname }} {{ lastname }} has been registered!', ' New Subscriber {{ firstname }} {{ lastname }} has been registered!', ' New Subscriber {{ firstname }} {{ lastname }} has been registered!', 'firstname, lastname', '[[regtime]]', '[[regtime]]', NULL, 0),
(21, 1, 'storefront_product_out_of_stock_admin_notify', 1, '', 'Product with ID #{{ product_id }} is out of Stock. ', ' Product with ID #{{ product_id }} is out of Stock. \r\n&lt;br/&gt;&lt;br/&gt;\r\n{{{ text_project_label }}}', ' Product with ID #{{ product_id }} is out of Stock. \r\n\r\n{{{ text_project_label }}}', 'product_id, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(22, 1, 'storefront_product_review_admin_notify', 1, '', ' New product review has been added.', ' New product review has been added. See details {{ product_url }}\r\n&lt;br/&gt;&lt;br/&gt;\r\n{{{ text_project_label }}}', ' New product review has been added. See details {{ product_url }}\r\n\r\n{{{ text_project_label }}}', 'product_url, product_id, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(23, 1, 'storefront_welcome_email_approved', 1, '', 'Welcome, {{store_name}} ', '&lt;html&gt;\r\n	&lt;head&gt;\r\n		&lt;meta http-equiv=&quot;Content-Type&quot; content=&quot;text/html; charset=utf-8&quot;&gt;\r\n	&lt;/head&gt;\r\n	&lt;body&gt;\r\n		&lt;table style=&quot;font-family: Verdana,sans-serif; font-size: 11px; color: #374953; width: 600px;&quot;&gt;\r\n			&lt;tr&gt;\r\n				&lt;td class=&quot;align_left&quot;&gt;\r\n				&lt;a href=&quot;{{ store_url }}&quot; title=&quot;{{ store_name }}&quot;&gt;\r\n						{{# logo_uri}}\r\n				&lt;img src=&quot;{{ logo_uri }}&quot; alt=&quot;{{store_name}}&quot; style=&quot;border: none;&quot;&gt;\r\n                                                 {{/ logo_uri}}\r\n                                                 {{^ logo_uri}}\r\n                                                       {{# logo_html}}\r\n                                                        {{logo_html}}\r\n                                                       {{/ logo_html}}\r\n                                                 {{/ logo_uri}}\r\n					&lt;/a&gt;\r\n				&lt;/td&gt;\r\n			&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n		&lt;td&gt;Welcome and thank you for registering at {{ store_name }}&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;\r\n                          Your account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:&lt;br/&gt;\r\n&lt;a href=&quot;{{ login_url }}&quot;&gt;{{ login_url }}&lt;/a&gt;&lt;br/&gt;\r\nOnce you logging in, you will be able to access, your wishlist, order history, printing invoices and editing your account information.\r\n	&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;\r\n					Thank you.&lt;br/&gt;\r\n                                        {{ store_name }}\r\n&lt;br/&gt;&lt;br/&gt;\r\n{{{ text_project_label }}}\r\n		&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n		&lt;/table&gt;\r\n	&lt;/body&gt;\r\n&lt;/html&gt;', 'Welcome and thank you for registering at {{ store_name }}\r\n\r\nYour account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:\r\n{{ login_url }}\r\n\r\nOnce you logging in, you will be able to access, your wishlist, order history, printing invoices and editing your account information.\r\n\r\nThank you.\r\n{{ store_name }}\r\n{{{ text_project_label }}}', 'store_name, login_url, store_url, logo_html, logo_uri, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0),
(24, 1, 'fast_checkout_welcome_email_guest_registration', 1, '', 'Welcome, {{store_name}}', '&lt;html&gt;\r\n	&lt;head&gt;\r\n		&lt;meta http-equiv=&quot;Content-Type&quot; content=&quot;text/html; charset=utf-8&quot;&gt;\r\n	&lt;/head&gt;\r\n	&lt;body&gt;\r\n		&lt;table style=&quot;font-family: Verdana,sans-serif; font-size: 11px; color: #374953; width: 600px;&quot;&gt;\r\n			&lt;tr&gt;\r\n				&lt;td class=&quot;align_left&quot;&gt;\r\n				&lt;a href=&quot;{{ store_url }}&quot; title=&quot;{{ store_name }}&quot;&gt;\r\n						{{# logo_uri}}\r\n				&lt;img src=&quot;{{ logo_uri }}&quot; alt=&quot;{{store_name}}&quot; style=&quot;border: none;&quot;&gt;\r\n                                                 {{/ logo_uri}}\r\n                                                 {{^ logo_uri}}\r\n                                                       {{# logo_html}}\r\n                                                        {{logo_html}}\r\n                                                       {{/ logo_html}}\r\n                                                 {{/ logo_uri}}\r\n					&lt;/a&gt;\r\n				&lt;/td&gt;\r\n			&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n		&lt;td&gt;Welcome and thank you for registering at {{ store_name }}&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;\r\n                          Your account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:&lt;br/&gt;\r\n&lt;a href=&quot;{{ login_url }}&quot;&gt;{{ login_url }}&lt;/a&gt;&lt;br/&gt;\r\n&lt;br/&gt;\r\nYour Login Name: {{login}}  &lt;br/&gt;\r\nYour Password: {{password}}  &lt;br/&gt;\r\n	&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;&amp;nbsp;&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n			&lt;tr&gt;\r\n				&lt;td&gt;\r\n					Thank you.&lt;br/&gt;\r\n                                        {{ store_name }}\r\n&lt;br/&gt;&lt;br/&gt;\r\n{{{ text_project_label }}}\r\n		&lt;/td&gt;\r\n			&lt;/tr&gt;\r\n		&lt;/table&gt;\r\n	&lt;/body&gt;\r\n&lt;/html&gt;', 'Welcome and thank you for registering at {{ store_name }}\r\n\r\nYour account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:\r\n{{ login_url }}\r\n\r\nYour Login Name: {{login}}\r\nYour Password: {{password}}\r\n\r\n\r\nThank you.\r\n{{ store_name }}\r\n{{{ text_project_label }}}', 'store_name, login_url, store_url, logo_html, logo_uri, text_project_label, login, password', '[[regtime]]', '[[regtime]]', NULL, 0),
(25, 1, 'admin_reset_password_link', 1, '', '{{store_name}} - Password reset', 'A password reset was requested from {{store_name}}&lt;br /&gt;\r\nTo reset your password click link below:&lt;br /&gt;\r\n&lt;a href="{{ reset_link }}"&gt;{{ reset_link }}&lt;/a &gt;\r\n&lt;br /&gt;&lt;br /&gt;\r\n{{{ text_project_label }}}', 'A password reset was requested from {{store_name}} \r\nTo reset your password click link below:\r\n{{ reset_link }}\r\n\r\n\r\n{{{ text_project_label }}}', 'store_name, reset_link, text_project_label', '[[regtime]]', '[[regtime]]', NULL, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]encryption_keys`
--

CREATE TABLE `[[dbprefix]]encryption_keys` (
  `key_id` int NOT NULL AUTO_INCREMENT,
  `key_name` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `status` int NOT NULL,
  `comment` text COLLATE utf8mb4_unicode_ci NOT NULL,
  PRIMARY KEY (`key_id`),
  UNIQUE KEY `encryption_keys_key_name` (`key_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]extensions`
--

CREATE TABLE `[[dbprefix]]extensions` (
  `extension_id` int NOT NULL AUTO_INCREMENT,
  `type` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL,
  `key` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL,
  `category` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL,
  `status` smallint NOT NULL,
  `priority` smallint NOT NULL DEFAULT '0',
  `version` varchar(32) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `license_key` varchar(32) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `date_installed` timestamp NULL DEFAULT NULL,
  `support_expiration` datetime DEFAULT NULL,
  `mp_product_url` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT '',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`extension_id`),
  UNIQUE KEY `extension_key` (`key`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=24 ;

--
-- Dumping data for table `[[dbprefix]]extensions`
--

INSERT INTO `[[dbprefix]]extensions` VALUES
(1, 'total', 'coupon', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(2, 'total', 'shipping', 'shipping', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(3, 'total', 'low_order_fee', '', 0, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(4, 'total', 'handling', '', 0, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(5, 'total', 'sub_total', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(6, 'total', 'tax', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(7, 'total', 'total', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(8, 'total', 'balance', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(9, 'block', 'cart', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(10, 'block', 'category', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(11, 'block', 'content', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(12, 'block', 'manufacturer', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(13, 'block', 'bestseller', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(14, 'block', 'latest', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(15, 'block', 'featured', '', 1, 1, '', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(16, 'extensions', 'banner_manager', 'extensions', 1, 1, '1.4.4', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(17, 'extensions', 'forms_manager', 'extensions', 1, 1, '1.4.4', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(18, 'template', 'novator', 'template', 1, 0, '1.4.4', NULL, '[[regtime_yest]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(19, 'extensions', 'page_builder', 'tools', 1, 10000, '1.4.4', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(20, 'payment', 'paypal_commerce', 'payment', 0, 100, '1.4.4', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(21, 'payment', 'default_cod', 'payment', 1, 1, '1.4.4', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(22, 'shipping', 'default_flat_rate_shipping', 'shipping', 1, 1, '1.4.4', NULL, '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]'),
(23, 'shipping', 'default_local_delivery', 'shipping', 1, 10, '1.4.4', '', '[[regtime]]', NULL, '', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]extension_dependencies`
--

CREATE TABLE `[[dbprefix]]extension_dependencies` (
  `extension_id` int NOT NULL,
  `extension_parent_id` int NOT NULL,
  PRIMARY KEY (`extension_id`,`extension_parent_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]fields`
--

CREATE TABLE `[[dbprefix]]fields` (
  `field_id` int NOT NULL AUTO_INCREMENT,
  `form_id` int NOT NULL DEFAULT '0',
  `group_id` int DEFAULT NULL,
  `field_name` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL,
  `element_type` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 'I',
  `sort_order` int NOT NULL,
  `attributes` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `settings` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `required` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 'N',
  `status` smallint NOT NULL DEFAULT '0',
  `regexp_pattern` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `resource_id` int DEFAULT NULL,
  `locked` int NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`field_id`),
  KEY `field_id` (`field_id`,`form_id`,`status`),
  KEY `[[dbprefix]]field_group_fk` (`group_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=63 ;

--
-- Dumping data for table `[[dbprefix]]fields`
--

INSERT INTO `[[dbprefix]]fields` VALUES
(11, 2, NULL, 'first_name', 'I', 1, 'autocomplete="given-name"', '', '1', 1, '/^.{3,100}$/u', 17, 1, '[[regtime]]', '[[regtime]]'),
(12, 2, NULL, 'email', 'E', 2, 'minlength="1" maxlength="96" autocomplete="email"', '', '1', 1, '', 19, 1, '[[regtime]]', '[[regtime]]'),
(13, 2, NULL, 'enquiry', 'T', 3, 'cols="50" rows="8" autocomplete="off"', '', '1', 1, '/^.{3,1000}$/su', NULL, 1, '[[regtime]]', '[[regtime]]'),
(14, 2, NULL, 'captcha', 'K', 4, 'autocomplete="off"', '', '1', 1, '', NULL, 0, '[[regtime]]', '[[regtime]]'),
(19, 4, NULL, 'country_id', 'O', 1, 'autocomplete="country"', '', '1', 1, '/^[1-9]\\d*$/', 10, 1, '[[regtime]]', '[[regtime]]'),
(20, 4, NULL, 'zone_id', 'Z', 2, 'autocomplete="address-level1"', '', '1', 1, '/^[1-9]\\d*$/', 11, 1, '[[regtime]]', '[[regtime]]'),
(21, 4, NULL, 'company', 'I', 3, 'autocomplete="organization"', '', '0', 1, '/^.{0,255}$/u', 13, 1, '[[regtime]]', '[[regtime]]'),
(22, 4, NULL, 'address_1', 'I', 4, 'minlength="3" maxlength="128" autocomplete="address-line1"', '', '1', 1, '/^.{3,128}$/u', 14, 1, '[[regtime]]', '[[regtime]]'),
(23, 4, NULL, 'address_2', 'I', 5, 'minlength="0" maxlength="128" autocomplete="address-line2"', '', '0', 1, '/^.{0,128}$/u', 15, 1, '[[regtime]]', '[[regtime]]'),
(24, 4, NULL, 'city', 'I', 6, 'maxlength="128" autocomplete="address-level2"', '', '1', 1, '/^.{1,128}$/u', 16, 1, '[[regtime]]', '[[regtime]]'),
(25, 4, NULL, 'postcode', 'I', 7, 'autocomplete="postal-code"', '', '1', 1, '/^[A-Za-z0-9\\- ]+$/', 12, 1, '[[regtime]]', '[[regtime]]'),
(26, 4, NULL, 'firstname', 'I', 8, 'minlength="1" maxlength="32" autocomplete="given-name"', '', '1', 1, '/^.{1,32}$/u', 17, 1, '[[regtime]]', '[[regtime]]'),
(27, 4, NULL, 'lastname', 'I', 9, 'minlength="1" maxlength="32" autocomplete="family-name"', '', '1', 1, '/^.{1,32}$/u', 18, 1, '[[regtime]]', '[[regtime]]'),
(29, 4, NULL, 'default', 'C', 11, '', '', '0', 1, '', 0, 1, '[[regtime]]', '[[regtime]]'),
(30, 4, NULL, 'vat_id', 'I', 10, 'autocomplete="off"', '', '0', 0, '/^.{8,14}$/u', 0, 0, '[[regtime]]', '[[regtime]]'),
(31, 5, NULL, 'country_id', 'O', 1, 'data-pair-with="zone_id" autocomplete="country"', '', '1', 1, '/^[1-9]\\d*$/', 10, 1, '[[regtime]]', '[[regtime]]'),
(32, 5, NULL, 'zone_id', 'Z', 2, 'data-pair-with="country_id" autocomplete="address-level1"', '', '1', 1, '/^[1-9]\\d*$/', 11, 1, '[[regtime]]', '[[regtime]]'),
(33, 5, NULL, 'company', 'I', 3, 'autocomplete="organization"', '', '0', 1, '/^.{0,255}$/u', 13, 1, '[[regtime]]', '[[regtime]]'),
(34, 5, NULL, 'address_1', 'I', 4, 'minlength="3" maxlength="128" autocomplete="address-line1"', '', '1', 1, '/^.{3,128}$/u', 14, 1, '[[regtime]]', '[[regtime]]'),
(35, 5, NULL, 'address_2', 'I', 5, 'minlength="0" maxlength="128" autocomplete="address-line2"', '', '0', 1, '/^.{0,128}$/u', 15, 1, '[[regtime]]', '[[regtime]]'),
(36, 5, NULL, 'city', 'I', 6, 'maxlength="128" data-pair-with="postcode" autocomplete="address-level2"', '', '1', 1, '/^.{1,128}$/u', 16, 1, '[[regtime]]', '[[regtime]]'),
(37, 5, NULL, 'postcode', 'I', 7, 'data-pair-with="city" autocomplete="postal-code"', '', '1', 1, '/^[A-Za-z0-9\\- ]+$/', 12, 1, '[[regtime]]', '[[regtime]]'),
(38, 5, NULL, 'firstname', 'I', 8, 'minlength="1" maxlength="32" data-pair-with="lastname" autocomplete="given-name"', '', '1', 1, '/^.{1,32}$/u', 17, 1, '[[regtime]]', '[[regtime]]'),
(39, 5, NULL, 'lastname', 'I', 9, 'minlength="1" maxlength="32" data-pair-with="firstname" autocomplete="family-name"', '', '1', 1, '/^.{1,32}$/u', 18, 1, '[[regtime]]', '[[regtime]]'),
(40, 5, NULL, 'vat_id', 'I', 10, 'autocomplete="off"', '', '0', 0, '/^.{8,14}$/u', 0, 0, '[[regtime]]', '[[regtime]]'),
(41, 5, NULL, 'email', 'E', 15, 'minlength="1" maxlength="96" autocomplete="email"', '', '1', 1, '', 19, 1, '[[regtime]]', '[[regtime]]'),
(42, 5, NULL, 'telephone', 'F', 16, 'maxlength="32" autocomplete="tel"', '', '0', 1, '/^[+\\- 0-9\\(\\)]+$/', 20, 1, '[[regtime]]', '[[regtime]]'),
(43, 6, NULL, 'loginname', 'I', 1, 'minlength="5" maxlength="64" autocomplete="username"', '', '1', 1, '/^[A-Za-z0-9._]{5,64}$/i', 21, 1, '[[regtime]]', '[[regtime]]'),
(44, 6, NULL, 'firstname', 'I', 2, 'minlength="1" maxlength="32" data-pair-with="lastname" autocomplete="given-name"', '', '1', 1, '/^.{1,32}$/u', 17, 1, '[[regtime]]', '[[regtime]]'),
(45, 6, NULL, 'lastname', 'I', 3, 'minlength="1" maxlength="32" data-pair-with="firstname" autocomplete="family-name"', '', '1', 1, '/^.{1,32}$/u', 18, 1, '[[regtime]]', '[[regtime]]'),
(46, 6, NULL, 'email', 'E', 4, 'minlength="1" maxlength="96" autocomplete="email"', '', '1', 1, '', 19, 1, '[[regtime]]', '[[regtime]]'),
(47, 6, NULL, 'telephone', 'F', 5, 'maxlength="32" autocomplete="tel"', '', '0', 1, '/^[+\\- 0-9\\(\\)]+$/', 20, 1, '[[regtime]]', '[[regtime]]'),
(49, 7, 1, 'firstname', 'I', 1, 'minlength="1" maxlength="32" data-pair-with="lastname" autocomplete="given-name"', '', '1', 1, '/^.{1,32}$/u', 17, 1, '[[regtime]]', '[[regtime]]'),
(50, 7, 1, 'lastname', 'I', 2, 'minlength="1" maxlength="32" data-pair-with="firstname" autocomplete="family-name"', '', '1', 1, '/^.{1,32}$/u', 18, 1, '[[regtime]]', '[[regtime]]'),
(51, 7, 1, 'email', 'E', 3, 'minlength="1" maxlength="96" autocomplete="email"', '', '1', 1, '', 19, 1, '[[regtime]]', '[[regtime]]'),
(52, 7, 1, 'telephone', 'F', 4, 'maxlength="32" autocomplete="tel"', '', '0', 1, '/^[+\\- 0-9\\(\\)]+$/', 20, 1, '[[regtime]]', '[[regtime]]'),
(53, 7, 2, 'country_id', 'O', 10, 'autocomplete="country"', '', '1', 1, '/^[1-9]\\d*$/', 10, 1, '[[regtime]]', '[[regtime]]'),
(54, 7, 2, 'zone_id', 'Z', 11, 'autocomplete="address-level1"', '', '1', 1, '/^[1-9]\\d*$/', 11, 1, '[[regtime]]', '[[regtime]]'),
(55, 7, 2, 'address_1', 'I', 13, 'minlength="3" maxlength="128" autocomplete="address-line1"', '', '1', 1, '/^.{3,128}$/u', 14, 1, '[[regtime]]', '[[regtime]]'),
(56, 7, 2, 'address_2', 'I', 14, 'minlength="0" maxlength="128" autocomplete="address-line2"', '', '0', 1, '/^.{0,128}$/u', 15, 1, '[[regtime]]', '[[regtime]]'),
(57, 7, 2, 'city', 'I', 15, 'maxlength="128" autocomplete="address-level2"', '', '1', 1, '/^.{1,128}$/u', 16, 1, '[[regtime]]', '[[regtime]]'),
(58, 7, 2, 'postcode', 'I', 16, 'autocomplete="postal-code"', '', '1', 1, '/^[A-Za-z0-9\\- ]+$/', 12, 1, '[[regtime]]', '[[regtime]]'),
(59, 7, 2, 'company', 'I', 12, 'autocomplete="organization"', '', '0', 1, '/^.{0,255}$/u', 13, 1, '[[regtime]]', '[[regtime]]'),
(60, 7, 3, 'loginname', 'I', 20, 'minlength="5" maxlength="64" autocomplete="username"', '', '1', 1, '/^[A-Za-z0-9._]{5,64}$/i', 21, 1, '[[regtime]]', '[[regtime]]'),
(61, 7, 4, 'newsletter', 'C', 30, '', '', '0', 1, '', 0, 1, '[[regtime]]', '[[regtime]]'),
(62, 7, 2, 'vat_id', 'I', 28, 'autocomplete="off"', '', '0', 0, '/^.{8,14}$/u', 0, 0, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]fields_history`
--

CREATE TABLE `[[dbprefix]]fields_history` (
  `hist_id` int NOT NULL AUTO_INCREMENT,
  `table_name` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL,
  `record_id` int NOT NULL,
  `field` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `version` int NOT NULL DEFAULT '1',
  `language_id` int NOT NULL,
  `text` longtext COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`hist_id`),
  KEY `[[dbprefix]]fields_history_idx` (`table_name`,`record_id`,`field`,`language_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=3 ;

--
-- Dumping data for table `[[dbprefix]]fields_history`
--

INSERT INTO `[[dbprefix]]fields_history` VALUES
(1, 'block_descriptions', 11, 'content', 1, 1, '&lt;div class=&quot;contactus-block text-center text-md-start&quot;&gt;\n&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/5.svg&quot; alt=&quot;images&quot; class=&quot;img-fluid h-auto&quot; width=&quot;350&quot; height=&quot;79&quot;&gt;&lt;p class=&quot;text-white&quot;&gt;1487 Rocky Horse Carrefour&lt;br&gt;Arlington, TX 16819&lt;/p&gt;&lt;h4 class=&quot;text-white&quot;&gt;&lt;i class=&quot;bi bi-telephone&quot;&gt;&lt;/i&gt; (444) 019 120 0401&lt;/h4&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-success d-inline-block&quot;&gt;Live Chat&lt;/a&gt; &lt;a href=&quot;#&quot; class=&quot;btn btn-outline-light d-inline-block&quot;&gt;Help Desk&lt;/a&gt;\n&lt;/div&gt;', '[[regtime]]'),
(2, 'block_descriptions', 11, 'content', 2, 1, '&lt;div class=&quot;contactus-block text-center text-md-start&quot;&gt;\n&lt;img src=&quot;extensions/novator/storefront/view/novator/image/presets/18/7b/5.svg&quot; alt=&quot;images&quot; class=&quot;img-fluid h-auto&quot; width=&quot;350&quot; height=&quot;79&quot;&gt;&lt;p class=&quot;text-white&quot;&gt;1487 Rocky Horse Carrefour&lt;br&gt;Arlington, TX 16819&lt;/p&gt;&lt;h4 class=&quot;text-white&quot;&gt;&lt;i class=&quot;bi bi-telephone&quot;&gt;&lt;/i&gt; (444) 019 120 0401&lt;/h4&gt;&lt;a href=&quot;#&quot; class=&quot;btn btn-success&quot;&gt;Live Chat&lt;/a&gt; &lt;a href=&quot;#&quot; class=&quot;btn btn-outline-light d-inline-block&quot;&gt;Help Desk&lt;/a&gt;\n&lt;/div&gt;', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]field_descriptions`
--

CREATE TABLE `[[dbprefix]]field_descriptions` (
  `field_id` int NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  `language_id` int NOT NULL,
  `error_text` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  PRIMARY KEY (`field_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]field_descriptions`
--

INSERT INTO `[[dbprefix]]field_descriptions` VALUES
(11, 'First name:', '', 1, 'Name must be between 3 and 32 characters!'),
(12, 'Email:', '', 1, 'E-Mail Address does not appear to be valid!'),
(13, 'Enquiry:', '', 1, 'Enquiry must be between 10 and 3000 characters!'),
(14, 'Enter the code in the box below:', '', 1, 'Human verification has failed! Please try agan.'),
(19, 'Country', '', 1, 'Please select a country!'),
(20, 'Zone', '', 1, 'Please select a region/state!'),
(21, 'Company', '', 1, 'Company Name must be less than 255 characters!'),
(22, 'Address Line 1', '', 1, 'Address Line 1 must be between 3 and 128 characters!'),
(23, 'Address Line 2', '', 1, 'Address Line 2 must be less than 128 characters!'),
(24, 'City', '', 1, 'City must be between 3 and 128 characters!'),
(25, 'Zip/Post Code', '', 1, 'Zip/Post Code must be less than 11 characters!'),
(26, 'First Name', '', 1, 'First Name must be between 1 and 32 characters!'),
(27, 'Last Name', '', 1, 'Last Name must be between 1 and 32 characters!'),
(29, 'Default Address', '', 1, ''),
(30, 'VAT ID', '', 1, 'VAT ID Code must be between 8 and 14 characters!'),
(31, 'Country', '', 1, 'Please select a country!'),
(32, 'Region/State', '', 1, 'Please select a region/state!'),
(33, 'Company', '', 1, 'Company Name must be less than 255 characters!'),
(34, 'Address Line 1', '', 1, 'Address Line 1 must be between 3 and 128 characters!'),
(35, 'Address Line 2', '', 1, 'Address Line 2 must be less than 128 characters!'),
(36, 'City', '', 1, 'City must be between 3 and 128 characters!'),
(37, 'Zip/Post Code', '', 1, 'Zip/Post Code must be less than 11 characters!'),
(38, 'First Name', '', 1, 'First Name must be between 1 and 32 characters!'),
(39, 'Last Name', '', 1, 'Last Name must be between 1 and 32 characters!'),
(40, 'VAT ID', '', 1, 'VAT ID Code must be between 8 and 14 characters!'),
(41, 'Email', '', 1, 'Your email is not provided or invalid!'),
(42, 'Phone Number', '', 1, 'Your contact phone number is not provided or invalid.'),
(43, 'Login Name', '', 1, 'Login Name must be between 5 and 65 characters!'),
(44, 'First Name', '', 1, 'First Name must be between 1 and 32 characters!'),
(45, 'Last Name', '', 1, 'Last Name must be between 1 and 32 characters!'),
(46, 'Email', '', 1, 'Your email is not provided or invalid!'),
(47, 'Phone Number', '', 1, 'Your contact phone number is not provided or invalid.'),
(49, 'First Name', '', 1, 'First Name must be between 1 and 32 characters!'),
(50, 'Last Name', '', 1, 'Last Name must be between 1 and 32 characters!'),
(51, 'Email', '', 1, 'Your email is not provided or invalid!'),
(52, 'Phone Number', '', 1, 'Your contact phone number is not provided or invalid.'),
(53, 'Country', '', 1, 'Please select a country!'),
(54, 'Region/State', '', 1, 'Please select a region/state!'),
(55, 'Address Line 1', '', 1, 'Address Line 1 must be between 3 and 128 characters!'),
(56, 'Address Line 2', '', 1, 'Address Line 2 must be less than 128 characters!'),
(57, 'City', '', 1, 'City must be between 3 and 128 characters!'),
(58, 'Zip/Post Code', '', 1, 'Zip/Post Code must be less than 11 characters!'),
(59, 'Company', '', 1, 'Company Name must be less than 255 characters!'),
(60, 'Login Name', '', 1, 'Login Name must be alphanumeric only and between 5 and 64 characters!'),
(61, 'Subscribe', '', 1, ''),
(62, 'VAT ID', '', 1, 'VAT ID Code must be between 8 and 14 characters!');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]field_groups`
--

CREATE TABLE `[[dbprefix]]field_groups` (
  `group_id` int NOT NULL AUTO_INCREMENT,
  `group_txt_id` varchar(40) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  PRIMARY KEY (`group_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=5 ;

--
-- Dumping data for table `[[dbprefix]]field_groups`
--

INSERT INTO `[[dbprefix]]field_groups` VALUES
(1, 'details'),
(2, 'address'),
(3, 'login'),
(4, 'newsletter');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]field_group_descriptions`
--

CREATE TABLE `[[dbprefix]]field_group_descriptions` (
  `group_id` int NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  `language_id` int NOT NULL,
  PRIMARY KEY (`group_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]field_group_descriptions`
--

INSERT INTO `[[dbprefix]]field_group_descriptions` VALUES
(1, 'Your Personal Details', '', 1),
(2, 'Your Address', '', 1),
(3, 'Login Details', '', 1),
(4, 'Newsletter', '', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]field_group_to_form`
--

CREATE TABLE `[[dbprefix]]field_group_to_form` (
  `group_id` int DEFAULT NULL,
  `form_id` int DEFAULT NULL,
  `sort_order` int DEFAULT NULL,
  KEY `[[dbprefix]]field_group_to_form_fk` (`form_id`),
  KEY `[[dbprefix]]field_group_to_group_fk` (`group_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

--
-- Dumping data for table `[[dbprefix]]field_group_to_form`
--

INSERT INTO `[[dbprefix]]field_group_to_form` VALUES
(1, 7, 1),
(2, 7, 2),
(3, 7, 3),
(4, 7, 4);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]field_values`
--

CREATE TABLE `[[dbprefix]]field_values` (
  `value_id` int NOT NULL AUTO_INCREMENT,
  `field_id` int NOT NULL DEFAULT '0',
  `value` text COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `language_id` int NOT NULL,
  PRIMARY KEY (`value_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=8 ;

--
-- Dumping data for table `[[dbprefix]]field_values`
--

INSERT INTO `[[dbprefix]]field_values` VALUES
(4, 29, 'a:1:{i:0;a:2:{s:4:"name";s:1:"1";s:10:"sort_order";N;}}', 1),
(6, 61, 'a:1:{i:0;a:2:{s:4:"name";s:1:"1";s:10:"sort_order";N;}}', 1),
(7, 30, 'a:1:{i:0;a:2:{s:4:"name";s:0:"";s:10:"sort_order";N;}}', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]forms`
--

CREATE TABLE `[[dbprefix]]forms` (
  `form_id` int NOT NULL AUTO_INCREMENT,
  `form_name` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `controller` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `success_page` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `status` smallint NOT NULL DEFAULT '0',
  `locked` int NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`form_id`),
  UNIQUE KEY `form_name` (`form_name`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=8 ;

--
-- Dumping data for table `[[dbprefix]]forms`
--

INSERT INTO `[[dbprefix]]forms` VALUES
(2, 'ContactUsFrm', 'content/contact', 'content/contact/success', 1, 1, '[[regtime]]', '[[regtime]]'),
(4, 'AddressFrm', '', '', 1, 1, '[[regtime]]', '[[regtime]]'),
(5, 'GuestCheckoutFrm', '', '', 1, 1, '[[regtime]]', '[[regtime]]'),
(6, 'CustomerFrm', '', '', 1, 1, '[[regtime]]', '[[regtime]]'),
(7, 'RegisterCustomerFrm', 'account/create', 'account/create', 1, 1, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]form_descriptions`
--

CREATE TABLE `[[dbprefix]]form_descriptions` (
  `form_id` int NOT NULL DEFAULT '0',
  `language_id` int NOT NULL,
  `description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  PRIMARY KEY (`form_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]form_descriptions`
--

INSERT INTO `[[dbprefix]]form_descriptions` VALUES
(2, 1, 'Contact Us Form'),
(4, 1, 'Customer Address Form'),
(5, 1, 'Guest Address and Details Form'),
(6, 1, 'Customer Details Form'),
(7, 1, 'Customer Registration Form');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]global_attributes`
--

CREATE TABLE `[[dbprefix]]global_attributes` (
  `attribute_id` int NOT NULL AUTO_INCREMENT,
  `attribute_parent_id` int DEFAULT NULL,
  `attribute_group_id` int DEFAULT NULL,
  `attribute_type_id` int NOT NULL,
  `element_type` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 'I',
  `sort_order` int NOT NULL DEFAULT '0',
  `required` smallint NOT NULL DEFAULT '0',
  `settings` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `status` smallint NOT NULL DEFAULT '0',
  `regexp_pattern` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  PRIMARY KEY (`attribute_id`),
  KEY `[[dbprefix]]global_attributes_idx` (`attribute_parent_id`,`attribute_group_id`,`attribute_type_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=9 ;

--
-- Dumping data for table `[[dbprefix]]global_attributes`
--

INSERT INTO `[[dbprefix]]global_attributes` VALUES
(1, NULL, NULL, 1, 'S', 1, 1, '', 1, NULL),
(2, NULL, NULL, 1, 'C', 0, 0, '', 1, NULL),
(5, NULL, NULL, 1, 'G', 1, 1, '', 1, NULL),
(6, NULL, NULL, 1, 'S', 0, 0, 'a:4:{s:10:"extensions";s:0:"";s:8:"min_size";s:0:"";s:8:"max_size";s:0:"";s:9:"directory";s:0:"";}', 1, ''),
(7, 6, NULL, 1, 'S', 0, 0, 'a:4:{s:10:"extensions";s:0:"";s:8:"min_size";s:0:"";s:8:"max_size";s:0:"";s:9:"directory";s:0:"";}', 1, ''),
(8, 6, NULL, 1, 'S', 0, 0, 'a:4:{s:10:"extensions";s:0:"";s:8:"min_size";s:0:"";s:8:"max_size";s:0:"";s:9:"directory";s:0:"";}', 1, '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]global_attributes_descriptions`
--

CREATE TABLE `[[dbprefix]]global_attributes_descriptions` (
  `attribute_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `placeholder` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT '' COMMENT 'translatable',
  `error_text` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`attribute_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]global_attributes_descriptions`
--

INSERT INTO `[[dbprefix]]global_attributes_descriptions` VALUES
(1, 1, 'Size', '', ''),
(2, 1, 'Gift Wrapping', '', ''),
(5, 1, 'Fragrance Type', '', ''),
(6, 1, 'Color&amp;Size', '', ''),
(7, 1, 'UK Size', '', ''),
(8, 1, 'Color', '', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]global_attributes_groups`
--

CREATE TABLE `[[dbprefix]]global_attributes_groups` (
  `attribute_group_id` int NOT NULL AUTO_INCREMENT,
  `sort_order` int NOT NULL DEFAULT '0',
  `status` smallint NOT NULL DEFAULT '0',
  PRIMARY KEY (`attribute_group_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]global_attributes_groups_descriptions`
--

CREATE TABLE `[[dbprefix]]global_attributes_groups_descriptions` (
  `attribute_group_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`attribute_group_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]global_attributes_types`
--

CREATE TABLE `[[dbprefix]]global_attributes_types` (
  `attribute_type_id` int NOT NULL AUTO_INCREMENT,
  `type_key` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  `controller` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  `sort_order` int NOT NULL DEFAULT '0',
  `status` smallint NOT NULL DEFAULT '0',
  PRIMARY KEY (`attribute_type_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=3 ;

--
-- Dumping data for table `[[dbprefix]]global_attributes_types`
--

INSERT INTO `[[dbprefix]]global_attributes_types` VALUES
(1, 'product_option', 'responses/catalog/attribute/getProductOptionSubform', 1, 1),
(2, 'download_attribute', 'responses/catalog/attribute/getDownloadAttributeSubform', 2, 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]global_attributes_type_descriptions`
--

CREATE TABLE `[[dbprefix]]global_attributes_type_descriptions` (
  `attribute_type_id` int NOT NULL,
  `language_id` int NOT NULL,
  `type_name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`attribute_type_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]global_attributes_type_descriptions`
--

INSERT INTO `[[dbprefix]]global_attributes_type_descriptions` VALUES
(1, 1, 'Product Option', '[[regtime]]', '[[regtime]]'),
(2, 1, 'Download Attribute', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]global_attributes_values`
--

CREATE TABLE `[[dbprefix]]global_attributes_values` (
  `attribute_value_id` int NOT NULL AUTO_INCREMENT,
  `attribute_id` int NOT NULL,
  `price_modifier` float DEFAULT '0',
  `price_prefix` char(1) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `sort_order` int NOT NULL DEFAULT '0',
  `txt_id` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  PRIMARY KEY (`attribute_value_id`),
  UNIQUE KEY `ga_value_txt_id_idx` (`txt_id`),
  KEY `[[dbprefix]]global_attributes_values_idx` (`attribute_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=99 ;

--
-- Dumping data for table `[[dbprefix]]global_attributes_values`
--

INSERT INTO `[[dbprefix]]global_attributes_values` VALUES
(32, 2, 0, NULL, 0, NULL),
(43, 1, 0, NULL, 0, NULL),
(44, 1, 0, NULL, 0, NULL),
(45, 1, 0, NULL, 0, NULL),
(46, 1, 0, NULL, 0, NULL),
(47, 1, 0, NULL, 0, NULL),
(48, 1, 0, NULL, 0, NULL),
(49, 1, 0, NULL, 0, NULL),
(50, 1, 0, NULL, 0, NULL),
(51, 1, 0, NULL, 0, NULL),
(52, 1, 0, NULL, 0, NULL),
(53, 1, 0, NULL, 0, NULL),
(75, 5, 0, NULL, 0, NULL),
(76, 5, 0, NULL, 0, NULL),
(77, 5, 0, NULL, 0, NULL),
(78, 6, 0, NULL, 0, NULL),
(79, 7, 0, NULL, 0, NULL),
(80, 7, 0, NULL, 0, NULL),
(81, 7, 0, NULL, 0, NULL),
(82, 7, 0, NULL, 0, NULL),
(83, 7, 0, NULL, 0, NULL),
(84, 7, 0, NULL, 0, NULL),
(85, 7, 0, NULL, 0, NULL),
(86, 7, 0, NULL, 0, NULL),
(87, 7, 0, NULL, 0, NULL),
(88, 8, 0, NULL, 0, NULL),
(89, 8, 0, NULL, 0, NULL),
(90, 8, 0, NULL, 0, NULL),
(91, 8, 0, NULL, 0, NULL),
(92, 8, 0, NULL, 0, NULL),
(93, 7, 0, NULL, 0, NULL),
(94, 7, 0, NULL, 0, NULL),
(95, 7, 0, NULL, 0, NULL),
(96, 7, 0, NULL, 0, NULL),
(97, 7, 0, NULL, 0, NULL),
(98, 8, 0, NULL, 0, NULL);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]global_attributes_value_descriptions`
--

CREATE TABLE `[[dbprefix]]global_attributes_value_descriptions` (
  `attribute_value_id` int NOT NULL,
  `attribute_id` int NOT NULL,
  `language_id` int NOT NULL,
  `value` text COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`attribute_value_id`,`attribute_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]global_attributes_value_descriptions`
--

INSERT INTO `[[dbprefix]]global_attributes_value_descriptions` VALUES
(32, 2, 1, ''),
(42, 1, 1, '1.7 oz'),
(43, 1, 1, '3.4 oz'),
(44, 1, 1, '100ml'),
(45, 1, 1, '8.45 oz'),
(46, 1, 1, '15.2 oz'),
(47, 1, 1, '33.8 oz'),
(48, 1, 1, '1.5 oz'),
(49, 1, 1, '2.5 oz'),
(50, 1, 1, '30ml'),
(51, 1, 1, '50ml'),
(52, 1, 1, '75ml'),
(53, 1, 1, '1 oz'),
(75, 5, 1, 'Eau de Parfum'),
(76, 5, 1, 'Eau de Toilette'),
(77, 5, 1, 'Eau de Cologne'),
(78, 6, 1, ''),
(79, 7, 1, 'UK 3'),
(80, 7, 1, 'UK 3.5'),
(81, 7, 1, 'UK 4'),
(82, 7, 1, 'UK 4.5'),
(83, 7, 1, 'UK 5'),
(84, 7, 1, 'UK 5.5'),
(85, 7, 1, 'UK 6'),
(86, 7, 1, 'UK 7'),
(87, 7, 1, 'UK 8'),
(88, 8, 1, 'Red'),
(89, 8, 1, 'White'),
(90, 8, 1, 'Black'),
(91, 8, 1, 'Blue'),
(92, 8, 1, 'Green'),
(93, 7, 1, 'XXL'),
(94, 7, 1, 'XL'),
(95, 7, 1, 'S'),
(96, 7, 1, 'L'),
(97, 7, 1, 'M'),
(98, 8, 1, 'Yellow');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]languages`
--

CREATE TABLE `[[dbprefix]]languages` (
  `language_id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `code` varchar(5) COLLATE utf8mb4_unicode_ci NOT NULL,
  `locale` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `image` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `directory` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `filename` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `sort_order` int NOT NULL DEFAULT '0',
  `status` int NOT NULL,
  PRIMARY KEY (`language_id`),
  UNIQUE KEY `[[dbprefix]]languages_idx` (`language_id`,`code`),
  KEY `name` (`name`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]languages`
--

INSERT INTO `[[dbprefix]]languages` VALUES
(1, 'English', 'en', 'en_US.UTF-8,en_US,en-gb,english', '', 'english', 'english', 1, 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]language_definitions`
--

CREATE TABLE `[[dbprefix]]language_definitions` (
  `language_definition_id` int NOT NULL AUTO_INCREMENT,
  `language_id` int NOT NULL,
  `section` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0-SF, 1-ADMIN',
  `block` varchar(160) COLLATE utf8mb4_unicode_ci NOT NULL,
  `language_key` varchar(170) COLLATE utf8mb4_unicode_ci NOT NULL,
  `language_value` text COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`language_definition_id`,`language_id`,`section`,`block`,`language_key`),
  KEY `[[dbprefix]]lang_definition_idx` (`language_value`(500))
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=4963 ;

--
-- Dumping data for table `[[dbprefix]]language_definitions`
--

INSERT INTO `[[dbprefix]]language_definitions` VALUES
(1, 1, 1, 'english', 'code', 'en', '[[regtime]]', '[[regtime]]'),
(2, 1, 1, 'english', 'direction', 'ltr', '[[regtime]]', '[[regtime]]'),
(3, 1, 1, 'english', 'date_format_short', 'm/d/Y', '[[regtime]]', '[[regtime]]'),
(4, 1, 1, 'english', 'date_format_long', 'l dS F Y', '[[regtime]]', '[[regtime]]'),
(5, 1, 1, 'english', 'time_format', 'h:i:s A', '[[regtime]]', '[[regtime]]'),
(6, 1, 1, 'english', 'time_format_short', 'H:i', '[[regtime]]', '[[regtime]]'),
(7, 1, 1, 'english', 'decimal_point', '.', '[[regtime]]', '[[regtime]]'),
(8, 1, 1, 'english', 'thousand_point', ',', '[[regtime]]', '[[regtime]]'),
(9, 1, 1, 'english', 'text_yes', 'Yes', '[[regtime]]', '[[regtime]]'),
(10, 1, 1, 'english', 'text_no', 'No', '[[regtime]]', '[[regtime]]'),
(11, 1, 1, 'english', 'text_plus', '+', '[[regtime]]', '[[regtime]]'),
(12, 1, 1, 'english', 'text_minus', '-', '[[regtime]]', '[[regtime]]'),
(13, 1, 1, 'english', 'text_enabled', 'Enabled', '[[regtime]]', '[[regtime]]'),
(14, 1, 1, 'english', 'text_disabled', 'Disabled', '[[regtime]]', '[[regtime]]'),
(15, 1, 1, 'english', 'text_none', ' --- None --- ', '[[regtime]]', '[[regtime]]'),
(16, 1, 1, 'english', 'text_select', ' --- Please Select --- ', '[[regtime]]', '[[regtime]]'),
(17, 1, 1, 'english', 'text_select_all', 'Select All', '[[regtime]]', '[[regtime]]'),
(18, 1, 1, 'english', 'text_unselect_all', 'Unselect All', '[[regtime]]', '[[regtime]]'),
(19, 1, 1, 'english', 'text_all_zones', 'All Zones', '[[regtime]]', '[[regtime]]'),
(20, 1, 1, 'english', 'text_default', '(Default)', '[[regtime]]', '[[regtime]]'),
(21, 1, 1, 'english', 'text_close', 'Close', '[[regtime]]', '[[regtime]]'),
(22, 1, 1, 'english', 'text_pagination', 'Showing {start} to {end} of {total} ({pages} Pages)', '[[regtime]]', '[[regtime]]'),
(23, 1, 1, 'english', 'text_per_page', 'Per Page', '[[regtime]]', '[[regtime]]'),
(24, 1, 1, 'english', 'text_no_results', 'No result found.', '[[regtime]]', '[[regtime]]'),
(25, 1, 1, 'english', 'text_separator', ' &gt; ', '[[regtime]]', '[[regtime]]'),
(26, 1, 1, 'english', 'text_edit', 'Edit ', '[[regtime]]', '[[regtime]]'),
(27, 1, 1, 'english', 'text_view', 'View', '[[regtime]]', '[[regtime]]'),
(28, 1, 1, 'english', 'text_home', 'Home', '[[regtime]]', '[[regtime]]'),
(29, 1, 1, 'english', 'button_insert', 'Insert', '[[regtime]]', '[[regtime]]'),
(30, 1, 1, 'english', 'button_delete', 'Delete', '[[regtime]]', '[[regtime]]'),
(31, 1, 1, 'english', 'button_save', 'Save', '[[regtime]]', '[[regtime]]'),
(32, 1, 1, 'english', 'button_save_and_close', 'Save & Close', '[[regtime]]', '[[regtime]]'),
(33, 1, 1, 'english', 'button_cancel', 'Cancel', '[[regtime]]', '[[regtime]]'),
(34, 1, 1, 'english', 'button_reset', 'Reset', '[[regtime]]', '[[regtime]]'),
(35, 1, 1, 'english', 'button_reload', 'Reload', '[[regtime]]', '[[regtime]]'),
(36, 1, 1, 'english', 'button_clear', 'Clear Log', '[[regtime]]', '[[regtime]]'),
(37, 1, 1, 'english', 'button_close', 'Close', '[[regtime]]', '[[regtime]]'),
(38, 1, 1, 'english', 'button_upgrade', 'Upgrade', '[[regtime]]', '[[regtime]]'),
(39, 1, 1, 'english', 'button_filter', 'Filter', '[[regtime]]', '[[regtime]]'),
(40, 1, 1, 'english', 'button_send', 'Send', '[[regtime]]', '[[regtime]]'),
(41, 1, 1, 'english', 'button_edit', 'Edit', '[[regtime]]', '[[regtime]]'),
(42, 1, 1, 'english', 'button_copy', 'Copy', '[[regtime]]', '[[regtime]]'),
(43, 1, 1, 'english', 'button_agree', 'Agree', '[[regtime]]', '[[regtime]]'),
(44, 1, 1, 'english', 'button_back', 'Back', '[[regtime]]', '[[regtime]]'),
(45, 1, 1, 'english', 'button_continue', 'Continue', '[[regtime]]', '[[regtime]]'),
(46, 1, 1, 'english', 'button_remove', 'Remove', '[[regtime]]', '[[regtime]]'),
(47, 1, 1, 'english', 'button_backup', 'Backup', '[[regtime]]', '[[regtime]]'),
(48, 1, 1, 'english', 'button_restore', 'Restore', '[[regtime]]', '[[regtime]]'),
(49, 1, 1, 'english', 'button_invoice', 'Print Invoice', '[[regtime]]', '[[regtime]]'),
(50, 1, 1, 'english', 'button_invoices', 'Print Invoices', '[[regtime]]', '[[regtime]]'),
(51, 1, 1, 'english', 'button_add_option', 'Add Option', '[[regtime]]', '[[regtime]]'),
(52, 1, 1, 'english', 'button_add_option_value', 'Add Option Value', '[[regtime]]', '[[regtime]]'),
(53, 1, 1, 'english', 'button_add_discount', 'Add Discount', '[[regtime]]', '[[regtime]]'),
(54, 1, 1, 'english', 'button_add_special', 'Add Special', '[[regtime]]', '[[regtime]]'),
(55, 1, 1, 'english', 'button_add_image', 'Add Image', '[[regtime]]', '[[regtime]]'),
(56, 1, 1, 'english', 'button_add_location_zone', 'Add Location Zone', '[[regtime]]', '[[regtime]]'),
(57, 1, 1, 'english', 'button_add_rate', 'Add Tax Rate', '[[regtime]]', '[[regtime]]'),
(58, 1, 1, 'english', 'button_add_history', 'Add Order History', '[[regtime]]', '[[regtime]]'),
(59, 1, 1, 'english', 'button_actas', 'Act on behalf of', '[[regtime]]', '[[regtime]]'),
(60, 1, 1, 'english', 'button_message', 'Contact this customer', '[[regtime]]', '[[regtime]]'),
(61, 1, 1, 'english', 'button_approve', 'Approve', '[[regtime]]', '[[regtime]]'),
(62, 1, 1, 'english', 'button_generate', 'Generate', '[[regtime]]', '[[regtime]]'),
(63, 1, 1, 'english', 'tab_admin', 'Admin', '[[regtime]]', '[[regtime]]'),
(64, 1, 1, 'english', 'tab_data', 'Data', '[[regtime]]', '[[regtime]]'),
(65, 1, 1, 'english', 'text_quantity_discount', 'Quantity Discounts', '[[regtime]]', '[[regtime]]'),
(66, 1, 1, 'english', 'tab_details', 'Store Details', '[[regtime]]', '[[regtime]]'),
(67, 1, 1, 'english', 'tab_checkout', 'Checkout', '[[regtime]]', '[[regtime]]'),
(68, 1, 1, 'english', 'tab_appearance', 'Appearance', '[[regtime]]', '[[regtime]]'),
(69, 1, 1, 'english', 'tab_im', 'IM', '[[regtime]]', '[[regtime]]'),
(70, 1, 1, 'english', 'tab_api', 'API', '[[regtime]]', '[[regtime]]'),
(71, 1, 1, 'english', 'tab_general', 'General', '[[regtime]]', '[[regtime]]'),
(72, 1, 1, 'english', 'tab_image', 'Additional Images', '[[regtime]]', '[[regtime]]'),
(73, 1, 1, 'english', 'tab_option', 'Options', '[[regtime]]', '[[regtime]]'),
(74, 1, 1, 'english', 'tab_system', 'System', '[[regtime]]', '[[regtime]]'),
(75, 1, 1, 'english', 'tab_store', 'Store', '[[regtime]]', '[[regtime]]'),
(76, 1, 1, 'english', 'tab_special', 'Specials', '[[regtime]]', '[[regtime]]'),
(77, 1, 1, 'english', 'tab_local', 'Local', '[[regtime]]', '[[regtime]]'),
(78, 1, 1, 'english', 'tab_mail', 'Mail', '[[regtime]]', '[[regtime]]'),
(79, 1, 1, 'english', 'tab_order', 'Order Details', '[[regtime]]', '[[regtime]]'),
(80, 1, 1, 'english', 'tab_history', 'Order History', '[[regtime]]', '[[regtime]]'),
(81, 1, 1, 'english', 'tab_product', 'Products', '[[regtime]]', '[[regtime]]'),
(82, 1, 1, 'english', 'tab_shipping', 'Shipping Address', '[[regtime]]', '[[regtime]]'),
(83, 1, 1, 'english', 'tab_payment', 'Payment Address', '[[regtime]]', '[[regtime]]'),
(84, 1, 1, 'english', 'entry_discount', 'Discount', '[[regtime]]', '[[regtime]]'),
(85, 1, 1, 'english', 'entry_special', 'Special', '[[regtime]]', '[[regtime]]'),
(86, 1, 1, 'english', 'error_upload_1', 'Warning: The uploaded file exceeds the upload_max_filesize directive in php.ini!', '[[regtime]]', '[[regtime]]'),
(87, 1, 1, 'english', 'error_upload_2', 'Warning: The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form!', '[[regtime]]', '[[regtime]]'),
(88, 1, 1, 'english', 'error_upload_3', 'Warning: The uploaded file was only partially uploaded!', '[[regtime]]', '[[regtime]]'),
(89, 1, 1, 'english', 'error_upload_4', 'Warning: No file was uploaded!', '[[regtime]]', '[[regtime]]'),
(90, 1, 1, 'english', 'error_upload_6', 'Warning: Missing a temporary folder!', '[[regtime]]', '[[regtime]]'),
(91, 1, 1, 'english', 'error_upload_7', 'Warning: Failed to write file to disk!', '[[regtime]]', '[[regtime]]'),
(92, 1, 1, 'english', 'error_upload_8', 'Warning: File upload stopped by extension!', '[[regtime]]', '[[regtime]]'),
(93, 1, 1, 'english', 'error_upload_999', 'Warning: No error code available!', '[[regtime]]', '[[regtime]]'),
(94, 1, 1, 'english', 'text_choose_action', 'choose action..', '[[regtime]]', '[[regtime]]'),
(95, 1, 1, 'english', 'text_delete', 'Delete', '[[regtime]]', '[[regtime]]'),
(96, 1, 1, 'english', 'text_delete_selected', 'delete selected', '[[regtime]]', '[[regtime]]'),
(97, 1, 1, 'english', 'text_save_selected', 'Save Selected', '[[regtime]]', '[[regtime]]'),
(98, 1, 1, 'english', 'text_save_all', 'save all', '[[regtime]]', '[[regtime]]'),
(99, 1, 1, 'english', 'text_select_status', '- Select Status -', '[[regtime]]', '[[regtime]]'),
(100, 1, 1, 'english', 'text_all_orders', 'All Orders', '[[regtime]]', '[[regtime]]'),
(101, 1, 1, 'english', 'text_confirm_password', 'confirm password', '[[regtime]]', '[[regtime]]'),
(102, 1, 1, 'english', 'text_insert', 'Insert ', '[[regtime]]', '[[regtime]]'),
(103, 1, 1, 'english', 'text_select_items', 'Please Select Items', '[[regtime]]', '[[regtime]]'),
(104, 1, 1, 'english', 'button_go', 'GO', '[[regtime]]', '[[regtime]]'),
(105, 1, 1, 'english', 'search_everywhere', 'Search Entire Site', '[[regtime]]', '[[regtime]]'),
(106, 1, 1, 'english', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(107, 1, 1, 'english', 'error_permission_access', 'Warning: You do not have permission to access %s!', '[[regtime]]', '[[regtime]]'),
(108, 1, 1, 'english', 'error_permission_modify', 'Warning: You do not have permission to modify %s!', '[[regtime]]', '[[regtime]]'),
(109, 1, 1, 'english', 'text_add', 'Add', '[[regtime]]', '[[regtime]]'),
(110, 1, 1, 'english', 'text_add_block', 'Add Block', '[[regtime]]', '[[regtime]]'),
(111, 1, 1, 'english', 'text_resource_library', 'Resource Library', '[[regtime]]', '[[regtime]]'),
(112, 1, 1, 'english', 'text_add_media', 'Add Media', '[[regtime]]', '[[regtime]]'),
(113, 1, 1, 'english', 'confirm_unmap_title', 'Confirm resource(s) Unlink', '[[regtime]]', '[[regtime]]'),
(114, 1, 1, 'english', 'text_confirm_unmap', 'Are you sure you want to unlink resource(s)?', '[[regtime]]', '[[regtime]]'),
(115, 1, 1, 'english', 'confirm_del_title', 'Confirm resource(s) Delete', '[[regtime]]', '[[regtime]]'),
(116, 1, 1, 'english', 'text_confirm_del', 'Are you sure you want to delete resource(s)?', '[[regtime]]', '[[regtime]]'),
(117, 1, 1, 'english', 'text_type_image', 'Images', '[[regtime]]', '[[regtime]]'),
(118, 1, 1, 'english', 'text_type_audio', 'Audio', '[[regtime]]', '[[regtime]]'),
(119, 1, 1, 'english', 'text_type_video', 'Video', '[[regtime]]', '[[regtime]]'),
(120, 1, 1, 'english', 'text_type_pdf', 'PDF Document', '[[regtime]]', '[[regtime]]'),
(121, 1, 1, 'english', 'text_type_archive', 'Archive', '[[regtime]]', '[[regtime]]'),
(122, 1, 1, 'english', 'text_type_download', 'Download File', '[[regtime]]', '[[regtime]]'),
(123, 1, 1, 'english', 'button_unmap', 'Unlink', '[[regtime]]', '[[regtime]]'),
(124, 1, 1, 'english', 'button_select_resource', 'select', '[[regtime]]', '[[regtime]]'),
(125, 1, 1, 'english', 'text_click_to_change', 'Click image to change it', '[[regtime]]', '[[regtime]]'),
(126, 1, 1, 'english', 'text_select_from_list', 'Select from the list', '[[regtime]]', '[[regtime]]'),
(127, 1, 1, 'english', 'text_count_selected', 'Count of selected items:', '[[regtime]]', '[[regtime]]'),
(128, 1, 1, 'english', 'text_delete_confirm', 'Please, confirm delete', '[[regtime]]', '[[regtime]]'),
(129, 1, 1, 'english', 'text_save_edit', 'Add/Edit', '[[regtime]]', '[[regtime]]'),
(130, 1, 1, 'english', 'text_apply', 'Apply', '[[regtime]]', '[[regtime]]'),
(131, 1, 1, 'english', 'text_on_top', 'back on top', '[[regtime]]', '[[regtime]]'),
(132, 1, 1, 'english', 'text_all', 'All', '[[regtime]]', '[[regtime]]'),
(133, 1, 1, 'english', 'text_all_stores', 'All Stores', '[[regtime]]', '[[regtime]]'),
(134, 1, 1, 'english', 'text_create_new_block', ' Create New Block ', '[[regtime]]', '[[regtime]]'),
(135, 1, 1, 'english', 'button_unlink', 'Unlink', '[[regtime]]', '[[regtime]]'),
(136, 1, 1, 'english', 'text_confirm_unlink', 'Are you sure you want to unlink resource?', '[[regtime]]', '[[regtime]]'),
(137, 1, 1, 'english', 'confirm_unlink_title', 'Confirm resource Unlink', '[[regtime]]', '[[regtime]]'),
(138, 1, 1, 'english', 'text_select_store', 'Select a different store', '[[regtime]]', '[[regtime]]'),
(139, 1, 1, 'english', 'text_click_browse_file', 'Click to browse file', '[[regtime]]', '[[regtime]]'),
(140, 1, 1, 'english', 'text_browse', 'Browse', '[[regtime]]', '[[regtime]]'),
(141, 1, 1, 'english', 'text_or', 'or', '[[regtime]]', '[[regtime]]'),
(142, 1, 1, 'english', 'error_seo_keyword', 'SEO keyword <a target="_blank" href="%s">"%s"</a> is already exists!', '[[regtime]]', '[[regtime]]'),
(143, 1, 1, 'english', 'column_update_date', 'Update Date', '[[regtime]]', '[[regtime]]'),
(144, 1, 1, 'english', 'text_automatic', 'Automatic', '[[regtime]]', '[[regtime]]'),
(145, 1, 1, 'english', 'text_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(146, 1, 1, 'english', 'text_select_copy_layout', 'Select to copy layout from', '[[regtime]]', '[[regtime]]'),
(147, 1, 1, 'english', 'text_apply_layout', 'Apply Now', '[[regtime]]', '[[regtime]]'),
(148, 1, 1, 'english', 'text_new_download', 'New Download', '[[regtime]]', '[[regtime]]'),
(149, 1, 1, 'english', 'text_free', 'Free', '[[regtime]]', '[[regtime]]'),
(150, 1, 1, 'english', 'text_sure', 'Are you sure?', '[[regtime]]', '[[regtime]]'),
(151, 1, 1, 'english', 'button_add', 'Add', '[[regtime]]', '[[regtime]]'),
(152, 1, 1, 'english', 'text_please_confirm', 'Please Confirm', '[[regtime]]', '[[regtime]]'),
(153, 1, 1, 'english', 'button_confirm', 'Confirm', '[[regtime]]', '[[regtime]]'),
(154, 1, 1, 'english', 'button_download', 'Download', '[[regtime]]', '[[regtime]]'),
(155, 1, 1, 'english', 'recent_customers', 'Recently Registered Customers', '[[regtime]]', '[[regtime]]'),
(156, 1, 1, 'english', 'new_orders', 'New Orders', '[[regtime]]', '[[regtime]]'),
(157, 1, 1, 'english', 'text_saved', 'Saved Successfully', '[[regtime]]', '[[regtime]]'),
(158, 1, 1, 'english', 'text_processing', 'Processing ...', '[[regtime]]', '[[regtime]]'),
(159, 1, 1, 'english', 'text_next', 'Next', '[[regtime]]', '[[regtime]]'),
(160, 1, 1, 'english', 'text_previous', 'Previous', '[[regtime]]', '[[regtime]]'),
(161, 1, 1, 'english', 'text_on', 'ON', '[[regtime]]', '[[regtime]]'),
(162, 1, 1, 'english', 'text_off', 'OFF', '[[regtime]]', '[[regtime]]'),
(163, 1, 1, 'english', 'text_external_help', 'External Help', '[[regtime]]', '[[regtime]]'),
(164, 1, 1, 'english', 'text_select_from_lookup', 'Start typing (name, model, sku, etc.) to look up and select result', '[[regtime]]', '[[regtime]]'),
(165, 1, 1, 'english', 'text_continue_typing', 'Continue typing ...', '[[regtime]]', '[[regtime]]'),
(166, 1, 1, 'english', 'text_looking_for', 'Looking for', '[[regtime]]', '[[regtime]]'),
(167, 1, 1, 'english', 'button_manage_extensions', 'Manage Extensions', '[[regtime]]', '[[regtime]]'),
(168, 1, 1, 'english', 'text_abc_notification', 'Software Updates & Notifications', '[[regtime]]', '[[regtime]]'),
(169, 1, 1, 'english', 'text_not_applicable', 'NA', '[[regtime]]', '[[regtime]]'),
(170, 1, 1, 'english', 'text_share_embed_code', 'Get Embed Code', '[[regtime]]', '[[regtime]]'),
(171, 1, 1, 'english', 'text_copy_embed_code', 'Сopy and paste this into your HTML-code where you''d like to sell', '[[regtime]]', '[[regtime]]'),
(172, 1, 1, 'english', 'text_copy_embed_url', 'Сopy and paste this URL into your another site where you''d like to sell', '[[regtime]]', '[[regtime]]'),
(173, 1, 1, 'english', 'button_retry', 'Retry', '[[regtime]]', '[[regtime]]'),
(174, 1, 1, 'english', 'text_system_error', 'System error has been encountered. Check system <a target="_blank" href="%s">messages</a> or <a target="_blank" href="%s">error log</a>', '[[regtime]]', '[[regtime]]'),
(175, 1, 1, 'english', 'text_system_warning', 'System warning has been reported. Check system <a target="_blank" href="%s">messages</a>', '[[regtime]]', '[[regtime]]'),
(176, 1, 1, 'english', 'text_system_notice', 'System notice has been reported. Check system <a target="_blank" href="%s">messages</a>', '[[regtime]]', '[[regtime]]'),
(177, 1, 1, 'english', 'text_set_related', 'Set Related', '[[regtime]]', '[[regtime]]'),
(178, 1, 1, 'english', 'tab_text', 'HTML/Text', '[[regtime]]', '[[regtime]]'),
(179, 1, 1, 'english', 'tab_visual', 'Visual', '[[regtime]]', '[[regtime]]'),
(180, 1, 1, 'english', 'button_add_media', 'Add Media', '[[regtime]]', '[[regtime]]'),
(181, 1, 1, 'english', 'button_field_history', 'View Field History', '[[regtime]]', '[[regtime]]'),
(182, 1, 1, 'english', 'text_view_more', 'View More', '[[regtime]]', '[[regtime]]'),
(183, 1, 1, 'english', 'text_admin', 'Control Panel', '[[regtime]]', '[[regtime]]'),
(184, 1, 1, 'english', 'text_storefront', 'Storefront', '[[regtime]]', '[[regtime]]'),
(185, 1, 1, 'english', 'text_texteditor_extended_mode', '<a class="texteditor_ext_mode" href="%s" ><i class="fa fa-external-link"></i> Edit in Extended Mode</a>', '[[regtime]]', '[[regtime]]'),
(186, 1, 1, 'english', 'text_quick_view', 'Quick View', '[[regtime]]', '[[regtime]]'),
(187, 1, 1, 'english', 'text_more_current', 'Full page edit', '[[regtime]]', '[[regtime]]'),
(188, 1, 1, 'english', 'text_more_new', 'New tab edit', '[[regtime]]', '[[regtime]]'),
(189, 1, 1, 'english', 'text_back_to_list', 'Back to listing', '[[regtime]]', '[[regtime]]'),
(190, 1, 1, 'english', 'text_help_link', '<a href="https://www.abantecart.com/contact-us" target="_abantecart">Need help?</a>', '[[regtime]]', '[[regtime]]'),
(191, 1, 1, 'english', 'text_subtract_order', 'Subtract Order', '[[regtime]]', '[[regtime]]'),
(192, 1, 1, 'english', 'button_preview', 'Preview', '[[regtime]]', '[[regtime]]'),
(193, 1, 1, 'english', 'warning_extensions_with_layouts', ' Following extensions <br> %s <br> includes pages or layouts that are not present in the selected template. To include features from these extensions you will need to reinstall extensions after you enable new template. If reinstallation does not help, contact original developers of the above extensions for help.  ', '[[regtime]]', '[[regtime]]'),
(194, 1, 1, 'english', 'column_sku', 'SKU', '[[regtime]]', '[[regtime]]'),
(195, 1, 1, 'english', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(196, 1, 1, 'english', 'text_data_history', 'Data Change History', '[[regtime]]', '[[regtime]]'),
(197, 1, 1, 'english', 'text_design', 'Design', '[[regtime]]', '[[regtime]]'),
(198, 1, 1, 'english', 'text_select_brand', '-Select Brand-', '[[regtime]]', '[[regtime]]'),
(199, 1, 1, 'english', 'text_advanced_settings', 'Advanced', '[[regtime]]', '[[regtime]]'),
(200, 1, 1, 'banner_manager_banner_manager', 'banner_manager_name', 'Banner Manager', '[[regtime]]', '[[regtime]]'),
(201, 1, 1, 'banner_manager_banner_manager', 'banner_manager_note', 'To manage banners follow menu <b>Design -> Banner Mannger</b> after extension is enabled <br>\n		To see banner statistic follow <b>Reports -> Banner Statistic</b> after extension is enabled and banners created', '[[regtime]]', '[[regtime]]'),
(202, 1, 1, 'banner_manager_banner_manager', 'banner_manager_list', 'Banner List', '[[regtime]]', '[[regtime]]'),
(203, 1, 1, 'banner_manager_banner_manager', 'banner_manager_name_stat', 'Banner Statistic', '[[regtime]]', '[[regtime]]'),
(204, 1, 1, 'banner_manager_banner_manager', 'column_banner_id', ' Id ', '[[regtime]]', '[[regtime]]'),
(205, 1, 1, 'banner_manager_banner_manager', 'column_banner_name', ' Name ', '[[regtime]]', '[[regtime]]'),
(206, 1, 1, 'banner_manager_banner_manager', 'column_banner_group', ' Group ', '[[regtime]]', '[[regtime]]'),
(207, 1, 1, 'banner_manager_banner_manager', 'column_banner_type', ' Type ', '[[regtime]]', '[[regtime]]'),
(208, 1, 1, 'banner_manager_banner_manager', 'column_status', ' Status ', '[[regtime]]', '[[regtime]]'),
(209, 1, 1, 'banner_manager_banner_manager', 'column_update_date', ' Update Date ', '[[regtime]]', '[[regtime]]'),
(210, 1, 1, 'banner_manager_banner_manager', 'column_clicked', ' Clicks ', '[[regtime]]', '[[regtime]]'),
(211, 1, 1, 'banner_manager_banner_manager', 'column_viewed', ' Viewed ', '[[regtime]]', '[[regtime]]'),
(212, 1, 1, 'banner_manager_banner_manager', 'column_percent', ' Conversion ', '[[regtime]]', '[[regtime]]'),
(213, 1, 1, 'banner_manager_banner_manager', 'text_create', ' Create New Banner ', '[[regtime]]', '[[regtime]]'),
(214, 1, 1, 'banner_manager_banner_manager', 'text_graphic_banner', ' Graphic Banner ', '[[regtime]]', '[[regtime]]'),
(215, 1, 1, 'banner_manager_banner_manager', 'text_text_banner', ' Text Banner ', '[[regtime]]', '[[regtime]]'),
(216, 1, 1, 'banner_manager_banner_manager', 'entry_banner_name', ' Name: ', '[[regtime]]', '[[regtime]]'),
(217, 1, 1, 'banner_manager_banner_manager', 'entry_banner_status', ' Status: ', '[[regtime]]', '[[regtime]]'),
(218, 1, 1, 'banner_manager_banner_manager', 'entry_banner_group_name', ' Banner Group Name: ', '[[regtime]]', '[[regtime]]'),
(219, 1, 1, 'banner_manager_banner_manager', 'entry_banner_description', ' Description: ', '[[regtime]]', '[[regtime]]'),
(220, 1, 1, 'banner_manager_banner_manager', 'entry_banner_html', ' Banner HTML-code: ', '[[regtime]]', '[[regtime]]'),
(221, 1, 1, 'banner_manager_banner_manager', 'entry_banner_meta', ' Meta information: <span class="help">SEO keywords etc</span> ', '[[regtime]]', '[[regtime]]'),
(222, 1, 1, 'banner_manager_banner_manager', 'entry_banner_url', ' URL: ', '[[regtime]]', '[[regtime]]'),
(223, 1, 1, 'banner_manager_banner_manager', 'entry_banner_blank', ' Open in New Window: ', '[[regtime]]', '[[regtime]]'),
(224, 1, 1, 'banner_manager_banner_manager', 'entry_banner_sort_order', ' Sort Order in Group: ', '[[regtime]]', '[[regtime]]'),
(225, 1, 1, 'banner_manager_banner_manager', 'entry_banner_date_start', ' Date Start: ', '[[regtime]]', '[[regtime]]'),
(226, 1, 1, 'banner_manager_banner_manager', 'entry_banner_date_end', ' Date End: ', '[[regtime]]', '[[regtime]]'),
(227, 1, 1, 'banner_manager_banner_manager', 'text_add_new_group', ' -- Add New Group -- ', '[[regtime]]', '[[regtime]]'),
(228, 1, 1, 'banner_manager_banner_manager', 'text_put_new_group', ' Put New Group Name Here ', '[[regtime]]', '[[regtime]]'),
(229, 1, 1, 'banner_manager_banner_manager', 'error_empty', ' Error: Please Fill All Required Fields of Form. ', '[[regtime]]', '[[regtime]]'),
(230, 1, 1, 'banner_manager_banner_manager', 'text_banner_success', ' Success : You have modified banner. ', '[[regtime]]', '[[regtime]]'),
(231, 1, 1, 'banner_manager_banner_manager', 'text_view_stat', ' View Statistic ', '[[regtime]]', '[[regtime]]'),
(232, 1, 1, 'banner_manager_banner_manager', 'text_banner_block', ' Banner Block ', '[[regtime]]', '[[regtime]]'),
(233, 1, 1, 'banner_manager_banner_manager', 'text_create_block', ' Create Banner Block ', '[[regtime]]', '[[regtime]]'),
(234, 1, 1, 'banner_manager_banner_manager', 'text_banner', ' Banner ', '[[regtime]]', '[[regtime]]'),
(235, 1, 1, 'banner_manager_banner_manager', 'entry_banners_selected', ' Selected banners: ', '[[regtime]]', '[[regtime]]'),
(236, 1, 1, 'banner_manager_banner_manager', 'text_select_banners', ' Select banners ', '[[regtime]]', '[[regtime]]'),
(237, 1, 1, 'banner_manager_banner_manager', 'text_hours', ' hours ', '[[regtime]]', '[[regtime]]'),
(238, 1, 1, 'banner_manager_banner_manager', 'text_weeks', ' week days ', '[[regtime]]', '[[regtime]]'),
(239, 1, 1, 'banner_manager_banner_manager', 'text_days', ' days ', '[[regtime]]', '[[regtime]]'),
(240, 1, 1, 'banner_manager_banner_manager', 'text_months', ' months ', '[[regtime]]', '[[regtime]]'),
(241, 1, 1, 'banner_manager_banner_manager', 'text_count', ' count ', '[[regtime]]', '[[regtime]]'),
(242, 1, 1, 'banner_manager_banner_manager', 'text_banners', ' Banners ', '[[regtime]]', '[[regtime]]'),
(243, 1, 1, 'banner_manager_banner_manager', 'text_delete_statistic', ' Delete Statistic ', '[[regtime]]', '[[regtime]]'),
(244, 1, 1, 'banner_manager_banner_manager', 'text_delete_success', ' Statistic have been successfully deleted! ', '[[regtime]]', '[[regtime]]'),
(245, 1, 1, 'forms_manager_forms_manager', 'forms_manager_name', 'Forms Manager', '[[regtime]]', '[[regtime]]'),
(246, 1, 1, 'forms_manager_forms_manager', 'forms_manager_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(247, 1, 1, 'forms_manager_forms_manager', 'forms_manager_note', '            To manage forms, please enable extension and follow Design-><a href="#admin#rt=tool/forms_manager">Forms Manager</a>', '[[regtime]]', '[[regtime]]'),
(248, 1, 1, 'forms_manager_forms_manager', 'custom_forms_block', 'Custom Forms Block', '[[regtime]]', '[[regtime]]'),
(249, 1, 1, 'forms_manager_forms_manager', 'entry_form_name', 'Form Name<br/><span class="help">Latin letters, underscore, minus only</span>', '[[regtime]]', '[[regtime]]'),
(250, 1, 1, 'forms_manager_forms_manager', 'entry_controller_path', 'Processing Controller', '[[regtime]]', '[[regtime]]'),
(251, 1, 1, 'forms_manager_forms_manager', 'entry_success_page', '            Success page<br/><span class="help">Leave it empty if you want to redirect to the same page as controller</span>', '[[regtime]]', '[[regtime]]'),
(252, 1, 1, 'forms_manager_forms_manager', 'entry_form_description', 'Description', '[[regtime]]', '[[regtime]]'),
(253, 1, 1, 'forms_manager_forms_manager', 'text_default_email', 'Default Email', '[[regtime]]', '[[regtime]]'),
(254, 1, 1, 'forms_manager_forms_manager', 'text_contactus_page', 'Contact Us Page', '[[regtime]]', '[[regtime]]'),
(255, 1, 1, 'forms_manager_forms_manager', 'text_form', 'Form', '[[regtime]]', '[[regtime]]'),
(256, 1, 1, 'forms_manager_forms_manager', 'column_name', 'Name', '[[regtime]]', '[[regtime]]'),
(257, 1, 1, 'forms_manager_forms_manager', 'column_field_name', 'Field Name', '[[regtime]]', '[[regtime]]'),
(258, 1, 1, 'forms_manager_forms_manager', 'column_description', 'Description', '[[regtime]]', '[[regtime]]'),
(259, 1, 1, 'forms_manager_forms_manager', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(260, 1, 1, 'forms_manager_forms_manager', 'filter_exact_match', 'The exact phrase', '[[regtime]]', '[[regtime]]'),
(261, 1, 1, 'forms_manager_forms_manager', 'filter_any_word', 'Any of these words', '[[regtime]]', '[[regtime]]'),
(262, 1, 1, 'forms_manager_forms_manager', 'filter_all_words', 'All of these words', '[[regtime]]', '[[regtime]]'),
(263, 1, 1, 'forms_manager_forms_manager', 'text_clone', 'Clone', '[[regtime]]', '[[regtime]]'),
(264, 1, 1, 'forms_manager_forms_manager', 'filter_form', 'Search for form', '[[regtime]]', '[[regtime]]'),
(265, 1, 1, 'forms_manager_forms_manager', 'text_add_new_field', '-- Add new field --', '[[regtime]]', '[[regtime]]'),
(266, 1, 1, 'forms_manager_forms_manager', 'button_add_field', 'Add Field', '[[regtime]]', '[[regtime]]'),
(267, 1, 1, 'forms_manager_forms_manager', 'button_reset', 'Reset', '[[regtime]]', '[[regtime]]'),
(268, 1, 1, 'forms_manager_forms_manager', 'text_field_type', 'Field type:', '[[regtime]]', '[[regtime]]'),
(269, 1, 1, 'forms_manager_forms_manager', 'button_remove_field', 'Remove field', '[[regtime]]', '[[regtime]]'),
(270, 1, 1, 'forms_manager_forms_manager', 'entry_field', 'Field', '[[regtime]]', '[[regtime]]'),
(271, 1, 1, 'forms_manager_forms_manager', 'entry_field_name', 'Field Name', '[[regtime]]', '[[regtime]]'),
(272, 1, 1, 'forms_manager_forms_manager', 'entry_sort_order', 'Sort order within a group', '[[regtime]]', '[[regtime]]'),
(273, 1, 1, 'forms_manager_forms_manager', 'entry_required', 'Required', '[[regtime]]', '[[regtime]]'),
(274, 1, 1, 'forms_manager_forms_manager', 'entry_edit_fields', 'Edit Fields', '[[regtime]]', '[[regtime]]'),
(275, 1, 1, 'forms_manager_forms_manager', 'entry_field_value', 'Field value', '[[regtime]]', '[[regtime]]'),
(276, 1, 1, 'forms_manager_forms_manager', 'error_required', 'This field is required!', '[[regtime]]', '[[regtime]]'),
(277, 1, 1, 'forms_manager_forms_manager', 'error_duplicate_form_name', 'There is already Form with such a Name attribute.', '[[regtime]]', '[[regtime]]'),
(278, 1, 1, 'forms_manager_forms_manager', 'error_duplicate_field_name', 'There is already Field with such a Name in the current Form.', '[[regtime]]', '[[regtime]]'),
(279, 1, 1, 'forms_manager_forms_manager', 'text_field_removed', 'The field has been successfully removed.', '[[regtime]]', '[[regtime]]'),
(280, 1, 1, 'forms_manager_forms_manager', 'text_success_form', 'The form has been successfully updated.', '[[regtime]]', '[[regtime]]'),
(281, 1, 1, 'forms_manager_forms_manager', 'text_success_field', 'The field has been successfully updated.', '[[regtime]]', '[[regtime]]'),
(282, 1, 1, 'forms_manager_forms_manager', 'text_success_added_form', 'The new Form has been successfully added.', '[[regtime]]', '[[regtime]]'),
(283, 1, 1, 'forms_manager_forms_manager', 'text_success_added_field', 'The new field has been successfully added.', '[[regtime]]', '[[regtime]]'),
(284, 1, 1, 'forms_manager_forms_manager', 'text_add_field', 'Add a new field', '[[regtime]]', '[[regtime]]'),
(285, 1, 1, 'forms_manager_forms_manager', 'entry_field_description', 'Display name', '[[regtime]]', '[[regtime]]'),
(286, 1, 1, 'forms_manager_forms_manager', 'entry_add_new_form', 'Add New Form', '[[regtime]]', '[[regtime]]'),
(287, 1, 1, 'forms_manager_forms_manager', 'text_create_block', 'Create Form Block', '[[regtime]]', '[[regtime]]'),
(288, 1, 1, 'forms_manager_forms_manager', 'entry_no_set_values', 'You can''t set values for this field type.', '[[regtime]]', '[[regtime]]'),
(289, 1, 1, 'forms_manager_forms_manager', 'text_field_values', 'Field Values', '[[regtime]]', '[[regtime]]'),
(290, 1, 1, 'forms_manager_forms_manager', 'note_create_form_block', '            NOTE: To see this form shown on storefront, create form block at Design-><a href="%s">Blocks</a> and add it to appropriate page at Design-><a href="%s">Layouts</a> page.', '[[regtime]]', '[[regtime]]'),
(291, 1, 1, 'forms_manager_forms_manager', 'note_edit_layout', '            NOTE: To see this block shown on storefront, add it to appropriate page	at Design-><a href="%s">Layouts</a>. To create new form go to Design-><a href="%s">Form Manager</a> page.', '[[regtime]]', '[[regtime]]'),
(292, 1, 1, 'forms_manager_forms_manager', 'text_select_field_type', '--- Please select ---', '[[regtime]]', '[[regtime]]'),
(293, 1, 1, 'forms_manager_forms_manager', 'entry_field_note', 'Field internal note', '[[regtime]]', '[[regtime]]'),
(294, 1, 1, 'forms_manager_forms_manager', 'forms_manager_default_sender_name', 'Default Sender:', '[[regtime]]', '[[regtime]]'),
(295, 1, 1, 'forms_manager_forms_manager', 'forms_manager_default_sender_email', 'Default Sender Email:', '[[regtime]]', '[[regtime]]'),
(296, 1, 1, 'forms_manager_forms_manager', 'entry_field_placeholder', 'Placeholder:', '[[regtime]]', '[[regtime]]'),
(297, 1, 1, 'forms_manager_forms_manager', 'entry_regexp_pattern', 'Regular Expression Pattern:', '[[regtime]]', '[[regtime]]'),
(298, 1, 1, 'forms_manager_forms_manager', 'entry_html_attributes', '            html-attributes:<br /><span class="help">You can add your custom html-attributes for option element. Example: data-some-attribute="some value"</span>', '[[regtime]]', '[[regtime]]'),
(299, 1, 1, 'forms_manager_forms_manager', 'entry_error_text', 'Error Message about invalid Value:', '[[regtime]]', '[[regtime]]'),
(300, 1, 1, 'forms_manager_forms_manager', 'entry_form', 'Form', '[[regtime]]', '[[regtime]]'),
(301, 1, 1, 'forms_manager_forms_manager', 'error_fill_required', 'Please fill all required fields of form!', '[[regtime]]', '[[regtime]]'),
(302, 1, 1, 'forms_manager_forms_manager', 'error_form_name', 'Name of form cannot be empty!', '[[regtime]]', '[[regtime]]'),
(303, 1, 1, 'forms_manager_forms_manager', 'error_form_description', 'Description of form cannot be empty!', '[[regtime]]', '[[regtime]]'),
(304, 1, 1, 'forms_manager_forms_manager', 'error_field_name_exists', 'Field With Name %s already present in the Form!', '[[regtime]]', '[[regtime]]'),
(305, 1, 1, 'forms_manager_forms_manager', 'error_regexp_pattern', 'Regex pattern is invalid!', '[[regtime]]', '[[regtime]]'),
(306, 1, 1, 'forms_manager_forms_manager', 'forms_manager_error_empty_sender', '            Warning! Please set the default sender name and default sender email in <a href="#admin#rt=extension/extensions/edit&extension=forms_manager" target="_blank">forms manager settings</a>', '[[regtime]]', '[[regtime]]'),
(307, 1, 1, 'forms_manager_forms_manager', 'text_groups', 'Groups', '[[regtime]]', '[[regtime]]'),
(308, 1, 1, 'forms_manager_forms_manager', 'text_fields', 'Fields', '[[regtime]]', '[[regtime]]'),
(309, 1, 1, 'forms_manager_forms_manager', 'text_assign_fields_to_groups', 'Assign Fields to Groups', '[[regtime]]', '[[regtime]]'),
(310, 1, 1, 'forms_manager_forms_manager', 'text_add_new_group', 'Add New Field Group', '[[regtime]]', '[[regtime]]'),
(311, 1, 1, 'forms_manager_forms_manager', 'text_no_group', 'No field groups available', '[[regtime]]', '[[regtime]]'),
(312, 1, 1, 'forms_manager_forms_manager', 'text_no_fields', 'No fields available', '[[regtime]]', '[[regtime]]'),
(313, 1, 1, 'forms_manager_forms_manager', 'text_action', 'Action', '[[regtime]]', '[[regtime]]'),
(314, 1, 1, 'forms_manager_forms_manager', 'entry_group_name', 'Group Name', '[[regtime]]', '[[regtime]]'),
(315, 1, 1, 'forms_manager_forms_manager', 'entry_group', 'Group', '[[regtime]]', '[[regtime]]'),
(316, 1, 1, 'forms_manager_forms_manager', 'entry_group_description', 'Group Description', '[[regtime]]', '[[regtime]]'),
(317, 1, 1, 'forms_manager_forms_manager', 'button_save', 'Save', '[[regtime]]', '[[regtime]]'),
(318, 1, 1, 'forms_manager_forms_manager', 'button_cancel', 'Cancel', '[[regtime]]', '[[regtime]]'),
(319, 1, 1, 'forms_manager_forms_manager', 'error_group_name_required', 'Group name is required!', '[[regtime]]', '[[regtime]]'),
(320, 1, 1, 'forms_manager_forms_manager', 'error_unknown', 'An unknown error occurred', '[[regtime]]', '[[regtime]]'),
(321, 1, 1, 'forms_manager_forms_manager', 'text_success_fields_assigned', 'The fields have been successfully assigned to groups.', '[[regtime]]', '[[regtime]]'),
(322, 1, 1, 'forms_manager_forms_manager', 'text_success_added_group', 'The group has been successfully added.', '[[regtime]]', '[[regtime]]'),
(323, 1, 1, 'forms_manager_forms_manager', 'column_text_id', 'Text ID', '[[regtime]]', '[[regtime]]'),
(324, 1, 1, 'forms_manager_forms_manager', 'error_group_has_fields', 'Cannot remove a group. One or more fields are assigned to this group.', '[[regtime]]', '[[regtime]]'),
(325, 1, 1, 'forms_manager_forms_manager', 'text_edit_field_values', 'Edit Field Values', '[[regtime]]', '[[regtime]]'),
(326, 1, 1, '2checkout_2checkout', '2checkout_name', '2Checkout', '[[regtime]]', '[[regtime]]'),
(327, 1, 1, '2checkout_2checkout', 'text_payment', 'Payment', '[[regtime]]', '[[regtime]]'),
(328, 1, 1, '2checkout_2checkout', 'text_success', 'Success: You have modified 2Checkout account details!', '[[regtime]]', '[[regtime]]'),
(329, 1, 1, '2checkout_2checkout', '2checkout_note', 'With this extension you can use 2Checkout payment system to accept payments from your customers.<br>\n<b>Sign up free today!  Use promo code ABANTECART2CO for a waiver of your application service fee (a savings of $10.99) and start selling online today! </b> Visit <a href="https://www.2checkout.com/signup/">www.2checkout.com</a>, complete the application, and then enter the code into the promo code field to take advantage of this special offer today!\n<br> Once register login to get account credentials to configure this extension\n<br>Don''t forget to setup INS URL and Redirect URL here <a href="https://secure.2checkout.com/cpanel/webhooks_api.php">https://secure.2checkout.com/cpanel/webhooks_api.php</a>.\n<br><br>Your INS URL is <h4>#storefront#rt=extension/2checkout/callback</h4>\n<br><br>Also setup the Redirect URL and choose Return method "Header redirect".\n<br><br>Your Redirect URL is <h4>#storefront#rt=checkout/success</h4>\n		 ', '[[regtime]]', '[[regtime]]'),
(330, 1, 1, '2checkout_2checkout', '2checkout_account', '2Checkout Merchant Code:', '[[regtime]]', '[[regtime]]'),
(331, 1, 1, '2checkout_2checkout', '2checkout_secret', 'Secret Key:<br /><span class="help">The secret word to confirm transactions with (must be the same as defined on the merchant account configuration page.</span>', '[[regtime]]', '[[regtime]]'),
(332, 1, 1, '2checkout_2checkout', '2checkout_test', 'Test Mode:', '[[regtime]]', '[[regtime]]'),
(333, 1, 1, '2checkout_2checkout', '2checkout_test_1', 'Yes', '[[regtime]]', '[[regtime]]'),
(334, 1, 1, '2checkout_2checkout', '2checkout_test_0', 'No', '[[regtime]]', '[[regtime]]'),
(335, 1, 1, '2checkout_2checkout', '2checkout_order_status_id', 'Order Status:', '[[regtime]]', '[[regtime]]'),
(336, 1, 1, '2checkout_2checkout', '2checkout_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(337, 1, 1, '2checkout_2checkout', '2checkout_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(338, 1, 1, '2checkout_2checkout', 'error_permission', 'Warning: You do not have permission to modify payment 2Checkout!', '[[regtime]]', '[[regtime]]'),
(339, 1, 1, '2checkout_2checkout', 'error_account', 'Merchant Code Required!', '[[regtime]]', '[[regtime]]'),
(340, 1, 1, '2checkout_2checkout', 'error_secret', 'Secret Key Required!', '[[regtime]]', '[[regtime]]'),
(341, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_name', 'Avatax integration', '[[regtime]]', '[[regtime]]'),
(342, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_note', 'If you have standard tax enabled, it will function together with Avatax and you might need to disable standard taxes. Check System -> Localization -> <a target="_blank" href="#admin#rt=localisation/tax_class">Tax Class</a><br>Also don''t forget to enable extension <a href="#admin#rt=total/avatax_integration_total">Avatax Integration Total</a><br>Important! Avatax Integration Total calculation order in extension totals must be after subtotal. Subtotal calculation should precede this extension total calculation. Check this in extensions total settings.', '[[regtime]]', '[[regtime]]'),
(343, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_account_number', 'Account Number:<br /><span class="help">Account number provided by Avalara</span>', '[[regtime]]', '[[regtime]]'),
(344, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_license_key', 'License Key:<br /><span class="help">License key provided by Avalara</span>', '[[regtime]]', '[[regtime]]'),
(345, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_test_mode', 'Test mode:', '[[regtime]]', '[[regtime]]'),
(346, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_tax_name', 'Tax Name:<br /><span class="help">Tax name to be shown to the customer in the totals section</span>', '[[regtime]]', '[[regtime]]'),
(347, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_company_code', 'Company Code:<br /><span class="help">Company code to be used with Avalara</span>', '[[regtime]]', '[[regtime]]'),
(348, 1, 1, 'avatax_integration_avatax_integration', 'error_turn_extension_on', 'Error! Please check if the extension is turned ON.', '[[regtime]]', '[[regtime]]'),
(349, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_default_taxcode', 'Product Default TaxCode', '[[regtime]]', '[[regtime]]'),
(350, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_shipping_taxcode', 'Shipping Methods Default TaxCodes', '[[regtime]]', '[[regtime]]'),
(351, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_text_shipping_method', 'Shipping Method', '[[regtime]]', '[[regtime]]'),
(352, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_text_shipping_taxcode', 'Freight Tax Code', '[[regtime]]', '[[regtime]]'),
(353, 1, 1, 'avatax_integration_avatax_integration', 'text_test', 'Test connection', '[[regtime]]', '[[regtime]]'),
(354, 1, 1, 'avatax_integration_avatax_integration', 'text_connection_success', 'Connection is successful and API Credentials are configured correctly.', '[[regtime]]', '[[regtime]]'),
(355, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_test_connection', 'Test connection:', '[[regtime]]', '[[regtime]]'),
(356, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_address_validation', 'Address Validation:<br /><span class="help">Address validation will be performed at customer checkout step</span>', '[[regtime]]', '[[regtime]]'),
(357, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_address_validate_button_title', 'Title for Address Validation Button:', '[[regtime]]', '[[regtime]]'),
(358, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_commit_documents', 'Commit documents on Avatax Service:<br /><span class="help">If enable tax document will be committed at specified order status</span>', '[[regtime]]', '[[regtime]]'),
(359, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_return_documents', 'Return documents on Avatax Service:<br /><span class="help">Return will be recorded at specified order status</span>', '[[regtime]]', '[[regtime]]'),
(360, 1, 1, 'avatax_integration_avatax_integration', 'button_add_tax_code', 'Save', '[[regtime]]', '[[regtime]]'),
(361, 1, 1, 'avatax_integration_avatax_integration', 'button_delete_tax_code', 'Clear TaxCode', '[[regtime]]', '[[regtime]]'),
(362, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_taxcode_name', 'Product TaxCode:', '[[regtime]]', '[[regtime]]'),
(363, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_button_find_taxcode', 'Find Tax Code', '[[regtime]]', '[[regtime]]'),
(364, 1, 1, 'avatax_integration_avatax_integration', 'exemption_status', 'Exemption Status:', '[[regtime]]', '[[regtime]]'),
(365, 1, 1, 'avatax_integration_avatax_integration', 'exemption_status_pending', 'Pending', '[[regtime]]', '[[regtime]]'),
(366, 1, 1, 'avatax_integration_avatax_integration', 'exemption_status_approved', 'Approved', '[[regtime]]', '[[regtime]]'),
(367, 1, 1, 'avatax_integration_avatax_integration', 'exemption_status_declined', 'Declined', '[[regtime]]', '[[regtime]]'),
(368, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_subject', 'Your tax-exempt number has been declined', '[[regtime]]', '[[regtime]]'),
(369, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_mail_text', 'Your tax-exempt number has been declined. To check validity, please visit your account details page %s', '[[regtime]]', '[[regtime]]'),
(370, 1, 1, 'avatax_integration_avatax_integration', 'exemption_number_name', 'Exemption Number:<br /><span class="help">Tax exemption number</span>', '[[regtime]]', '[[regtime]]'),
(371, 1, 1, 'avatax_integration_avatax_integration', 'entity_use_code_name', 'Entity\\Use Code:<br /><span class="help">AvaTax has a group of codes that indicate the type of exemption. See the standard codes or create custom codes in AvaTax site</span>', '[[regtime]]', '[[regtime]]'),
(372, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_status_success_settled', 'Commit on Order status:', '[[regtime]]', '[[regtime]]'),
(373, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_status_return_settled', 'Return on Order status:', '[[regtime]]', '[[regtime]]'),
(374, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_status_cancel_settled', 'Cancel on Order status:', '[[regtime]]', '[[regtime]]'),
(375, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_account_number_validation_error', 'Account Number error. Check it!', '[[regtime]]', '[[regtime]]'),
(376, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_address_validation_countries_Both', 'Both', '[[regtime]]', '[[regtime]]'),
(377, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_address_validation_countries_US', 'USA', '[[regtime]]', '[[regtime]]'),
(378, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_address_validation_countries_CA', 'Canada', '[[regtime]]', '[[regtime]]'),
(379, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_address_validation_countries', 'Countries for address validation', '[[regtime]]', '[[regtime]]'),
(380, 1, 1, 'avatax_integration_avatax_integration', 'total_name', 'Avatax Integration Total', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(381, 1, 1, 'avatax_integration_avatax_integration', 'avatax_integration_logging', 'Enable transaction logging', '[[regtime]]', '[[regtime]]'),
(382, 1, 1, 'cardconnect_cardconnect', 'cardconnect_name', 'CardConnect', '[[regtime]]', '[[regtime]]'),
(383, 1, 1, 'cardconnect_cardconnect', 'cardconnect_note', 'To obtain API Credentials please visit https://cardconnect.com/signup/developer', '[[regtime]]', '[[regtime]]'),
(384, 1, 1, 'cardconnect_cardconnect', 'cardconnect_merchant_id', 'Merchant ID', '[[regtime]]', '[[regtime]]'),
(385, 1, 1, 'cardconnect_cardconnect', 'cardconnect_username', 'API Username', '[[regtime]]', '[[regtime]]'),
(386, 1, 1, 'cardconnect_cardconnect', 'cardconnect_password', 'API Password', '[[regtime]]', '[[regtime]]'),
(387, 1, 1, 'cardconnect_cardconnect', 'cardconnect_logging', 'Logging:<br /><span class="help">Log file is located in system/logs/cardconnect.txt file</span>', '[[regtime]]', '[[regtime]]'),
(388, 1, 1, 'cardconnect_cardconnect', 'cardconnect_test', 'Test', '[[regtime]]', '[[regtime]]'),
(389, 1, 1, 'cardconnect_cardconnect', 'cardconnect_test_connection', 'Test Connection', '[[regtime]]', '[[regtime]]'),
(390, 1, 1, 'cardconnect_cardconnect', 'cardconnect_get_test_api_credentials', 'Get Test API Credentials', '[[regtime]]', '[[regtime]]'),
(391, 1, 1, 'cardconnect_cardconnect', 'cardconnect_test_mode', 'Test Mode', '[[regtime]]', '[[regtime]]'),
(392, 1, 1, 'cardconnect_cardconnect', 'cardconnect_site', 'Domain portion to API:<br /><span class="help">This value should not be changed, unless different specified by cardConnent.</span>', '[[regtime]]', '[[regtime]]'),
(393, 1, 1, 'cardconnect_cardconnect', 'cardconnect_connection_success', 'Connection is successful and API Credentials are configured correctly.', '[[regtime]]', '[[regtime]]'),
(394, 1, 1, 'cardconnect_cardconnect', 'cardconnect_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(395, 1, 1, 'cardconnect_cardconnect', 'cardconnect_location_id', 'Location', '[[regtime]]', '[[regtime]]'),
(396, 1, 1, 'cardconnect_cardconnect', 'cardconnect_status_refund', 'Refunded:<br /><span class="help">Order status you want to be set if payment is refunded in admin/order', '[[regtime]]', '[[regtime]]'),
(397, 1, 1, 'cardconnect_cardconnect', 'cardconnect_status_decline', 'Decline:<br /><span class="help">Order status you want to record in history in response to payment processor status. Main order status is not affected. Order will not be placed only after payment is a success.</span>', '[[regtime]]', '[[regtime]]'),
(398, 1, 1, 'cardconnect_cardconnect', 'cardconnect_status_success_unsettled', 'Success & not settled:<br /><span class="help">Select main order status you want to set in response to payment processor status</span>', '[[regtime]]', '[[regtime]]'),
(399, 1, 1, 'cardconnect_cardconnect', 'cardconnect_status_success_settled', 'Success & settled:<br /><span class="help">Select main order status you want to set in response to payment processor status</span>', '[[regtime]]', '[[regtime]]'),
(400, 1, 1, 'cardconnect_cardconnect', 'cardconnect_status_void', 'Voided:<br /><span class="help">Order status you want to be set if payment is voided in admin/order.</span>', '[[regtime]]', '[[regtime]]'),
(401, 1, 1, 'cardconnect_cardconnect', 'cardconnect_settlement_payment', 'Auto (authorize and capture)', '[[regtime]]', '[[regtime]]'),
(402, 1, 1, 'cardconnect_cardconnect', 'cardconnect_settlement_auth', 'Delayed (authorize only)', '[[regtime]]', '[[regtime]]'),
(403, 1, 1, 'cardconnect_cardconnect', 'cardconnect_settlement', 'Settlement type:<br /><span class="help">If set to "auto", then the transaction will be included in today''s settlement. If set to ''delayed'', then the transaction will be authorised but not settled(captured). You must manually capture transactions within 7 days of authorisation</span>', '[[regtime]]', '[[regtime]]'),
(404, 1, 1, 'cardconnect_cardconnect', 'cardconnect_save_cards_limit', 'Max credit cards saved: <br/><span class="help">Set maximum number of credit cards to be saved by customers (up to 100). If set to 0 or blank saving of cards will not be allowed. Security note: Customer credit card details are saved on CardConnect secure servers to ensure maximum data security measures. No credit card details will be saved on your site.</span>', '[[regtime]]', '[[regtime]]'),
(405, 1, 1, 'cardconnect_cardconnect', 'text_column_date_added', 'Transaction Date', '[[regtime]]', '[[regtime]]'),
(406, 1, 1, 'cardconnect_cardconnect', 'text_column_amount', 'Amount', '[[regtime]]', '[[regtime]]'),
(407, 1, 1, 'cardconnect_cardconnect', 'text_captured_ok', 'Funds were captured successfully', '[[regtime]]', '[[regtime]]'),
(408, 1, 1, 'cardconnect_cardconnect', 'text_captured_order', 'Capture was successful, order status updated to success - settled', '[[regtime]]', '[[regtime]]'),
(409, 1, 1, 'cardconnect_cardconnect', 'text_refunded_ok', 'Refund was processed successfully', '[[regtime]]', '[[regtime]]'),
(410, 1, 1, 'cardconnect_cardconnect', 'text_refund_order', 'Refund was successful, order status updated to refunded', '[[regtime]]', '[[regtime]]'),
(411, 1, 1, 'cardconnect_cardconnect', 'text_voided', 'Void was successful, order status updated to voided', '[[regtime]]', '[[regtime]]'),
(412, 1, 1, 'cardconnect_cardconnect', 'text_payment_info', 'Payment Details', '[[regtime]]', '[[regtime]]'),
(413, 1, 1, 'cardconnect_cardconnect', 'text_capture_status', 'Payment captured', '[[regtime]]', '[[regtime]]'),
(414, 1, 1, 'cardconnect_cardconnect', 'text_void_status', 'Payment voided', '[[regtime]]', '[[regtime]]'),
(415, 1, 1, 'cardconnect_cardconnect', 'text_refund_status', 'Payment refunded', '[[regtime]]', '[[regtime]]'),
(416, 1, 1, 'cardconnect_cardconnect', 'text_capture_amount', 'Capture Amount', '[[regtime]]', '[[regtime]]'),
(417, 1, 1, 'cardconnect_cardconnect', 'text_refund_amount', 'Refund Amount', '[[regtime]]', '[[regtime]]'),
(418, 1, 1, 'cardconnect_cardconnect', 'text_order_ref', 'CardConnect Charge ID', '[[regtime]]', '[[regtime]]'),
(419, 1, 1, 'cardconnect_cardconnect', 'text_authorized_ammount', 'Total amount authorized', '[[regtime]]', '[[regtime]]'),
(420, 1, 1, 'cardconnect_cardconnect', 'text_balance', 'Balance amount', '[[regtime]]', '[[regtime]]'),
(421, 1, 1, 'cardconnect_cardconnect', 'text_transactions', 'Refund Transactions', '[[regtime]]', '[[regtime]]'),
(422, 1, 1, 'cardconnect_cardconnect', 'text_confirm_void', 'Please confirm you want to void the payment?', '[[regtime]]', '[[regtime]]'),
(423, 1, 1, 'cardconnect_cardconnect', 'text_confirm_capture', 'Please confirm you want to capture the payment?', '[[regtime]]', '[[regtime]]'),
(424, 1, 1, 'cardconnect_cardconnect', 'text_confirm_refund', 'Please confirm you want to refund the payment?', '[[regtime]]', '[[regtime]]'),
(425, 1, 1, 'cardconnect_cardconnect', 'button_refund', 'Refund', '[[regtime]]', '[[regtime]]'),
(426, 1, 1, 'cardconnect_cardconnect', 'button_void', 'Void', '[[regtime]]', '[[regtime]]'),
(427, 1, 1, 'cardconnect_cardconnect', 'button_capture', 'Capture', '[[regtime]]', '[[regtime]]'),
(428, 1, 1, 'cardconnect_cardconnect', 'error_system', 'Internal error. Check error log or input parameters!', '[[regtime]]', '[[regtime]]'),
(429, 1, 1, 'cardconnect_cardconnect', 'error_missing_amount', 'Please enter positive amount', '[[regtime]]', '[[regtime]]'),
(430, 1, 1, 'cardconnect_cardconnect', 'error_unable_to_void', 'Unable to void transaction, refresh and check transaction details', '[[regtime]]', '[[regtime]]'),
(431, 1, 1, 'cardconnect_cardconnect', 'error_unable_to_capture', 'Unable to capture, refresh transaction details and check capture amount', '[[regtime]]', '[[regtime]]'),
(432, 1, 1, 'cardconnect_cardconnect', 'error_unable_to_refund', 'Unable to refund, refresh transaction details and check refund amount', '[[regtime]]', '[[regtime]]'),
(433, 1, 1, 'cardconnect_cardconnect', 'text_settlement_status', 'Current Settlement Status', '[[regtime]]', '[[regtime]]'),
(434, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_name', 'Authorize.Net Payment', '[[regtime]]', '[[regtime]]'),
(435, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_note', 'Additional settings are required to complete Authorize.Net payment setup. See additional settings tab.', '[[regtime]]', '[[regtime]]'),
(436, 1, 1, 'default_authorizenet_default_authorizenet', 'text_payment', 'Payment', '[[regtime]]', '[[regtime]]'),
(437, 1, 1, 'default_authorizenet_default_authorizenet', 'text_success', 'Success: You have modified Authorize.Net payment settings!', '[[regtime]]', '[[regtime]]'),
(438, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(439, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(440, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_api_login_id', 'API Login ID:', '[[regtime]]', '[[regtime]]'),
(441, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_test_mode', 'Test mode:<br /><span class="help">Set to ON if you want to use test key</span>', '[[regtime]]', '[[regtime]]'),
(442, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_api_transaction_key', 'Transaction Key:', '[[regtime]]', '[[regtime]]'),
(443, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_api_public_key', 'Public Key:', '[[regtime]]', '[[regtime]]'),
(444, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_autoselect', '            Auto Select:<br /><span class="help">You can set to skip payment selection page if there is only one payment option. This payment method will be selected automatically</span>', '[[regtime]]', '[[regtime]]'),
(445, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_save_cards_limit', '            Can save credit cards:<br /><span class="help">Set maximum number of credit cards to be saved by customers (up to 100). If set to 0 or blank saving of cards will not be allowed. Security note: Customer credit card details are saved on authorizenet secure servers to ensure maximum data security measures. No credit card details will be saved on your site.</span>', '[[regtime]]', '[[regtime]]'),
(446, 1, 1, 'default_authorizenet_default_authorizenet', 'text_authorizenet_connect', 'You need to connect with authorizenet to set up payment details', '[[regtime]]', '[[regtime]]'),
(447, 1, 1, 'default_authorizenet_default_authorizenet', 'text_authorizenet_settings', 'Authorize.Net settings', '[[regtime]]', '[[regtime]]'),
(448, 1, 1, 'default_authorizenet_default_authorizenet', 'text_connect', 'Connect with Authorize.Net', '[[regtime]]', '[[regtime]]'),
(449, 1, 1, 'default_authorizenet_default_authorizenet', 'text_disconnect', 'Disconnect Authorize.Net', '[[regtime]]', '[[regtime]]'),
(450, 1, 1, 'default_authorizenet_default_authorizenet', 'text_skip_connect', 'Cannot connect?', '[[regtime]]', '[[regtime]]'),
(451, 1, 1, 'default_authorizenet_default_authorizenet', 'text_connect_success', 'Connected to Authorize.Net successfully', '[[regtime]]', '[[regtime]]'),
(452, 1, 1, 'default_authorizenet_default_authorizenet', 'text_disconnect_success', 'Disconnected from Authorize.Net successfully', '[[regtime]]', '[[regtime]]'),
(453, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(454, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_sk_live', 'Live Secret Key:<br /><span class="help">Locate this in Authorize.Net API Keys Section. Key starts with sk_live_... </span>', '[[regtime]]', '[[regtime]]'),
(455, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_pk_live', 'Live Publishable Key:<br /><span class="help">Locate this in Authorize.Net API Keys Section. Key starts with pk_live_... </span>', '[[regtime]]', '[[regtime]]'),
(456, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_sk_test', 'Test Secret Key:<br /><span class="help">Locate this in Authorize.Net API Keys Section. Key starts with sk_test_... </span>', '[[regtime]]', '[[regtime]]'),
(457, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_pk_test', 'Test Publishable Key:<br /><span class="help">Locate this in Authorize.Net API Keys Section. Key starts with pk_test_... </span>', '[[regtime]]', '[[regtime]]'),
(458, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_settlement', 'Settlement type:', '[[regtime]]', '[[regtime]]'),
(459, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_settlement_auth', 'Authorize Only', '[[regtime]]', '[[regtime]]'),
(460, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_settlement_authcapture', 'Authorize & Capture ', '[[regtime]]', '[[regtime]]'),
(461, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_status_success_settled', 'Success & settled:<br /><span class="help">Select main order status you want to set in responce to payment processor status</span>', '[[regtime]]', '[[regtime]]'),
(462, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_status_success_unsettled', 'Success & not settled:<br /><span class="help">Select main order status you want to set in responce to payment processor status</span>', '[[regtime]]', '[[regtime]]'),
(463, 1, 1, 'default_authorizenet_default_authorizenet', 'text_column_date_added', 'Transaction Date', '[[regtime]]', '[[regtime]]'),
(464, 1, 1, 'default_authorizenet_default_authorizenet', 'text_column_amount', 'Amount', '[[regtime]]', '[[regtime]]'),
(465, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_settlement_auto', 'Auto (authorize and capture)', '[[regtime]]', '[[regtime]]'),
(466, 1, 1, 'default_authorizenet_default_authorizenet', 'default_authorizenet_settlement_delayed', 'Delayed (authorize only)', '[[regtime]]', '[[regtime]]'),
(467, 1, 1, 'default_authorizenet_default_authorizenet', 'text_payment_info', 'Payment Details', '[[regtime]]', '[[regtime]]'),
(468, 1, 1, 'default_authorizenet_default_authorizenet', 'text_order_ref', 'Authorize.Net Transaction ID', '[[regtime]]', '[[regtime]]'),
(469, 1, 1, 'default_authorizenet_default_authorizenet', 'text_transaction_status', 'Transaction Status', '[[regtime]]', '[[regtime]]'),
(470, 1, 1, 'default_authorizenet_default_authorizenet', 'text_order_total', 'Total amount authorized', '[[regtime]]', '[[regtime]]'),
(471, 1, 1, 'default_authorizenet_default_authorizenet', 'text_balance', 'Balance amount', '[[regtime]]', '[[regtime]]'),
(472, 1, 1, 'default_authorizenet_default_authorizenet', 'error_system', 'Internal error. Check error log or input parameters!', '[[regtime]]', '[[regtime]]'),
(473, 1, 1, 'default_authorizenet_default_authorizenet', 'error_missing_amount', 'Please enter positive amount', '[[regtime]]', '[[regtime]]'),
(474, 1, 1, 'default_authorizenet_default_authorizenet', 'error_authorizenet_sk_test', 'Authorize.Net test key is required', '[[regtime]]', '[[regtime]]'),
(475, 1, 1, 'default_authorizenet_default_authorizenet', 'error_authorizenet_sk_live', 'Authorize.Net live key is required', '[[regtime]]', '[[regtime]]'),
(476, 1, 1, 'default_authorizenet_default_authorizenet', 'error_permission', 'Warning: You do not have permission to modify Authorize.Net Payment!', '[[regtime]]', '[[regtime]]'),
(477, 1, 1, 'default_banktransfer_default_banktransfer', 'default_banktransfer_name', 'Bank Transfer', '[[regtime]]', '[[regtime]]'),
(478, 1, 1, 'default_banktransfer_default_banktransfer', 'text_payment', 'Payment', '[[regtime]]', '[[regtime]]'),
(479, 1, 1, 'default_banktransfer_default_banktransfer', 'text_success', 'Success: You have modified bank transfer settings and details!', '[[regtime]]', '[[regtime]]'),
(480, 1, 1, 'default_banktransfer_default_banktransfer', 'default_banktransfer_instructions', 'Bank Transfer Instructions:<span class="help">Instruction shown to customers to make bank or wire transfer into your bank account</span>', '[[regtime]]', '[[regtime]]'),
(481, 1, 1, 'default_banktransfer_default_banktransfer', 'default_banktransfer_order_min', 'Total Order limit:<span class="help">Minimum order amount to be reached to allow this payment</span>', '[[regtime]]', '[[regtime]]'),
(482, 1, 1, 'default_banktransfer_default_banktransfer', 'default_banktransfer_order_status_id', 'Order Status:', '[[regtime]]', '[[regtime]]'),
(483, 1, 1, 'default_banktransfer_default_banktransfer', 'default_banktransfer_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(484, 1, 1, 'default_banktransfer_default_banktransfer', 'default_banktransfer_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(485, 1, 1, 'default_banktransfer_default_banktransfer', 'error_permission', 'Warning: You do not have permission to modify payment banktransfer!', '[[regtime]]', '[[regtime]]'),
(486, 1, 1, 'default_banktransfer_default_banktransfer', 'error_instructions', 'Bank Transfer Instructions are required!', '[[regtime]]', '[[regtime]]'),
(487, 1, 1, 'default_cheque_default_cheque', 'default_cheque_name', 'Cheque / Money Order', '[[regtime]]', '[[regtime]]'),
(488, 1, 1, 'default_cheque_default_cheque', 'text_payment', 'Payment', '[[regtime]]', '[[regtime]]'),
(489, 1, 1, 'default_cheque_default_cheque', 'text_success', 'Success: You have modified cheque / money order account details!', '[[regtime]]', '[[regtime]]'),
(490, 1, 1, 'default_cheque_default_cheque', 'default_cheque_payable', 'Payable To:<br /><span class="help">Provide name check needs to be written to</span>', '[[regtime]]', '[[regtime]]'),
(491, 1, 1, 'default_cheque_default_cheque', 'default_cheque_address', 'Mail or Send To:<br /><span class="help">Provide address where to send the check. Main store address will be used if blank</span>', '[[regtime]]', '[[regtime]]'),
(492, 1, 1, 'default_cheque_default_cheque', 'default_cheque_order_status_id', 'Order Status:', '[[regtime]]', '[[regtime]]'),
(493, 1, 1, 'default_cheque_default_cheque', 'default_cheque_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(494, 1, 1, 'default_cheque_default_cheque', 'default_cheque_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(495, 1, 1, 'default_cheque_default_cheque', 'error_permission', 'Warning: You do not have permission to modify payment cheque / money order!', '[[regtime]]', '[[regtime]]'),
(496, 1, 1, 'default_cheque_default_cheque', 'error_payable', 'Payable To Required!', '[[regtime]]', '[[regtime]]'),
(497, 1, 1, 'default_cod_default_cod', 'default_cod_name', 'Cash On Delivery', '[[regtime]]', '[[regtime]]'),
(498, 1, 1, 'default_cod_default_cod', 'text_payment', 'Payment', '[[regtime]]', '[[regtime]]'),
(499, 1, 1, 'default_cod_default_cod', 'text_success', 'Success: You have modified Cash On Delivery payment module!', '[[regtime]]', '[[regtime]]'),
(500, 1, 1, 'default_cod_default_cod', 'default_cod_order_status_id', 'Order Status:', '[[regtime]]', '[[regtime]]'),
(501, 1, 1, 'default_cod_default_cod', 'default_cod_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(502, 1, 1, 'default_cod_default_cod', 'default_cod_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(503, 1, 1, 'default_cod_default_cod', 'error_permission', 'Warning: You do not have permission to modify payment Cash On Delivery!', '[[regtime]]', '[[regtime]]'),
(504, 1, 1, 'default_fedex_default_fedex', 'default_fedex_name', 'FEDEX', '[[regtime]]', '[[regtime]]'),
(505, 1, 1, 'default_fedex_default_fedex', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(506, 1, 1, 'default_fedex_default_fedex', 'text_success', 'Success: You have modified shipping FEDEX!', '[[regtime]]', '[[regtime]]'),
(507, 1, 1, 'default_fedex_default_fedex', 'default_fedex_key', 'Fedex Production Key:<br /><span class="help">Enter the Fedex Production Key Assigned to You, Required. </span>', '[[regtime]]', '[[regtime]]'),
(508, 1, 1, 'default_fedex_default_fedex', 'default_fedex_password', 'Fedex Production Password:<br /><span class="help"></span>', '[[regtime]]', '[[regtime]]'),
(509, 1, 1, 'default_fedex_default_fedex', 'default_fedex_account', 'Account Number:<br /><span class="help">Enter the fedex Account Number assigned to you, required.</span>', '[[regtime]]', '[[regtime]]'),
(510, 1, 1, 'default_fedex_default_fedex', 'default_fedex_meter', 'Fedex Meter Number:<br /><span class="help">Enter FedEx Meter Number.</span>', '[[regtime]]', '[[regtime]]'),
(511, 1, 1, 'default_fedex_default_fedex', 'default_fedex_address', 'Address:<br /><span class="help">Shipping from street address.</span>', '[[regtime]]', '[[regtime]]'),
(512, 1, 1, 'default_fedex_default_fedex', 'default_fedex_city', 'City:<br /><span class="help">Shipping from city.</span>', '[[regtime]]', '[[regtime]]'),
(513, 1, 1, 'default_fedex_default_fedex', 'default_fedex_state', 'State:<br /><span class="help">Shipping from state (two letters).</span>', '[[regtime]]', '[[regtime]]'),
(514, 1, 1, 'default_fedex_default_fedex', 'default_fedex_zip', 'Zip/postal code:<br /><span class="help">Shipping from Zip-code.</span>', '[[regtime]]', '[[regtime]]'),
(515, 1, 1, 'default_fedex_default_fedex', 'default_fedex_country', 'Country:<br /><span class="help">Shipping from country(two letters).</span>', '[[regtime]]', '[[regtime]]'),
(516, 1, 1, 'default_fedex_default_fedex', 'default_fedex_quote_type', 'Quote Type:<br /><span class="help">Quote for Residential or Commercial Delivery.</span>', '[[regtime]]', '[[regtime]]'),
(517, 1, 1, 'default_fedex_default_fedex', 'default_fedex_quote_type_residential', 'Residential', '[[regtime]]', '[[regtime]]'),
(518, 1, 1, 'default_fedex_default_fedex', 'default_fedex_quote_type_commercial', 'Commercial', '[[regtime]]', '[[regtime]]'),
(519, 1, 1, 'default_fedex_default_fedex', 'default_fedex_add_chrg', 'Additional Charges:<br /><span class="help">Additional charge applied to fedex quote.</span>', '[[regtime]]', '[[regtime]]'),
(520, 1, 1, 'default_fedex_default_fedex', 'default_fedex_default_fedex_us_01', ' FEDEX First Overnight ', '[[regtime]]', '[[regtime]]'),
(521, 1, 1, 'default_fedex_default_fedex', 'default_fedex_default_fedex_us_02', ' FEDEX Priority Overnight  ', '[[regtime]]', '[[regtime]]'),
(522, 1, 1, 'default_fedex_default_fedex', 'default_fedex_default_fedex_us_03', ' FEDEX Standard Overnight  ', '[[regtime]]', '[[regtime]]'),
(523, 1, 1, 'default_fedex_default_fedex', 'default_fedex_default_fedex_us_04', ' FEDEX 2nd Day ', '[[regtime]]', '[[regtime]]'),
(524, 1, 1, 'default_fedex_default_fedex', 'default_fedex_default_fedex_us_05', ' FEDEX Express Saver  ', '[[regtime]]', '[[regtime]]'),
(525, 1, 1, 'default_fedex_default_fedex', 'default_fedex_default_fedex_us_06', ' FEDEX Ground  ', '[[regtime]]', '[[regtime]]'),
(526, 1, 1, 'default_fedex_default_fedex', 'error_permission', 'Warning: You do not have permission to modify shipping FEDEX!', '[[regtime]]', '[[regtime]]'),
(527, 1, 1, 'default_fedex_default_fedex', 'error_account', 'Account ID Required!', '[[regtime]]', '[[regtime]]'),
(528, 1, 1, 'default_fedex_default_fedex', 'error_meter', 'Fedex Meter ID Required!', '[[regtime]]', '[[regtime]]'),
(529, 1, 1, 'default_fedex_default_fedex', 'default_fedex_note', 'To obtain your Meter Number and Authorization Key, you will need to follow these steps:</br>\n            Go to <a href="http://fedex.com/us/developer" target="_blank">http://fedex.com/us/developer</a><br>\n            Login in with FedEx username and password or click Register Now if they don''t have one.<br>\n            Click "Technical Resources" (left side).<br>\n            Under that click "FedEx web services for shipping.<br>\n            Click on "Move To Production" (right side).<br>\n            Scroll down to button and click "Obtain Production Key".<br>\n            On form choose "No" on question 1.<br>\n            Check the first box on question 2.<br>\n            Choose "Corporate Developer" on question 3.<br>\n            Accept agreement.<br>\n            Fill out the form (do not use dashes in the account number).<br>\n            Receive meter number and key instantly.  Your Production Password will be emailed to you once you complete the above steps.', '[[regtime]]', '[[regtime]]'),
(530, 1, 1, 'default_fedex_default_fedex', 'default_fedex_test', 'Test Mode:<br /><span class="help">Use the live or testing gateway server?</span>', '[[regtime]]', '[[regtime]]'),
(531, 1, 1, 'default_fedex_default_fedex', 'default_fedex_test_1', ' Yes ', '[[regtime]]', '[[regtime]]'),
(532, 1, 1, 'default_fedex_default_fedex', 'default_fedex_test_0', ' No ', '[[regtime]]', '[[regtime]]'),
(533, 1, 1, 'default_fedex_default_fedex', 'text_test_connection', 'Test Your Connection:<span class="help">You can test if API credentials that you''ve entered are correct.</span>', '[[regtime]]', '[[regtime]]'),
(534, 1, 1, 'default_fedex_default_fedex', 'text_test', 'Test', '[[regtime]]', '[[regtime]]'),
(535, 1, 1, 'default_fedex_default_fedex', 'text_connection_success', 'Connection is successful and API Credentials are configured correctly.', '[[regtime]]', '[[regtime]]'),
(536, 1, 1, 'default_fedex_default_fedex', 'error_turn_extension_on', 'Error! Please check if extension is turned ON.', '[[regtime]]', '[[regtime]]'),
(537, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'default_flat_rate_shipping_name', 'Flat Rate', '[[regtime]]', '[[regtime]]'),
(538, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(539, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'text_success', 'Success: You have modified flat rate shipping!', '[[regtime]]', '[[regtime]]'),
(540, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'default_flat_rate_shipping_rates', 'Rates:', '[[regtime]]', '[[regtime]]'),
(541, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'default_flat_rate_shipping_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(542, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'default_flat_rate_shipping_cost', 'Cost:', '[[regtime]]', '[[regtime]]'),
(543, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'default_flat_rate_shipping_tax_class_id', 'Tax Class:', '[[regtime]]', '[[regtime]]'),
(544, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'default_flat_rate_shipping_tax_class_id_0', ' ---None---', '[[regtime]]', '[[regtime]]'),
(545, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'default_flat_rate_shipping_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(546, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'default_flat_rate_shipping_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(547, 1, 1, 'default_flat_rate_shipping_default_flat_rate_shipping', 'error_permission', 'Warning: You do not have permission to modify flat rate shipping!', '[[regtime]]', '[[regtime]]'),
(548, 1, 1, 'default_free_shipping_default_free_shipping', 'default_free_shipping_name', 'Free Shipping', '[[regtime]]', '[[regtime]]'),
(549, 1, 1, 'default_free_shipping_default_free_shipping', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(550, 1, 1, 'default_free_shipping_default_free_shipping', 'text_success', 'Success: You have modified free shipping!', '[[regtime]]', '[[regtime]]'),
(551, 1, 1, 'default_free_shipping_default_free_shipping', 'default_free_shipping_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(552, 1, 1, 'default_free_shipping_default_free_shipping', 'default_free_shipping_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(553, 1, 1, 'default_free_shipping_default_free_shipping', 'error_permission', 'Warning: You do not have permission to modify free shipping!', '[[regtime]]', '[[regtime]]'),
(554, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_name', 'LIQPAY', '[[regtime]]', '[[regtime]]'),
(555, 1, 1, 'default_liqpay_default_liqpay', 'text_payment', 'Payment', '[[regtime]]', '[[regtime]]'),
(556, 1, 1, 'default_liqpay_default_liqpay', 'text_success', 'Success: You have modified LIQPAY account details!', '[[regtime]]', '[[regtime]]'),
(557, 1, 1, 'default_liqpay_default_liqpay', 'text_pay', 'LIQPAY', '[[regtime]]', '[[regtime]]'),
(558, 1, 1, 'default_liqpay_default_liqpay', 'text_card', 'Credit Card', '[[regtime]]', '[[regtime]]'),
(559, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_merchant', 'Merchant ID:', '[[regtime]]', '[[regtime]]'),
(560, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_signature', 'Signature:', '[[regtime]]', '[[regtime]]'),
(561, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_public_key', 'Public Key:', '[[regtime]]', '[[regtime]]'),
(562, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_private_key', 'Private Key:', '[[regtime]]', '[[regtime]]'),
(563, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_type', 'Type:', '[[regtime]]', '[[regtime]]'),
(564, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_type_pay', 'Pay', '[[regtime]]', '[[regtime]]'),
(565, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_type_card', 'Card', '[[regtime]]', '[[regtime]]'),
(566, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_test_mode', 'Test Mode:', '[[regtime]]', '[[regtime]]'),
(567, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_order_status_id', 'Order Status:', '[[regtime]]', '[[regtime]]'),
(568, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(569, 1, 1, 'default_liqpay_default_liqpay', 'default_liqpay_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(570, 1, 1, 'default_liqpay_default_liqpay', 'error_permission', 'Warning: You do not have permission to modify payment LIQPAY!', '[[regtime]]', '[[regtime]]'),
(571, 1, 1, 'default_liqpay_default_liqpay', 'error_merchant', 'Merchant ID Required!', '[[regtime]]', '[[regtime]]'),
(572, 1, 1, 'default_liqpay_default_liqpay', 'error_signature', 'Signature Required!', '[[regtime]]', '[[regtime]]'),
(573, 1, 1, 'default_local_delivery_default_local_delivery', 'default_local_delivery_name', 'Local Delivery', '[[regtime]]', '[[regtime]]'),
(574, 1, 1, 'default_local_delivery_default_local_delivery', 'text_shipping', 'Delivery', '[[regtime]]', '[[regtime]]'),
(575, 1, 1, 'default_local_delivery_default_local_delivery', 'text_success', 'Success: You have modified local delivery!', '[[regtime]]', '[[regtime]]'),
(576, 1, 1, 'default_local_delivery_default_local_delivery', 'default_local_delivery_total', 'Min order amount:<br /><span class="help">Minimum sub-total amount to be met for delivery option to be available.</span>', '[[regtime]]', '[[regtime]]'),
(577, 1, 1, 'default_local_delivery_default_local_delivery', 'default_local_delivery_cost', 'Delivery Fee:', '[[regtime]]', '[[regtime]]'),
(578, 1, 1, 'default_local_delivery_default_local_delivery', 'default_local_delivery_tax_class_id', 'Tax Class:', '[[regtime]]', '[[regtime]]'),
(579, 1, 1, 'default_local_delivery_default_local_delivery', 'default_local_delivery_tax_class_id_0', ' -------- ', '[[regtime]]', '[[regtime]]'),
(580, 1, 1, 'default_local_delivery_default_local_delivery', 'default_local_delivery_postal_codes', 'Postal Codes:<br /><span class="help"> Comma separated postal codes list. Wildcard * supported. Example 30001,3002,40*,*ND</span>', '[[regtime]]', '[[regtime]]'),
(581, 1, 1, 'default_local_delivery_default_local_delivery', 'error_permission', 'Warning: You do not have permission to modify local delivery!', '[[regtime]]', '[[regtime]]'),
(582, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_name', 'Parcelforce 48', '[[regtime]]', '[[regtime]]'),
(583, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(584, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'text_success', 'Success: You have modified Parcelforce 48 shipping!', '[[regtime]]', '[[regtime]]'),
(585, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_rate', 'Parcelforce 48 Rates:<br /><span class="help">Example: 0:0,10:15.99,12:19.99, - Weights less than or equal to 10 pounds would cost $15.99, Weights less than 12 pounds but more than 10 pounds will cost $19.99. Where Pound is your Store Weight class and $ is Store Base currency. You can change both in the Store Settings. Do not enter KG or any symbols. Enter values upto 5,2 decimal places. (12345.67) </span>', '[[regtime]]', '[[regtime]]'),
(586, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_display_weight', 'Display Delivery Weight:<br /><span class="help">Do you want to display the shipping weight? (e.g. Delivery Weight : 2.7674 Kg''s)</span>', '[[regtime]]', '[[regtime]]'),
(587, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_display_weight_1', 'Yes', '[[regtime]]', '[[regtime]]'),
(588, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_display_weight_0', 'No', '[[regtime]]', '[[regtime]]'),
(589, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_display_insurance', 'Display Insurance:<br /><span class="help">Do you want to display the shipping insurance? (e.g. Insured upto 500)</span>', '[[regtime]]', '[[regtime]]'),
(590, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_display_insurance_1', 'Yes', '[[regtime]]', '[[regtime]]'),
(591, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_display_insurance_0', 'No', '[[regtime]]', '[[regtime]]'),
(592, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_display_time', 'Display Delivery Time:<br /><span class="help">Do you want to display the shipping time? (e.g. Ships within 3 to 5 days)</span>', '[[regtime]]', '[[regtime]]'),
(593, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_display_time_1', 'Yes', '[[regtime]]', '[[regtime]]'),
(594, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_display_time_0', 'No', '[[regtime]]', '[[regtime]]'),
(595, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_compensation', 'Parcelforce48 Compensation Rates:<br /><span class="help">Enter values upto 5,2 decimal places. (12345.67) Example: 34:0,100:1,250:2.25 - Insurance cover for cart values upto 34 would cost 0.00 extra, those values more than 100 and upto 250 will cost 2.25 extra. Do not enter currency symbols.</span>', '[[regtime]]', '[[regtime]]'),
(596, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_tax', 'Tax Class:', '[[regtime]]', '[[regtime]]'),
(597, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_tax_0', '---None---', '[[regtime]]', '[[regtime]]'),
(598, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(599, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'default_parcelforce_48_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(600, 1, 1, 'default_parcelforce_48_default_parcelforce_48', 'error_permission', 'Warning: You do not have permission to modify Parcelforce 48 shipping!', '[[regtime]]', '[[regtime]]'),
(601, 1, 1, 'default_per_item_shipping_default_per_item_shipping', 'default_per_item_shipping_name', 'Per Item', '[[regtime]]', '[[regtime]]'),
(602, 1, 1, 'default_per_item_shipping_default_per_item_shipping', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(603, 1, 1, 'default_per_item_shipping_default_per_item_shipping', 'text_success', 'Success: You have modified shipping per item rates!', '[[regtime]]', '[[regtime]]'),
(604, 1, 1, 'default_per_item_shipping_default_per_item_shipping', 'default_per_item_shipping_cost', 'Cost:', '[[regtime]]', '[[regtime]]'),
(605, 1, 1, 'default_per_item_shipping_default_per_item_shipping', 'default_per_item_shipping_tax', 'Tax Class:', '[[regtime]]', '[[regtime]]'),
(606, 1, 1, 'default_per_item_shipping_default_per_item_shipping', 'default_per_item_shipping_tax_0', '---None---', '[[regtime]]', '[[regtime]]'),
(607, 1, 1, 'default_per_item_shipping_default_per_item_shipping', 'default_per_item_shipping_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(608, 1, 1, 'default_per_item_shipping_default_per_item_shipping', 'default_per_item_shipping_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(609, 1, 1, 'default_per_item_shipping_default_per_item_shipping', 'error_permission', 'Warning: You do not have permission to modify shipping per item rates!', '[[regtime]]', '[[regtime]]'),
(610, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_name', 'Royal Mail', '[[regtime]]', '[[regtime]]'),
(611, 1, 1, 'default_royal_mail_default_royal_mail', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(612, 1, 1, 'default_royal_mail_default_royal_mail', 'text_success', 'Success: You have modified Royal Mail shipping!', '[[regtime]]', '[[regtime]]'),
(613, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_1st_class', '1st Class (for GB only)<br/><span class="help">Next-day delivery aim for letters and parcels</span>', '[[regtime]]', '[[regtime]]'),
(614, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_1st_class_rates', '1st Class Rates:<br/><span class="help">Example: .1:1.58,.25:1.96,.5:2.48 Weight:Cost,Weight:Cost, etc. In this example 0.1kg = £1.58. Where KG is your Weight class set in the Royal Mail settings and £ is Store Base currency. Store Weight class will be ignored.</span>', '[[regtime]]', '[[regtime]]'),
(615, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_1st_class_compensation_rates', '1st Class Compensation Rates', '[[regtime]]', '[[regtime]]'),
(616, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_2nd_class', '2nd Class (for GB only)', '[[regtime]]', '[[regtime]]'),
(617, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_2nd_class_rates', '2nd Class Rates', '[[regtime]]', '[[regtime]]'),
(618, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_2nd_class_compensation_rates', '2nd Class Compensation Rates', '[[regtime]]', '[[regtime]]'),
(619, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tracked24', 'Tracked 24® (for GB only)', '[[regtime]]', '[[regtime]]'),
(620, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tracked24_rates', 'Tracked 24® Rates', '[[regtime]]', '[[regtime]]'),
(621, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tracked24_compensation_rates', 'Tracked 24® Compensation Rates', '[[regtime]]', '[[regtime]]'),
(622, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tracked48', 'Tracked 48® (for GB only)', '[[regtime]]', '[[regtime]]'),
(623, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tracked48_rates', 'Tracked 48® Rates', '[[regtime]]', '[[regtime]]'),
(624, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tracked48_compensation_rates', 'Tracked 48® Compensation Rates', '[[regtime]]', '[[regtime]]'),
(625, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_mail24', 'Mail 24® (for GB only)', '[[regtime]]', '[[regtime]]'),
(626, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_mail24_rates', 'Mail 24® Rates', '[[regtime]]', '[[regtime]]'),
(627, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_mail24_compensation_rates', 'Mail 24® Compensation Rates', '[[regtime]]', '[[regtime]]'),
(628, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_mail48', 'Mail 48® (for GB only)', '[[regtime]]', '[[regtime]]'),
(629, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_mail48_rates', 'Mail 48® Rates', '[[regtime]]', '[[regtime]]'),
(630, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_mail48_compensation_rates', 'Mail 48® Compensation Rates', '[[regtime]]', '[[regtime]]'),
(631, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_sameday', 'Sameday® (for GB only)', '[[regtime]]', '[[regtime]]'),
(632, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_sameday_rates', 'Sameday® Rates', '[[regtime]]', '[[regtime]]'),
(633, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_sameday_compensation_rates', 'Sameday® Compensation Rates', '[[regtime]]', '[[regtime]]'),
(634, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_special_delivery_guaranteed', 'Special Delivery Guaranteed® (for GB only)', '[[regtime]]', '[[regtime]]'),
(635, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_special_delivery_guaranteed_rates', 'Special Delivery Guaranteed® Rates', '[[regtime]]', '[[regtime]]'),
(636, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_special_delivery_guaranteed_compensation_rates', 'Special Delivery Guaranteed® Compensation Rates', '[[regtime]]', '[[regtime]]'),
(637, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_free_gb', 'Shipping method for free shipping (GB only)<span class="help">Please select what method will chosen for case when cart contains only products with free shipping</span>', '[[regtime]]', '[[regtime]]'),
(638, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_free_gb_1st_class', '1st Class', '[[regtime]]', '[[regtime]]'),
(639, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_free_gb_2nd_class', '2nd Class', '[[regtime]]', '[[regtime]]'),
(640, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_free_gb_tracked24', 'Tracked 24®', '[[regtime]]', '[[regtime]]'),
(641, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_free_gb_tracked48', 'Tracked 48®', '[[regtime]]', '[[regtime]]'),
(642, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_free_gb_mail24', 'Mail 24®', '[[regtime]]', '[[regtime]]'),
(643, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_free_gb_mail48', 'Mail 48®', '[[regtime]]', '[[regtime]]'),
(644, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_free_gb_sameday', 'Sameday®', '[[regtime]]', '[[regtime]]'),
(645, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_free_gb_special_delivery_guaranteed', 'Special Delivery Guaranteed®', '[[regtime]]', '[[regtime]]'),
(646, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_europe_zone_1', 'International Pricing Europe Zone 1', '[[regtime]]', '[[regtime]]'),
(647, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_europe_zone_2', 'International Pricing Europe Zone 2', '[[regtime]]', '[[regtime]]'),
(648, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_europe_zone_3', 'International Pricing Europe Zone 3', '[[regtime]]', '[[regtime]]'),
(649, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_world_zone_1', 'International Pricing World Zone 1', '[[regtime]]', '[[regtime]]'),
(650, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_world_zone_2', 'International Pricing World Zone 2', '[[regtime]]', '[[regtime]]'),
(651, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_world_zone_3', 'International Pricing World Zone 3', '[[regtime]]', '[[regtime]]'),
(652, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_europe_zone_1', 'International Standard Economy (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(653, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_europe_zone_1_rates', 'Standard Economy Rates (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(654, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_europe_zone_2', 'International Standard Economy (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(655, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_europe_zone_2_rates', 'Standard Economy Rates (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(656, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_europe_zone_3', 'International Standard Economy (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(657, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_europe_zone_3_rates', 'Standard Economy Rates (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(658, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_world_zone_1', 'International Standard Economy (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(659, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_world_zone_1_rates', 'Standard Economy Rates (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(660, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_world_zone_2', 'International Standard Economy (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(661, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_world_zone_2_rates', 'Standard Economy Rates (World Zone 2)', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(662, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_world_zone_3', 'International Standard Economy (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(663, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy_world_zone_3_rates', 'Standard Economy Rates (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(664, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_europe_zone_1', 'International Standard Priority (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(665, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_europe_zone_1_rates', 'Standard Priority Rates (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(666, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_europe_zone_2', 'International Standard Priority (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(667, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_europe_zone_2_rates', 'Standard Priority Rates (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(668, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_europe_zone_3', 'International Standard Priority (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(669, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_europe_zone_3_rates', 'Standard Priority Rates (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(670, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_world_zone_1', 'International Standard Priority (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(671, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_world_zone_1_rates', 'Standard Priority Rates (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(672, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_world_zone_2', 'International Standard Priority (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(673, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_world_zone_2_rates', 'Standard Priority Rates (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(674, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_world_zone_3', 'International Standard Priority (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(675, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority_world_zone_3_rates', 'Standard Priority Rates (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(676, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_europe_zone_1', 'International Signed (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(677, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_europe_zone_1_rates', 'Signed Rates (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(678, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_europe_zone_2', 'International Signed (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(679, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_europe_zone_2_rates', 'Signed Rates (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(680, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_europe_zone_3', 'International Signed (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(681, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_europe_zone_3_rates', 'Signed Rates (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(682, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_world_zone_1', 'International Signed (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(683, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_world_zone_1_rates', 'Signed Rates (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(684, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_world_zone_2', 'International Signed (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(685, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_world_zone_2_rates', 'Signed Rates (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(686, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_world_zone_3', 'International Signed (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(687, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed_world_zone_3_rates', 'Signed Rates (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(688, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_europe_zone_1', 'International Tracked Signed (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(689, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_europe_zone_1_rates', 'Tracked Signed Rates (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(690, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_europe_zone_2', 'International Tracked Signed (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(691, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_europe_zone_2_rates', 'Tracked Signed Rates (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(692, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_europe_zone_3', 'International Tracked Signed (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(693, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_europe_zone_3_rates', 'Tracked Signed Rates (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(694, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_world_zone_1', 'International Tracked Signed (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(695, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_world_zone_1_rates', 'Tracked Signed Rates (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(696, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_world_zone_2', 'International Tracked Signed (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(697, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_world_zone_2_rates', 'Tracked Signed Rates (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(698, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_world_zone_3', 'International Tracked Signed (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(699, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed_world_zone_3_rates', 'Tracked Signed Rates (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(700, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_europe_zone_1', 'International Tracked (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(701, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_europe_zone_1_rates', 'Tracked Rates (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(702, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_europe_zone_2', 'International Tracked (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(703, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_europe_zone_2_rates', 'Tracked Rates (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(704, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_europe_zone_3', 'International Tracked (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(705, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_europe_zone_3_rates', 'Tracked Rates (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(706, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_world_zone_1', 'International Tracked (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(707, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_world_zone_1_rates', 'Tracked Rates (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(708, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_world_zone_2', 'International Tracked (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(709, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_world_zone_2_rates', 'Tracked Rates (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(710, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_world_zone_3', 'International Tracked (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(711, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_world_zone_3_rates', 'Tracked Rates (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(712, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_europe_zone_1', 'International Tracked Heavier (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(713, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_europe_zone_1_rates', 'Tracked Heavier Rates (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(714, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_europe_zone_2', 'International Tracked Heavier (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(715, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_europe_zone_2_rates', 'Tracked Heavier Rates (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(716, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_europe_zone_3', 'International Tracked Heavier (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(717, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_europe_zone_3_rates', 'Tracked Heavier Rates (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(718, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_world_zone_1', 'International Tracked Heavier (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(719, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_world_zone_1_rates', 'Tracked Heavier Rates (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(720, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_world_zone_2', 'International Tracked Heavier (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(721, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_world_zone_2_rates', 'Tracked Heavier Rates (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(722, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_world_zone_3', 'International Tracked Heavier (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(723, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier_world_zone_3_rates', 'Tracked Heavier Rates (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(724, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free', 'International Shipping Method for free shipping <span class="help">Please select what method will chosen for case when cart contains only products with free shipping</span>', '[[regtime]]', '[[regtime]]'),
(725, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_economy_europe_zone_1', 'Standard Economy (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(726, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_economy_europe_zone_2', 'Standard Economy (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(727, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_economy_europe_zone_3', 'Standard Economy (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(728, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_economy_world_zone_1', 'Standard Economy (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(729, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_economy_world_zone_2', 'Standard Economy (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(730, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_economy_world_zone_3', 'Standard Economy (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(731, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_priority_europe_zone_1', 'Standard Priority (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(732, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_priority_europe_zone_2', 'Standard Priority (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(733, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_priority_europe_zone_3', 'Standard Priority (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(734, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_priority_world_zone_1', 'Standard Priority (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(735, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_priority_world_zone_2', 'Standard Priority (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(736, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_standard_priority_world_zone_3', 'Standard Priority (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(737, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_signed_europe_zone_1', 'Signed (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(738, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_signed_europe_zone_2', 'Signed (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(739, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_signed_europe_zone_3', 'Signed (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(740, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_signed_world_zone_1', 'Signed (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(741, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_signed_world_zone_2', 'Signed (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(742, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_signed_world_zone_3', 'Signed (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(743, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_signed_europe_zone_1', 'Tracked Signed (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(744, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_signed_europe_zone_2', 'Tracked Signed (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(745, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_signed_europe_zone_3', 'Tracked Signed (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(746, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_signed_world_zone_1', 'Tracked Signed (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(747, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_signed_world_zone_2', 'Tracked Signed (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(748, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_signed_world_zone_3', 'Tracked Signed (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(749, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_europe_zone_1', 'Tracked (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(750, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_europe_zone_2', 'Tracked (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(751, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_europe_zone_3', 'Tracked (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(752, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_world_zone_1', 'Tracked (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(753, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_world_zone_2', 'Tracked (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(754, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_world_zone_3', 'Tracked (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(755, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_heavier_europe_zone_1', 'Tracked Heavier (Europe Zone 1)', '[[regtime]]', '[[regtime]]'),
(756, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_heavier_europe_zone_2', 'Tracked Heavier (Europe Zone 2)', '[[regtime]]', '[[regtime]]'),
(757, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_heavier_europe_zone_3', 'Tracked Heavier (Europe Zone 3)', '[[regtime]]', '[[regtime]]'),
(758, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_heavier_world_zone_1', 'Tracked Heavier (World Zone 1)', '[[regtime]]', '[[regtime]]'),
(759, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_heavier_world_zone_2', 'Tracked Heavier (World Zone 2)', '[[regtime]]', '[[regtime]]'),
(760, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_free_tracked_heavier_world_zone_3', 'Tracked Heavier (World Zone 3)', '[[regtime]]', '[[regtime]]'),
(761, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_display_weight', 'Display Delivery Weight:<br /><span class="help">Do you want to display the shipping weight? (e.g. Delivery Weight : 2.7674 Kg''s)</span>', '[[regtime]]', '[[regtime]]'),
(762, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_display_insurance', 'Display Insurance:<br /><span class="help">Do you want to display the shipping insurance? (e.g. Insured upto &pound;500)</span>', '[[regtime]]', '[[regtime]]'),
(763, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_display_time', 'Display Delivery Time:<br /><span class="help">Do you want to display the shipping time? (e.g. Ships within 3 to 5 days)</span>', '[[regtime]]', '[[regtime]]'),
(764, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_weight_class', 'Weight Class:<br /><span class="help">Your rates weight class. Store weight class will be ignored</span>', '[[regtime]]', '[[regtime]]'),
(765, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tax', 'Tax Class:', '[[regtime]]', '[[regtime]]'),
(766, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tax_0', '---None---', '[[regtime]]', '[[regtime]]'),
(767, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(768, 1, 1, 'default_royal_mail_default_royal_mail', 'default_royal_mail_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(769, 1, 1, 'default_royal_mail_default_royal_mail', 'error_permission', 'Warning: You do not have permission to modify Royal Mail shipping!', '[[regtime]]', '[[regtime]]'),
(770, 1, 1, 'default_store_pickup_default_store_pickup', 'default_store_pickup_name', 'Pickup From Store', '[[regtime]]', '[[regtime]]'),
(771, 1, 1, 'default_store_pickup_default_store_pickup', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(772, 1, 1, 'default_store_pickup_default_store_pickup', 'text_success', 'Success: You have modified pickup from store!', '[[regtime]]', '[[regtime]]'),
(773, 1, 1, 'default_store_pickup_default_store_pickup', 'default_store_pickup_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(774, 1, 1, 'default_store_pickup_default_store_pickup', 'default_store_pickup_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(775, 1, 1, 'default_store_pickup_default_store_pickup', 'error_permission', 'Warning: You do not have permission to modify pickup from store!', '[[regtime]]', '[[regtime]]'),
(776, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_name', 'TextMarketer', '[[regtime]]', '[[regtime]]'),
(777, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_note', 'To enable sms-messaging go to System -> Settings -> <a href="#admin#rt=setting/setting/im" target="_im">IM</a> <br/>\n		and choose TextMarketer as default sms-driver. Do not forget to enable section where you wish to receive sms from (admin or storefront).<br/>\n		This extension will enable Mobile Phone field for admins and customers to provide. Remember that disabling of this extension will hide this field.\n		If added to existing store with customers, keep in mind that this information will be missing.', '[[regtime]]', '[[regtime]]'),
(778, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_username', 'API Username', '[[regtime]]', '[[regtime]]'),
(779, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_password', 'API Password', '[[regtime]]', '[[regtime]]'),
(780, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_originator', 'Originator: <span class="help">Who the message is from (the originator or sender ID). This can be 11 alpha-numeric or 16 numeric only characters.</span>', '[[regtime]]', '[[regtime]]'),
(781, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_test', 'Test Mode', '[[regtime]]', '[[regtime]]'),
(782, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_test_0', 'No', '[[regtime]]', '[[regtime]]'),
(783, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_test_1', 'Yes', '[[regtime]]', '[[regtime]]'),
(784, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_logging', 'Error Logging Status<span class="help">If you want to log all errors of TextMarketer extension turn this setting ON.</span>', '[[regtime]]', '[[regtime]]'),
(785, 1, 1, 'default_textmarketer_default_textmarketer', 'entry_sms', ' Mobile Phone ', '[[regtime]]', '[[regtime]]'),
(786, 1, 1, 'default_textmarketer_default_textmarketer', 'default_textmarketer_test_connection', 'Test Your Connection:<span class="help">You can test if API credentials that you''ve entered are correct.</span>', '[[regtime]]', '[[regtime]]'),
(787, 1, 1, 'default_textmarketer_default_textmarketer', 'text_test', ' Test ', '[[regtime]]', '[[regtime]]'),
(788, 1, 1, 'default_textmarketer_default_textmarketer', 'error_turn_extension_on', 'Error! Please check if extension is turned ON.', '[[regtime]]', '[[regtime]]'),
(789, 1, 1, 'default_textmarketer_default_textmarketer', 'error_empty_test_phone_number', 'Error! Please place recipient phone number.', '[[regtime]]', '[[regtime]]'),
(790, 1, 1, 'default_textmarketer_default_textmarketer', 'text_see_log', 'See error log for details.', '[[regtime]]', '[[regtime]]'),
(791, 1, 1, 'default_textmarketer_default_textmarketer', 'text_connection_success', 'Connection is successful and API Credentials are configured correctly.', '[[regtime]]', '[[regtime]]'),
(792, 1, 1, 'default_twilio_default_twilio', 'default_twilio_name', 'Twilio', '[[regtime]]', '[[regtime]]'),
(793, 1, 1, 'default_twilio_default_twilio', 'default_twilio_note', 'To enable sms-messaging go to System -> Settings -> <a href="#admin#rt=setting/setting/im" target="_im">IM</a> <br/>\n		and choose Twilio as default sms-driver. Do not forget to enable section where you wish to receive sms from (admin or storefront).<br/>\n		This extension will enable Mobile Phone field for admins and customers to provide. Remember that disabling of this extension will hide this field.\n		If added to existing store with customers, keep in mind that this information will be missing.', '[[regtime]]', '[[regtime]]'),
(794, 1, 1, 'default_twilio_default_twilio', 'default_twilio_username', 'API AccountSID', '[[regtime]]', '[[regtime]]'),
(795, 1, 1, 'default_twilio_default_twilio', 'default_twilio_token', 'API AuthToken', '[[regtime]]', '[[regtime]]'),
(796, 1, 1, 'default_twilio_default_twilio', 'default_twilio_test', 'Test Mode', '[[regtime]]', '[[regtime]]'),
(797, 1, 1, 'default_twilio_default_twilio', 'default_twilio_sender_phone', 'Sender (Twilio) Phone: <span class="help">Phone number of sender in international format (ex. +14158675309)</span>', '[[regtime]]', '[[regtime]]'),
(798, 1, 1, 'default_twilio_default_twilio', 'default_twilio_send_to', 'Send test SMS to: ', '[[regtime]]', '[[regtime]]'),
(799, 1, 1, 'default_twilio_default_twilio', 'default_twilio_test_0', 'No', '[[regtime]]', '[[regtime]]'),
(800, 1, 1, 'default_twilio_default_twilio', 'default_twilio_test_1', 'Yes', '[[regtime]]', '[[regtime]]'),
(801, 1, 1, 'default_twilio_default_twilio', 'default_twilio_test_connection', 'Test Your Connection:<span class="help">You can test if API credentials that you''ve entered are correct.</span>', '[[regtime]]', '[[regtime]]'),
(802, 1, 1, 'default_twilio_default_twilio', 'default_twilio_logging', 'Error Logging Status<span class="help">If you want to log all errors of Twilio extension turn this setting ON.</span>', '[[regtime]]', '[[regtime]]'),
(803, 1, 1, 'default_twilio_default_twilio', 'entry_sms', ' Mobile Phone ', '[[regtime]]', '[[regtime]]'),
(804, 1, 1, 'default_twilio_default_twilio', 'text_test', ' Test ', '[[regtime]]', '[[regtime]]'),
(805, 1, 1, 'default_twilio_default_twilio', 'error_turn_extension_on', 'Error! Please check if extension is turned ON.', '[[regtime]]', '[[regtime]]'),
(806, 1, 1, 'default_twilio_default_twilio', 'text_connection_success', 'Connection is successful and API Credentials are configured correctly.', '[[regtime]]', '[[regtime]]'),
(807, 1, 1, 'default_weight_default_weight', 'default_weight_name', 'Weight Based Shipping', '[[regtime]]', '[[regtime]]'),
(808, 1, 1, 'default_weight_default_weight', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(809, 1, 1, 'default_weight_default_weight', 'text_additional_settings', ' Additional Settings ', '[[regtime]]', '[[regtime]]'),
(810, 1, 1, 'default_weight_default_weight', 'text_success', 'Success: You have modified weight based shipping!', '[[regtime]]', '[[regtime]]'),
(811, 1, 1, 'default_weight_default_weight', 'entry_rate', 'Rates:<br /><span class="help">Example: 5:10.00,7:12.00 Weight:Cost,Weight:Cost, etc. In this example 5 pounds = $10.00. Where Pound is your Store Weight class and $ is Store Base currency. You can change both in the Store Settings</span>', '[[regtime]]', '[[regtime]]'),
(812, 1, 1, 'default_weight_default_weight', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(813, 1, 1, 'default_weight_default_weight', 'entry_tax', 'Tax Class:', '[[regtime]]', '[[regtime]]'),
(814, 1, 1, 'default_weight_default_weight', 'entry_location', 'Location:', '[[regtime]]', '[[regtime]]'),
(815, 1, 1, 'default_weight_default_weight', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(816, 1, 1, 'default_weight_default_weight', 'error_permission', 'Warning: You do not have permission to modify weight based shipping!', '[[regtime]]', '[[regtime]]'),
(817, 1, 1, 'default_weight_default_weight', 'example_weight_text', 'Weight: ', '[[regtime]]', '[[regtime]]'),
(818, 1, 1, 'default_weight_default_weight', 'example_currency_text', 'Currency: ', '[[regtime]]', '[[regtime]]'),
(819, 1, 1, 'encryption_data_manager_encryption_data_manager', 'encryption_data_manager_name', 'Encryption Data Manager', '[[regtime]]', '[[regtime]]'),
(820, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_extensions', 'Extensions', '[[regtime]]', '[[regtime]]'),
(821, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_additional_settings', ' Encryption Data Tools ', '[[regtime]]', '[[regtime]]'),
(822, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(823, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(824, 1, 1, 'encryption_data_manager_encryption_data_manager', 'button_generate_keys', 'Generate Key Pair', '[[regtime]]', '[[regtime]]'),
(825, 1, 1, 'encryption_data_manager_encryption_data_manager', 'button_encrypt_data', 'Encrypt Data', '[[regtime]]', '[[regtime]]'),
(826, 1, 1, 'encryption_data_manager_encryption_data_manager', 'error_permission', 'Warning: You do not have permission to modify weight based shipping!', '[[regtime]]', '[[regtime]]'),
(827, 1, 1, 'encryption_data_manager_encryption_data_manager', 'error_duplicate_key', 'Error: Selected key name pair already exists!', '[[regtime]]', '[[regtime]]'),
(828, 1, 1, 'encryption_data_manager_encryption_data_manager', 'encryption_data_manager_note', '  <b>This extension requires ADVANCED configuration and attention</b><br/> \n		  <b>Once enabled and data encrypted, there is NO undo and extension can not be disabled! </b><br/> \n		  This extension helps managing encryption keys creation and data migration from open to encrypted tables (initial migration)<br/> \n		  <b>PLEASE NOTE:</b> you need to have PHP with SSL Encryption  <b>ENABLED</b>\n          <br/>\n          <br/>To enable data encryption please read help instructions (HOW TO button)', '[[regtime]]', '[[regtime]]'),
(829, 1, 1, 'encryption_data_manager_encryption_data_manager', 'error_openssl_disabled', 'Warning: OpenSSL for PHP is not available or not activated. You can not use encryption or this extension! <br> Check HELP for this extension for more details.', '[[regtime]]', '[[regtime]]'),
(830, 1, 1, 'encryption_data_manager_encryption_data_manager', 'error_data_encryption_disabled', 'Warning: Data Encryption is not enabled on your AbanteCart. You can not encrypt/decrypt data using this extension! <br> Check HELP for this extension for more details.', '[[regtime]]', '[[regtime]]'),
(831, 1, 1, 'encryption_data_manager_encryption_data_manager', 'key_gen_section_name', 'Generate Key Pair', '[[regtime]]', '[[regtime]]'),
(832, 1, 1, 'encryption_data_manager_encryption_data_manager', 'data_encryption', 'Encrypt Data', '[[regtime]]', '[[regtime]]'),
(833, 1, 1, 'encryption_data_manager_encryption_data_manager', 'error_required_data_missing', 'Missing required data field(s). Please check provided values', '[[regtime]]', '[[regtime]]'),
(834, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_key_name', 'Unique key pair name:<br /><span class="help">Name should not contain any spaces or special characters. Keeps it short and simple.</span>', '[[regtime]]', '[[regtime]]'),
(835, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_key_length', 'Key length (bits):<br /><span class="help">Specify key encryption bit length. Larger number represent stronger encryption, but can slower performance (Range 256 - 8192 )</span>', '[[regtime]]', '[[regtime]]'),
(836, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_private_key_type', 'Ecncryption type:<br /><span class="help">This is an encryption algorithm. Use default RSA if you are not advanced user.</span>', '[[regtime]]', '[[regtime]]'),
(837, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_encrypt_key', 'Enable password based key:<br /><span class="help">If enable, addtional passphrase will be required to decrypt text with use of private key. NOTE. This is not currently supported in data encryption.</span>', '[[regtime]]', '[[regtime]]'),
(838, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_passphrase', 'Passphrase or key password:<br /><span class="help">Remember the passphrase or key(s) will be useless and data might be lost</span>', '[[regtime]]', '[[regtime]]'),
(839, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_success_key_get', '<b>Key pair has been created. See keys below and keep them safe.</b> <br/><br/> %s <br/><br/> %s ', '[[regtime]]', '[[regtime]]'),
(840, 1, 1, 'encryption_data_manager_encryption_data_manager', 'error_generating_keys_failed', 'Key pair generation failed. Check your settings and check error log.', '[[regtime]]', '[[regtime]]'),
(841, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_enc_key', 'Key pair name:<br /><span class="help">Select key to be used for encryption. IMPORTANT: Remember key that you used</span>', '[[regtime]]', '[[regtime]]'),
(842, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_enc_tables', 'Table(s) to encrypt:<br /><span class="help">Shown table(s) will be encryted with the key selected. Data can only be opened with this key</span>', '[[regtime]]', '[[regtime]]'),
(843, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_enc_test_mode', 'Test Mode:<br /><span class="help">Check first that all is OK to be encrepted.</span>', '[[regtime]]', '[[regtime]]'),
(844, 1, 1, 'encryption_data_manager_encryption_data_manager', 'entry_enc_remove_original', 'Remove source data:<br /><span class="help">Remove source un-encrepted data records after encryption is complete</span>', '[[regtime]]', '[[regtime]]'),
(845, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_success_encrypting', '<b>Data has been encrypted. <br />  See details:</b> <br/><br/> %s <br /><br /> <b>If you want this key to be used for new data encryption, add following line to file system/config.php : define(''DATA_ENCRYPTION_KEYPAIR'', ''%s''); </b> ', '[[regtime]]', '[[regtime]]'),
(846, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_encryption_test', '<b>Data encryption test result</b> Check error log for any possible errors! <br/><br/> %s ', '[[regtime]]', '[[regtime]]'),
(847, 1, 1, 'encryption_data_manager_encryption_data_manager', 'error_encrypting', 'Data encryption failed. Check your settings and check error log.', '[[regtime]]', '[[regtime]]'),
(848, 1, 1, 'encryption_data_manager_encryption_data_manager', 'post_encrypting_notice', '<b>Important notes! After encryption is completed data will be copied to mirror tables with data encrypted in them. \n    		<br />Follow instructions to add configuration to system/config.php for AbanteCart to switch read/write operations to encrypted tables. </b><br /> Add following line to configuration file: define(''DATA_ENCRYPTION_KEYPAIR'', ''your_key_name''); <br> This will be default key for read/write operations ', '[[regtime]]', '[[regtime]]'),
(849, 1, 1, 'encryption_data_manager_encryption_data_manager', 'encryption_usage', 'Encryption Usage', '[[regtime]]', '[[regtime]]'),
(850, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_unencrepted_records', 'Un-encrypted data records', '[[regtime]]', '[[regtime]]'),
(851, 1, 1, 'encryption_data_manager_encryption_data_manager', 'warn_encrypt_open_data', 'Use ''Encrypt Data'' Tab for initial encryption', '[[regtime]]', '[[regtime]]'),
(852, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_encrepted_records', 'Encrypted data records', '[[regtime]]', '[[regtime]]'),
(853, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_usage_heading_key_id', 'Key ID', '[[regtime]]', '[[regtime]]'),
(854, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_usage_heading_key_name', 'Key Name', '[[regtime]]', '[[regtime]]'),
(855, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_usage_heading_key_tables', 'Encrypted Tables Usage', '[[regtime]]', '[[regtime]]'),
(856, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_usage_heading_key_rotate', 'Rotate (change) Encryption to new key', '[[regtime]]', '[[regtime]]'),
(857, 1, 1, 'encryption_data_manager_encryption_data_manager', 'text_usage_records', 'record(s)', '[[regtime]]', '[[regtime]]'),
(858, 1, 1, 'novator_novator', 'novator_name', 'novator', '[[regtime]]', '[[regtime]]'),
(859, 1, 1, 'novator_novator', 'novator_note', '', '[[regtime]]', '[[regtime]]'),
(860, 1, 1, 'novator_novator', 'novator_category_form_info_alert', '<div class="alert alert-info">All images following the first one can be used in the ''category slides'' block. (see block in the category page layout)</div>', '[[regtime]]', '[[regtime]]'),
(861, 1, 1, 'page_builder_page_builder', 'page_builder_name', 'Page Builder', '[[regtime]]', '[[regtime]]'),
(862, 1, 1, 'page_builder_page_builder', 'page_builder_logging', 'Logging <span class="help">Enable to save javascript exceptions into AbanteCart error log</span>', '[[regtime]]', '[[regtime]]'),
(863, 1, 1, 'page_builder_page_builder', 'text_select_template', 'Select template: ', '[[regtime]]', '[[regtime]]'),
(864, 1, 1, 'page_builder_page_builder', 'page_builder_text_preset', 'Preset: ', '[[regtime]]', '[[regtime]]'),
(865, 1, 1, 'page_builder_page_builder', 'page_builder_button_load_preset', 'Load Preset', '[[regtime]]', '[[regtime]]'),
(866, 1, 1, 'page_builder_page_builder', 'page_builder_text_load_preset_confirm_text', 'Do you really wish to load preset? Already saved changes will be rewritten.', '[[regtime]]', '[[regtime]]'),
(867, 1, 1, 'page_builder_page_builder', 'page_builder_text_delete_preset_confirm_text', 'Do you really wish to delete preset?', '[[regtime]]', '[[regtime]]'),
(868, 1, 1, 'page_builder_page_builder', 'page_builder_text_select_preset', ' -- please select -- ', '[[regtime]]', '[[regtime]]'),
(869, 1, 1, 'page_builder_page_builder', 'page_builder_text_prompt', 'Please enter preset name:', '[[regtime]]', '[[regtime]]'),
(870, 1, 1, 'page_builder_page_builder', 'page_builder_button_undo_title', ' Rollback to Save Point', '[[regtime]]', '[[regtime]]'),
(871, 1, 1, 'page_builder_page_builder', 'page_builder_button_undo', ' Undo', '[[regtime]]', '[[regtime]]'),
(872, 1, 1, 'page_builder_page_builder', 'page_builder_button_undo_confirm_text', ' Do you really wish to rollback changes to save point state?', '[[regtime]]', '[[regtime]]'),
(873, 1, 1, 'page_builder_page_builder', 'page_builder_undo_success_text', ' Success!', '[[regtime]]', '[[regtime]]'),
(874, 1, 1, 'page_builder_page_builder', 'page_builder_button_publish_title', ' Publish Page on a Storefront', '[[regtime]]', '[[regtime]]'),
(875, 1, 1, 'page_builder_page_builder', 'page_builder_button_publish', ' Publish', '[[regtime]]', '[[regtime]]'),
(876, 1, 1, 'page_builder_page_builder', 'page_builder_button_publish_success', ' Published successfully.', '[[regtime]]', '[[regtime]]'),
(877, 1, 1, 'page_builder_page_builder', 'page_builder_button_remove_custom_page_title', ' Remove Custom page to Default State', '[[regtime]]', '[[regtime]]'),
(878, 1, 1, 'page_builder_page_builder', 'page_builder_button_remove_custom_page', ' Delete Design ', '[[regtime]]', '[[regtime]]'),
(879, 1, 1, 'page_builder_page_builder', 'page_builder_button_remove_custom_page_confirm_text', 'Do you really wish to remove your design? ', '[[regtime]]', '[[regtime]]'),
(880, 1, 1, 'page_builder_page_builder', 'page_builder_remove_custom_page_success_text', 'Page has been successfully removed', '[[regtime]]', '[[regtime]]'),
(881, 1, 1, 'page_builder_page_builder', 'page_builder_save_preset_confirm_text', 'Do you really wish to save preset? ', '[[regtime]]', '[[regtime]]'),
(882, 1, 1, 'page_builder_page_builder', 'page_builder_save_preset_success_text', 'Preset %s has been saved successfully!', '[[regtime]]', '[[regtime]]'),
(883, 1, 1, 'page_builder_page_builder', 'page_builder_remove_preset_success_text', 'Preset %s has been deleted successfully!', '[[regtime]]', '[[regtime]]'),
(884, 1, 1, 'page_builder_page_builder', 'page_builder_text_abantecart_blocks', 'Storefront Blocks', '[[regtime]]', '[[regtime]]'),
(885, 1, 1, 'page_builder_page_builder', 'page_builder_text_basic_blocks', 'Basic', '[[regtime]]', '[[regtime]]'),
(886, 1, 1, 'page_builder_page_builder', 'page_builder_text_extra', 'Extra', '[[regtime]]', '[[regtime]]'),
(887, 1, 1, 'page_builder_page_builder', 'page_builder_text_forms', 'Forms', '[[regtime]]', '[[regtime]]'),
(888, 1, 1, 'page_builder_page_builder', 'page_builder_error_storage_permissions', 'PageBuilder Error: Directory %s does not exist or not writable. Please check permissions!', '[[regtime]]', '[[regtime]]'),
(889, 1, 1, 'page_builder_page_builder', 'page_builder_error_preset_permissions', 'Cannot to delete preset! Please check permissions of file %s', '[[regtime]]', '[[regtime]]'),
(890, 1, 1, 'page_builder_page_builder', 'page_builder_error_empty_preset_name', 'Preset name is empty!', '[[regtime]]', '[[regtime]]'),
(891, 1, 1, 'page_builder_page_builder', 'page_builder_error_route_not_found', 'Current Route not Found! Cannot to save.', '[[regtime]]', '[[regtime]]'),
(892, 1, 1, 'page_builder_page_builder', 'page_builder_error_preset_not_found', 'Preset not Found!', '[[regtime]]', '[[regtime]]'),
(893, 1, 1, 'page_builder_page_builder', 'page_builder_error_remove_page', 'Cannot to delete custom page! Please check permissions of file %s', '[[regtime]]', '[[regtime]]'),
(894, 1, 1, 'page_builder_page_builder', 'page_builder_error_cannot_copy', 'Cannot to copy file %s.json to %s! Please check permissions or existing of target', '[[regtime]]', '[[regtime]]'),
(895, 1, 1, 'page_builder_page_builder', 'page_builder_error_nothing_to_publish', 'Nothing to publish. No any save points found.', '[[regtime]]', '[[regtime]]'),
(896, 1, 1, 'page_builder_page_builder', 'page_builder_error_cannot_undo', 'Rollback is unavailable. Save point not found', '[[regtime]]', '[[regtime]]'),
(897, 1, 1, 'page_builder_page_builder', 'page_builder_error_cannot_save', 'Cannot save changes. Please check permissions for directory %s', '[[regtime]]', '[[regtime]]'),
(898, 1, 1, 'page_builder_page_builder', 'page_builder_tab_title', 'To start building a page, please create the layout first.', '[[regtime]]', '[[regtime]]'),
(899, 1, 1, 'page_builder_page_builder', 'page_builder_text_already_published', 'This page is already published by Page Builder.', '[[regtime]]', '[[regtime]]'),
(900, 1, 1, 'page_builder_page_builder', 'page_builder_text_can_try', '...or this page can be customized with Page Builder.', '[[regtime]]', '[[regtime]]'),
(901, 1, 1, 'page_builder_page_builder', 'page_builder_button_click_to_edit_page', 'Click to Edit page', '[[regtime]]', '[[regtime]]'),
(902, 1, 1, 'page_builder_page_builder', 'page_builder_button_click_to_try', 'Click to Try', '[[regtime]]', '[[regtime]]'),
(903, 1, 1, 'paypal_commerce_paypal_commerce', 'text_title', 'Credit Card / Debit Card (Via PayPal)', '[[regtime]]', '[[regtime]]'),
(904, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_name', 'PayPal Commerce', '[[regtime]]', '[[regtime]]'),
(905, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_manual_connect', '&nbsp;', '[[regtime]]', '[[regtime]]'),
(906, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_client_id', 'Your API Client ID<br /><span class="help">Locate this in My Apps & Credentials Section Of PayPal Dashboard -> Developer</span>', '[[regtime]]', '[[regtime]]'),
(907, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_client_secret', 'Your API Secret Key<br /><span class="help">Locate this in My Apps & Credentials Section Of PayPal Dashboard -> Developer</span>', '[[regtime]]', '[[regtime]]'),
(908, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_test_mode', 'Test mode:<br /><span class="help">Set to ON if you want to use the test key</span>', '[[regtime]]', '[[regtime]]'),
(909, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_transaction_type', 'Transaction Method:<br/><span class="help">PayPal transaction to run at customer''s checkout before order status is set. Authorization only or capture.</span>', '[[regtime]]', '[[regtime]]'),
(910, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_transaction_type_capture', 'Capture', '[[regtime]]', '[[regtime]]'),
(911, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_transaction_type_authorize', 'Authorize Only', '[[regtime]]', '[[regtime]]'),
(912, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_components', '            Enabled Components:<span class="help">Select which payment components to enable: PayPal Buttons for express checkout or Card Fields for direct credit card processing.</span>', '[[regtime]]', '[[regtime]]'),
(913, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_components_buttons', 'PayPal Buttons', '[[regtime]]', '[[regtime]]'),
(914, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_components_card-fields', 'Card Fields', '[[regtime]]', '[[regtime]]'),
(915, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_test_connection', 'Test Connection', '[[regtime]]', '[[regtime]]'),
(916, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_text_test', 'Test Now', '[[regtime]]', '[[regtime]]'),
(917, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_text_update_webhooks', 'Update Webhooks', '[[regtime]]', '[[regtime]]'),
(918, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_tooltip_update_webhooks', ' Webhooks will be set up automatically during connection to PayPal. Use this button to update webhooks in PayPal ', '[[regtime]]', '[[regtime]]'),
(919, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_connection_success', 'Connection has been established successfully.', '[[regtime]]', '[[regtime]]'),
(920, 1, 1, 'paypal_commerce_paypal_commerce', 'text_payment', 'Payment', '[[regtime]]', '[[regtime]]'),
(921, 1, 1, 'paypal_commerce_paypal_commerce', 'text_success', 'Success: You have modified PayPal payment settings!', '[[regtime]]', '[[regtime]]'),
(922, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(923, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(924, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(925, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_autoselect', 'Auto Select:<br /><span class="help">You can set to skip the payment selection page if there is only one payment option. This payment method will be selected automatically</span>', '[[regtime]]', '[[regtime]]'),
(926, 1, 1, 'paypal_commerce_paypal_commerce', 'text_paypal_commerce_connect', 'You need to connect with PayPal to set up payment details', '[[regtime]]', '[[regtime]]'),
(927, 1, 1, 'paypal_commerce_paypal_commerce', 'text_paypal_commerce_settings', 'PayPal settings', '[[regtime]]', '[[regtime]]'),
(928, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(929, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_text_register_webhooks', 'Update Webhooks Endpoints on the API side', '[[regtime]]', '[[regtime]]'),
(930, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_text_register_webhooks_success', 'Webhook Endpoints have been updated successfully!', '[[regtime]]', '[[regtime]]'),
(931, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_status_success_settled', 'Success & captured:<br /><span class="help">Select the main order status you want to set in response to payment processor status</span>', '[[regtime]]', '[[regtime]]'),
(932, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_status_success_unsettled', 'Success & not captured:<br /><span class="help">Select the main order status you want to set in response to payment processor status</span>', '[[regtime]]', '[[regtime]]'),
(933, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_status_decline', 'Decline:<br /><span class="help">Order status you want to record in history in response to payment processor status. Main order status is not affected. Order will not be placed only after payment is a success.</span>', '[[regtime]]', '[[regtime]]'),
(934, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_status_capture_pending', 'Pending:</span>', '[[regtime]]', '[[regtime]]'),
(935, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_status_refund', 'Refunded:<br /><span class="help">Order status you want to be set if payment is refunded in admin/order.</span>', '[[regtime]]', '[[regtime]]'),
(936, 1, 1, 'paypal_commerce_paypal_commerce', 'text_column_date_added', 'Transaction Date', '[[regtime]]', '[[regtime]]'),
(937, 1, 1, 'paypal_commerce_paypal_commerce', 'text_column_amount', 'Amount', '[[regtime]]', '[[regtime]]'),
(938, 1, 1, 'paypal_commerce_paypal_commerce', 'text_captured_ok', 'Funds were captured successfully', '[[regtime]]', '[[regtime]]'),
(939, 1, 1, 'paypal_commerce_paypal_commerce', 'text_captured_order', 'Capture was successful, order status updated to success - captured', '[[regtime]]', '[[regtime]]'),
(940, 1, 1, 'paypal_commerce_paypal_commerce', 'text_refunded_ok', 'Refund was processed successfully', '[[regtime]]', '[[regtime]]'),
(941, 1, 1, 'paypal_commerce_paypal_commerce', 'text_refund_order', 'Refund was successful, order status updated to refund', '[[regtime]]', '[[regtime]]'),
(942, 1, 1, 'paypal_commerce_paypal_commerce', 'text_voided', 'Void was successful, order status updated to void', '[[regtime]]', '[[regtime]]'),
(943, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_settlement_auto', 'Auto (authorize and capture)', '[[regtime]]', '[[regtime]]'),
(944, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_settlement_delayed', 'Delayed (authorize only)', '[[regtime]]', '[[regtime]]'),
(945, 1, 1, 'paypal_commerce_paypal_commerce', 'text_payment_info', 'Payment Details', '[[regtime]]', '[[regtime]]'),
(946, 1, 1, 'paypal_commerce_paypal_commerce', 'text_capture_status', 'Payment was captured', '[[regtime]]', '[[regtime]]'),
(947, 1, 1, 'paypal_commerce_paypal_commerce', 'text_void_status', 'Payment was voided', '[[regtime]]', '[[regtime]]'),
(948, 1, 1, 'paypal_commerce_paypal_commerce', 'text_refund_status', 'Payment was refunded', '[[regtime]]', '[[regtime]]'),
(949, 1, 1, 'paypal_commerce_paypal_commerce', 'text_capture_amount', 'Capture Amount', '[[regtime]]', '[[regtime]]'),
(950, 1, 1, 'paypal_commerce_paypal_commerce', 'text_refund_amount', 'Refund Amount', '[[regtime]]', '[[regtime]]'),
(951, 1, 1, 'paypal_commerce_paypal_commerce', 'text_order_ref', 'PayPal Charge ID', '[[regtime]]', '[[regtime]]'),
(952, 1, 1, 'paypal_commerce_paypal_commerce', 'text_order_total', 'Total amount authorized', '[[regtime]]', '[[regtime]]'),
(953, 1, 1, 'paypal_commerce_paypal_commerce', 'text_balance', 'Balance amount', '[[regtime]]', '[[regtime]]'),
(954, 1, 1, 'paypal_commerce_paypal_commerce', 'text_transactions', 'Refund Transactions', '[[regtime]]', '[[regtime]]'),
(955, 1, 1, 'paypal_commerce_paypal_commerce', 'text_confirm_void', 'Please confirm you want to void the payment?', '[[regtime]]', '[[regtime]]'),
(956, 1, 1, 'paypal_commerce_paypal_commerce', 'text_confirm_capture', 'Please confirm you want to capture the payment?', '[[regtime]]', '[[regtime]]'),
(957, 1, 1, 'paypal_commerce_paypal_commerce', 'text_confirm_refund', 'Please confirm you want to refund the payment?', '[[regtime]]', '[[regtime]]'),
(958, 1, 1, 'paypal_commerce_paypal_commerce', 'button_refund', 'Refund', '[[regtime]]', '[[regtime]]'),
(959, 1, 1, 'paypal_commerce_paypal_commerce', 'button_void', 'Void', '[[regtime]]', '[[regtime]]'),
(960, 1, 1, 'paypal_commerce_paypal_commerce', 'button_capture', 'Capture', '[[regtime]]', '[[regtime]]'),
(961, 1, 1, 'paypal_commerce_paypal_commerce', 'error_system', 'Internal error. Check error log or input parameters!', '[[regtime]]', '[[regtime]]'),
(962, 1, 1, 'paypal_commerce_paypal_commerce', 'error_missing_amount', 'Please enter a positive amount', '[[regtime]]', '[[regtime]]'),
(963, 1, 1, 'paypal_commerce_paypal_commerce', 'error_unable_to_capture', 'Unable to capture, refresh transaction details and check the capture amount', '[[regtime]]', '[[regtime]]'),
(964, 1, 1, 'paypal_commerce_paypal_commerce', 'error_unable_to_void', 'Unable to void transaction, refresh and check transaction details', '[[regtime]]', '[[regtime]]'),
(965, 1, 1, 'paypal_commerce_paypal_commerce', 'error_unable_to_refund', 'Unable to refund, refresh transaction details and check the refund amount', '[[regtime]]', '[[regtime]]'),
(966, 1, 1, 'paypal_commerce_paypal_commerce', 'text_connect', 'Connect with PayPal', '[[regtime]]', '[[regtime]]'),
(967, 1, 1, 'paypal_commerce_paypal_commerce', 'text_disconnect_sandbox', 'Disconnect Sandbox', '[[regtime]]', '[[regtime]]'),
(968, 1, 1, 'paypal_commerce_paypal_commerce', 'text_disconnect_live', 'Disconnect Live', '[[regtime]]', '[[regtime]]'),
(969, 1, 1, 'paypal_commerce_paypal_commerce', 'text_skip_connect', 'Cannot connect?', '[[regtime]]', '[[regtime]]'),
(970, 1, 1, 'paypal_commerce_paypal_commerce', 'text_connected_account', 'You are connected with the account:', '[[regtime]]', '[[regtime]]'),
(971, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_error_cannot_connect', 'Connection to Paypal server can not be established.<br>%s<br>Check your server configuration or contact your hosting provider.', '[[regtime]]', '[[regtime]]'),
(972, 1, 1, 'paypal_commerce_paypal_commerce', 'text_connect_success', 'Connected to PayPal successfully', '[[regtime]]', '[[regtime]]'),
(973, 1, 1, 'paypal_commerce_paypal_commerce', 'text_disconnect_success', 'Disconnected from PayPal successfully', '[[regtime]]', '[[regtime]]'),
(974, 1, 1, 'paypal_commerce_paypal_commerce', 'error_permission', 'Warning: You do not have permission to modify PayPal Commerce Payment!', '[[regtime]]', '[[regtime]]'),
(975, 1, 1, 'paypal_commerce_paypal_commerce', 'error_paypal_commerce_client_id', 'App Client ID is required', '[[regtime]]', '[[regtime]]'),
(976, 1, 1, 'paypal_commerce_paypal_commerce', 'error_paypal_commerce_client_secret', 'App Secret key is required', '[[regtime]]', '[[regtime]]'),
(977, 1, 1, 'paypal_commerce_paypal_commerce', 'error_turn_extension_on', 'Error! Please check if the extension is turned ON.', '[[regtime]]', '[[regtime]]'),
(978, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_text_back', 'Back', '[[regtime]]', '[[regtime]]'),
(979, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_webhook_howto_text', 'Note: To complete setup, you should to create webhooks on PayPal Account Side.\n<br> Go to Your <a href="https://dashboard.paypal.com/webhooks" target="_blank">PayPal Dashboard Developer Section</a>\nand Add Endpoints receiving events from your account. After Endpoint has been created, copy Signing Secret and save into PayPal Subscription Extension settings belong.', '[[regtime]]', '[[regtime]]'),
(980, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding', 'Funding Options:', '[[regtime]]', '[[regtime]]'),
(981, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_venmo', 'Venmo', '[[regtime]]', '[[regtime]]'),
(982, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_paylater', 'Pay Later', '[[regtime]]', '[[regtime]]'),
(983, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_credit', 'Credit', '[[regtime]]', '[[regtime]]'),
(984, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_bancontact', 'Bancontact', '[[regtime]]', '[[regtime]]'),
(985, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_blik', 'BLIK', '[[regtime]]', '[[regtime]]'),
(986, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_eps', 'EPS', '[[regtime]]', '[[regtime]]'),
(987, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_giropay', 'Giropay', '[[regtime]]', '[[regtime]]'),
(988, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_ideal', 'iDEAL', '[[regtime]]', '[[regtime]]'),
(989, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_mybank', 'MyBank', '[[regtime]]', '[[regtime]]'),
(990, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_p24', 'Przelewy24', '[[regtime]]', '[[regtime]]'),
(991, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_sepa', 'SEPA', '[[regtime]]', '[[regtime]]'),
(992, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_sofort', 'Sofort', '[[regtime]]', '[[regtime]]'),
(993, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_trustly', 'Trustly', '[[regtime]]', '[[regtime]]'),
(994, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_mercadopago', 'Mercado Pago', '[[regtime]]', '[[regtime]]'),
(995, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_oxxo', 'OXXO', '[[regtime]]', '[[regtime]]'),
(996, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_boleto', 'Boleto', '[[regtime]]', '[[regtime]]'),
(997, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_enabled_funding_wechatpay', 'WeChat Pay', '[[regtime]]', '[[regtime]]'),
(998, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_3ds_policy', '3D Secure Policy (Card Fields only)', '[[regtime]]', '[[regtime]]'),
(999, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_3ds_policy_0', ' -- n/a -- ', '[[regtime]]', '[[regtime]]'),
(1000, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_3ds_policy_SCA_WHEN_REQUIRED', 'When Required (depends on credit card settings)', '[[regtime]]', '[[regtime]]'),
(1001, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_3ds_policy_SCA_ALWAYS', 'Always', '[[regtime]]', '[[regtime]]'),
(1002, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_pay_later_message_configurator', 'Pay Later Offer Messages<span class="help">Pay Later offers messages can be configured to display on product pages and checkout pages. This feature allows merchants to provide customers with information about available payment options and terms.</span>', '[[regtime]]', '[[regtime]]'),
(1003, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_text_run_configurator', 'Run Configurator', '[[regtime]]', '[[regtime]]'),
(1004, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_text_connect_for_configurator', 'Please connect to PayPal to see Configurator', '[[regtime]]', '[[regtime]]'),
(1005, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_show_buttons_product', 'Product Page Checkout Buttons', '[[regtime]]', '[[regtime]]'),
(1006, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_show_buttons_cart', 'Cart Page Checkout Buttons', '[[regtime]]', '[[regtime]]'),
(1007, 1, 1, 'paypal_commerce_paypal_commerce', 'paypal_commerce_debug_logging', 'Debug Logging:<span class="help">See the log in Admin->System->Error Logs section</span>', '[[regtime]]', '[[regtime]]'),
(1008, 1, 1, 'sola_sola', 'sola_name', 'Sola', '[[regtime]]', '[[regtime]]'),
(1009, 1, 1, 'sola_sola', 'sola_note', '', '[[regtime]]', '[[regtime]]'),
(1010, 1, 1, 'sola_sola', 'sola_transaction_key', 'Transaction Key (xKey)', '[[regtime]]', '[[regtime]]'),
(1011, 1, 1, 'sola_sola', 'sola_transaction_token', 'Transaction Token (xToken)', '[[regtime]]', '[[regtime]]'),
(1012, 1, 1, 'sola_sola', 'sola_test', 'Test Mode', '[[regtime]]', '[[regtime]]'),
(1013, 1, 1, 'sola_sola', 'sola_success_order_status', 'Order Status:<br /><span class="help">Order status to be set after customer''s order finished based on set Transaction Method</span>', '[[regtime]]', '[[regtime]]'),
(1014, 1, 1, 'sola_sola', 'sola_location_id', 'Location:<br /><span class="help">Restrict to allow only selected locations to use this payment method.', '[[regtime]]', '[[regtime]]'),
(1015, 1, 1, 'sola_sola', 'sola_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(1016, 1, 1, 'sola_sola', 'sola_transaction_method', 'Transaction Method:<br /><span class="help">Sola transaction to run at customer''s checkout before order status is set. Authorization only or capture.</span>', '[[regtime]]', '[[regtime]]'),
(1017, 1, 1, 'sola_sola', 'sola_transaction_method_capture', 'Capture', '[[regtime]]', '[[regtime]]'),
(1018, 1, 1, 'sola_sola', 'sola_transaction_method_authorization', 'Authorization Only', '[[regtime]]', '[[regtime]]'),
(1019, 1, 1, 'sola_sola', 'sola_ifields_key', 'iFields Key', '[[regtime]]', '[[regtime]]'),
(1020, 1, 1, 'sola_sola', 'sola_text_pending_authorization', 'Pending Authorization', '[[regtime]]', '[[regtime]]'),
(1021, 1, 1, 'sola_sola', 'sola_text_capture_funds', 'Capture Funds', '[[regtime]]', '[[regtime]]'),
(1022, 1, 1, 'sola_sola', 'sola_text_capture', 'Capture', '[[regtime]]', '[[regtime]]'),
(1023, 1, 1, 'sola_sola', 'sola_text_payment_status', 'Payment Status', '[[regtime]]', '[[regtime]]'),
(1024, 1, 1, 'sola_sola', 'sola_text_capture_success', 'Success! Funds have been captured successfully.', '[[regtime]]', '[[regtime]]'),
(1025, 1, 1, 'sola_sola', 'sola_text_processing', 'Processing', '[[regtime]]', '[[regtime]]'),
(1026, 1, 1, 'sola_sola', 'sola_text_do_refund', 'Do Sola Refund:<span class="help">You can enter amount that needs to be refunded.</span>', '[[regtime]]', '[[regtime]]'),
(1027, 1, 1, 'sola_sola', 'sola_text_refunded', 'Refunded', '[[regtime]]', '[[regtime]]'),
(1028, 1, 1, 'sola_sola', 'sola_text_refund', 'Refund', '[[regtime]]', '[[regtime]]'),
(1029, 1, 1, 'sola_sola', 'sola_refund_title', 'Sola Refund', '[[regtime]]', '[[regtime]]'),
(1030, 1, 1, 'sola_sola', 'sola_text_refund_success', 'Success! Order has been refunded successfully.', '[[regtime]]', '[[regtime]]'),
(1031, 1, 1, 'sola_sola', 'sola_error_empty_amount', 'Error! Amount is wrong.', '[[regtime]]', '[[regtime]]'),
(1032, 1, 1, 'sola_sola', 'sola_error_no_payment_method_data', 'Error! There is no payment method data for this order.', '[[regtime]]', '[[regtime]]'),
(1033, 1, 1, 'sola_sola', 'sola_error_no_order_id', 'Error! There is no order ID.', '[[regtime]]', '[[regtime]]'),
(1034, 1, 1, 'stripe_stripe', 'stripe_name', 'Stripe Payment', '[[regtime]]', '[[regtime]]'),
(1035, 1, 1, 'stripe_stripe', 'stripe_note', 'Additional settings are required to complete Stripe payment setup. See additional settings tab.', '[[regtime]]', '[[regtime]]'),
(1036, 1, 1, 'stripe_stripe', 'text_payment', 'Payment', '[[regtime]]', '[[regtime]]'),
(1037, 1, 1, 'stripe_stripe', 'text_success', 'Success: You have modified Stripe payment settings!', '[[regtime]]', '[[regtime]]'),
(1038, 1, 1, 'stripe_stripe', 'stripe_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(1039, 1, 1, 'stripe_stripe', 'stripe_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(1040, 1, 1, 'stripe_stripe', 'stripe_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(1041, 1, 1, 'stripe_stripe', 'stripe_published_key', 'Published Key:', '[[regtime]]', '[[regtime]]'),
(1042, 1, 1, 'stripe_stripe', 'stripe_autoselect', 'Auto Select:<br /><span class="help">You can set to skip payment selection page if there is only one payment option. This payment method will be selected automatically</span>', '[[regtime]]', '[[regtime]]'),
(1043, 1, 1, 'stripe_stripe', 'stripe_payment_method_list', 'Allowed payment methods. <br /><span class="help">Leave empty for automatic selection</span>', '[[regtime]]', '[[regtime]]'),
(1044, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_card', 'Cards', '[[regtime]]', '[[regtime]]'),
(1045, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_klarna', 'Klarna', '[[regtime]]', '[[regtime]]'),
(1046, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_acss_debit', 'ACSS', '[[regtime]]', '[[regtime]]'),
(1047, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_afterpay_clearpay', 'Afterpay/Clearpay', '[[regtime]]', '[[regtime]]'),
(1048, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_alipay', 'Alipay', '[[regtime]]', '[[regtime]]'),
(1049, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_au_becs_debit', 'BECS Direct Debit', '[[regtime]]', '[[regtime]]'),
(1050, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_bacs_debit', 'Bacs Direct Debit', '[[regtime]]', '[[regtime]]'),
(1051, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_affirm', 'Affirm', '[[regtime]]', '[[regtime]]'),
(1052, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_bancontact', 'Bancontact', '[[regtime]]', '[[regtime]]'),
(1053, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_blik', 'Blik', '[[regtime]]', '[[regtime]]'),
(1054, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_boleto', 'Boleto', '[[regtime]]', '[[regtime]]'),
(1055, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_interac_present', 'Interac', '[[regtime]]', '[[regtime]]'),
(1056, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_pix', 'Pix', '[[regtime]]', '[[regtime]]'),
(1057, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_revolut_pay', 'Revolut Pay', '[[regtime]]', '[[regtime]]'),
(1058, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_swish', 'Swish', '[[regtime]]', '[[regtime]]'),
(1059, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_mobilepay', 'MobilePay', '[[regtime]]', '[[regtime]]'),
(1060, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_zip', 'Zip', '[[regtime]]', '[[regtime]]'),
(1061, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_eps', 'EPS', '[[regtime]]', '[[regtime]]'),
(1062, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_fpx', 'FPX', '[[regtime]]', '[[regtime]]'),
(1063, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_giropay', 'giropay', '[[regtime]]', '[[regtime]]'),
(1064, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_grabpay', 'Grabpay', '[[regtime]]', '[[regtime]]'),
(1065, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_ideal', 'iDEAL', '[[regtime]]', '[[regtime]]'),
(1066, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_konbini', 'Konbini', '[[regtime]]', '[[regtime]]'),
(1067, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_link', 'Link', '[[regtime]]', '[[regtime]]'),
(1068, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_oxxo', 'OXXO', '[[regtime]]', '[[regtime]]'),
(1069, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_sofort', 'Sofort', '[[regtime]]', '[[regtime]]'),
(1070, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_p24', 'Przelewy24', '[[regtime]]', '[[regtime]]'),
(1071, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_paynow', 'PayNow', '[[regtime]]', '[[regtime]]'),
(1072, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_promptpay', 'PromptPay', '[[regtime]]', '[[regtime]]'),
(1073, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_sepa_debit', 'SEPA Direct Debit', '[[regtime]]', '[[regtime]]'),
(1074, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_us_bank_account', 'ACH Direct Debit', '[[regtime]]', '[[regtime]]'),
(1075, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_wechat_pay', 'WeChat Pay', '[[regtime]]', '[[regtime]]'),
(1076, 1, 1, 'stripe_stripe', 'stripe_payment_method_list_twint', 'TWINT', '[[regtime]]', '[[regtime]]'),
(1077, 1, 1, 'stripe_stripe', 'text_stripe_connect', 'You need to connect with stripe to set up payment details', '[[regtime]]', '[[regtime]]'),
(1078, 1, 1, 'stripe_stripe', 'text_stripe_settings', 'Stripe settings', '[[regtime]]', '[[regtime]]'),
(1079, 1, 1, 'stripe_stripe', 'text_connect', 'Connect with Stripe', '[[regtime]]', '[[regtime]]'),
(1080, 1, 1, 'stripe_stripe', 'text_disconnect', 'Disconnect Stripe', '[[regtime]]', '[[regtime]]'),
(1081, 1, 1, 'stripe_stripe', 'text_skip_connect', 'Cannot connect?', '[[regtime]]', '[[regtime]]'),
(1082, 1, 1, 'stripe_stripe', 'text_connect_success', 'Connected to Stripe successfully', '[[regtime]]', '[[regtime]]'),
(1083, 1, 1, 'stripe_stripe', 'text_disconnect_success', 'Disconnected from Stripe successfully', '[[regtime]]', '[[regtime]]'),
(1084, 1, 1, 'stripe_stripe', 'text_connected_account', 'You connected with account: ', '[[regtime]]', '[[regtime]]'),
(1085, 1, 1, 'stripe_stripe', 'stripe_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(1086, 1, 1, 'stripe_stripe', 'stripe_test_mode', 'Test mode:<br /><span class="help">Set to ON if you want to use test key</span>', '[[regtime]]', '[[regtime]]'),
(1087, 1, 1, 'stripe_stripe', 'stripe_sk_live', 'Live Secret Key:<br /><span class="help">Locate this in Stripe API Keys Section. Key starts with sk_live_... </span>', '[[regtime]]', '[[regtime]]'),
(1088, 1, 1, 'stripe_stripe', 'stripe_pk_live', 'Live Publishable Key:<br /><span class="help">Locate this in Stripe API Keys Section. Key starts with pk_live_... </span>', '[[regtime]]', '[[regtime]]'),
(1089, 1, 1, 'stripe_stripe', 'stripe_sk_test', 'Test Secret Key:<br /><span class="help">Locate this in Stripe API Keys Section. Key starts with sk_test_... </span>', '[[regtime]]', '[[regtime]]'),
(1090, 1, 1, 'stripe_stripe', 'stripe_pk_test', 'Test Publishable Key:<br /><span class="help">Locate this in Stripe API Keys Section. Key starts with pk_test_... </span>', '[[regtime]]', '[[regtime]]'),
(1091, 1, 1, 'stripe_stripe', 'stripe_settlement', 'Settlement type:<br /><span class="help">If set to ''auto'', then the transaction will be included in today''s settlement. If set to ''delayed'', then the transaction will be authorised but not settled(captured). You must manually capture transactions within 7 days of authorisation</span>', '[[regtime]]', '[[regtime]]'),
(1092, 1, 1, 'stripe_stripe', 'stripe_status_success_settled', 'Success & settled:<br /><span class="help">Select main order status you want to set in response to payment processor status</span>', '[[regtime]]', '[[regtime]]'),
(1093, 1, 1, 'stripe_stripe', 'stripe_status_success_unsettled', 'Success & not settled:<br /><span class="help">Select main order status you want to set in response to payment processor status</span>', '[[regtime]]', '[[regtime]]'),
(1094, 1, 1, 'stripe_stripe', 'stripe_status_decline', 'Decline:<br /><span class="help">Order status you want to record in history in response to payment processor status. Main order status is not affected. Order will not be placed only after payment is a success.</span>', '[[regtime]]', '[[regtime]]'),
(1095, 1, 1, 'stripe_stripe', 'stripe_status_void', 'Voided:<br /><span class="help">Order status you want to be set if payment is voided in admin/order.</span>', '[[regtime]]', '[[regtime]]'),
(1096, 1, 1, 'stripe_stripe', 'stripe_status_refund', 'Refunded:<br /><span class="help">Order status you want to be set if payment is refunded in admin/order.</span>', '[[regtime]]', '[[regtime]]'),
(1097, 1, 1, 'stripe_stripe', 'text_column_date_added', 'Transaction Date', '[[regtime]]', '[[regtime]]'),
(1098, 1, 1, 'stripe_stripe', 'text_column_amount', 'Amount', '[[regtime]]', '[[regtime]]'),
(1099, 1, 1, 'stripe_stripe', 'text_captured_ok', 'Funds were captured successfully', '[[regtime]]', '[[regtime]]'),
(1100, 1, 1, 'stripe_stripe', 'text_captured_order', 'Capture was successful, order status updated to success - settled', '[[regtime]]', '[[regtime]]'),
(1101, 1, 1, 'stripe_stripe', 'text_refunded_ok', 'Refund was processed successfully', '[[regtime]]', '[[regtime]]'),
(1102, 1, 1, 'stripe_stripe', 'text_refund_order', 'Refund was successful, order status updated to refunded', '[[regtime]]', '[[regtime]]'),
(1103, 1, 1, 'stripe_stripe', 'text_voided', 'Void was successful, order status updated to voided', '[[regtime]]', '[[regtime]]'),
(1104, 1, 1, 'stripe_stripe', 'stripe_settlement_auto', 'Auto (authorize and capture)', '[[regtime]]', '[[regtime]]'),
(1105, 1, 1, 'stripe_stripe', 'stripe_settlement_delayed', 'Delayed (authorize only)', '[[regtime]]', '[[regtime]]'),
(1106, 1, 1, 'stripe_stripe', 'text_payment_info', 'Payment Details', '[[regtime]]', '[[regtime]]'),
(1107, 1, 1, 'stripe_stripe', 'text_capture_status', 'Payment was captured', '[[regtime]]', '[[regtime]]'),
(1108, 1, 1, 'stripe_stripe', 'text_void_status', 'Payment was voided', '[[regtime]]', '[[regtime]]'),
(1109, 1, 1, 'stripe_stripe', 'text_refund_status', 'Payment was refunded', '[[regtime]]', '[[regtime]]'),
(1110, 1, 1, 'stripe_stripe', 'text_capture_amount', 'Capture Amount', '[[regtime]]', '[[regtime]]'),
(1111, 1, 1, 'stripe_stripe', 'text_refund_amount', 'Refund Amount', '[[regtime]]', '[[regtime]]'),
(1112, 1, 1, 'stripe_stripe', 'text_order_ref', 'Stripe Charge ID', '[[regtime]]', '[[regtime]]'),
(1113, 1, 1, 'stripe_stripe', 'text_order_total', 'Total amount authorized', '[[regtime]]', '[[regtime]]'),
(1114, 1, 1, 'stripe_stripe', 'text_balance', 'Balance amount', '[[regtime]]', '[[regtime]]'),
(1115, 1, 1, 'stripe_stripe', 'text_transactions', 'Refund Transactions', '[[regtime]]', '[[regtime]]'),
(1116, 1, 1, 'stripe_stripe', 'text_confirm_void', 'Please confirm you want to void the payment?', '[[regtime]]', '[[regtime]]'),
(1117, 1, 1, 'stripe_stripe', 'text_confirm_capture', 'Please confirm you want to capture the payment?', '[[regtime]]', '[[regtime]]'),
(1118, 1, 1, 'stripe_stripe', 'text_confirm_refund', 'Please confirm you want to refund the payment?', '[[regtime]]', '[[regtime]]'),
(1119, 1, 1, 'stripe_stripe', 'button_refund', 'Refund', '[[regtime]]', '[[regtime]]'),
(1120, 1, 1, 'stripe_stripe', 'button_void', 'Void', '[[regtime]]', '[[regtime]]'),
(1121, 1, 1, 'stripe_stripe', 'button_capture', 'Capture', '[[regtime]]', '[[regtime]]'),
(1122, 1, 1, 'stripe_stripe', 'error_system', 'Internal error. Check error log or input parameters!', '[[regtime]]', '[[regtime]]'),
(1123, 1, 1, 'stripe_stripe', 'error_missing_amount', 'Please enter positive amount', '[[regtime]]', '[[regtime]]'),
(1124, 1, 1, 'stripe_stripe', 'error_unable_to_capture', 'Unable to capture, refresh transaction details and check capture amount', '[[regtime]]', '[[regtime]]'),
(1125, 1, 1, 'stripe_stripe', 'error_unable_to_void', 'Unable to void transaction, refresh and check transaction details', '[[regtime]]', '[[regtime]]'),
(1126, 1, 1, 'stripe_stripe', 'error_unable_to_refund', 'Unable to refund, refresh transaction details and check refund amount', '[[regtime]]', '[[regtime]]'),
(1127, 1, 1, 'stripe_stripe', 'error_stripe_pk_test', 'Stripe Published key is required', '[[regtime]]', '[[regtime]]'),
(1128, 1, 1, 'stripe_stripe', 'error_stripe_pk_live', 'Stripe Published key is required', '[[regtime]]', '[[regtime]]'),
(1129, 1, 1, 'stripe_stripe', 'error_stripe_sk_test', 'Stripe test key is required', '[[regtime]]', '[[regtime]]'),
(1130, 1, 1, 'stripe_stripe', 'error_stripe_sk_live', 'Stripe live key is required', '[[regtime]]', '[[regtime]]'),
(1131, 1, 1, 'stripe_stripe', 'error_permission', 'Warning: You do not have permission to modify Stripe Payment!', '[[regtime]]', '[[regtime]]'),
(1132, 1, 1, 'stripe_stripe', 'stripe_webhook_howto_text', 'Note: To complete setup you should to create webhooks on Stripe Account Side.\n<br> Go to Your <a href="https://dashboard.stripe.com/webhooks" target="_blank">Stripe Dashboard Developer Section</a>\nand Add Endpoints receiving events from your account. After Endpoint has been created copy Signing Secret and save into Stripe Subscription Extension settings belong.', '[[regtime]]', '[[regtime]]'),
(1133, 1, 1, 'stripe_stripe', 'stripe_entry_endpoint_url', 'Endpoint URL:', '[[regtime]]', '[[regtime]]'),
(1134, 1, 1, 'stripe_stripe', 'stripe_entry_endpoint_signing_secret', 'Endpoint Signing Secret:', '[[regtime]]', '[[regtime]]'),
(1135, 1, 1, 'ups_ups', 'ups_name', 'United Parcel Service', '[[regtime]]', '[[regtime]]'),
(1136, 1, 1, 'ups_ups', 'heading_title', 'UPS', '[[regtime]]', '[[regtime]]'),
(1137, 1, 1, 'ups_ups', 'ups_account_number', 'Account(Shipper) Number', '[[regtime]]', '[[regtime]]'),
(1138, 1, 1, 'ups_ups', 'ups_client_id', 'API Client ID<br/><span class="help">You can find it in your application section on https://developer.ups.com/apps </span>', '[[regtime]]', '[[regtime]]'),
(1139, 1, 1, 'ups_ups', 'ups_password', 'API Password<br/><span class="help">You can find it in your application section on https://developer.ups.com/apps </span>', '[[regtime]]', '[[regtime]]'),
(1140, 1, 1, 'ups_ups', 'ups_test_mode', 'Test mode', '[[regtime]]', '[[regtime]]'),
(1141, 1, 1, 'ups_ups', 'ups_validate_address', 'Address Validation', '[[regtime]]', '[[regtime]]'),
(1142, 1, 1, 'ups_ups', 'ups_country', 'Shipper Country & Zone', '[[regtime]]', '[[regtime]]'),
(1143, 1, 1, 'ups_ups', 'ups_telephone', 'Shipper Phone Number (10 digits or more)', '[[regtime]]', '[[regtime]]'),
(1144, 1, 1, 'ups_ups', 'ups_address', 'Shipper Address', '[[regtime]]', '[[regtime]]'),
(1145, 1, 1, 'ups_ups', 'ups_city', 'Shipper City', '[[regtime]]', '[[regtime]]'),
(1146, 1, 1, 'ups_ups', 'ups_postcode', 'Shipper Postal Code', '[[regtime]]', '[[regtime]]'),
(1147, 1, 1, 'ups_ups', 'ups_weight_code', 'Weight Code:<br /><span class="help">Allowed kgs, lbs.</span>', '[[regtime]]', '[[regtime]]'),
(1148, 1, 1, 'ups_ups', 'ups_test_connection', 'Test Connection', '[[regtime]]', '[[regtime]]'),
(1149, 1, 1, 'ups_ups', 'ups_length_code', 'Length Code:<br /><span class="help">Allowed inches or centimeters.</span>', '[[regtime]]', '[[regtime]]'),
(1150, 1, 1, 'ups_ups', 'ups_tax_class_id', 'Tax Class:', '[[regtime]]', '[[regtime]]'),
(1151, 1, 1, 'ups_ups', 'ups_tax_class_id_0', '-- None --', '[[regtime]]', '[[regtime]]'),
(1152, 1, 1, 'ups_ups', 'ups_location_id', 'Location:', '[[regtime]]', '[[regtime]]'),
(1153, 1, 1, 'ups_ups', 'ups_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(1154, 1, 1, 'ups_ups', 'ups_default_weight', 'Default Product Weight:<br /><span class="help">Weight of products if not set</span>', '[[regtime]]', '[[regtime]]'),
(1155, 1, 1, 'ups_ups', 'ups_default_length', 'Default Product Length:<br /><span class="help">Length of product if not set</span>', '[[regtime]]', '[[regtime]]'),
(1156, 1, 1, 'ups_ups', 'ups_default_width', 'Default  Product Width:<br /><span class="help">Width of product if not set</span>', '[[regtime]]', '[[regtime]]'),
(1157, 1, 1, 'ups_ups', 'ups_default_height', 'Default  Product Height:<br /><span class="help">Height of product if not set</span>', '[[regtime]]', '[[regtime]]'),
(1158, 1, 1, 'ups_ups', 'ups_packaging', 'Packaging', '[[regtime]]', '[[regtime]]'),
(1159, 1, 1, 'ups_ups', 'ups_packaging_02', 'Box', '[[regtime]]', '[[regtime]]'),
(1160, 1, 1, 'ups_ups', 'ups_manifest_order_status_id', 'Create Shipment when Order Status becomes', '[[regtime]]', '[[regtime]]'),
(1161, 1, 1, 'ups_ups', 'ups_text_print_label', 'Print UPS Label (Original Order)', '[[regtime]]', '[[regtime]]'),
(1162, 1, 1, 'ups_ups', 'ups_text_print_label_title', 'Prints the UPS label using the original weight and dimensions submitted by the customer at checkout. Any changes made to the order by the admin will not affect the label.', '[[regtime]]', '[[regtime]]'),
(1163, 1, 1, 'ups_ups', 'ups_text_print_label_suggestion', 'Change order status to "%s" to create shipment via UPS API and get parcel labels', '[[regtime]]', '[[regtime]]'),
(1164, 1, 1, 'ups_ups', 'ups_entry_weight', 'Weight:', '[[regtime]]', '[[regtime]]'),
(1165, 1, 1, 'ups_ups', 'ups_entry_height', 'Height:', '[[regtime]]', '[[regtime]]'),
(1166, 1, 1, 'ups_ups', 'ups_entry_width', 'Width:', '[[regtime]]', '[[regtime]]'),
(1167, 1, 1, 'ups_ups', 'ups_entry_depth', 'Depth:', '[[regtime]]', '[[regtime]]'),
(1168, 1, 1, 'ups_ups', 'ups_entry_parcel_info', 'Parcel Info:', '[[regtime]]', '[[regtime]]'),
(1169, 1, 1, 'ups_ups', 'ups_shipment_created_success_message', 'UPS Shipment has been successfully created. See more info <a href="%s">here</a>', '[[regtime]]', '[[regtime]]'),
(1170, 1, 1, 'usps_usps', 'usps_name', 'United States Postal Service', '[[regtime]]', '[[regtime]]'),
(1171, 1, 1, 'usps_usps', 'text_shipping', ' Shipping', '[[regtime]]', '[[regtime]]'),
(1172, 1, 1, 'usps_usps', 'text_additional_settings', 'USPS Settings', '[[regtime]]', '[[regtime]]'),
(1173, 1, 1, 'usps_usps', 'text_usps_success', 'Success: You have modified United States Postal Service!', '[[regtime]]', '[[regtime]]'),
(1174, 1, 1, 'usps_usps', 'text_international_1', 'Express Mail International', '[[regtime]]', '[[regtime]]'),
(1175, 1, 1, 'usps_usps', 'text_international_2', 'Priority Mail International', '[[regtime]]', '[[regtime]]'),
(1176, 1, 1, 'usps_usps', 'text_international_4', 'Global Express Guaranteed (Document and Non-document)', '[[regtime]]', '[[regtime]]'),
(1177, 1, 1, 'usps_usps', 'text_international_5', 'Global Express Guaranteed Document used', '[[regtime]]', '[[regtime]]'),
(1178, 1, 1, 'usps_usps', 'text_international_6', 'Global Express Guaranteed Non-Document Rectangular shape', '[[regtime]]', '[[regtime]]'),
(1179, 1, 1, 'usps_usps', 'text_international_7', 'Global Express Guaranteed Non-Document Non-Rectangular', '[[regtime]]', '[[regtime]]'),
(1180, 1, 1, 'usps_usps', 'text_international_8', 'Priority Mail Flat Rate Envelope', '[[regtime]]', '[[regtime]]'),
(1181, 1, 1, 'usps_usps', 'text_international_9', 'Priority Mail Flat Rate Box', '[[regtime]]', '[[regtime]]'),
(1182, 1, 1, 'usps_usps', 'text_international_10', 'Express Mail International Flat Rate Envelope', '[[regtime]]', '[[regtime]]'),
(1183, 1, 1, 'usps_usps', 'text_international_11', 'Priority Mail Large Flat Rate Box', '[[regtime]]', '[[regtime]]'),
(1184, 1, 1, 'usps_usps', 'text_international_12', 'Global Express Guaranteed Envelope', '[[regtime]]', '[[regtime]]'),
(1185, 1, 1, 'usps_usps', 'text_international_13', 'First Class Mail International Letters', '[[regtime]]', '[[regtime]]'),
(1186, 1, 1, 'usps_usps', 'text_international_14', 'First Class Mail International Flats', '[[regtime]]', '[[regtime]]'),
(1187, 1, 1, 'usps_usps', 'text_international_15', 'First Class Mail International Parcels', '[[regtime]]', '[[regtime]]'),
(1188, 1, 1, 'usps_usps', 'text_international_16', 'Priority Mail Small Flat Rate Box', '[[regtime]]', '[[regtime]]'),
(1189, 1, 1, 'usps_usps', 'text_international_21', 'Postcards', '[[regtime]]', '[[regtime]]'),
(1190, 1, 1, 'usps_usps', 'text_regular', 'Regular', '[[regtime]]', '[[regtime]]'),
(1191, 1, 1, 'usps_usps', 'text_large', 'Large', '[[regtime]]', '[[regtime]]'),
(1192, 1, 1, 'usps_usps', 'text_oversize', 'Oversize', '[[regtime]]', '[[regtime]]'),
(1193, 1, 1, 'usps_usps', 'text_rectangular', 'Rectangular', '[[regtime]]', '[[regtime]]'),
(1194, 1, 1, 'usps_usps', 'text_non_rectangular', 'Non Rectangular', '[[regtime]]', '[[regtime]]'),
(1195, 1, 1, 'usps_usps', 'text_variable', 'Variable', '[[regtime]]', '[[regtime]]'),
(1196, 1, 1, 'usps_usps', 'entry_api_environment', 'API Developer Mode', '[[regtime]]', '[[regtime]]'),
(1197, 1, 1, 'usps_usps', 'usps_api_environment', 'API Developer Mode', '[[regtime]]', '[[regtime]]'),
(1198, 1, 1, 'usps_usps', 'usps_api_environment_production', 'Production (live rates)', '[[regtime]]', '[[regtime]]'),
(1199, 1, 1, 'usps_usps', 'text_api_environment_shipping', 'Developer Mode', '[[regtime]]', '[[regtime]]'),
(1200, 1, 1, 'usps_usps', 'entry_client_id', 'Consumer Key<br/><span class="help">Create an APP in your https://cop.usps.com. These credentials are required for generating the OAuth Token</span>', '[[regtime]]', '[[regtime]]'),
(1201, 1, 1, 'usps_usps', 'usps_client_id', 'Consumer Key:<span class="help">You can find it in your application section on https://cop.usps.com. These credentials are required for generating the OAuth Token</span>', '[[regtime]]', '[[regtime]]'),
(1202, 1, 1, 'usps_usps', 'text_client_id_shipping', 'API Client ID', '[[regtime]]', '[[regtime]]'),
(1203, 1, 1, 'usps_usps', 'text_country_shipping', 'Shipper Country &amp; Zone', '[[regtime]]', '[[regtime]]'),
(1204, 1, 1, 'usps_usps', 'text_address_shipping', 'Shipper Address', '[[regtime]]', '[[regtime]]'),
(1205, 1, 1, 'usps_usps', 'text_city_shipping', 'Shipper City', '[[regtime]]', '[[regtime]]'),
(1206, 1, 1, 'usps_usps', 'text_telephone_shipping', 'Shipper Phone Number<span class="help">10 digits or more, no spaces or special character</span>', '[[regtime]]', '[[regtime]]'),
(1207, 1, 1, 'usps_usps', 'entry_client_secret', 'API Client Secret<br/><span class="help">You can find it in your application section on https://developers.usps.com</span>', '[[regtime]]', '[[regtime]]'),
(1208, 1, 1, 'usps_usps', 'usps_generate_payment_token', 'Test Label Generation:<span class="help">For label generation, USPS may require additional permissions for payment token generation on your account. Contact USPS support to enable this access.</span>', '[[regtime]]', '[[regtime]]'),
(1209, 1, 1, 'usps_usps', 'usps_generate_payment_token_button', 'Test Label Generation', '[[regtime]]', '[[regtime]]'),
(1210, 1, 1, 'usps_usps', 'usps_country', 'Shipper Country &amp; Zone', '[[regtime]]', '[[regtime]]'),
(1211, 1, 1, 'usps_usps', 'usps_telephone', 'Shipper Phone Number (10 digits or more)', '[[regtime]]', '[[regtime]]'),
(1212, 1, 1, 'usps_usps', 'usps_address', 'Shipper Address', '[[regtime]]', '[[regtime]]'),
(1213, 1, 1, 'usps_usps', 'usps_city', 'Shipper City', '[[regtime]]', '[[regtime]]'),
(1214, 1, 1, 'usps_usps', 'usps_postcode', 'Shipper Postal Code', '[[regtime]]', '[[regtime]]'),
(1215, 1, 1, 'usps_usps', 'usps_payment_crid', 'Customer Registration ID (CRID):<span class="help">Required for USPS label generation. You can find it in your account section on https://developers.usps.com</span>', '[[regtime]]', '[[regtime]]'),
(1216, 1, 1, 'usps_usps', 'usps_payment_mid', 'Mailer ID (MID):<span class="help">Required for USPS label generation. You can find it in your account section on https://developers.usps.com</span>', '[[regtime]]', '[[regtime]]'),
(1217, 1, 1, 'usps_usps', 'usps_payment_manifest_mid', 'Manifest MID:<span class="help">Required for USPS label generation. You can find it in your account section on https://developers.usps.com</span>', '[[regtime]]', '[[regtime]]'),
(1218, 1, 1, 'usps_usps', 'usps_payment_account_number', 'EPS Account Number:<span class="help">Required for USPS label generation. You can find it in your Enterprise Payment System account on https://epay.usps.com/</span>', '[[regtime]]', '[[regtime]]'),
(1219, 1, 1, 'usps_usps', 'entry_manifest_order_status_id', 'Create Shipment when Order Status becomes', '[[regtime]]', '[[regtime]]'),
(1220, 1, 1, 'usps_usps', 'usps_client_secret', 'Consumer Secret:<span class="help">You can find it in your application section on https://cop.usps.com. These credentials are required for generating the OAuth Token</span>', '[[regtime]]', '[[regtime]]'),
(1221, 1, 1, 'usps_usps', 'usps_manifest_order_status_id', 'Create Shipment when Order Status becomes', '[[regtime]]', '[[regtime]]'),
(1222, 1, 1, 'usps_usps', 'usps_shipping_storefront_icon', 'Storefront Icon', '[[regtime]]', '[[regtime]]'),
(1223, 1, 1, 'usps_usps', 'usps_debug', 'Debug Logging Status', '[[regtime]]', '[[regtime]]'),
(1224, 1, 1, 'usps_usps', 'usps_domestic_1', 'Priority Mail', '[[regtime]]', '[[regtime]]'),
(1225, 1, 1, 'usps_usps', 'usps_domestic_2', 'Priority Mail Express', '[[regtime]]', '[[regtime]]'),
(1226, 1, 1, 'usps_usps', 'usps_domestic_3', 'Parcel Select', '[[regtime]]', '[[regtime]]'),
(1227, 1, 1, 'usps_usps', 'usps_domestic_4', 'Bound Printed Matter', '[[regtime]]', '[[regtime]]'),
(1228, 1, 1, 'usps_usps', 'usps_domestic_5', 'Media Mail', '[[regtime]]', '[[regtime]]'),
(1229, 1, 1, 'usps_usps', 'usps_domestic_6', 'Library Mail', '[[regtime]]', '[[regtime]]'),
(1230, 1, 1, 'usps_usps', 'usps_domestic_7', 'USPS Ground Advantage', '[[regtime]]', '[[regtime]]'),
(1231, 1, 1, 'usps_usps', 'usps_international_1', 'Priority Mail Express International', '[[regtime]]', '[[regtime]]'),
(1232, 1, 1, 'usps_usps', 'usps_international_2', 'Priority Mail International', '[[regtime]]', '[[regtime]]'),
(1233, 1, 1, 'usps_usps', 'usps_international_3', 'Global Express Guaranteed (GXG)', '[[regtime]]', '[[regtime]]'),
(1234, 1, 1, 'usps_usps', 'usps_international_4', 'First-Class Package International Service', '[[regtime]]', '[[regtime]]'),
(1235, 1, 1, 'usps_usps', 'usps_free_domestic_method_usps_domestic_1', 'Priority Mail', '[[regtime]]', '[[regtime]]'),
(1236, 1, 1, 'usps_usps', 'usps_free_domestic_method_usps_domestic_2', 'Priority Mail Express', '[[regtime]]', '[[regtime]]'),
(1237, 1, 1, 'usps_usps', 'usps_free_domestic_method_usps_domestic_3', 'Parcel Select', '[[regtime]]', '[[regtime]]'),
(1238, 1, 1, 'usps_usps', 'usps_free_domestic_method_usps_domestic_4', 'Bound Printed Matter', '[[regtime]]', '[[regtime]]'),
(1239, 1, 1, 'usps_usps', 'usps_free_domestic_method_usps_domestic_5', 'Media Mail', '[[regtime]]', '[[regtime]]'),
(1240, 1, 1, 'usps_usps', 'usps_free_domestic_method_usps_domestic_6', 'Library Mail', '[[regtime]]', '[[regtime]]'),
(1241, 1, 1, 'usps_usps', 'usps_free_domestic_method_usps_domestic_7', 'USPS Ground Advantage', '[[regtime]]', '[[regtime]]'),
(1242, 1, 1, 'usps_usps', 'usps_free_international_method_usps_international_1', 'Priority Mail Express International', '[[regtime]]', '[[regtime]]'),
(1243, 1, 1, 'usps_usps', 'usps_free_international_method_usps_international_2', 'Priority Mail International', '[[regtime]]', '[[regtime]]'),
(1244, 1, 1, 'usps_usps', 'usps_free_international_method_usps_international_3', 'Global Express Guaranteed (GXG)', '[[regtime]]', '[[regtime]]'),
(1245, 1, 1, 'usps_usps', 'usps_free_international_method_usps_international_4', 'First-Class Package International Service', '[[regtime]]', '[[regtime]]'),
(1246, 1, 1, 'usps_usps', 'usps_length', 'Dimensions Length', '[[regtime]]', '[[regtime]]'),
(1247, 1, 1, 'usps_usps', 'usps_width', 'Dimensions Width', '[[regtime]]', '[[regtime]]'),
(1248, 1, 1, 'usps_usps', 'usps_height', 'Dimensions Height', '[[regtime]]', '[[regtime]]'),
(1249, 1, 1, 'usps_usps', 'usps_display_weight', 'Display Delivery Weight', '[[regtime]]', '[[regtime]]'),
(1250, 1, 1, 'usps_usps', 'usps_tax_class_id', 'Tax Class', '[[regtime]]', '[[regtime]]'),
(1251, 1, 1, 'usps_usps', 'usps_location_id', 'Location', '[[regtime]]', '[[regtime]]'),
(1252, 1, 1, 'usps_usps', 'usps_location_id_0', 'All Locations', '[[regtime]]', '[[regtime]]'),
(1253, 1, 1, 'usps_usps', 'usps_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(1254, 1, 1, 'usps_usps', 'usps_test_connection', 'Test Connection', '[[regtime]]', '[[regtime]]'),
(1255, 1, 1, 'usps_usps', 'text_client_secret_shipping', 'API Client Secret', '[[regtime]]', '[[regtime]]'),
(1256, 1, 1, 'usps_usps', 'text_manifest_order_status_id_shipping', 'Create Shipment when Order Status becomes', '[[regtime]]', '[[regtime]]'),
(1257, 1, 1, 'usps_usps', 'entry_postcode', 'Zip Code:<span class="help">Zip/Postal code of the starting location of your package.</span>', '[[regtime]]', '[[regtime]]'),
(1258, 1, 1, 'usps_usps', 'entry_domestic', 'Domestic Services:', '[[regtime]]', '[[regtime]]'),
(1259, 1, 1, 'usps_usps', 'entry_international', 'International Services:', '[[regtime]]', '[[regtime]]'),
(1260, 1, 1, 'usps_usps', 'entry_size', 'Size:<span class="help">Select the container size that you typically use to package the products ordered from your store.</span>', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(1261, 1, 1, 'usps_usps', 'entry_container', 'Container:<span class="help">Select the container type that you typically use to package the products ordered from your store. USPS will only deliver packages weighing up to 70 lbs</span>', '[[regtime]]', '[[regtime]]'),
(1262, 1, 1, 'usps_usps', 'entry_machinable', 'Machinable:<br /><span class="help"> It is recommended that you select Yes. Specify whether it is OK to handle your shipments by machines. Enabling this option reduces the shipping costs.</span>', '[[regtime]]', '[[regtime]]'),
(1263, 1, 1, 'usps_usps', 'entry_dimension', 'Dimensions (L x W x H):', '[[regtime]]', '[[regtime]]'),
(1264, 1, 1, 'usps_usps', 'entry_length', 'Dimensions Length:<br /><span class="help">Average package dimension for shipping package.</span>', '[[regtime]]', '[[regtime]]'),
(1265, 1, 1, 'usps_usps', 'entry_width', 'Dimensions Width:<br /><span class="help">Average package dimension for shipping package.</span>', '[[regtime]]', '[[regtime]]'),
(1266, 1, 1, 'usps_usps', 'entry_height', 'Dimensions Height:<br /><span class="help">Average package dimension for shipping package.</span>', '[[regtime]]', '[[regtime]]'),
(1267, 1, 1, 'usps_usps', 'entry_girth', 'Girth:<br /><span class="help">To find the girth of your package, measure the distance around the thickest part of the non-rectangular package.</span>', '[[regtime]]', '[[regtime]]'),
(1268, 1, 1, 'usps_usps', 'entry_display_time', 'Display Delivery Time:<br /><span class="help">Do you want to display the shipping time? (e.g. Ships within 3 to 5 days)</span>', '[[regtime]]', '[[regtime]]'),
(1269, 1, 1, 'usps_usps', 'entry_display_weight', 'Display Delivery Weight:<br /><span class="help">Do you want to display the shipping weight? (e.g. Delivery Weight : 2.7674 Kg''s)</span>', '[[regtime]]', '[[regtime]]'),
(1270, 1, 1, 'usps_usps', 'entry_weight_class', 'Weight Class:<br /><span class="help">Set to pounds.</span>', '[[regtime]]', '[[regtime]]'),
(1271, 1, 1, 'usps_usps', 'entry_length_class', 'Length Class:<br /><span class="help">The dimension or default length class of your store.</span>', '[[regtime]]', '[[regtime]]'),
(1272, 1, 1, 'usps_usps', 'entry_tax', 'Tax Class:<br /><span class="help">If you are required to charge tax on this item, select tax class.</span>', '[[regtime]]', '[[regtime]]'),
(1273, 1, 1, 'usps_usps', 'entry_location', 'Location:', '[[regtime]]', '[[regtime]]'),
(1274, 1, 1, 'usps_usps', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(1275, 1, 1, 'usps_usps', 'error_permission', 'Warning: You do not have permission to modify United States Postal Service!', '[[regtime]]', '[[regtime]]'),
(1276, 1, 1, 'usps_usps', 'error_client_id', 'API Client ID Required!', '[[regtime]]', '[[regtime]]'),
(1277, 1, 1, 'usps_usps', 'error_client_secret', 'API Client Secret Required!', '[[regtime]]', '[[regtime]]'),
(1278, 1, 1, 'usps_usps', 'error_postcode', 'Zip Code Required!', '[[regtime]]', '[[regtime]]'),
(1279, 1, 1, 'usps_usps', 'text_api_environment_production', 'Production (live rates)', '[[regtime]]', '[[regtime]]'),
(1280, 1, 1, 'usps_usps', 'usps_text_print_label', 'Print USPS Label (Original Order)', '[[regtime]]', '[[regtime]]'),
(1281, 1, 1, 'usps_usps', 'usps_text_print_label_title', 'Prints the USPS label using the original weight and dimensions submitted by the customer at checkout. Any changes made to the order by the admin will not affect the label.', '[[regtime]]', '[[regtime]]'),
(1282, 1, 1, 'usps_usps', 'usps_text_print_label_suggestion', 'Change order status to "%s" to create shipment via USPS API and get parcel labels', '[[regtime]]', '[[regtime]]'),
(1283, 1, 1, 'usps_usps', 'usps_text_print_label_missing_settings', 'To generate labels, first complete your USPS account details in Extension Settings.', '[[regtime]]', '[[regtime]]'),
(1284, 1, 1, 'usps_usps', 'usps_entry_weight', 'Weight:', '[[regtime]]', '[[regtime]]'),
(1285, 1, 1, 'usps_usps', 'usps_entry_height', 'Height:', '[[regtime]]', '[[regtime]]'),
(1286, 1, 1, 'usps_usps', 'usps_entry_width', 'Width:', '[[regtime]]', '[[regtime]]'),
(1287, 1, 1, 'usps_usps', 'usps_entry_depth', 'Depth:', '[[regtime]]', '[[regtime]]'),
(1288, 1, 1, 'usps_usps', 'usps_entry_parcel_info', 'Parcel Info:', '[[regtime]]', '[[regtime]]'),
(1289, 1, 1, 'usps_usps', 'usps_shipment_created_success_message', 'USPS Shipment has been successfully created. Tracking number: %s. See more info <a href="%s">here</a>', '[[regtime]]', '[[regtime]]'),
(1290, 1, 1, 'catalog_attribute', 'heading_title', 'Global Attributes', '[[regtime]]', '[[regtime]]'),
(1291, 1, 1, 'catalog_attribute', 'text_attribute', 'Global Attribute', '[[regtime]]', '[[regtime]]'),
(1292, 1, 1, 'catalog_attribute', 'text_success', 'Success: You have modified attributes!', '[[regtime]]', '[[regtime]]'),
(1293, 1, 1, 'catalog_attribute', 'text_select_type', '- Select Type -', '[[regtime]]', '[[regtime]]'),
(1294, 1, 1, 'catalog_attribute', 'text_select_parent', '- Select Parent -', '[[regtime]]', '[[regtime]]'),
(1295, 1, 1, 'catalog_attribute', 'column_name', 'Name', '[[regtime]]', '[[regtime]]'),
(1296, 1, 1, 'catalog_attribute', 'column_type', 'Type', '[[regtime]]', '[[regtime]]'),
(1297, 1, 1, 'catalog_attribute', 'column_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(1298, 1, 1, 'catalog_attribute', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(1299, 1, 1, 'catalog_attribute', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(1300, 1, 1, 'catalog_attribute', 'column_txt_id', 'Unique Text ID', '[[regtime]]', '[[regtime]]'),
(1301, 1, 1, 'catalog_attribute', 'entry_name', 'Name:', '[[regtime]]', '[[regtime]]'),
(1302, 1, 1, 'catalog_attribute', 'entry_attribute_parent', 'Attribute Parent:', '[[regtime]]', '[[regtime]]'),
(1303, 1, 1, 'catalog_attribute', 'entry_attribute_group', 'Attribute Group:', '[[regtime]]', '[[regtime]]'),
(1304, 1, 1, 'catalog_attribute', 'entry_attribute_type', 'Attribute Type:', '[[regtime]]', '[[regtime]]'),
(1305, 1, 1, 'catalog_attribute', 'entry_element_type', 'Element Type:', '[[regtime]]', '[[regtime]]'),
(1306, 1, 1, 'catalog_attribute', 'entry_element_values', 'Element Values:', '[[regtime]]', '[[regtime]]'),
(1307, 1, 1, 'catalog_attribute', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(1308, 1, 1, 'catalog_attribute', 'entry_required', 'Required:', '[[regtime]]', '[[regtime]]'),
(1309, 1, 1, 'catalog_attribute', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(1310, 1, 1, 'catalog_attribute', 'entry_children_attributes', 'Children Attributes:', '[[regtime]]', '[[regtime]]'),
(1311, 1, 1, 'catalog_attribute', 'error_permission', 'Warning: You do not have permission to modify global attributes!', '[[regtime]]', '[[regtime]]'),
(1312, 1, 1, 'catalog_attribute', 'error_name', 'Group Name must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(1313, 1, 1, 'catalog_attribute', 'error_required', 'This field is required!', '[[regtime]]', '[[regtime]]'),
(1314, 1, 1, 'catalog_attribute', 'text_parent_note', 'If this is a parent attribute with children attributes, it can only be of type SelectBox, MultiSelect Box, Checkbox and Checkbox group.<br>Children values combination will be shown as one set.', '[[regtime]]', '[[regtime]]'),
(1315, 1, 1, 'catalog_attribute', 'entry_allowed_extensions', 'Allowed File Extensions (txt, jpg …)', '[[regtime]]', '[[regtime]]'),
(1316, 1, 1, 'catalog_attribute', 'entry_min_size', 'Min file size (Kb)', '[[regtime]]', '[[regtime]]'),
(1317, 1, 1, 'catalog_attribute', 'entry_max_size', 'Max file size (Kb)', '[[regtime]]', '[[regtime]]'),
(1318, 1, 1, 'catalog_attribute', 'entry_upload_dir', 'Upload directory name<br>%s', '[[regtime]]', '[[regtime]]'),
(1319, 1, 1, 'catalog_attribute', 'entry_regexp_pattern', 'Regular Expression Pattern for Validation of Values:', '[[regtime]]', '[[regtime]]'),
(1320, 1, 1, 'catalog_attribute', 'entry_error_text', 'Error Message of invalid Value:', '[[regtime]]', '[[regtime]]'),
(1321, 1, 1, 'catalog_attribute', 'entry_placeholder', 'Placeholder:', '[[regtime]]', '[[regtime]]'),
(1322, 1, 1, 'catalog_attribute', 'error_attribute_name', 'Attribute Name must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(1323, 1, 1, 'catalog_attribute', 'error_error_text', 'Error text about invalid attribute value must be between 2 and 255 characters!', '[[regtime]]', '[[regtime]]'),
(1324, 1, 1, 'catalog_attribute', 'error_regexp_pattern', 'Regular Expression Pattern is invalid!', '[[regtime]]', '[[regtime]]'),
(1325, 1, 1, 'catalog_attribute', 'entry_show_to_customer', 'Show to Customer', '[[regtime]]', '[[regtime]]'),
(1326, 1, 1, 'catalog_attribute', 'entry_price_prefix', 'Modify Price By:', '[[regtime]]', '[[regtime]]'),
(1327, 1, 1, 'catalog_attribute', 'entry_price_modifier', 'Price Modifier:', '[[regtime]]', '[[regtime]]'),
(1328, 1, 1, 'catalog_attribute', 'error_not_unique', 'Value Text ID is not unique!', '[[regtime]]', '[[regtime]]'),
(1329, 1, 1, 'catalog_attribute_groups', 'heading_title', 'Global Attribute Groups', '[[regtime]]', '[[regtime]]'),
(1330, 1, 1, 'catalog_attribute_groups', 'text_group', 'Attribute Group', '[[regtime]]', '[[regtime]]'),
(1331, 1, 1, 'catalog_attribute_groups', 'text_success', 'Success: You have modified groups!', '[[regtime]]', '[[regtime]]'),
(1332, 1, 1, 'catalog_attribute_groups', 'column_name', 'Group Name', '[[regtime]]', '[[regtime]]'),
(1333, 1, 1, 'catalog_attribute_groups', 'column_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(1334, 1, 1, 'catalog_attribute_groups', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(1335, 1, 1, 'catalog_attribute_groups', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(1336, 1, 1, 'catalog_attribute_groups', 'entry_name', 'Group Name:', '[[regtime]]', '[[regtime]]'),
(1337, 1, 1, 'catalog_attribute_groups', 'entry_sort_order', 'Group Sort Order:', '[[regtime]]', '[[regtime]]'),
(1338, 1, 1, 'catalog_attribute_groups', 'entry_status', 'Group Status:', '[[regtime]]', '[[regtime]]'),
(1339, 1, 1, 'catalog_attribute_groups', 'error_permission', 'Warning: You do not have permission to modify attribute groups!', '[[regtime]]', '[[regtime]]'),
(1340, 1, 1, 'catalog_attribute_groups', 'error_name', 'Group Name must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(1341, 1, 1, 'catalog_category', 'heading_title', 'Categories', '[[regtime]]', '[[regtime]]'),
(1342, 1, 1, 'catalog_category', 'text_category', 'Category', '[[regtime]]', '[[regtime]]'),
(1343, 1, 1, 'catalog_category', 'text_success', 'Success: You have modified categories!', '[[regtime]]', '[[regtime]]'),
(1344, 1, 1, 'catalog_category', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(1345, 1, 1, 'catalog_category', 'text_image_manager', 'Image Manager', '[[regtime]]', '[[regtime]]'),
(1346, 1, 1, 'catalog_category', 'update_title', 'Update Category', '[[regtime]]', '[[regtime]]'),
(1347, 1, 1, 'catalog_category', 'column_image', 'Image', '[[regtime]]', '[[regtime]]'),
(1348, 1, 1, 'catalog_category', 'column_name', 'Category Name', '[[regtime]]', '[[regtime]]'),
(1349, 1, 1, 'catalog_category', 'column_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(1350, 1, 1, 'catalog_category', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(1351, 1, 1, 'catalog_category', 'column_products', 'Products count', '[[regtime]]', '[[regtime]]'),
(1352, 1, 1, 'catalog_category', 'column_subcategories', 'Subcategories count', '[[regtime]]', '[[regtime]]'),
(1353, 1, 1, 'catalog_category', 'entry_name', 'Category Name:', '[[regtime]]', '[[regtime]]'),
(1354, 1, 1, 'catalog_category', 'entry_meta_keywords', 'Meta Tag Keywords:', '[[regtime]]', '[[regtime]]'),
(1355, 1, 1, 'catalog_category', 'entry_meta_description', 'Meta Tag Description:', '[[regtime]]', '[[regtime]]'),
(1356, 1, 1, 'catalog_category', 'entry_description', 'Description:', '[[regtime]]', '[[regtime]]'),
(1357, 1, 1, 'catalog_category', 'entry_status', 'Category Status:', '[[regtime]]', '[[regtime]]'),
(1358, 1, 1, 'catalog_category', 'entry_parent_category', 'Parent Category:', '[[regtime]]', '[[regtime]]'),
(1359, 1, 1, 'catalog_category', 'entry_store', 'Stores:', '[[regtime]]', '[[regtime]]'),
(1360, 1, 1, 'catalog_category', 'entry_keyword', 'SEO Keyword:', '[[regtime]]', '[[regtime]]'),
(1361, 1, 1, 'catalog_category', 'entry_image', 'Image:', '[[regtime]]', '[[regtime]]'),
(1362, 1, 1, 'catalog_category', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(1363, 1, 1, 'catalog_category', 'error_permission', 'Warning: You do not have permission to modify categories!', '[[regtime]]', '[[regtime]]'),
(1364, 1, 1, 'catalog_category', 'error_name', 'Category Name must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(1365, 1, 1, 'catalog_category', 'error_required_data', 'Required Data has not been entered. Check for field errors!', '[[regtime]]', '[[regtime]]'),
(1366, 1, 1, 'catalog_category', 'text_select_all', '- All Categories -', '[[regtime]]', '[[regtime]]'),
(1367, 1, 1, 'catalog_category', 'text_top_level', '- Top Level -', '[[regtime]]', '[[regtime]]'),
(1368, 1, 1, 'catalog_category', 'text_select_parent', '- Select Parent -', '[[regtime]]', '[[regtime]]'),
(1369, 1, 1, 'catalog_category', 'text_success_layout', 'Success: You have modified category page layout.', '[[regtime]]', '[[regtime]]'),
(1370, 1, 1, 'catalog_category', 'tab_image', 'Images', '[[regtime]]', '[[regtime]]'),
(1371, 1, 1, 'catalog_category', 'error_deadlock', 'Cannot assign to parent category, because it''s a child!', '[[regtime]]', '[[regtime]]'),
(1372, 1, 1, 'catalog_collections', 'heading_title', 'Collections', '[[regtime]]', '[[regtime]]'),
(1373, 1, 1, 'catalog_collections', 'collection_column_name', 'Collection Name', '[[regtime]]', '[[regtime]]'),
(1374, 1, 1, 'catalog_collections', 'collection_column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(1375, 1, 1, 'catalog_collections', 'collection_column_date_added', 'Date Added', '[[regtime]]', '[[regtime]]'),
(1376, 1, 1, 'catalog_collections', 'entry_name', 'Collection Name:', '[[regtime]]', '[[regtime]]'),
(1377, 1, 1, 'catalog_collections', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(1378, 1, 1, 'catalog_collections', 'entry_description', 'Internal description:', '[[regtime]]', '[[regtime]]'),
(1379, 1, 1, 'catalog_collections', 'save_error_name', 'Collection Name is required.', '[[regtime]]', '[[regtime]]'),
(1380, 1, 1, 'catalog_collections', 'collection_new', 'New Collection', '[[regtime]]', '[[regtime]]'),
(1381, 1, 1, 'catalog_collections', 'collection_update', 'Update Collection', '[[regtime]]', '[[regtime]]'),
(1382, 1, 1, 'catalog_collections', 'conditions_title', 'Conditions:', '[[regtime]]', '[[regtime]]'),
(1383, 1, 1, 'catalog_collections', 'text_if_1', 'If:', '[[regtime]]', '[[regtime]]'),
(1384, 1, 1, 'catalog_collections', 'text_all', 'All', '[[regtime]]', '[[regtime]]'),
(1385, 1, 1, 'catalog_collections', 'text_any', 'Any', '[[regtime]]', '[[regtime]]'),
(1386, 1, 1, 'catalog_collections', 'text_if_2', 'of these conditions are', '[[regtime]]', '[[regtime]]'),
(1387, 1, 1, 'catalog_collections', 'text_true', 'True', '[[regtime]]', '[[regtime]]'),
(1388, 1, 1, 'catalog_collections', 'text_false', 'False', '[[regtime]]', '[[regtime]]'),
(1389, 1, 1, 'catalog_collections', 'entry_condition_object', 'Add Condition:', '[[regtime]]', '[[regtime]]'),
(1390, 1, 1, 'catalog_collections', 'text_product_price', 'Product Price', '[[regtime]]', '[[regtime]]'),
(1391, 1, 1, 'catalog_collections', 'text_categories', 'Categories', '[[regtime]]', '[[regtime]]'),
(1392, 1, 1, 'catalog_collections', 'text_brands', 'Brands', '[[regtime]]', '[[regtime]]'),
(1393, 1, 1, 'catalog_collections', 'text_products', 'Products', '[[regtime]]', '[[regtime]]'),
(1394, 1, 1, 'catalog_collections', 'text_tags', 'Tags', '[[regtime]]', '[[regtime]]'),
(1395, 1, 1, 'catalog_collections', 'entry_categories', 'Categories:', '[[regtime]]', '[[regtime]]'),
(1396, 1, 1, 'catalog_collections', 'text_in', 'In', '[[regtime]]', '[[regtime]]'),
(1397, 1, 1, 'catalog_collections', 'text_not_in', 'Not in', '[[regtime]]', '[[regtime]]'),
(1398, 1, 1, 'catalog_collections', 'text_select_category', '-Select Category-', '[[regtime]]', '[[regtime]]'),
(1399, 1, 1, 'catalog_collections', 'entry_product_price', 'Product Price:', '[[regtime]]', '[[regtime]]'),
(1400, 1, 1, 'catalog_collections', 'text_equal', 'Equal', '[[regtime]]', '[[regtime]]'),
(1401, 1, 1, 'catalog_collections', 'text_not_equal', 'Not Equal', '[[regtime]]', '[[regtime]]'),
(1402, 1, 1, 'catalog_collections', 'text_equal_or_less', 'Equal or Less', '[[regtime]]', '[[regtime]]'),
(1403, 1, 1, 'catalog_collections', 'text_equal_or_greater', 'Equal or Greater', '[[regtime]]', '[[regtime]]'),
(1404, 1, 1, 'catalog_collections', 'text_greater', 'Greater', '[[regtime]]', '[[regtime]]'),
(1405, 1, 1, 'catalog_collections', 'text_less', 'Less', '[[regtime]]', '[[regtime]]'),
(1406, 1, 1, 'catalog_collections', 'entry_brands', 'Brands:', '[[regtime]]', '[[regtime]]'),
(1407, 1, 1, 'catalog_collections', 'entry_products', 'Products:', '[[regtime]]', '[[regtime]]'),
(1408, 1, 1, 'catalog_collections', 'entry_tags', 'Tags:', '[[regtime]]', '[[regtime]]'),
(1409, 1, 1, 'catalog_collections', 'text_select_tags', '-Select Tag-', '[[regtime]]', '[[regtime]]'),
(1410, 1, 1, 'catalog_collections', 'text_select_tag', '-Select Tag-', '[[regtime]]', '[[regtime]]'),
(1411, 1, 1, 'catalog_collections', 'save_complete', 'Save Complete', '[[regtime]]', '[[regtime]]'),
(1412, 1, 1, 'catalog_collections', 'entry_meta_keywords', 'Meta Keywords:', '[[regtime]]', '[[regtime]]'),
(1413, 1, 1, 'catalog_collections', 'entry_meta_description', 'Meta Description:', '[[regtime]]', '[[regtime]]'),
(1414, 1, 1, 'catalog_collections', 'entry_keyword', 'SEO Keyword:', '[[regtime]]', '[[regtime]]'),
(1415, 1, 1, 'catalog_collections', 'tab_design', 'Design', '[[regtime]]', '[[regtime]]'),
(1416, 1, 1, 'catalog_collections', 'text_collection', 'Collection', '[[regtime]]', '[[regtime]]'),
(1417, 1, 1, 'catalog_collections', 'text_success_layout', 'Layout Save Complete', '[[regtime]]', '[[regtime]]'),
(1418, 1, 1, 'catalog_collections', 'entry_title', 'Title:', '[[regtime]]', '[[regtime]]'),
(1419, 1, 1, 'catalog_collections', 'entry_products_count', 'Products Count:', '[[regtime]]', '[[regtime]]'),
(1420, 1, 1, 'catalog_collections', 'entry_collection_id', 'Select Collection:', '[[regtime]]', '[[regtime]]'),
(1421, 1, 1, 'catalog_collections', 'save_error_unique_keyword', 'Keyword must be unique!', '[[regtime]]', '[[regtime]]'),
(1422, 1, 1, 'catalog_download', 'heading_title', 'Shared Downloads', '[[regtime]]', '[[regtime]]'),
(1423, 1, 1, 'catalog_download', 'text_download', 'Shared Download', '[[regtime]]', '[[regtime]]'),
(1424, 1, 1, 'catalog_download', 'insert_title', 'Insert Download', '[[regtime]]', '[[regtime]]'),
(1425, 1, 1, 'catalog_download', 'update_title', 'Update Download', '[[regtime]]', '[[regtime]]'),
(1426, 1, 1, 'catalog_download', 'text_success', 'Success: You have modified downloads!', '[[regtime]]', '[[regtime]]'),
(1427, 1, 1, 'catalog_download', 'column_name', 'Download Name', '[[regtime]]', '[[regtime]]'),
(1428, 1, 1, 'catalog_download', 'column_remaining', 'Total Downloads Allowed', '[[regtime]]', '[[regtime]]'),
(1429, 1, 1, 'catalog_download', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(1430, 1, 1, 'catalog_download', 'entry_name', 'Download Name:', '[[regtime]]', '[[regtime]]'),
(1431, 1, 1, 'catalog_download', 'entry_filename', 'Filename:', '[[regtime]]', '[[regtime]]'),
(1432, 1, 1, 'catalog_download', 'entry_remaining', 'Total Downloads Allowed:', '[[regtime]]', '[[regtime]]'),
(1433, 1, 1, 'catalog_download', 'entry_update', 'Push to Previous Customers:<br /><span class="help">Check this to update previously purchased versions as well.</span>', '[[regtime]]', '[[regtime]]'),
(1434, 1, 1, 'catalog_download', 'error_permission', 'Warning: You do not have permission to modify downloads!', '[[regtime]]', '[[regtime]]'),
(1435, 1, 1, 'catalog_download', 'error_name', 'Name must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(1436, 1, 1, 'catalog_download', 'error_file', 'Please set the file for download.', '[[regtime]]', '[[regtime]]'),
(1437, 1, 1, 'catalog_download', 'error_product', 'Warning: This download cannot be deleted as it is currently assigned to %s products!', '[[regtime]]', '[[regtime]]'),
(1438, 1, 1, 'catalog_download', 'column_image', 'Image', '[[regtime]]', '[[regtime]]'),
(1439, 1, 1, 'catalog_download', 'column_products_count', 'Products Count', '[[regtime]]', '[[regtime]]'),
(1440, 1, 1, 'catalog_files', 'heading_title', 'Product Files', '[[regtime]]', '[[regtime]]'),
(1441, 1, 1, 'catalog_files', 'text_product', 'Product', '[[regtime]]', '[[regtime]]'),
(1442, 1, 1, 'catalog_files', 'text_edit_product_file', 'Edit Product File', '[[regtime]]', '[[regtime]]'),
(1443, 1, 1, 'catalog_files', 'tab_files', 'Files', '[[regtime]]', '[[regtime]]'),
(1444, 1, 1, 'catalog_files', 'tab_general', 'General', '[[regtime]]', '[[regtime]]'),
(1445, 1, 1, 'catalog_files', 'tab_attributes', 'Download Attributes', '[[regtime]]', '[[regtime]]'),
(1446, 1, 1, 'catalog_files', 'entry_file_icon', 'File Icon', '[[regtime]]', '[[regtime]]'),
(1447, 1, 1, 'catalog_files', 'entry_status', ' Status', '[[regtime]]', '[[regtime]]'),
(1448, 1, 1, 'catalog_files', 'entry_resource', ' Resource', '[[regtime]]', '[[regtime]]'),
(1449, 1, 1, 'catalog_files', 'entry_name', ' Name', '[[regtime]]', '[[regtime]]'),
(1450, 1, 1, 'catalog_files', 'entry_download_name', 'Download Name', '[[regtime]]', '[[regtime]]'),
(1451, 1, 1, 'catalog_files', 'entry_mask', 'Download mask <span class="help">Filename alias for customer download output</span>', '[[regtime]]', '[[regtime]]'),
(1452, 1, 1, 'catalog_files', 'entry_file_full_path', 'File Server Path ', '[[regtime]]', '[[regtime]]'),
(1453, 1, 1, 'catalog_files', 'entry_file_max_downloads', 'Max Download', '[[regtime]]', '[[regtime]]'),
(1454, 1, 1, 'catalog_files', 'entry_file_sort_order', 'Sort order', '[[regtime]]', '[[regtime]]'),
(1455, 1, 1, 'catalog_files', 'entry_file_status', 'Status', '[[regtime]]', '[[regtime]]'),
(1456, 1, 1, 'catalog_files', 'entry_also_mapped_to', 'Shared With', '[[regtime]]', '[[regtime]]'),
(1457, 1, 1, 'catalog_files', 'entry_file_push_to_customers', 'Push to customers', '[[regtime]]', '[[regtime]]'),
(1458, 1, 1, 'catalog_files', 'entry_file_activation', 'Activation Mode', '[[regtime]]', '[[regtime]]'),
(1459, 1, 1, 'catalog_files', 'text_add_file', 'Add File', '[[regtime]]', '[[regtime]]'),
(1460, 1, 1, 'catalog_files', 'text_new_file', 'Add New File', '[[regtime]]', '[[regtime]]'),
(1461, 1, 1, 'catalog_files', 'text_download_attributes', 'Download Attributes', '[[regtime]]', '[[regtime]]'),
(1462, 1, 1, 'catalog_files', 'text_download_information', 'General', '[[regtime]]', '[[regtime]]'),
(1463, 1, 1, 'catalog_files', 'entry_date_added', 'Added on ', '[[regtime]]', '[[regtime]]'),
(1464, 1, 1, 'catalog_files', 'entry_date_modified', 'Modified ', '[[regtime]]', '[[regtime]]'),
(1465, 1, 1, 'catalog_files', 'entry_max_downloads', 'Max downloads <span class="help">Count of downloads allowed for customer</span>', '[[regtime]]', '[[regtime]]'),
(1466, 1, 1, 'catalog_files', 'entry_activate', 'Activated<span class="help">Download will be activates on the event selected.<br>Example: Immediately. Download is activate  after order is placed, regardless of the order status</span>', '[[regtime]]', '[[regtime]]'),
(1467, 1, 1, 'catalog_files', 'entry_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(1468, 1, 1, 'catalog_files', 'entry_expire_days', 'Expire days<span class="help">Count of days from date of purchase</span>', '[[regtime]]', '[[regtime]]'),
(1469, 1, 1, 'catalog_files', 'text_before_order', 'Before Order', '[[regtime]]', '[[regtime]]'),
(1470, 1, 1, 'catalog_files', 'text_immediately', 'Immediately', '[[regtime]]', '[[regtime]]'),
(1471, 1, 1, 'catalog_files', 'text_on_order_status', 'on Order Status', '[[regtime]]', '[[regtime]]'),
(1472, 1, 1, 'catalog_files', 'text_manually', 'Manually', '[[regtime]]', '[[regtime]]'),
(1473, 1, 1, 'catalog_files', 'text_success_download_save', 'Success: You have modified file! ', '[[regtime]]', '[[regtime]]'),
(1474, 1, 1, 'catalog_files', 'error_download_exists', 'Error: Cannot to update download because it does not exists in database! ', '[[regtime]]', '[[regtime]]'),
(1475, 1, 1, 'catalog_files', 'error_download_name', 'Error: Download name must have length between 2 and 128 characters! ', '[[regtime]]', '[[regtime]]'),
(1476, 1, 1, 'catalog_files', 'error_max_downloads', 'Error: maximum downloads count must be greater 0! ', '[[regtime]]', '[[regtime]]'),
(1477, 1, 1, 'catalog_files', 'error_activate', 'Error: select action for activation of download! ', '[[regtime]]', '[[regtime]]'),
(1478, 1, 1, 'catalog_files', 'error_order_status', 'Error: select order status for activation of download! ', '[[regtime]]', '[[regtime]]'),
(1479, 1, 1, 'catalog_files', 'error_download_attributes', 'Download Attributes Error(s):', '[[regtime]]', '[[regtime]]'),
(1480, 1, 1, 'catalog_files', 'text_shared_downloads', 'Shared Downloads', '[[regtime]]', '[[regtime]]'),
(1481, 1, 1, 'catalog_files', 'text_create_download', 'Create new download', '[[regtime]]', '[[regtime]]'),
(1482, 1, 1, 'catalog_files', 'text_path', 'Relative path to file', '[[regtime]]', '[[regtime]]'),
(1483, 1, 1, 'catalog_files', 'text_preview', 'Preview', '[[regtime]]', '[[regtime]]'),
(1484, 1, 1, 'catalog_files', 'entry_shared', 'Shared Download', '[[regtime]]', '[[regtime]]'),
(1485, 1, 1, 'catalog_files', 'text_assign', ' Save ', '[[regtime]]', '[[regtime]]'),
(1486, 1, 1, 'catalog_files', 'text_assigned_to', 'Also assigned to: ', '[[regtime]]', '[[regtime]]'),
(1487, 1, 1, 'catalog_files', 'text_select_shared_downloads', 'Select shared downloads', '[[regtime]]', '[[regtime]]'),
(1488, 1, 1, 'catalog_files', 'error_selected_downloads', 'Warning: Please select the shared downloads for assign.', '[[regtime]]', '[[regtime]]'),
(1489, 1, 1, 'catalog_files', 'text_map_success', 'Success: You have assigned shared downloads to product!', '[[regtime]]', '[[regtime]]'),
(1490, 1, 1, 'catalog_files', 'text_delete_or_refuse', 'delete or refuse (for shared)', '[[regtime]]', '[[regtime]]'),
(1491, 1, 1, 'catalog_files', 'text_confirm_delete', 'Confirm download delete/refuse', '[[regtime]]', '[[regtime]]'),
(1492, 1, 1, 'catalog_files', 'text_success_remove', 'Success: product files list changed!', '[[regtime]]', '[[regtime]]'),
(1493, 1, 1, 'catalog_files', 'text_push', 'Push', '[[regtime]]', '[[regtime]]'),
(1494, 1, 1, 'catalog_files', 'text_push_to_customers', 'Push to Customers', '[[regtime]]', '[[regtime]]'),
(1495, 1, 1, 'catalog_files', 'text_push_to_orders', 'Push Download to %s Orders', '[[regtime]]', '[[regtime]]'),
(1496, 1, 1, 'catalog_files', 'success_push_to_orders', 'Success: Download was pushed  to %s order(s) successfully', '[[regtime]]', '[[regtime]]'),
(1497, 1, 1, 'catalog_files', 'text_no_download_attributes_yet', ' No download attributes yet. <a href="%s" target="_blank">Click to add</a>', '[[regtime]]', '[[regtime]]'),
(1498, 1, 1, 'catalog_files', 'text_confirm_push', ' Confirm? ', '[[regtime]]', '[[regtime]]'),
(1499, 1, 1, 'catalog_files', 'error_downloads_disabled', 'Warning: Downloads are disabled in store settings. <a href="#admin#rt=setting/setting&active=general" target="new">Click to Edit</a>!', '[[regtime]]', '[[regtime]]'),
(1500, 1, 1, 'catalog_files', 'error_permission', 'Warning: You do not have permission to modify product files!', '[[regtime]]', '[[regtime]]'),
(1501, 1, 1, 'catalog_files', 'error_file', 'Please set the file for download.', '[[regtime]]', '[[regtime]]'),
(1502, 1, 1, 'catalog_files', 'attention_shared', 'You are about to edit shared download. Edit will effect other products.', '[[regtime]]', '[[regtime]]'),
(1503, 1, 1, 'catalog_files', 'text_shared_with', 'Shared with:', '[[regtime]]', '[[regtime]]'),
(1504, 1, 1, 'catalog_manufacturer', 'heading_title', 'Brands', '[[regtime]]', '[[regtime]]'),
(1505, 1, 1, 'catalog_manufacturer', 'text_manufacturer', 'Brand', '[[regtime]]', '[[regtime]]'),
(1506, 1, 1, 'catalog_manufacturer', 'text_success', 'Success: You have modified brands!', '[[regtime]]', '[[regtime]]'),
(1507, 1, 1, 'catalog_manufacturer', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(1508, 1, 1, 'catalog_manufacturer', 'text_image_manager', 'Image Manager', '[[regtime]]', '[[regtime]]'),
(1509, 1, 1, 'catalog_manufacturer', 'column_name', 'Brand Name', '[[regtime]]', '[[regtime]]'),
(1510, 1, 1, 'catalog_manufacturer', 'column_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(1511, 1, 1, 'catalog_manufacturer', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(1512, 1, 1, 'catalog_manufacturer', 'column_products', 'Products count', '[[regtime]]', '[[regtime]]'),
(1513, 1, 1, 'catalog_manufacturer', 'entry_name', 'Brand Name:', '[[regtime]]', '[[regtime]]'),
(1514, 1, 1, 'catalog_manufacturer', 'entry_store', 'Stores:', '[[regtime]]', '[[regtime]]'),
(1515, 1, 1, 'catalog_manufacturer', 'entry_keyword', 'SEO Keyword:', '[[regtime]]', '[[regtime]]'),
(1516, 1, 1, 'catalog_manufacturer', 'entry_edit', 'Edit', '[[regtime]]', '[[regtime]]'),
(1517, 1, 1, 'catalog_manufacturer', 'entry_image', 'Image:', '[[regtime]]', '[[regtime]]'),
(1518, 1, 1, 'catalog_manufacturer', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(1519, 1, 1, 'catalog_manufacturer', 'error_manufacturer_not_found', 'Error: Brand not found!', '[[regtime]]', '[[regtime]]'),
(1520, 1, 1, 'catalog_manufacturer', 'error_permission', 'Warning: You do not have permission to modify brands!', '[[regtime]]', '[[regtime]]'),
(1521, 1, 1, 'catalog_manufacturer', 'error_name', 'Brand Name must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(1522, 1, 1, 'catalog_manufacturer', 'error_product', 'Warning: This brand cannot be deleted as it is currently assigned to %s products!', '[[regtime]]', '[[regtime]]'),
(1523, 1, 1, 'catalog_manufacturer', 'text_success_layout', 'Success: You have modified category page layout.', '[[regtime]]', '[[regtime]]'),
(1524, 1, 1, 'catalog_product', 'heading_title', 'Products', '[[regtime]]', '[[regtime]]'),
(1525, 1, 1, 'catalog_product', 'text_product', 'Product', '[[regtime]]', '[[regtime]]'),
(1526, 1, 1, 'catalog_product', 'tab_media', 'Media', '[[regtime]]', '[[regtime]]'),
(1527, 1, 1, 'catalog_product', 'tab_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(1528, 1, 1, 'catalog_product', 'tab_files', 'Files', '[[regtime]]', '[[regtime]]'),
(1529, 1, 1, 'catalog_product', 'tab_relations', 'Relations', '[[regtime]]', '[[regtime]]'),
(1530, 1, 1, 'catalog_product', 'tab_promotions', 'Promotions', '[[regtime]]', '[[regtime]]'),
(1531, 1, 1, 'catalog_product', 'tab_extensions', 'Extensions', '[[regtime]]', '[[regtime]]'),
(1532, 1, 1, 'catalog_product', 'text_success', 'Success: You have modified products!', '[[regtime]]', '[[regtime]]'),
(1533, 1, 1, 'catalog_product', 'text_success_copy', 'Success: You have successfully cloned product <b>%s</b>!', '[[regtime]]', '[[regtime]]'),
(1534, 1, 1, 'catalog_product', 'text_success_copy_layout', ' Note: Custom product layout has been cloned as well.', '[[regtime]]', '[[regtime]]'),
(1535, 1, 1, 'catalog_product', 'text_error_copy', 'Cloning has failed! Original product is not available', '[[regtime]]', '[[regtime]]'),
(1536, 1, 1, 'catalog_product', 'text_plus', '+', '[[regtime]]', '[[regtime]]'),
(1537, 1, 1, 'catalog_product', 'text_minus', '-', '[[regtime]]', '[[regtime]]'),
(1538, 1, 1, 'catalog_product', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(1539, 1, 1, 'catalog_product', 'text_product_summary', 'Product Summary', '[[regtime]]', '[[regtime]]'),
(1540, 1, 1, 'catalog_product', 'text_image_manager', 'Image Manager', '[[regtime]]', '[[regtime]]'),
(1541, 1, 1, 'catalog_product', 'text_option', 'Option', '[[regtime]]', '[[regtime]]'),
(1542, 1, 1, 'catalog_product', 'text_option_value', 'Option Value', '[[regtime]]', '[[regtime]]'),
(1543, 1, 1, 'catalog_product', 'column_name', 'Product Name', '[[regtime]]', '[[regtime]]'),
(1544, 1, 1, 'catalog_product', 'column_model', 'Model', '[[regtime]]', '[[regtime]]'),
(1545, 1, 1, 'catalog_product', 'column_sku', 'SKU', '[[regtime]]', '[[regtime]]'),
(1546, 1, 1, 'catalog_product', 'column_image', 'Image', '[[regtime]]', '[[regtime]]'),
(1547, 1, 1, 'catalog_product', 'column_quantity', 'Quantity', '[[regtime]]', '[[regtime]]'),
(1548, 1, 1, 'catalog_product', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(1549, 1, 1, 'catalog_product', 'column_price', 'Price', '[[regtime]]', '[[regtime]]'),
(1550, 1, 1, 'catalog_product', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(1551, 1, 1, 'catalog_product', 'entry_featured', 'Featured Product:', '[[regtime]]', '[[regtime]]'),
(1552, 1, 1, 'catalog_product', 'entry_name', 'Product Name:', '[[regtime]]', '[[regtime]]'),
(1553, 1, 1, 'catalog_product', 'entry_meta_keywords', 'Meta Tag Keywords:', '[[regtime]]', '[[regtime]]'),
(1554, 1, 1, 'catalog_product', 'entry_meta_description', 'Meta Tag Description:', '[[regtime]]', '[[regtime]]'),
(1555, 1, 1, 'catalog_product', 'entry_description', 'Description:', '[[regtime]]', '[[regtime]]'),
(1556, 1, 1, 'catalog_product', 'entry_blurb', 'Blurb:', '[[regtime]]', '[[regtime]]'),
(1557, 1, 1, 'catalog_product', 'entry_store', 'Stores:', '[[regtime]]', '[[regtime]]'),
(1558, 1, 1, 'catalog_product', 'entry_keyword', 'SEO Keyword:<br/><span class="help">SEO key that will show in URL for this product. You can generate key from product name</span>', '[[regtime]]', '[[regtime]]'),
(1559, 1, 1, 'catalog_product', 'entry_model', 'Model:', '[[regtime]]', '[[regtime]]'),
(1560, 1, 1, 'catalog_product', 'entry_sku', 'SKU:', '[[regtime]]', '[[regtime]]'),
(1561, 1, 1, 'catalog_product', 'entry_location', 'Misc Location:', '[[regtime]]', '[[regtime]]'),
(1562, 1, 1, 'catalog_product', 'entry_manufacturer', 'Brand:', '[[regtime]]', '[[regtime]]'),
(1563, 1, 1, 'catalog_product', 'entry_shipping', 'Requires Shipping:', '[[regtime]]', '[[regtime]]'),
(1564, 1, 1, 'catalog_product', 'entry_ship_individually', 'Ship Product Individually:<br/><span class="help">Product will be shipped in a separate package and additional shipping cost will be added to the order with multiple items. If enabled, Fixed Shipping Price needs to be set.</span>', '[[regtime]]', '[[regtime]]'),
(1565, 1, 1, 'catalog_product', 'entry_shipping_price', 'Fixed Shipping Price:<br/><span class="help">Master setting with fixed shipping price for this product.</span>', '[[regtime]]', '[[regtime]]'),
(1566, 1, 1, 'catalog_product', 'entry_free_shipping', 'Free Shipping:<br/><span class="help">Master setting to enable free shipping for this product.</span>', '[[regtime]]', '[[regtime]]'),
(1567, 1, 1, 'catalog_product', 'entry_date_available', 'Date Available:', '[[regtime]]', '[[regtime]]'),
(1568, 1, 1, 'catalog_product', 'entry_option_quantity', 'Quantity:', '[[regtime]]', '[[regtime]]'),
(1569, 1, 1, 'catalog_product', 'entry_quantity', 'Quantity:<br/><span class="help">Connected to Track Stock setting</span>', '[[regtime]]', '[[regtime]]'),
(1570, 1, 1, 'catalog_product', 'entry_minimum', 'Minimum Quantity:<br/><span class="help">Force a minimum ordered amount</span>', '[[regtime]]', '[[regtime]]'),
(1571, 1, 1, 'catalog_product', 'entry_maximum', 'Maximum Quantity:<br/><span class="help">Set a limit on quantity that can be selected per each order. 0 = no limit</span>', '[[regtime]]', '[[regtime]]'),
(1572, 1, 1, 'catalog_product', 'entry_stock_status', 'Pre-Order Stock Status:<br/><span class="help">Text shown when a product is out of stock and purchase allowed</span>', '[[regtime]]', '[[regtime]]'),
(1573, 1, 1, 'catalog_product', 'entry_stock_checkout', 'Stock Checkout:<br /><span class="help">Allow customers to checkout even if the products are out of stock.</span>', '[[regtime]]', '[[regtime]]'),
(1574, 1, 1, 'catalog_product', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(1575, 1, 1, 'catalog_product', 'entry_tax_class', 'Tax Class:', '[[regtime]]', '[[regtime]]'),
(1576, 1, 1, 'catalog_product', 'entry_cost', 'Cost:<br/><span class="help">The wholesale cost used for profit reporting</span>', '[[regtime]]', '[[regtime]]'),
(1577, 1, 1, 'catalog_product', 'entry_price', 'Price:', '[[regtime]]', '[[regtime]]'),
(1578, 1, 1, 'catalog_product', 'entry_product_option_cost', 'Actual Cost (total):<span class="help">Enter the actual cost (total) of this product option.</span>', '[[regtime]]', '[[regtime]]'),
(1579, 1, 1, 'catalog_product', 'entry_track_option_stock', 'Track Stock:', '[[regtime]]', '[[regtime]]'),
(1580, 1, 1, 'catalog_product', 'entry_subtract', 'Track Stock:<br/><span class="help">Set YES if you need to track stock quantity for this product. If options are used check subtract setting for each option value</span>', '[[regtime]]', '[[regtime]]'),
(1581, 1, 1, 'catalog_product', 'entry_weight_class', 'Weight Class:', '[[regtime]]', '[[regtime]]'),
(1582, 1, 1, 'catalog_product', 'entry_weight', 'Weight:', '[[regtime]]', '[[regtime]]'),
(1583, 1, 1, 'catalog_product', 'entry_weight_change', 'Weight: <span class="help">Important! If value provided as %(percent) option weight will be changed by specified percent based on the main product weight. If weight value provided it will be used as absolute value for the option, main weight will be ignored.</span>', '[[regtime]]', '[[regtime]]'),
(1584, 1, 1, 'catalog_product', 'entry_length_class', 'Length Class:', '[[regtime]]', '[[regtime]]'),
(1585, 1, 1, 'catalog_product', 'entry_length', 'Product package length: <span class="help">The package dimension refers to the size of the box, pouch, or parcel that your item will be shipped in</span>', '[[regtime]]', '[[regtime]]'),
(1586, 1, 1, 'catalog_product', 'entry_width', 'Product package Width: <span class="help">The package dimension refers to the size of the box, pouch, or parcel that your item will be shipped in</span>', '[[regtime]]', '[[regtime]]'),
(1587, 1, 1, 'catalog_product', 'entry_height', 'Product package Height:<span class="help">The package dimension refers to the size of the box, pouch, or parcel that your item will be shipped in</span>', '[[regtime]]', '[[regtime]]'),
(1588, 1, 1, 'catalog_product', 'entry_dimension', 'Dimensions (L x W x H):', '[[regtime]]', '[[regtime]]'),
(1589, 1, 1, 'catalog_product', 'entry_image', 'Image:<br /><span class="help">Click image to change it.</span>', '[[regtime]]', '[[regtime]]'),
(1590, 1, 1, 'catalog_product', 'entry_customer_group', 'Customer Group:', '[[regtime]]', '[[regtime]]'),
(1591, 1, 1, 'catalog_product', 'entry_date_start', 'Date Start:', '[[regtime]]', '[[regtime]]'),
(1592, 1, 1, 'catalog_product', 'entry_date_end', 'Date End:', '[[regtime]]', '[[regtime]]'),
(1593, 1, 1, 'catalog_product', 'entry_priority', 'Priority:', '[[regtime]]', '[[regtime]]'),
(1594, 1, 1, 'catalog_product', 'entry_option', 'Option:', '[[regtime]]', '[[regtime]]'),
(1595, 1, 1, 'catalog_product', 'entry_option_name', 'Option Name:', '[[regtime]]', '[[regtime]]'),
(1596, 1, 1, 'catalog_product', 'entry_option_value', 'Option Value:', '[[regtime]]', '[[regtime]]'),
(1597, 1, 1, 'catalog_product', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(1598, 1, 1, 'catalog_product', 'entry_prefix', 'Prefix:', '[[regtime]]', '[[regtime]]'),
(1599, 1, 1, 'catalog_product', 'entry_option_prefix', 'Modify Price By:', '[[regtime]]', '[[regtime]]'),
(1600, 1, 1, 'catalog_product', 'entry_option_price', 'Price Modifier:', '[[regtime]]', '[[regtime]]'),
(1601, 1, 1, 'catalog_product', 'entry_category', 'Categories:', '[[regtime]]', '[[regtime]]'),
(1602, 1, 1, 'catalog_product', 'entry_download', 'Downloads:', '[[regtime]]', '[[regtime]]'),
(1603, 1, 1, 'catalog_product', 'entry_related', 'Related Products:', '[[regtime]]', '[[regtime]]'),
(1604, 1, 1, 'catalog_product', 'entry_tags', 'Product Tags:<br /><span class="help">comma separated</span>', '[[regtime]]', '[[regtime]]'),
(1605, 1, 1, 'catalog_product', 'error_permission', 'Warning: You do not have permission to modify products!', '[[regtime]]', '[[regtime]]'),
(1606, 1, 1, 'catalog_product', 'error_name', 'Product Name must be greater than 3 and less than 255 characters!', '[[regtime]]', '[[regtime]]'),
(1607, 1, 1, 'catalog_product', 'error_model', 'Product Model must be less than 64 characters! Recommended 5-25 characters', '[[regtime]]', '[[regtime]]'),
(1608, 1, 1, 'catalog_product', 'error_required_data', 'Required Data has not been entered. Check for field errors!', '[[regtime]]', '[[regtime]]'),
(1609, 1, 1, 'catalog_product', 'error_product_not_found', 'Error: Product not found!', '[[regtime]]', '[[regtime]]'),
(1610, 1, 1, 'catalog_product', 'error_sku', 'Error: SKU not found!', '[[regtime]]', '[[regtime]]'),
(1611, 1, 1, 'catalog_product', 'filter_product', 'Search for product', '[[regtime]]', '[[regtime]]'),
(1612, 1, 1, 'catalog_product', 'filter_any_word', 'Any of these words', '[[regtime]]', '[[regtime]]'),
(1613, 1, 1, 'catalog_product', 'filter_all_words', 'All of these words', '[[regtime]]', '[[regtime]]'),
(1614, 1, 1, 'catalog_product', 'filter_exact_match', 'The exact phrase', '[[regtime]]', '[[regtime]]'),
(1615, 1, 1, 'catalog_product', 'filter_all_categories', '- All Categories -', '[[regtime]]', '[[regtime]]'),
(1616, 1, 1, 'catalog_product', 'filter_price_max', 'max', '[[regtime]]', '[[regtime]]'),
(1617, 1, 1, 'catalog_product', 'text_view', 'view', '[[regtime]]', '[[regtime]]'),
(1618, 1, 1, 'catalog_product', 'text_delete', 'delete', '[[regtime]]', '[[regtime]]'),
(1619, 1, 1, 'catalog_product', 'text_choose_action', 'Choose action', '[[regtime]]', '[[regtime]]'),
(1620, 1, 1, 'catalog_product', 'text_clone_selected', 'Clone selected', '[[regtime]]', '[[regtime]]'),
(1621, 1, 1, 'catalog_product', 'text_export_selected', 'Export selected', '[[regtime]]', '[[regtime]]'),
(1622, 1, 1, 'catalog_product', 'text_delete_selected', 'Delete selected', '[[regtime]]', '[[regtime]]'),
(1623, 1, 1, 'catalog_product', 'text_edit_selected', 'Edit selected', '[[regtime]]', '[[regtime]]'),
(1624, 1, 1, 'catalog_product', 'text_clone', 'Clone', '[[regtime]]', '[[regtime]]'),
(1625, 1, 1, 'catalog_product', 'text_export', 'Export', '[[regtime]]', '[[regtime]]'),
(1626, 1, 1, 'catalog_product', 'text_select_category', '- Select Category -', '[[regtime]]', '[[regtime]]'),
(1627, 1, 1, 'catalog_product', 'text_select_product', '- Select Product -', '[[regtime]]', '[[regtime]]'),
(1628, 1, 1, 'catalog_product', 'text_option_name', 'Option Name', '[[regtime]]', '[[regtime]]'),
(1629, 1, 1, 'catalog_product', 'text_group_option', 'Group Option', '[[regtime]]', '[[regtime]]'),
(1630, 1, 1, 'catalog_product', 'text_option_type', 'Option Type', '[[regtime]]', '[[regtime]]'),
(1631, 1, 1, 'catalog_product', 'text_option_values', 'Option Values', '[[regtime]]', '[[regtime]]'),
(1632, 1, 1, 'catalog_product', 'text_no_option_values', 'No Option Values', '[[regtime]]', '[[regtime]]'),
(1633, 1, 1, 'catalog_product', 'text_edit_option_values', 'Edit Option Value', '[[regtime]]', '[[regtime]]'),
(1634, 1, 1, 'catalog_product', 'text_save_option_values', 'Save Option Value', '[[regtime]]', '[[regtime]]'),
(1635, 1, 1, 'catalog_product', 'button_remove_option', 'Remove Option', '[[regtime]]', '[[regtime]]'),
(1636, 1, 1, 'catalog_product', 'text_option_removed', 'Option Removed', '[[regtime]]', '[[regtime]]'),
(1637, 1, 1, 'catalog_product', 'entry_weight_type', 'Weight Type', '[[regtime]]', '[[regtime]]'),
(1638, 1, 1, 'catalog_product', 'text_product_pagination', 'Product(s) {start} to {end} of {total}', '[[regtime]]', '[[regtime]]'),
(1639, 1, 1, 'catalog_product', 'entry_product_id', 'Product ID', '[[regtime]]', '[[regtime]]'),
(1640, 1, 1, 'catalog_product', 'error_product_load', 'Warning: No product with such ID!', '[[regtime]]', '[[regtime]]'),
(1641, 1, 1, 'catalog_product', 'error_attribute_not_selected', 'Please select option to add!', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(1642, 1, 1, 'catalog_product', 'error_date', '"Date End" can not be less than "Date Start"!', '[[regtime]]', '[[regtime]]'),
(1643, 1, 1, 'catalog_product', 'error_required', 'This field is required!', '[[regtime]]', '[[regtime]]'),
(1644, 1, 1, 'catalog_product', 'error_option_in_group', 'Option cannot be added to product as it is already a part of group option!', '[[regtime]]', '[[regtime]]'),
(1645, 1, 1, 'catalog_product', 'text_success_layout', 'Success: You have modified product page layout.', '[[regtime]]', '[[regtime]]'),
(1646, 1, 1, 'catalog_product', 'text_success_option', 'Success: You have modified product option.', '[[regtime]]', '[[regtime]]'),
(1647, 1, 1, 'catalog_product', 'text_add_new_option', '- Add New Option -', '[[regtime]]', '[[regtime]]'),
(1648, 1, 1, 'catalog_product', 'entry_required', 'Required:', '[[regtime]]', '[[regtime]]'),
(1649, 1, 1, 'catalog_product', 'entry_element_type', 'Element Type:', '[[regtime]]', '[[regtime]]'),
(1650, 1, 1, 'catalog_product', 'entry_element_values', 'Element Values:', '[[regtime]]', '[[regtime]]'),
(1651, 1, 1, 'catalog_product', 'text_expand', '+ expand', '[[regtime]]', '[[regtime]]'),
(1652, 1, 1, 'catalog_product', 'text_hide', '- hide', '[[regtime]]', '[[regtime]]'),
(1653, 1, 1, 'catalog_product', 'entry_option_placeholder', 'Placeholder:', '[[regtime]]', '[[regtime]]'),
(1654, 1, 1, 'catalog_product', 'entry_regexp_pattern', 'Regular Expression Pattern:', '[[regtime]]', '[[regtime]]'),
(1655, 1, 1, 'catalog_product', 'entry_error_text', 'Error Message about invalid Value:', '[[regtime]]', '[[regtime]]'),
(1656, 1, 1, 'catalog_product', 'text_product_condition', 'Product Condition:', '[[regtime]]', '[[regtime]]'),
(1657, 1, 1, 'catalog_product', 'text_product_available', 'Available', '[[regtime]]', '[[regtime]]'),
(1658, 1, 1, 'catalog_product', 'text_product_disabled', 'Disabled', '[[regtime]]', '[[regtime]]'),
(1659, 1, 1, 'catalog_product', 'text_product_unavailable', 'Unavailable', '[[regtime]]', '[[regtime]]'),
(1660, 1, 1, 'catalog_product', 'text_product_out_of_stock', 'Out of Stock', '[[regtime]]', '[[regtime]]'),
(1661, 1, 1, 'catalog_product', 'text_product_in_stock', 'In Stock', '[[regtime]]', '[[regtime]]'),
(1662, 1, 1, 'catalog_product', 'text_product_option_out_of_stock', 'Product Option(s) Out of Stock', '[[regtime]]', '[[regtime]]'),
(1663, 1, 1, 'catalog_product', 'text_call_to_order', 'Call To Order', '[[regtime]]', '[[regtime]]'),
(1664, 1, 1, 'catalog_product', 'entry_call_to_order', 'Block Product From Ordering:<br /><span class="help">This will put product to display mode only with no ability to order. Contact us for order message will be displayed.</span>', '[[regtime]]', '[[regtime]]'),
(1665, 1, 1, 'catalog_product', 'text_new_option', 'New Option', '[[regtime]]', '[[regtime]]'),
(1666, 1, 1, 'catalog_product', 'text_total_orders', 'Total Orders', '[[regtime]]', '[[regtime]]'),
(1667, 1, 1, 'catalog_product', 'error_measure_value', 'The limit of 999.99 has been reached. Provide smaller number.', '[[regtime]]', '[[regtime]]'),
(1668, 1, 1, 'catalog_product', 'error_dimension_value', 'This product requires shipping. Please fill all dimension values.', '[[regtime]]', '[[regtime]]'),
(1669, 1, 1, 'catalog_product', 'error_weight_value', 'This product requires shipping. Please set weight value.', '[[regtime]]', '[[regtime]]'),
(1670, 1, 1, 'catalog_product', 'error_weight_class', 'Please set weight class.', '[[regtime]]', '[[regtime]]'),
(1671, 1, 1, 'catalog_product', 'error_length_class', 'Please set length class.', '[[regtime]]', '[[regtime]]'),
(1672, 1, 1, 'catalog_product', 'entry_allowed_extensions', 'Allowed File Extensions (txt, jpg …)', '[[regtime]]', '[[regtime]]'),
(1673, 1, 1, 'catalog_product', 'entry_min_size', 'Min file size (Kb)', '[[regtime]]', '[[regtime]]'),
(1674, 1, 1, 'catalog_product', 'entry_max_size', 'Max file size (Kb)', '[[regtime]]', '[[regtime]]'),
(1675, 1, 1, 'catalog_product', 'entry_upload_dir', 'Upload directory name<br>%s', '[[regtime]]', '[[regtime]]'),
(1676, 1, 1, 'catalog_product', 'text_success_relation_set', 'Relations of selected products was set successfully!', '[[regtime]]', '[[regtime]]'),
(1677, 1, 1, 'catalog_product', 'entry_stock_locations', 'Stock Locations:', '[[regtime]]', '[[regtime]]'),
(1678, 1, 1, 'catalog_product', 'entry_locations', 'Locations:', '[[regtime]]', '[[regtime]]'),
(1679, 1, 1, 'catalog_product', 'text_create_collection', 'Create Collection', '[[regtime]]', '[[regtime]]'),
(1680, 1, 1, 'catalog_product', 'text_warning_empty_set', 'Please select at least one product', '[[regtime]]', '[[regtime]]'),
(1681, 1, 1, 'catalog_product', 'text_enable_selected', 'Enable Selected', '[[regtime]]', '[[regtime]]'),
(1682, 1, 1, 'catalog_product', 'text_disable_selected', 'Disable Selected', '[[regtime]]', '[[regtime]]'),
(1683, 1, 1, 'catalog_product', 'entry_tax_rule', 'Tax Rule', '[[regtime]]', '[[regtime]]'),
(1684, 1, 1, 'catalog_product', 'entry_price_with_tax', 'Price With Taxes:', '[[regtime]]', '[[regtime]]'),
(1685, 1, 1, 'catalog_product', 'entry_txt_id', 'Unique Text ID:', '[[regtime]]', '[[regtime]]'),
(1686, 1, 1, 'catalog_product', 'entry_html_attributes', 'html-attributes:<br /><span class="help">You can add your custom html-attributes for option element. Example: data-some-attribute="some value"</span>', '[[regtime]]', '[[regtime]]'),
(1687, 1, 1, 'catalog_product', 'text_new_price', 'New Price', '[[regtime]]', '[[regtime]]'),
(1688, 1, 1, 'catalog_product', 'text_prc_off', '% Off', '[[regtime]]', '[[regtime]]'),
(1689, 1, 1, 'catalog_product', 'text_fixed_amount_off', 'Fixed Amount Off', '[[regtime]]', '[[regtime]]'),
(1690, 1, 1, 'catalog_review', 'heading_title', 'Reviews', '[[regtime]]', '[[regtime]]'),
(1691, 1, 1, 'catalog_review', 'text_review', 'Review', '[[regtime]]', '[[regtime]]'),
(1692, 1, 1, 'catalog_review', 'insert_title', 'Insert Review', '[[regtime]]', '[[regtime]]'),
(1693, 1, 1, 'catalog_review', 'update_title', 'Update Review', '[[regtime]]', '[[regtime]]'),
(1694, 1, 1, 'catalog_review', 'text_success', 'Success: You have modified reviews!', '[[regtime]]', '[[regtime]]'),
(1695, 1, 1, 'catalog_review', 'column_product', 'Product', '[[regtime]]', '[[regtime]]'),
(1696, 1, 1, 'catalog_review', 'column_author', 'Author', '[[regtime]]', '[[regtime]]'),
(1697, 1, 1, 'catalog_review', 'column_rating', 'Rating', '[[regtime]]', '[[regtime]]'),
(1698, 1, 1, 'catalog_review', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(1699, 1, 1, 'catalog_review', 'column_date_added', 'Date Added', '[[regtime]]', '[[regtime]]'),
(1700, 1, 1, 'catalog_review', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(1701, 1, 1, 'catalog_review', 'entry_product', 'Product:', '[[regtime]]', '[[regtime]]'),
(1702, 1, 1, 'catalog_review', 'entry_author', 'Author:', '[[regtime]]', '[[regtime]]'),
(1703, 1, 1, 'catalog_review', 'entry_rating', 'Rating:', '[[regtime]]', '[[regtime]]'),
(1704, 1, 1, 'catalog_review', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(1705, 1, 1, 'catalog_review', 'entry_text', 'Text:', '[[regtime]]', '[[regtime]]'),
(1706, 1, 1, 'catalog_review', 'entry_good', 'Good', '[[regtime]]', '[[regtime]]'),
(1707, 1, 1, 'catalog_review', 'entry_bad', 'Bad', '[[regtime]]', '[[regtime]]'),
(1708, 1, 1, 'catalog_review', 'error_permission', 'Warning: You do not have permission to modify reviews!', '[[regtime]]', '[[regtime]]'),
(1709, 1, 1, 'catalog_review', 'error_product', 'Product required!', '[[regtime]]', '[[regtime]]'),
(1710, 1, 1, 'catalog_review', 'error_author', 'Author must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(1711, 1, 1, 'catalog_review', 'error_text', 'Review Text must be between 25 and 1000 characters!', '[[regtime]]', '[[regtime]]'),
(1712, 1, 1, 'catalog_review', 'error_rating', 'Review rating required!', '[[regtime]]', '[[regtime]]'),
(1713, 1, 1, 'catalog_review', 'text_select_product', '- Select Product -', '[[regtime]]', '[[regtime]]'),
(1714, 1, 1, 'catalog_review', 'text_select_category', '- Select Category -', '[[regtime]]', '[[regtime]]'),
(1715, 1, 1, 'catalog_review', 'column_verified_purchase', 'Verified purchase', '[[regtime]]', '[[regtime]]'),
(1716, 1, 1, 'catalog_review', 'entry_verified_purchase', 'Verified purchase:', '[[regtime]]', '[[regtime]]'),
(1717, 1, 1, 'common_action_commands', 'text_possible_commands', 'Bellow are possible Commands. You can speak more details after command keyword. Example, "open page messages" or "insert product"', '[[regtime]]', '[[regtime]]'),
(1718, 1, 1, 'common_action_commands', 'text_multiple_result_found', 'Multiple action result found:', '[[regtime]]', '[[regtime]]'),
(1719, 1, 1, 'common_action_commands', 'text_action_confirm', 'Please confirm your request:', '[[regtime]]', '[[regtime]]'),
(1720, 1, 1, 'common_action_commands', 'command_open', 'open, open page, open menu', '[[regtime]]', '[[regtime]]'),
(1721, 1, 1, 'common_action_commands', 'command_find', 'locate, find, search, search for, search 4', '[[regtime]]', '[[regtime]]'),
(1722, 1, 1, 'common_action_commands', 'command_clear_cache', 'clear cache, cache clear, clear all cache', '[[regtime]]', '[[regtime]]'),
(1723, 1, 1, 'common_action_commands', 'command_view_log', 'view log, log view, inspect log, see log, view error log, view errors', '[[regtime]]', '[[regtime]]'),
(1724, 1, 1, 'common_action_commands', 'command_clear_log', 'clear log, log clear, delete log, log delete', '[[regtime]]', '[[regtime]]'),
(1725, 1, 1, 'common_action_commands', 'command_view_order', 'view order, order number, open order, show order, open order number, view order number, show order number, order #', '[[regtime]]', '[[regtime]]'),
(1726, 1, 1, 'common_action_commands', 'command_view_product', 'view product, product number, open product, show product, open product number, view product number, show product number, product #', '[[regtime]]', '[[regtime]]'),
(1727, 1, 1, 'common_action_commands', 'command_create_new', 'insert, create, add, new, insert new, create new, add new', '[[regtime]]', '[[regtime]]'),
(1728, 1, 1, 'common_action_commands', 'category', 'category', '[[regtime]]', '[[regtime]]'),
(1729, 1, 1, 'common_action_commands', 'product', 'product', '[[regtime]]', '[[regtime]]'),
(1730, 1, 1, 'common_action_commands', 'brand', 'brand', '[[regtime]]', '[[regtime]]'),
(1731, 1, 1, 'common_action_commands', 'manufacturer', 'brand', '[[regtime]]', '[[regtime]]'),
(1732, 1, 1, 'common_action_commands', 'review', 'review', '[[regtime]]', '[[regtime]]'),
(1733, 1, 1, 'common_action_commands', 'download', 'download', '[[regtime]]', '[[regtime]]'),
(1734, 1, 1, 'common_action_commands', 'attribute', 'attribute', '[[regtime]]', '[[regtime]]'),
(1735, 1, 1, 'common_action_commands', 'customer', 'customer', '[[regtime]]', '[[regtime]]'),
(1736, 1, 1, 'common_action_commands', 'coupon', 'coupon', '[[regtime]]', '[[regtime]]'),
(1737, 1, 1, 'common_action_commands', 'discount', 'discount', '[[regtime]]', '[[regtime]]'),
(1738, 1, 1, 'common_action_commands', 'block', 'block', '[[regtime]]', '[[regtime]]'),
(1739, 1, 1, 'common_action_commands', 'menu', 'menu', '[[regtime]]', '[[regtime]]'),
(1740, 1, 1, 'common_action_commands', 'content', 'content', '[[regtime]]', '[[regtime]]'),
(1741, 1, 1, 'common_action_commands', 'banner', 'banner', '[[regtime]]', '[[regtime]]'),
(1742, 1, 1, 'common_action_commands', 'page', 'page', '[[regtime]]', '[[regtime]]'),
(1743, 1, 1, 'common_action_commands', 'store', 'store', '[[regtime]]', '[[regtime]]'),
(1744, 1, 1, 'common_action_commands', 'language', 'language', '[[regtime]]', '[[regtime]]'),
(1745, 1, 1, 'common_action_commands', 'currency', 'currency', '[[regtime]]', '[[regtime]]'),
(1746, 1, 1, 'common_action_commands', 'location', 'location', '[[regtime]]', '[[regtime]]'),
(1747, 1, 1, 'common_action_commands', 'tax', 'tax', '[[regtime]]', '[[regtime]]'),
(1748, 1, 1, 'common_ant', 'notification', 'Attention!', '[[regtime]]', '[[regtime]]'),
(1749, 1, 1, 'common_ant', 'warning', 'Warning!', '[[regtime]]', '[[regtime]]'),
(1750, 1, 1, 'common_do_embed', 'text_get_product_embed_code', 'Product Embed Code', '[[regtime]]', '[[regtime]]'),
(1751, 1, 1, 'common_do_embed', 'text_get_category_embed_code', 'Category Embed Code', '[[regtime]]', '[[regtime]]'),
(1752, 1, 1, 'common_do_embed', 'text_get_manufacturer_embed_code', 'Brand Embed Code', '[[regtime]]', '[[regtime]]'),
(1753, 1, 1, 'common_do_embed', 'entry_image', 'Show Image', '[[regtime]]', '[[regtime]]'),
(1754, 1, 1, 'common_do_embed', 'entry_name', 'Show Name', '[[regtime]]', '[[regtime]]'),
(1755, 1, 1, 'common_do_embed', 'entry_price', 'Show Price', '[[regtime]]', '[[regtime]]'),
(1756, 1, 1, 'common_do_embed', 'entry_limit', 'Limit ', '[[regtime]]', '[[regtime]]'),
(1757, 1, 1, 'common_do_embed', 'entry_rating', 'Show Reviews And Rating', '[[regtime]]', '[[regtime]]'),
(1758, 1, 1, 'common_do_embed', 'entry_blurb', 'Show Blurb', '[[regtime]]', '[[regtime]]'),
(1759, 1, 1, 'common_do_embed', 'entry_quantity', 'Show Quantity', '[[regtime]]', '[[regtime]]'),
(1760, 1, 1, 'common_do_embed', 'entry_addtocart', 'Show Button', '[[regtime]]', '[[regtime]]'),
(1761, 1, 1, 'common_do_embed', 'entry_language', 'Select Language', '[[regtime]]', '[[regtime]]'),
(1762, 1, 1, 'common_do_embed', 'entry_currency', 'Select Currency', '[[regtime]]', '[[regtime]]'),
(1763, 1, 1, 'common_do_embed', 'entry_products_count', 'Products Count', '[[regtime]]', '[[regtime]]'),
(1764, 1, 1, 'common_filemanager', 'heading_title', 'Image Manager', '[[regtime]]', '[[regtime]]'),
(1765, 1, 1, 'common_filemanager', 'text_uploaded', 'Success: Your file has been uploaded!', '[[regtime]]', '[[regtime]]'),
(1766, 1, 1, 'common_filemanager', 'text_file_delete', 'File has been deleted!', '[[regtime]]', '[[regtime]]'),
(1767, 1, 1, 'common_filemanager', 'text_create', 'Success: Directory created!', '[[regtime]]', '[[regtime]]'),
(1768, 1, 1, 'common_filemanager', 'text_delete', 'Success: Your file or directory has been deleted!', '[[regtime]]', '[[regtime]]'),
(1769, 1, 1, 'common_filemanager', 'text_move', 'Success: Your file or directory has been moved!', '[[regtime]]', '[[regtime]]'),
(1770, 1, 1, 'common_filemanager', 'text_copy', 'Success: Your file or directory has been copied!', '[[regtime]]', '[[regtime]]'),
(1771, 1, 1, 'common_filemanager', 'text_rename', 'Success: Your file or directory has been renamed!', '[[regtime]]', '[[regtime]]'),
(1772, 1, 1, 'common_filemanager', 'entry_folder', 'New Folder:', '[[regtime]]', '[[regtime]]'),
(1773, 1, 1, 'common_filemanager', 'entry_move', 'Move:', '[[regtime]]', '[[regtime]]'),
(1774, 1, 1, 'common_filemanager', 'entry_copy', 'Name:', '[[regtime]]', '[[regtime]]'),
(1775, 1, 1, 'common_filemanager', 'entry_rename', 'Name:', '[[regtime]]', '[[regtime]]'),
(1776, 1, 1, 'common_filemanager', 'error_select', 'Warning: Please select a directory or file!', '[[regtime]]', '[[regtime]]'),
(1777, 1, 1, 'common_filemanager', 'error_file', 'Warning: Please select a file!', '[[regtime]]', '[[regtime]]'),
(1778, 1, 1, 'common_filemanager', 'error_directory', 'Warning: Please select a directory!', '[[regtime]]', '[[regtime]]'),
(1779, 1, 1, 'common_filemanager', 'error_default', 'Warning: Can not alter your default directory!', '[[regtime]]', '[[regtime]]'),
(1780, 1, 1, 'common_filemanager', 'error_delete', 'Warning: You can not delete this directory!', '[[regtime]]', '[[regtime]]'),
(1781, 1, 1, 'common_filemanager', 'error_filename', 'Warning: Filename must be a between 3 and 255!', '[[regtime]]', '[[regtime]]'),
(1782, 1, 1, 'common_filemanager', 'error_missing', 'Warning: File or directory does not exist!', '[[regtime]]', '[[regtime]]'),
(1783, 1, 1, 'common_filemanager', 'error_exists', 'Warning: A file or directory with the same name already exists!', '[[regtime]]', '[[regtime]]'),
(1784, 1, 1, 'common_filemanager', 'error_name', 'Warning: Please enter a new name!', '[[regtime]]', '[[regtime]]'),
(1785, 1, 1, 'common_filemanager', 'error_move', 'Warning: Move to directory does not exists!', '[[regtime]]', '[[regtime]]'),
(1786, 1, 1, 'common_filemanager', 'error_copy', 'Warning: Can not copy this file or directory!', '[[regtime]]', '[[regtime]]'),
(1787, 1, 1, 'common_filemanager', 'error_rename', 'Warning: Can not rename this directory!', '[[regtime]]', '[[regtime]]'),
(1788, 1, 1, 'common_filemanager', 'error_file_type', 'Warning: Incorrect file type!', '[[regtime]]', '[[regtime]]'),
(1789, 1, 1, 'common_filemanager', 'error_file_size', 'Warning: File to big please keep below 300kb and no more than 1000px height or width!', '[[regtime]]', '[[regtime]]'),
(1790, 1, 1, 'common_filemanager', 'error_uploaded', 'Warning: File could not be uploaded for an unknown reason!', '[[regtime]]', '[[regtime]]'),
(1791, 1, 1, 'common_filemanager', 'error_permission', 'Warning: Permission Denied!', '[[regtime]]', '[[regtime]]'),
(1792, 1, 1, 'common_filemanager', 'button_folder', 'New Folder', '[[regtime]]', '[[regtime]]'),
(1793, 1, 1, 'common_filemanager', 'button_delete', 'Delete', '[[regtime]]', '[[regtime]]'),
(1794, 1, 1, 'common_filemanager', 'button_move', 'Move', '[[regtime]]', '[[regtime]]'),
(1795, 1, 1, 'common_filemanager', 'button_copy', 'Copy', '[[regtime]]', '[[regtime]]'),
(1796, 1, 1, 'common_filemanager', 'button_rename', 'Rename', '[[regtime]]', '[[regtime]]'),
(1797, 1, 1, 'common_filemanager', 'button_upload', 'Upload', '[[regtime]]', '[[regtime]]'),
(1798, 1, 1, 'common_filemanager', 'button_refresh', 'Refresh', '[[regtime]]', '[[regtime]]'),
(1799, 1, 1, 'common_footer', 'text_footer_left', ' AbanteCart is a trademark of Belavier Commerce LLC<br /> Copyright &copy; 2011 - %s All Rights Reserved ', '[[regtime]]', '[[regtime]]'),
(1800, 1, 1, 'common_footer', 'text_footer', '<a href="https://www.abantecart.com" target="_blank">AbanteCart</a> Version ', '[[regtime]]', '[[regtime]]'),
(1801, 1, 1, 'common_forgot_password', 'heading_title', 'Forgot Password?', '[[regtime]]', '[[regtime]]'),
(1802, 1, 1, 'common_forgot_password', 'text_heading', 'Forgot Password?', '[[regtime]]', '[[regtime]]'),
(1803, 1, 1, 'common_forgot_password', 'text_heading_reset', 'Reset Password', '[[regtime]]', '[[regtime]]'),
(1804, 1, 1, 'common_forgot_password', 'text_forgot', 'Please enter your username and email.', '[[regtime]]', '[[regtime]]'),
(1805, 1, 1, 'common_forgot_password', 'text_login', 'back to login page', '[[regtime]]', '[[regtime]]'),
(1806, 1, 1, 'common_forgot_password', 'text_instructions', 'Email with instructions on how to reset password sent to your email', '[[regtime]]', '[[regtime]]'),
(1807, 1, 1, 'common_forgot_password', 'text_enter_new_password', 'Enter new password and confirmation below', '[[regtime]]', '[[regtime]]'),
(1808, 1, 1, 'common_forgot_password', 'text_instructions_reset', 'Your password has been reset. Now you can login with your new password ', '[[regtime]]', '[[regtime]]'),
(1809, 1, 1, 'common_forgot_password', 'reset_email_subject', '%s - Password Reset Request ', '[[regtime]]', '[[regtime]]'),
(1810, 1, 1, 'common_forgot_password', 'reset_email_body_html', 'Password reset was requested for user with this email. Please click on link below to proceed.\n<br/>\n<br/><a href="%s">%s</a>\n<br/>\n<br/>Link is valid for one day.\n<br/>\n<br/>If you do not send request - just ignore this email.', '[[regtime]]', '[[regtime]]'),
(1811, 1, 1, 'common_forgot_password', 'reset_email_body_text', 'Password reset was requested for user with this email. Please click on link below to proceed.\n\n<a href="%s">%s</a>\n\nPlease note: Link is valid for one day.\n\nIf you do not send request - just ignore this email.', '[[regtime]]', '[[regtime]]'),
(1812, 1, 1, 'common_forgot_password', 'new_password_email_body', 'Your administration password was successfully reset!', '[[regtime]]', '[[regtime]]'),
(1813, 1, 1, 'common_forgot_password', 'entry_username', 'Username:', '[[regtime]]', '[[regtime]]'),
(1814, 1, 1, 'common_forgot_password', 'entry_email', 'Email:', '[[regtime]]', '[[regtime]]'),
(1815, 1, 1, 'common_forgot_password', 'entry_captcha', 'Enter the code:', '[[regtime]]', '[[regtime]]'),
(1816, 1, 1, 'common_forgot_password', 'button_reset_password', 'Reset Password', '[[regtime]]', '[[regtime]]'),
(1817, 1, 1, 'common_forgot_password', 'error_match', 'No match for Username and Email.', '[[regtime]]', '[[regtime]]'),
(1818, 1, 1, 'common_forgot_password', 'error_hash', 'Reset Password Hash is not valid .', '[[regtime]]', '[[regtime]]'),
(1819, 1, 1, 'common_forgot_password', 'error_username', 'Username cannot be empty', '[[regtime]]', '[[regtime]]'),
(1820, 1, 1, 'common_forgot_password', 'error_email', 'E-Mail Address does not appear to be valid!', '[[regtime]]', '[[regtime]]'),
(1821, 1, 1, 'common_forgot_password', 'error_captcha', 'Human verification Failed!', '[[regtime]]', '[[regtime]]'),
(1822, 1, 1, 'common_header', 'heading_title', 'Administration', '[[regtime]]', '[[regtime]]'),
(1823, 1, 1, 'common_header', 'text_backup', 'Backup / Restore', '[[regtime]]', '[[regtime]]'),
(1824, 1, 1, 'common_header', 'text_welcome', 'Welcome, <b>%s</b>', '[[regtime]]', '[[regtime]]'),
(1825, 1, 1, 'common_header', 'text_last_login', 'Last login: %s', '[[regtime]]', '[[regtime]]'),
(1826, 1, 1, 'common_header', 'text_edit_details', 'Edit Profile Details', '[[regtime]]', '[[regtime]]'),
(1827, 1, 1, 'common_header', 'text_edit_notifications', 'Edit Notification Settings', '[[regtime]]', '[[regtime]]'),
(1828, 1, 1, 'common_header', 'text_catalog', 'Catalog', '[[regtime]]', '[[regtime]]'),
(1829, 1, 1, 'common_header', 'text_category', 'Categories', '[[regtime]]', '[[regtime]]'),
(1830, 1, 1, 'common_header', 'text_confirm', 'Confirm?', '[[regtime]]', '[[regtime]]'),
(1831, 1, 1, 'common_header', 'text_country', 'Countries', '[[regtime]]', '[[regtime]]'),
(1832, 1, 1, 'common_header', 'text_coupon', 'Coupons', '[[regtime]]', '[[regtime]]'),
(1833, 1, 1, 'common_header', 'text_discount', 'Discounts', '[[regtime]]', '[[regtime]]'),
(1834, 1, 1, 'common_header', 'text_currency', 'Currencies', '[[regtime]]', '[[regtime]]'),
(1835, 1, 1, 'common_header', 'text_customer', 'Customers', '[[regtime]]', '[[regtime]]'),
(1836, 1, 1, 'common_header', 'text_customer_group', 'Customer Groups', '[[regtime]]', '[[regtime]]'),
(1837, 1, 1, 'common_header', 'text_dashboard', 'Dashboard', '[[regtime]]', '[[regtime]]'),
(1838, 1, 1, 'common_header', 'text_download', 'Downloads', '[[regtime]]', '[[regtime]]'),
(1839, 1, 1, 'common_header', 'text_error_log', 'Error Logs', '[[regtime]]', '[[regtime]]'),
(1840, 1, 1, 'common_header', 'text_extension', 'Extensions', '[[regtime]]', '[[regtime]]'),
(1841, 1, 1, 'common_header', 'text_extensions_short', 'Extensions', '[[regtime]]', '[[regtime]]'),
(1842, 1, 1, 'common_header', 'text_front', 'Storefront', '[[regtime]]', '[[regtime]]'),
(1843, 1, 1, 'common_header', 'text_location', 'Locations', '[[regtime]]', '[[regtime]]'),
(1844, 1, 1, 'common_header', 'text_help', 'Help', '[[regtime]]', '[[regtime]]'),
(1845, 1, 1, 'common_header', 'text_information', 'Information', '[[regtime]]', '[[regtime]]'),
(1846, 1, 1, 'common_header', 'text_language', 'Languages', '[[regtime]]', '[[regtime]]'),
(1847, 1, 1, 'common_header', 'text_language_definitions', 'Language Definitions', '[[regtime]]', '[[regtime]]'),
(1848, 1, 1, 'common_header', 'text_localisation', 'Localization', '[[regtime]]', '[[regtime]]'),
(1849, 1, 1, 'common_header', 'text_logged', 'You are logged in as <span>%s</span>', '[[regtime]]', '[[regtime]]'),
(1850, 1, 1, 'common_header', 'text_logout', 'Logout', '[[regtime]]', '[[regtime]]'),
(1851, 1, 1, 'common_header', 'text_contact', 'Send Mail', '[[regtime]]', '[[regtime]]'),
(1852, 1, 1, 'common_header', 'text_manufacturer', 'Brands', '[[regtime]]', '[[regtime]]'),
(1853, 1, 1, 'common_header', 'text_order', 'Orders', '[[regtime]]', '[[regtime]]'),
(1854, 1, 1, 'common_header', 'text_order_status', 'Order Statuses', '[[regtime]]', '[[regtime]]'),
(1855, 1, 1, 'common_header', 'text_abantecart', 'Homepage', '[[regtime]]', '[[regtime]]'),
(1856, 1, 1, 'common_header', 'text_payment', 'Payments', '[[regtime]]', '[[regtime]]'),
(1857, 1, 1, 'common_header', 'text_product', 'Products', '[[regtime]]', '[[regtime]]'),
(1858, 1, 1, 'common_header', 'text_reports', 'Reports', '[[regtime]]', '[[regtime]]'),
(1859, 1, 1, 'common_header', 'text_online', 'Online', '[[regtime]]', '[[regtime]]'),
(1860, 1, 1, 'common_header', 'text_transactions', 'Balance History', '[[regtime]]', '[[regtime]]'),
(1861, 1, 1, 'common_header', 'text_balance_history', 'Balance History', '[[regtime]]', '[[regtime]]'),
(1862, 1, 1, 'common_header', 'text_tax', 'Tax', '[[regtime]]', '[[regtime]]'),
(1863, 1, 1, 'common_header', 'text_report_purchased', 'Products Purchased', '[[regtime]]', '[[regtime]]'),
(1864, 1, 1, 'common_header', 'text_report_sale', 'Sales', '[[regtime]]', '[[regtime]]'),
(1865, 1, 1, 'common_header', 'text_analytics', 'Analytics & Insights', '[[regtime]]', '[[regtime]]'),
(1866, 1, 1, 'common_header', 'text_report_viewed', 'Products Viewed', '[[regtime]]', '[[regtime]]'),
(1867, 1, 1, 'common_header', 'text_review', 'Reviews', '[[regtime]]', '[[regtime]]'),
(1868, 1, 1, 'common_header', 'text_sale', 'Sales', '[[regtime]]', '[[regtime]]'),
(1869, 1, 1, 'common_header', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(1870, 1, 1, 'common_header', 'text_setting', 'Settings', '[[regtime]]', '[[regtime]]'),
(1871, 1, 1, 'common_header', 'text_stock_status', 'Stock Statuses', '[[regtime]]', '[[regtime]]'),
(1872, 1, 1, 'common_header', 'text_support', 'Support Forum', '[[regtime]]', '[[regtime]]'),
(1873, 1, 1, 'common_header', 'text_system', 'System', '[[regtime]]', '[[regtime]]'),
(1874, 1, 1, 'common_header', 'text_tax_class', 'Tax Classes', '[[regtime]]', '[[regtime]]'),
(1875, 1, 1, 'common_header', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(1876, 1, 1, 'common_header', 'text_user', 'Users', '[[regtime]]', '[[regtime]]'),
(1877, 1, 1, 'common_header', 'text_documentation', 'Documentation', '[[regtime]]', '[[regtime]]'),
(1878, 1, 1, 'common_header', 'text_users', 'Users', '[[regtime]]', '[[regtime]]'),
(1879, 1, 1, 'common_header', 'text_user_group', 'User Groups', '[[regtime]]', '[[regtime]]'),
(1880, 1, 1, 'common_header', 'text_weight_class', 'Weight Classes', '[[regtime]]', '[[regtime]]'),
(1881, 1, 1, 'common_header', 'text_length_class', 'Length Classes', '[[regtime]]', '[[regtime]]'),
(1882, 1, 1, 'common_header', 'text_zone', 'Zones', '[[regtime]]', '[[regtime]]'),
(1883, 1, 1, 'common_header', 'text_extensions', 'All Extensions', '[[regtime]]', '[[regtime]]'),
(1884, 1, 1, 'common_header', 'text_add_extension', ' Install Extension ', '[[regtime]]', '[[regtime]]'),
(1885, 1, 1, 'common_header', 'text_extensions_store', 'Get Extensions', '[[regtime]]', '[[regtime]]'),
(1886, 1, 1, 'common_header', 'text_migrate', 'Migration Tool', '[[regtime]]', '[[regtime]]'),
(1887, 1, 1, 'common_header', 'text_updater', 'Updater', '[[regtime]]', '[[regtime]]'),
(1888, 1, 1, 'common_header', 'text_templates', 'Templates', '[[regtime]]', '[[regtime]]'),
(1889, 1, 1, 'common_header', 'text_layout', 'Layouts', '[[regtime]]', '[[regtime]]'),
(1890, 1, 1, 'common_header', 'text_blocks', 'Blocks', '[[regtime]]', '[[regtime]]'),
(1891, 1, 1, 'common_header', 'text_menu', 'Menu', '[[regtime]]', '[[regtime]]'),
(1892, 1, 1, 'common_header', 'text_cache', 'Clear data', '[[regtime]]', '[[regtime]]'),
(1893, 1, 1, 'common_header', 'text_messages', 'Messages', '[[regtime]]', '[[regtime]]'),
(1894, 1, 1, 'common_header', 'text_content', 'Content', '[[regtime]]', '[[regtime]]'),
(1895, 1, 1, 'common_header', 'text_datasets_manager', 'Datasets', '[[regtime]]', '[[regtime]]'),
(1896, 1, 1, 'common_header', 'text_install_upgrade_history', ' Install/Upgrade History ', '[[regtime]]', '[[regtime]]'),
(1897, 1, 1, 'common_header', 'text_attribute', 'Global Attributes', '[[regtime]]', '[[regtime]]'),
(1898, 1, 1, 'common_header', 'text_attribute_groups', 'Global Attributes Groups', '[[regtime]]', '[[regtime]]'),
(1899, 1, 1, 'common_header', 'text_import_export', 'Import / Export', '[[regtime]]', '[[regtime]]'),
(1900, 1, 1, 'common_header', 'text_data', 'Data', '[[regtime]]', '[[regtime]]'),
(1901, 1, 1, 'common_header', 'text_logs', 'Logs', '[[regtime]]', '[[regtime]]'),
(1902, 1, 1, 'common_header', 'text_quick_edit_form', 'Quick Edit Form', '[[regtime]]', '[[regtime]]'),
(1903, 1, 1, 'common_header', 'text_all_matches', 'all matches', '[[regtime]]', '[[regtime]]'),
(1904, 1, 1, 'common_header', 'text_file_uploads', 'File Uploads', '[[regtime]]', '[[regtime]]'),
(1905, 1, 1, 'common_header', 'text_all_settings', 'All Settings', '[[regtime]]', '[[regtime]]'),
(1906, 1, 1, 'common_header', 'text_settings_details', 'Store Details', '[[regtime]]', '[[regtime]]'),
(1907, 1, 1, 'common_header', 'text_settings_general', 'General', '[[regtime]]', '[[regtime]]'),
(1908, 1, 1, 'common_header', 'text_settings_checkout', 'Checkout', '[[regtime]]', '[[regtime]]'),
(1909, 1, 1, 'common_header', 'text_settings_appearance', 'Appearance', '[[regtime]]', '[[regtime]]'),
(1910, 1, 1, 'common_header', 'text_settings_mail', 'Mail', '[[regtime]]', '[[regtime]]'),
(1911, 1, 1, 'common_header', 'text_settings_im', 'IM', '[[regtime]]', '[[regtime]]'),
(1912, 1, 1, 'common_header', 'text_settings_api', 'API', '[[regtime]]', '[[regtime]]'),
(1913, 1, 1, 'common_header', 'text_settings_system', 'System', '[[regtime]]', '[[regtime]]'),
(1914, 1, 1, 'common_header', 'text_settings_newstore', 'Create New Store', '[[regtime]]', '[[regtime]]'),
(1915, 1, 1, 'common_header', 'text_voice_command_prompt', 'Voice Command Prompt.', '[[regtime]]', '[[regtime]]'),
(1916, 1, 1, 'common_header', 'text_voice_select_dialect', 'Select your dialect', '[[regtime]]', '[[regtime]]'),
(1917, 1, 1, 'common_header', 'text_voice_confirm_action', 'Confirm this action or cancel', '[[regtime]]', '[[regtime]]'),
(1918, 1, 1, 'common_header', 'text_voice_speak_now', 'Speak now.', '[[regtime]]', '[[regtime]]'),
(1919, 1, 1, 'common_header', 'text_voice_no_speach_detected', 'No speech was detected. You may need to adjust your <a href="//support.google.com/chrome/bin/answer.py?hl=en&amp;answer=1407892">microphone settings</a>.', '[[regtime]]', '[[regtime]]'),
(1920, 1, 1, 'common_header', 'text_voice_no_mic_detected', 'No microphone was found. Ensure that a microphone is installed and that <a href="//support.google.com/chrome/bin/answer.py?hl=en&amp;answer=1407892"> microphone settings</a> are configured correctly.', '[[regtime]]', '[[regtime]]'),
(1921, 1, 1, 'common_header', 'text_voice_click_allow', 'Click the "Allow" button above to enable your microphone.', '[[regtime]]', '[[regtime]]'),
(1922, 1, 1, 'common_header', 'text_voice_mic_denied', 'Permission to use microphone was denied.', '[[regtime]]', '[[regtime]]'),
(1923, 1, 1, 'common_header', 'text_voice_mic_permission', 'Permission to use microphone is blocked. To change, go to browser <a href="chrome://settings/contentExceptions#media-stream">media settings</a>', '[[regtime]]', '[[regtime]]'),
(1924, 1, 1, 'common_header', 'text_voice_not_supported', 'Voice control is not supported by this browser. <a href="//www.google.com/chrome" target="_blank">Chrome</a> version 25 or later required.', '[[regtime]]', '[[regtime]]'),
(1925, 1, 1, 'common_header', 'text_tasks', 'Scheduled Tasks', '[[regtime]]', '[[regtime]]'),
(1926, 1, 1, 'common_header', 'text_read_all_messages', 'Read All Messages', '[[regtime]]', '[[regtime]]'),
(1927, 1, 1, 'common_header', 'text_short_stats', 'Quick Stats', '[[regtime]]', '[[regtime]]'),
(1928, 1, 1, 'common_header', 'text_online_now', 'Online Customers', '[[regtime]]', '[[regtime]]'),
(1929, 1, 1, 'common_header', 'text_online_new', 'New', '[[regtime]]', '[[regtime]]'),
(1930, 1, 1, 'common_header', 'text_online_registered', 'Logged In', '[[regtime]]', '[[regtime]]'),
(1931, 1, 1, 'common_header', 'text_today_orders', 'New Orders Today', '[[regtime]]', '[[regtime]]'),
(1932, 1, 1, 'common_header', 'text_today_sales', 'Total Sales Today', '[[regtime]]', '[[regtime]]'),
(1933, 1, 1, 'common_header', 'text_today_customers', 'New Customers Today', '[[regtime]]', '[[regtime]]'),
(1934, 1, 1, 'common_header', 'text_today_reviews', 'New Reviews Today', '[[regtime]]', '[[regtime]]'),
(1935, 1, 1, 'common_header', 'text_rl_manager', 'Media Manager', '[[regtime]]', '[[regtime]]'),
(1936, 1, 1, 'common_header', 'text_server_time', 'Server Time', '[[regtime]]', '[[regtime]]'),
(1937, 1, 1, 'common_header', 'text_taxes', 'Taxes', '[[regtime]]', '[[regtime]]'),
(1938, 1, 1, 'common_header', 'email_templates', 'Email Templates', '[[regtime]]', '[[regtime]]'),
(1939, 1, 1, 'common_header', 'text_collection', 'Collections', '[[regtime]]', '[[regtime]]'),
(1940, 1, 1, 'common_home', 'heading_title', 'Dashboard', '[[regtime]]', '[[regtime]]'),
(1941, 1, 1, 'common_home', 'text_overview', 'Overview', '[[regtime]]', '[[regtime]]'),
(1942, 1, 1, 'common_home', 'text_statistics', 'Statistics', '[[regtime]]', '[[regtime]]'),
(1943, 1, 1, 'common_home', 'text_latest_10_orders', 'Latest 10 Orders', '[[regtime]]', '[[regtime]]'),
(1944, 1, 1, 'common_home', 'text_total_sale', 'Total Sales:', '[[regtime]]', '[[regtime]]'),
(1945, 1, 1, 'common_home', 'text_total_sale_year', 'Total Sales This Year:', '[[regtime]]', '[[regtime]]'),
(1946, 1, 1, 'common_home', 'text_total_order', 'Total Orders:', '[[regtime]]', '[[regtime]]'),
(1947, 1, 1, 'common_home', 'text_total_customer', 'No. Of Customers:', '[[regtime]]', '[[regtime]]'),
(1948, 1, 1, 'common_home', 'text_total_customer_approval', 'Customers Waiting Approval:', '[[regtime]]', '[[regtime]]'),
(1949, 1, 1, 'common_home', 'text_total_product', 'No. Products:', '[[regtime]]', '[[regtime]]'),
(1950, 1, 1, 'common_home', 'text_total_review', 'No. Of Reviews:', '[[regtime]]', '[[regtime]]'),
(1951, 1, 1, 'common_home', 'text_total_review_approval', 'Reviews Waiting Approval:', '[[regtime]]', '[[regtime]]'),
(1952, 1, 1, 'common_home', 'text_day', 'Today', '[[regtime]]', '[[regtime]]'),
(1953, 1, 1, 'common_home', 'text_week', 'This Week', '[[regtime]]', '[[regtime]]'),
(1954, 1, 1, 'common_home', 'text_month', 'This Month', '[[regtime]]', '[[regtime]]'),
(1955, 1, 1, 'common_home', 'text_year', 'This Year', '[[regtime]]', '[[regtime]]'),
(1956, 1, 1, 'common_home', 'text_order', 'Total Orders', '[[regtime]]', '[[regtime]]'),
(1957, 1, 1, 'common_home', 'text_order_short', 'Total Orders', '[[regtime]]', '[[regtime]]'),
(1958, 1, 1, 'common_home', 'text_customer', 'Total Customers', '[[regtime]]', '[[regtime]]'),
(1959, 1, 1, 'common_home', 'column_order', 'Order ID', '[[regtime]]', '[[regtime]]'),
(1960, 1, 1, 'common_home', 'column_name', 'Customer Name', '[[regtime]]', '[[regtime]]'),
(1961, 1, 1, 'common_home', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(1962, 1, 1, 'common_home', 'column_date_added', 'Date Added', '[[regtime]]', '[[regtime]]'),
(1963, 1, 1, 'common_home', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(1964, 1, 1, 'common_home', 'column_firstname', 'First Name', '[[regtime]]', '[[regtime]]'),
(1965, 1, 1, 'common_home', 'column_lastname', 'Last Name', '[[regtime]]', '[[regtime]]'),
(1966, 1, 1, 'common_home', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(1967, 1, 1, 'common_home', 'entry_range', 'Select Range:', '[[regtime]]', '[[regtime]]'),
(1968, 1, 1, 'common_home', 'orders_text_all', 'All Orders', '[[regtime]]', '[[regtime]]'),
(1969, 1, 1, 'common_home', 'text_customer_all', 'All Customers', '[[regtime]]', '[[regtime]]'),
(1970, 1, 1, 'common_home', 'text_latest_10_customers', 'Latest Registrations', '[[regtime]]', '[[regtime]]'),
(1971, 1, 1, 'common_home', 'column_email', 'Email', '[[regtime]]', '[[regtime]]'),
(1972, 1, 1, 'common_im', 'im_text_notification', 'Notifications', '[[regtime]]', '[[regtime]]'),
(1973, 1, 1, 'common_im', 'im_sendpoint_name_order_update', 'Order Updates', '[[regtime]]', '[[regtime]]'),
(1974, 1, 1, 'common_im', 'im_order_update_text_to_customer', 'Your order <a href="%s">#%s</a> has been updated. For more details, login to %s account.', '[[regtime]]', '[[regtime]]'),
(1975, 1, 1, 'common_im', 'im_order_update_text_to_guest', 'Your order <a href="%s">#%s</a> has been updated. For more details, please visit order page %s.', '[[regtime]]', '[[regtime]]'),
(1976, 1, 1, 'common_im', 'im_sendpoint_name_new_order', 'New Orders', '[[regtime]]', '[[regtime]]'),
(1977, 1, 1, 'common_im', 'im_new_order_text_to_admin', 'New Order <a href="#admin#rt=sale/order/details&order_id=%s">#%s</a> has been created!', '[[regtime]]', '[[regtime]]'),
(1978, 1, 1, 'common_im', 'im_sendpoint_name_new_customer', 'Customer Registrations', '[[regtime]]', '[[regtime]]'),
(1979, 1, 1, 'common_im', 'im_new_customer_text_to_admin', ' New Customer #%s has been registered!', '[[regtime]]', '[[regtime]]'),
(1980, 1, 1, 'common_im', 'im_sendpoint_name_account_update', 'Administrator User Account Updates', '[[regtime]]', '[[regtime]]'),
(1981, 1, 1, 'common_im', 'im_account_update_text_to_admin', 'Your administrator user account details have been changed.', '[[regtime]]', '[[regtime]]'),
(1982, 1, 1, 'common_im', 'im_customer_account_update_text_to_admin', ' New Customer #%s has been updated!', '[[regtime]]', '[[regtime]]'),
(1983, 1, 1, 'common_im', 'im_sendpoint_name_customer_contact', 'Customer Enquiries', '[[regtime]]', '[[regtime]]'),
(1984, 1, 1, 'common_im', 'im_sendpoint_name_product_out_of_stock', 'Products Out of Stock', '[[regtime]]', '[[regtime]]'),
(1985, 1, 1, 'common_im', 'im_sendpoint_name_product_review', 'New Product Reviews', '[[regtime]]', '[[regtime]]'),
(1986, 1, 1, 'common_im', 'im_sendpoint_name_newsletter', ' Newsletters ', '[[regtime]]', '[[regtime]]'),
(1987, 1, 1, 'common_im', 'im_sendpoint_name_system_messages', ' System Messages ', '[[regtime]]', '[[regtime]]'),
(1988, 1, 1, 'common_im', 'im_customer_account_update_text_to_customer', 'New transaction has been posted to your %s account in the amount of %s. For more details, login to %s account.', '[[regtime]]', '[[regtime]]'),
(1989, 1, 1, 'common_im', 'text_notification_for', 'Notifications for user %s', '[[regtime]]', '[[regtime]]'),
(1990, 1, 1, 'common_im', 'error_unknown_sendpoint', 'Sendpoint %s does not found in sendpoints list!', '[[regtime]]', '[[regtime]]'),
(1991, 1, 1, 'common_im', 'text_settings_success_saved', 'Notification settings saved successfully!', '[[regtime]]', '[[regtime]]'),
(1992, 1, 1, 'common_im', 'im_error_mail_address', 'Email address %s looks like invalid!', '[[regtime]]', '[[regtime]]'),
(1993, 1, 1, 'common_im', 'im_threshold', 'Minimum stock level threshold', '[[regtime]]', '[[regtime]]'),
(1994, 1, 1, 'common_login', 'heading_title', 'Administration', '[[regtime]]', '[[regtime]]'),
(1995, 1, 1, 'common_login', 'text_heading', 'Administration', '[[regtime]]', '[[regtime]]'),
(1996, 1, 1, 'common_login', 'text_login', 'Please enter your login details.', '[[regtime]]', '[[regtime]]'),
(1997, 1, 1, 'common_login', 'entry_username', 'Username:', '[[regtime]]', '[[regtime]]'),
(1998, 1, 1, 'common_login', 'entry_password', 'Password:', '[[regtime]]', '[[regtime]]'),
(1999, 1, 1, 'common_login', 'entry_forgot_password', 'Forgot Password?', '[[regtime]]', '[[regtime]]'),
(2000, 1, 1, 'common_login', 'warning_capslock', 'CapsLock is On!', '[[regtime]]', '[[regtime]]'),
(2001, 1, 1, 'common_login', 'button_login', 'Login', '[[regtime]]', '[[regtime]]'),
(2002, 1, 1, 'common_login', 'error_login', 'No match for Username and/or Password.', '[[regtime]]', '[[regtime]]'),
(2003, 1, 1, 'common_login', 'error_token', 'Invalid token session. Please login again.', '[[regtime]]', '[[regtime]]'),
(2004, 1, 1, 'common_login', 'error_login_message', 'Failed login to admin attempt from IP:', '[[regtime]]', '[[regtime]]'),
(2005, 1, 1, 'common_login', 'error_login_message_text', 'Given user login: ', '[[regtime]]', '[[regtime]]'),
(2006, 1, 1, 'common_login', 'error_login_secure', 'You are trying to login in non-secure unsafe mode! Please switch to secure <a href="%s">HTTPS</a> to proceed ', '[[regtime]]', '[[regtime]]'),
(2007, 1, 1, 'common_quick_start', 'text_quick_start', 'Quick Start Wizard', '[[regtime]]', '[[regtime]]'),
(2008, 1, 1, 'common_quick_start', 'text_quick_start_note', '    	Welcome to AbanteCart administration.<br />\n    	This is a wizard to help you quickly set up your shopping cart with most common settings.\n		<br />\n    ', '[[regtime]]', '[[regtime]]'),
(2009, 1, 1, 'common_quick_start', 'text_quick_start_general', '    	Below are most common general settings. \n    	More settings are available <a href="%s" target="_new_admin"><i class="fa fa-link fa-fw"></i></a>\n    ', '[[regtime]]', '[[regtime]]'),
(2010, 1, 1, 'common_quick_start', 'text_quick_start_details', '    	Below are most common settings about your store. \n    	More settings are available <a href="%s" target="_new_admin"><i class="fa fa-link fa-fw"></i></a>\n    ', '[[regtime]]', '[[regtime]]'),
(2011, 1, 1, 'common_quick_start', 'text_quick_start_checkout', '    	Below are most common settings for checkout process. \n    	More settings are available <a href="%s" target="_new_admin"><i class="fa fa-link fa-fw"></i></a>\n    ', '[[regtime]]', '[[regtime]]'),
(2012, 1, 1, 'common_quick_start', 'text_quick_start_appearance', '    	Below are most common settings for storefront appearance. \n    	More settings are available <a href="%s" target="_new_admin"><i class="fa fa-link fa-fw"></i></a>\n    ', '[[regtime]]', '[[regtime]]'),
(2013, 1, 1, 'common_quick_start', 'text_quick_start_mail', '    	Below are most common settings to enable email. If you use external email server (google, etc) to send emails, you need to use SMTP option. For emails to be sent from this server use Mail option. \n    	More settings are available <a href="%s" target="_new_admin"><i class="fa fa-link fa-fw"></i></a>\n    ', '[[regtime]]', '[[regtime]]'),
(2014, 1, 1, 'common_quick_start', 'text_quick_start_last', '    	Bellow you can select desired payments and shipping methods, additional languages and many other features to extend your eCommerce functionality.\n    	Remember to check a selection of extensions on <a href="#admin#rt=extension/extensions_store" target="_extension">AbanteCart marketplace</a> offered by community of professional developers.\n    ', '[[regtime]]', '[[regtime]]'),
(2015, 1, 1, 'common_quick_start', 'text_quick_start_last_footer', '    	You have completed quick starter wizard. <br /><br /> \n    	You can locate all the settings <a href="%s">this link <i class="fa fa-link fa-fw"></i></a>\n    ', '[[regtime]]', '[[regtime]]'),
(2016, 1, 1, 'common_quick_start', 'payments_selection', '    <div class="info alert alert-info">\n    <i class="fa fa-money fa-fw"></i> Select your payment methods.\n    </div>\n    <div class="row">\n	    <div class="col-sm-3 h5 center">\n	        <a href="#admin#rt=extension/extensions/install&extension=stripe" target="_extension">\n	        <img style="width: 94px; height: 94px;" src="extensions/stripe/image/icon.png"><br><p class="mt10">Stripe</p></a>\n	    </div>\n	    <div class="col-sm-3 h5 center">\n	        <a href="#admin#rt=extension/extensions/install&extension=sola" target="_extension">\n	        <img style="height: 94px;" src="extensions/sola/image/icon.webp"><br><p class="mt10">Sola</p></a>\n	    </div>\n	    <div class="col-sm-3 h5 center">\n	        <a href="#admin#rt=extension/extensions/install&extension=paypal_commerce" target="_extension">\n	        <img style="width: 94px; height: 94px;" src="extensions/paypal_commerce/image/icon.png"><br><p class="mt10">Paypal Commerce</p></a>\n	    </div>\n	    <div class="col-sm-3 h5 center">\n	        <a style="margin-top: 36px; display: block;" href="#admin#rt=extension/extensions/payment" target="_extension">\n	        <img src="admin/view/default/image/default_extension.png"><br><p class="mt10">More Payments</p></a>\n	    </div>\n    </div>\n    ', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(2017, 1, 1, 'common_quick_start', 'shipping_selection', '    <div class="info alert alert-info">\n    <i class="fa fa-truck fa-fw"></i> Select your shipping methods.\n    </div>\n    <div class="row">\n	    <div class="col-sm-3 h5 center">\n	        <a href="#admin#rt=extension/extensions/install&extension=default_free_shipping" target="_extension">\n	        <img style="height: 94px;" src="extensions/default_free_shipping/image/icon.png"><br><p class="mt10">Free shipping</p></a>\n	    </div>\n	    <div class="col-sm-3 h5 center">\n	        <a href="#admin#rt=extension/extensions/install&extension=default_fedex" target="_extension">\n	        <img style="height: 94px;" src="extensions/default_fedex/image/icon.png"><br><p class="mt10">Fedex</p></a>\n	    </div>\n	    <div class="col-sm-3 h5 center">\n	        <a href="#admin#rt=extension/extensions/install&extension=default_local_delivery" target="_extension">\n	        <img style="height: 94px;" src="extensions/default_local_delivery/image/icon.png"><br><p class="mt10">Local Delivery</p></a>\n	    </div>\n	    <div class="col-sm-3 h5 center">\n	        <a style="margin-top: 36px; display: block;" href="#admin#rt=extension/extensions/shipping" target="_extension">\n	        <img src="admin/view/default/image/default_extension.png"><br><p class="mt10">More Shippings</p></a>\n	    </div>\n    </div>\n    ', '[[regtime]]', '[[regtime]]'),
(2018, 1, 1, 'common_quick_start', 'language_selection', '    <div class="info alert alert-info">\n    <i class="fa fa-language fa-fw"></i> Select additional languages.\n    </div>\n    <div class="row">\n	    <div class="col-sm-12 h5 center">\n	        %s\n	    </div>\n    </div>\n    ', '[[regtime]]', '[[regtime]]'),
(2019, 1, 1, 'common_quick_start', 'more_extensions', '    <div class="info alert alert-info">\n    <i class="fa fa-puzzle-piece fa-fw"></i> More extensions on AbanteCart marketplace.\n    </div>\n    <div class="row center">\n		<div class="btn-group center">\n		    <a class="btn btn-primary" href="#admin#rt=extension/extensions_store" target="_extension">\n		    	<i class="fa fa-cloud-download fa-fw"></i> Extensions Marketplace\n		    </a>\n		</div>\n    </div>\n    ', '[[regtime]]', '[[regtime]]'),
(2020, 1, 1, 'common_resource_library', 'heading_title', 'Resource Library', '[[regtime]]', '[[regtime]]'),
(2021, 1, 1, 'common_resource_library', 'view_title', 'View Object Resources', '[[regtime]]', '[[regtime]]'),
(2022, 1, 1, 'common_resource_library', 'confirm_title', 'Confirm resource(s) delete', '[[regtime]]', '[[regtime]]'),
(2023, 1, 1, 'common_resource_library', 'text_confirm_delete', 'Some resources might be included in the text. We can not check this automatically.  Delete?', '[[regtime]]', '[[regtime]]'),
(2024, 1, 1, 'common_resource_library', 'text_cant_delete_title', 'Resource(s) delete', '[[regtime]]', '[[regtime]]'),
(2025, 1, 1, 'common_resource_library', 'text_cant_delete', 'Cant delete resource(s) because one or more resources is linked to object', '[[regtime]]', '[[regtime]]'),
(2026, 1, 1, 'common_resource_library', 'text_edit_resource', 'Edit Resource', '[[regtime]]', '[[regtime]]'),
(2027, 1, 1, 'common_resource_library', 'text_resource_details', 'Resource Details', '[[regtime]]', '[[regtime]]'),
(2028, 1, 1, 'common_resource_library', 'text_mapped_to', 'Linked To', '[[regtime]]', '[[regtime]]'),
(2029, 1, 1, 'common_resource_library', 'text_products', 'Products', '[[regtime]]', '[[regtime]]'),
(2030, 1, 1, 'common_resource_library', 'text_add_file', 'Add Resource File', '[[regtime]]', '[[regtime]]'),
(2031, 1, 1, 'common_resource_library', 'text_add_code', 'Add Resource HTML', '[[regtime]]', '[[regtime]]'),
(2032, 1, 1, 'common_resource_library', 'text_add_files', 'Add files...', '[[regtime]]', '[[regtime]]'),
(2033, 1, 1, 'common_resource_library', 'text_upload_files', 'Upload files', '[[regtime]]', '[[regtime]]'),
(2034, 1, 1, 'common_resource_library', 'text_drag', 'or Drag them here to start upload', '[[regtime]]', '[[regtime]]'),
(2035, 1, 1, 'common_resource_library', 'text_start_upload', 'Start upload', '[[regtime]]', '[[regtime]]'),
(2036, 1, 1, 'common_resource_library', 'text_cancel_upload', 'Cancel upload', '[[regtime]]', '[[regtime]]'),
(2037, 1, 1, 'common_resource_library', 'text_start', 'Start', '[[regtime]]', '[[regtime]]'),
(2038, 1, 1, 'common_resource_library', 'text_cancel', 'Cancel', '[[regtime]]', '[[regtime]]'),
(2039, 1, 1, 'common_resource_library', 'text_save_sort_order', 'Save Sort Order', '[[regtime]]', '[[regtime]]'),
(2040, 1, 1, 'common_resource_library', 'text_error', 'Error', '[[regtime]]', '[[regtime]]'),
(2041, 1, 1, 'common_resource_library', 'text_delete_files', 'Delete files', '[[regtime]]', '[[regtime]]'),
(2042, 1, 1, 'common_resource_library', 'text_search', 'search', '[[regtime]]', '[[regtime]]'),
(2043, 1, 1, 'common_resource_library', 'text_type', 'Type', '[[regtime]]', '[[regtime]]'),
(2044, 1, 1, 'common_resource_library', 'text_resource_code', 'Resource HTML', '[[regtime]]', '[[regtime]]'),
(2045, 1, 1, 'common_resource_library', 'text_name', 'Name', '[[regtime]]', '[[regtime]]'),
(2046, 1, 1, 'common_resource_library', 'text_title', 'Title', '[[regtime]]', '[[regtime]]'),
(2047, 1, 1, 'common_resource_library', 'text_description', 'Description', '[[regtime]]', '[[regtime]]'),
(2048, 1, 1, 'common_resource_library', 'text_uploaded', 'Success: Resource has been uploaded!', '[[regtime]]', '[[regtime]]'),
(2049, 1, 1, 'common_resource_library', 'text_add', 'Add', '[[regtime]]', '[[regtime]]'),
(2050, 1, 1, 'common_resource_library', 'text_edit', 'Edit', '[[regtime]]', '[[regtime]]'),
(2051, 1, 1, 'common_resource_library', 'text_map', 'Link to Object', '[[regtime]]', '[[regtime]]'),
(2052, 1, 1, 'common_resource_library', 'text_map_to', 'Link to %s', '[[regtime]]', '[[regtime]]'),
(2053, 1, 1, 'common_resource_library', 'text_unmap', 'Unlink from Object', '[[regtime]]', '[[regtime]]'),
(2054, 1, 1, 'common_resource_library', 'text_unmap_from', 'Unlink from %s', '[[regtime]]', '[[regtime]]'),
(2055, 1, 1, 'common_resource_library', 'text_success_unmap', 'Success: Resource has been unlinked.', '[[regtime]]', '[[regtime]]'),
(2056, 1, 1, 'common_resource_library', 'text_file_delete', 'Resource has been deleted!', '[[regtime]]', '[[regtime]]'),
(2057, 1, 1, 'common_resource_library', 'text_delete', 'Success: Your Resource has been deleted!', '[[regtime]]', '[[regtime]]'),
(2058, 1, 1, 'common_resource_library', 'error_file_type', 'Warning: Incorrect file type!', '[[regtime]]', '[[regtime]]'),
(2059, 1, 1, 'common_resource_library', 'error_file_size', 'Warning: File to big please keep below 300kb and no more than 1000px height or width!', '[[regtime]]', '[[regtime]]'),
(2060, 1, 1, 'common_resource_library', 'error_maxFileSize', 'File is too big', '[[regtime]]', '[[regtime]]'),
(2061, 1, 1, 'common_resource_library', 'error_minFileSize', 'File is too small', '[[regtime]]', '[[regtime]]'),
(2062, 1, 1, 'common_resource_library', 'error_acceptFileTypes', 'Filetype not allowed', '[[regtime]]', '[[regtime]]'),
(2063, 1, 1, 'common_resource_library', 'error_maxNumberOfFiles', 'Max number of files exceeded', '[[regtime]]', '[[regtime]]'),
(2064, 1, 1, 'common_resource_library', 'error_uploadedBytes', 'Uploaded bytes exceed file size', '[[regtime]]', '[[regtime]]'),
(2065, 1, 1, 'common_resource_library', 'error_emptyResult', 'Empty file upload result. Possibly file is corrupted or too big. File size limited to 16MB. If file size is less than limit please check php settings for upload_max_filesize & post_max_size  ', '[[regtime]]', '[[regtime]]'),
(2066, 1, 1, 'common_resource_library', 'error_1', 'File exceeds upload_max_filesize (php.ini directive)', '[[regtime]]', '[[regtime]]'),
(2067, 1, 1, 'common_resource_library', 'error_2', 'File exceeds MAX_FILE_SIZE (HTML form directive)', '[[regtime]]', '[[regtime]]'),
(2068, 1, 1, 'common_resource_library', 'error_3', 'File was only partially uploaded', '[[regtime]]', '[[regtime]]'),
(2069, 1, 1, 'common_resource_library', 'error_4', 'No File was uploaded', '[[regtime]]', '[[regtime]]'),
(2070, 1, 1, 'common_resource_library', 'error_5', 'Missing a temporary folder', '[[regtime]]', '[[regtime]]'),
(2071, 1, 1, 'common_resource_library', 'error_6', 'Failed to write file to disk', '[[regtime]]', '[[regtime]]'),
(2072, 1, 1, 'common_resource_library', 'error_7', 'File upload stopped by extension', '[[regtime]]', '[[regtime]]'),
(2073, 1, 1, 'common_resource_library', 'error_uploaded', 'Warning: File could not be uploaded for an unknown reason!', '[[regtime]]', '[[regtime]]'),
(2074, 1, 1, 'common_resource_library', 'error_no_type', 'Please select resource type', '[[regtime]]', '[[regtime]]'),
(2075, 1, 1, 'common_resource_library', 'error_required_data', 'Required Data has not been entered', '[[regtime]]', '[[regtime]]'),
(2076, 1, 1, 'common_resource_library', 'error_not_added', 'Resource not added. Please check error log for more info', '[[regtime]]', '[[regtime]]'),
(2077, 1, 1, 'common_resource_library', 'error_ajax', 'Load data error. Please check error log for more info', '[[regtime]]', '[[regtime]]'),
(2078, 1, 1, 'common_resource_library', 'error_permission', 'Warning: Permission Denied!', '[[regtime]]', '[[regtime]]'),
(2079, 1, 1, 'common_resource_library', 'error_name', 'Error: Name field is required!', '[[regtime]]', '[[regtime]]'),
(2080, 1, 1, 'common_resource_library', 'button_delete', 'Delete', '[[regtime]]', '[[regtime]]'),
(2081, 1, 1, 'common_resource_library', 'button_add', 'Add Resource', '[[regtime]]', '[[regtime]]'),
(2082, 1, 1, 'common_resource_library', 'button_done', 'Done', '[[regtime]]', '[[regtime]]'),
(2083, 1, 1, 'common_resource_library', 'button_select', 'Select Resources', '[[regtime]]', '[[regtime]]'),
(2084, 1, 1, 'common_resource_library', 'text_with_selected', 'With selected:', '[[regtime]]', '[[regtime]]'),
(2085, 1, 1, 'common_resource_library', 'text_success', 'Resource successfully updated', '[[regtime]]', '[[regtime]]'),
(2086, 1, 1, 'common_resource_library', 'text_map_success', 'Resource successfully linked', '[[regtime]]', '[[regtime]]'),
(2087, 1, 1, 'common_resource_library', 'text_no_resources', 'No resources available', '[[regtime]]', '[[regtime]]'),
(2088, 1, 1, 'common_resource_library', 'text_preview', 'Preview/Download', '[[regtime]]', '[[regtime]]'),
(2089, 1, 1, 'common_resource_library', 'error_file size', 'Attention: Maximum size of file for upload is %s. You can increase this value in php.ini.', '[[regtime]]', '[[regtime]]'),
(2090, 1, 1, 'common_resource_library', 'text_product_option_value', 'Product options value', '[[regtime]]', '[[regtime]]'),
(2091, 1, 1, 'common_resource_library', 'text_categories', 'Categories', '[[regtime]]', '[[regtime]]'),
(2092, 1, 1, 'common_resource_library', 'text_manufacturers', 'Brands', '[[regtime]]', '[[regtime]]'),
(2093, 1, 1, 'common_resource_library', 'error_delete', 'Cannot delete resource linked to multiple objects', '[[regtime]]', '[[regtime]]'),
(2094, 1, 1, 'common_resource_library', 'error_unmap', 'Cannot unlink resource. Object wasn''t set.', '[[regtime]]', '[[regtime]]'),
(2095, 1, 1, 'common_resource_library', 'text_replace_file', 'Replace File', '[[regtime]]', '[[regtime]]'),
(2096, 1, 1, 'common_resource_library', 'error_not_replaced', 'File Replacement Error. ID required!', '[[regtime]]', '[[regtime]]'),
(2097, 1, 1, 'common_resource_library', 'error_not_exists', 'File Replacement Error. Resource does not exists!', '[[regtime]]', '[[regtime]]'),
(2098, 1, 1, 'common_resource_library', 'error_cannot_move', 'Error: Cannot move file %s to resources directory.', '[[regtime]]', '[[regtime]]'),
(2099, 1, 1, 'common_resource_library', 'button_save_n_apply', 'Save and Apply', '[[regtime]]', '[[regtime]]'),
(2100, 1, 1, 'common_resource_library', 'text_image_size', 'Image size:', '[[regtime]]', '[[regtime]]'),
(2101, 1, 1, 'common_resource_library', 'text_file_size', 'File size:', '[[regtime]]', '[[regtime]]'),
(2102, 1, 1, 'common_resource_library', 'text_file_mime', 'MIME:', '[[regtime]]', '[[regtime]]'),
(2103, 1, 1, 'common_resource_library', 'text_file_path', 'File location:', '[[regtime]]', '[[regtime]]'),
(2104, 1, 1, 'common_resource_library', 'text_file_url', 'Resource URL:', '[[regtime]]', '[[regtime]]'),
(2105, 1, 1, 'common_resource_library', 'text_sorting_date_asc', 'Date Old &gt; New', '[[regtime]]', '[[regtime]]'),
(2106, 1, 1, 'common_resource_library', 'text_sorting_date_desc', 'Date New &gt; Old', '[[regtime]]', '[[regtime]]'),
(2107, 1, 1, 'common_resource_library', 'text_sorting_name_asc', 'Name A - Z', '[[regtime]]', '[[regtime]]'),
(2108, 1, 1, 'common_resource_library', 'text_sorting_name_desc', 'Name Z - A', '[[regtime]]', '[[regtime]]'),
(2109, 1, 1, 'common_resource_library', 'text_sorting_asc', 'Sort Order Low &gt; High', '[[regtime]]', '[[regtime]]'),
(2110, 1, 1, 'common_resource_library', 'text_sorting_desc', 'Sort Order High &gt; Low', '[[regtime]]', '[[regtime]]'),
(2111, 1, 1, 'common_template_debug', 'text_block_id', 'Block ID:', '[[regtime]]', '[[regtime]]'),
(2112, 1, 1, 'common_template_debug', 'text_block_name', 'Name:', '[[regtime]]', '[[regtime]]'),
(2113, 1, 1, 'common_template_debug', 'text_block_controller', 'Controller:', '[[regtime]]', '[[regtime]]'),
(2114, 1, 1, 'common_template_debug', 'text_block_path', 'Path:', '[[regtime]]', '[[regtime]]'),
(2115, 1, 1, 'common_template_debug', 'text_block_template', 'Template:', '[[regtime]]', '[[regtime]]'),
(2116, 1, 1, 'common_template_debug', 'text_block_parent', 'Parent:', '[[regtime]]', '[[regtime]]'),
(2117, 1, 1, 'common_template_debug', 'text_parent_id', 'Parent ID:', '[[regtime]]', '[[regtime]]'),
(2118, 1, 1, 'common_template_debug', 'text_close', 'Close', '[[regtime]]', '[[regtime]]'),
(2119, 1, 1, 'common_template_debug', 'text_click', 'Click Me', '[[regtime]]', '[[regtime]]'),
(2120, 1, 1, 'common_tips', 'text_tip', 'Tip', '[[regtime]]', '[[regtime]]'),
(2121, 1, 1, 'common_tips', 'no_enabled_payments_tip', '    <div class="info alert alert-warning"><i class="fa fa fa-exclamation-triangle fa-fw"></i> You have no payment method enabled yet.</div>\n    <label class="h4 heading">Check most common payments:</label>\n    <div class="row">\n	    <div class="col-sm-4 h5 center">\n	        <a href="#admin#rt=extension/extensions/install&extension=stripe">\n	        <img src="extensions/stripe/image/icon.png"><br>Install Stripe Extension</a>\n	    </div>\n	    <div class="col-sm-4 h5 center">\n	        <a href="#admin#rt=extension/extensions/install&extension=paypal_commerce">\n	        <img src="extensions/paypal_commerce/image/icon.png"><br>Install Paypal Extension</a>\n	    </div>\n	    <div class="col-sm-4 h5 center">\n	        <a href="#admin#rt=extension/extensions/payment" target="_extension">\n	        <img src="admin/view/default/image/default_extension.png"><br>More Payments</a>\n	    </div>\n    </div>\n\n    ', '[[regtime]]', '[[regtime]]'),
(2122, 1, 1, 'design_blocks', 'heading_title', 'Blocks', '[[regtime]]', '[[regtime]]'),
(2123, 1, 1, 'design_blocks', 'text_delete', 'delete block', '[[regtime]]', '[[regtime]]'),
(2124, 1, 1, 'design_blocks', 'text_edit', 'edit block', '[[regtime]]', '[[regtime]]'),
(2125, 1, 1, 'design_blocks', 'text_enable', 'Enable/Disable', '[[regtime]]', '[[regtime]]'),
(2126, 1, 1, 'design_blocks', 'text_details', 'Details', '[[regtime]]', '[[regtime]]'),
(2127, 1, 1, 'design_blocks', 'text_create', 'Create block', '[[regtime]]', '[[regtime]]'),
(2128, 1, 1, 'design_blocks', 'text_success', 'Success: You have modified block!', '[[regtime]]', '[[regtime]]'),
(2129, 1, 1, 'design_blocks', 'column_block_id', 'ID', '[[regtime]]', '[[regtime]]'),
(2130, 1, 1, 'design_blocks', 'column_block_txt_id', ' Unique Text ID ', '[[regtime]]', '[[regtime]]'),
(2131, 1, 1, 'design_blocks', 'column_block_name', 'Name', '[[regtime]]', '[[regtime]]'),
(2132, 1, 1, 'design_blocks', 'column_date_added', 'Date Added', '[[regtime]]', '[[regtime]]'),
(2133, 1, 1, 'design_blocks', 'column_block_type', ' Type ', '[[regtime]]', '[[regtime]]'),
(2134, 1, 1, 'design_blocks', 'column_action', ' Action ', '[[regtime]]', '[[regtime]]'),
(2135, 1, 1, 'design_blocks', 'column_sort_order', ' Sort Order ', '[[regtime]]', '[[regtime]]'),
(2136, 1, 1, 'design_blocks', 'column_image', ' Image ', '[[regtime]]', '[[regtime]]'),
(2137, 1, 1, 'design_blocks', 'entry_block_status', ' Status ', '[[regtime]]', '[[regtime]]'),
(2138, 1, 1, 'design_blocks', 'entry_block_status_note', ' Note: You need to add this block in the <a style="text-decoration: underline; font-weight: bold;" href="#admin#rt=design/layout">LAYOUT</a> on desired page to see it working ', '[[regtime]]', '[[regtime]]'),
(2139, 1, 1, 'design_blocks', 'entry_block_type', ' Custom Block Type ', '[[regtime]]', '[[regtime]]'),
(2140, 1, 1, 'design_blocks', 'entry_block_name', ' Custom Block Name ', '[[regtime]]', '[[regtime]]'),
(2141, 1, 1, 'design_blocks', 'entry_block_wrapper', ' Use block wrapper (appearance) ', '[[regtime]]', '[[regtime]]'),
(2142, 1, 1, 'design_blocks', 'entry_block_framed', ' Use block''s frame ', '[[regtime]]', '[[regtime]]'),
(2143, 1, 1, 'design_blocks', 'entry_block_title', ' Custom Block Title ', '[[regtime]]', '[[regtime]]'),
(2144, 1, 1, 'design_blocks', 'entry_block_description', ' Custom Block description <p>Note: internal use only </p> ', '[[regtime]]', '[[regtime]]'),
(2145, 1, 1, 'design_blocks', 'entry_block_content', ' Custom Block content ', '[[regtime]]', '[[regtime]]'),
(2146, 1, 1, 'design_blocks', 'entry_listing_datasource', ' Listing Data Source ', '[[regtime]]', '[[regtime]]'),
(2147, 1, 1, 'design_blocks', 'text_delete_confirm', ' Confirm to delete block? ', '[[regtime]]', '[[regtime]]'),
(2148, 1, 1, 'design_blocks', 'error_empty', 'Please Fill All Required Fields!', '[[regtime]]', '[[regtime]]'),
(2149, 1, 1, 'design_blocks', 'error_delete', 'Can''t delete because this block is in use. Please visit Layout section. ', '[[regtime]]', '[[regtime]]'),
(2150, 1, 1, 'design_blocks', 'error_text_status', 'Can''t change status because this block is not in use. Please visit Layout section. ', '[[regtime]]', '[[regtime]]'),
(2151, 1, 1, 'design_blocks', 'text_success_deleted', 'Success: You have deleted custom block!', '[[regtime]]', '[[regtime]]'),
(2152, 1, 1, 'design_blocks', 'entry_data_source', 'Data Source:', '[[regtime]]', '[[regtime]]'),
(2153, 1, 1, 'design_blocks', 'entry_limit', 'Limit:', '[[regtime]]', '[[regtime]]'),
(2154, 1, 1, 'design_blocks', 'text_listing_auto', 'Auto listing', '[[regtime]]', '[[regtime]]'),
(2155, 1, 1, 'design_blocks', 'text_listing_manual', 'Custom listing', '[[regtime]]', '[[regtime]]'),
(2156, 1, 1, 'design_blocks', 'text_select_listing', '--- select data listing source ---', '[[regtime]]', '[[regtime]]'),
(2157, 1, 1, 'design_blocks', 'text_products_special', 'Special Offers', '[[regtime]]', '[[regtime]]'),
(2158, 1, 1, 'design_blocks', 'text_products_related', 'Related Products', '[[regtime]]', '[[regtime]]'),
(2159, 1, 1, 'design_blocks', 'text_products_popular', 'Popular Products', '[[regtime]]', '[[regtime]]'),
(2160, 1, 1, 'design_blocks', 'text_categories', 'All Categories', '[[regtime]]', '[[regtime]]'),
(2161, 1, 1, 'design_blocks', 'text_manufacturers', 'All Brands', '[[regtime]]', '[[regtime]]'),
(2162, 1, 1, 'design_blocks', 'text_featured', 'Featured Products', '[[regtime]]', '[[regtime]]'),
(2163, 1, 1, 'design_blocks', 'text_latest', 'Latest Products', '[[regtime]]', '[[regtime]]'),
(2164, 1, 1, 'design_blocks', 'text_bestsellers', 'Bestsellers Products', '[[regtime]]', '[[regtime]]'),
(2165, 1, 1, 'design_blocks', 'text_media', 'Media', '[[regtime]]', '[[regtime]]'),
(2166, 1, 1, 'design_blocks', 'entry_resource_type', 'Media Type:', '[[regtime]]', '[[regtime]]'),
(2167, 1, 1, 'design_blocks', 'text_custom_products', 'Selected Products', '[[regtime]]', '[[regtime]]'),
(2168, 1, 1, 'design_blocks', 'text_custom_categories', 'Selected Categories', '[[regtime]]', '[[regtime]]'),
(2169, 1, 1, 'design_blocks', 'text_custom_manufacturers', 'Selected Brands', '[[regtime]]', '[[regtime]]'),
(2170, 1, 1, 'design_blocks', 'text_selected_content', 'Selected Content', '[[regtime]]', '[[regtime]]'),
(2171, 1, 1, 'design_blocks', 'text_html_block', 'HTML', '[[regtime]]', '[[regtime]]'),
(2172, 1, 1, 'design_blocks', 'text_listing_block', 'Data Listing', '[[regtime]]', '[[regtime]]'),
(2173, 1, 1, 'design_blocks', 'text_selected', ' Selected items: ', '[[regtime]]', '[[regtime]]'),
(2174, 1, 1, 'design_blocks', 'text_data_listed', ' Data to be listed ', '[[regtime]]', '[[regtime]]'),
(2175, 1, 1, 'design_blocks', 'text_save_edit', ' Add / Edit ', '[[regtime]]', '[[regtime]]'),
(2176, 1, 1, 'design_blocks', 'text_apply', ' Apply selection ', '[[regtime]]', '[[regtime]]'),
(2177, 1, 1, 'design_blocks', 'text_block_id', ' Block ID ', '[[regtime]]', '[[regtime]]'),
(2178, 1, 1, 'design_blocks', 'text_block_txt_id', ' Block Text ID ', '[[regtime]]', '[[regtime]]'),
(2179, 1, 1, 'design_blocks', 'text_controller', ' Controller ', '[[regtime]]', '[[regtime]]'),
(2180, 1, 1, 'design_blocks', 'text_templates', ' Block Templates ', '[[regtime]]', '[[regtime]]'),
(2181, 1, 1, 'design_blocks', 'text_block_date_added', ' Block Creation Date ', '[[regtime]]', '[[regtime]]'),
(2182, 1, 1, 'design_blocks', 'text_layouts', ' Used in layouts ', '[[regtime]]', '[[regtime]]'),
(2183, 1, 1, 'design_blocks', 'text_block_info', ' Information About Custom Block ', '[[regtime]]', '[[regtime]]'),
(2184, 1, 1, 'design_blocks', 'text_add_block', 'Adding block to section', '[[regtime]]', '[[regtime]]'),
(2185, 1, 1, 'design_blocks', 'text_available_block', 'Available Blocks', '[[regtime]]', '[[regtime]]'),
(2186, 1, 1, 'design_blocks', 'error_block_not_available', 'This block will not be displayed in selected position on a storefront!', '[[regtime]]', '[[regtime]]'),
(2187, 1, 1, 'design_blocks', 'text_collection', 'Collection', '[[regtime]]', '[[regtime]]'),
(2188, 1, 1, 'design_blocks', 'entry_collection_resource_type', 'Selected Collection:', '[[regtime]]', '[[regtime]]'),
(2189, 1, 1, 'design_blocks', 'text_top_level', 'Top Level', '[[regtime]]', '[[regtime]]'),
(2190, 1, 1, 'design_content', 'heading_title', 'Content Manager', '[[regtime]]', '[[regtime]]'),
(2191, 1, 1, 'design_content', 'insert_title', 'Add New Content', '[[regtime]]', '[[regtime]]'),
(2192, 1, 1, 'design_content', 'update_title', 'Update Content', '[[regtime]]', '[[regtime]]'),
(2193, 1, 1, 'design_content', 'text_success', 'Success: You have modified content!', '[[regtime]]', '[[regtime]]'),
(2194, 1, 1, 'design_content', 'text_success_layout', 'Success: You have modified content page layout.', '[[regtime]]', '[[regtime]]'),
(2195, 1, 1, 'design_content', 'text_hidden', 'Hidden', '[[regtime]]', '[[regtime]]'),
(2196, 1, 1, 'design_content', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(2197, 1, 1, 'design_content', 'column_title', 'Content Title', '[[regtime]]', '[[regtime]]'),
(2198, 1, 1, 'design_content', 'column_parent', 'Parent Content', '[[regtime]]', '[[regtime]]'),
(2199, 1, 1, 'design_content', 'entry_parent', 'Parent Content Page', '[[regtime]]', '[[regtime]]'),
(2200, 1, 1, 'design_content', 'column_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(2201, 1, 1, 'design_content', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(2202, 1, 1, 'design_content', 'column_publish_date', 'Publish Date', '[[regtime]]', '[[regtime]]'),
(2203, 1, 1, 'design_content', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2204, 1, 1, 'design_content', 'entry_title', 'Content Title:', '[[regtime]]', '[[regtime]]'),
(2205, 1, 1, 'design_content', 'entry_description', 'Description:<br /><span class="help">HTML tags are not suggested for the content description! This depends on your storefront template</span>', '[[regtime]]', '[[regtime]]'),
(2206, 1, 1, 'design_content', 'entry_content', 'Content:', '[[regtime]]', '[[regtime]]'),
(2207, 1, 1, 'design_content', 'entry_store', 'Stores:', '[[regtime]]', '[[regtime]]'),
(2208, 1, 1, 'design_content', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(2209, 1, 1, 'design_content', 'entry_keyword', 'SEO Keyword:', '[[regtime]]', '[[regtime]]'),
(2210, 1, 1, 'design_content', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(2211, 1, 1, 'design_content', 'entry_publish_date', 'Publish Date:', '[[regtime]]', '[[regtime]]'),
(2212, 1, 1, 'design_content', 'entry_expire_date', 'Expiration Date:', '[[regtime]]', '[[regtime]]'),
(2213, 1, 1, 'design_content', 'entry_content_bar', 'Content Details Bar:<br /><span class="help">Enable this setting to show the bar with the author and publish date on the content page</span>', '[[regtime]]', '[[regtime]]'),
(2214, 1, 1, 'design_content', 'entry_show_title', 'Show Content Title:<br /><span class="help">Enable this setting to show the title on the content page</span>', '[[regtime]]', '[[regtime]]'),
(2215, 1, 1, 'design_content', 'entry_icon', 'Main Image or Icon:', '[[regtime]]', '[[regtime]]'),
(2216, 1, 1, 'design_content', 'entry_tags', 'Content Tags:<br /><span class="help">comma separated list</span>', '[[regtime]]', '[[regtime]]'),
(2217, 1, 1, 'design_content', 'entry_author', 'Author:', '[[regtime]]', '[[regtime]]'),
(2218, 1, 1, 'design_content', 'error_permission', 'Warning: You do not have permission to modify content!', '[[regtime]]', '[[regtime]]'),
(2219, 1, 1, 'design_content', 'error_title', 'Content Title must be between 2 and 255 characters!', '[[regtime]]', '[[regtime]]'),
(2220, 1, 1, 'design_content', 'error_title_html', 'Content Title cannot contain HTML tags!', '[[regtime]]', '[[regtime]]'),
(2221, 1, 1, 'design_content', 'error_description', 'Description must be more than 1 characters!', '[[regtime]]', '[[regtime]]'),
(2222, 1, 1, 'design_content', 'error_description_html', 'Content description HTML tags are not supported!', '[[regtime]]', '[[regtime]]'),
(2223, 1, 1, 'design_content', 'error_content', 'Content must be more than 1 characters!', '[[regtime]]', '[[regtime]]'),
(2224, 1, 1, 'design_content', 'error_seo_url', 'SEO URL must be more than 1 characters!', '[[regtime]]', '[[regtime]]'),
(2225, 1, 1, 'design_content', 'error_account', 'Warning: This content cannot be deleted as it is currently assigned as the default store account terms!', '[[regtime]]', '[[regtime]]'),
(2226, 1, 1, 'design_content', 'error_checkout', 'Warning: This content cannot be deleted as it is currently assigned as the default store checkout terms!', '[[regtime]]', '[[regtime]]'),
(2227, 1, 1, 'design_content', 'error_delete_parent', 'Warning: Parent contents cannot be deleted! Move or delete child content pages first.', '[[regtime]]', '[[regtime]]'),
(2228, 1, 1, 'design_content', 'error_required_data', 'Required Data has not been entered. Check for field errors!', '[[regtime]]', '[[regtime]]'),
(2229, 1, 1, 'design_content', 'text_top_level', 'Top Level', '[[regtime]]', '[[regtime]]'),
(2230, 1, 1, 'design_content', 'text_any', 'any', '[[regtime]]', '[[regtime]]'),
(2231, 1, 1, 'design_content', 'tab_form', ' Edit ', '[[regtime]]', '[[regtime]]'),
(2232, 1, 1, 'design_content', 'entry_meta_description', ' Meta Tag Description: ', '[[regtime]]', '[[regtime]]'),
(2233, 1, 1, 'design_content', 'entry_meta_keywords', 'Meta Tag Keywords:', '[[regtime]]', '[[regtime]]'),
(2234, 1, 1, 'design_content', 'text_clone', 'Clone', '[[regtime]]', '[[regtime]]'),
(2235, 1, 1, 'design_content', 'text_success_copy', 'Success: You have successfully copied content page <b>%s</b>!', '[[regtime]]', '[[regtime]]'),
(2236, 1, 1, 'design_content', 'text_success_copy_layout', ' Note: Content page layout has been cloned as well.', '[[regtime]]', '[[regtime]]'),
(2237, 1, 1, 'design_content', 'text_error_copy', 'Cloning has failed! Original content page is not available', '[[regtime]]', '[[regtime]]'),
(2238, 1, 1, 'design_email_templates', 'email_templates', 'Email Templates', '[[regtime]]', '[[regtime]]'),
(2239, 1, 1, 'design_email_templates', 'heading_title', 'Email Templates', '[[regtime]]', '[[regtime]]'),
(2240, 1, 1, 'design_email_templates', 'column_text_id', 'Email Template Text ID', '[[regtime]]', '[[regtime]]'),
(2241, 1, 1, 'design_email_templates', 'column_language', 'Language', '[[regtime]]', '[[regtime]]'),
(2242, 1, 1, 'design_email_templates', 'column_subject', 'Subject', '[[regtime]]', '[[regtime]]'),
(2243, 1, 1, 'design_email_templates', 'button_save', 'Save', '[[regtime]]', '[[regtime]]'),
(2244, 1, 1, 'design_email_templates', 'entry_status', 'Status: ', '[[regtime]]', '[[regtime]]'),
(2245, 1, 1, 'design_email_templates', 'entry_text_id', 'Text ID: ', '[[regtime]]', '[[regtime]]'),
(2246, 1, 1, 'design_email_templates', 'entry_language_id', 'Language: ', '[[regtime]]', '[[regtime]]'),
(2247, 1, 1, 'design_email_templates', 'entry_headers', 'Custom Headers: ', '[[regtime]]', '[[regtime]]'),
(2248, 1, 1, 'design_email_templates', 'entry_subject', 'Subject: ', '[[regtime]]', '[[regtime]]'),
(2249, 1, 1, 'design_email_templates', 'entry_html_body', 'Html Body: ', '[[regtime]]', '[[regtime]]'),
(2250, 1, 1, 'design_email_templates', 'entry_text_body', 'Text Body: ', '[[regtime]]', '[[regtime]]'),
(2251, 1, 1, 'design_email_templates', 'entry_allowed_placeholders', 'Allowed Placeholders:<br /><span class="help">Coma separated list of variable names</span>', '[[regtime]]', '[[regtime]]'),
(2252, 1, 1, 'design_email_templates', 'save_complete', 'Save Complete', '[[regtime]]', '[[regtime]]'),
(2253, 1, 1, 'design_email_templates', 'save_error', 'Save Error. Please see log.', '[[regtime]]', '[[regtime]]'),
(2254, 1, 1, 'design_email_templates', 'save_error_text_id', 'Text ID is required and must be up to 254 characters! One word. Charsets: A-Z a-z and _ ', '[[regtime]]', '[[regtime]]'),
(2255, 1, 1, 'design_email_templates', 'save_error_text_id_unique', 'Text ID must be unique!', '[[regtime]]', '[[regtime]]'),
(2256, 1, 1, 'design_email_templates', 'save_error_text_header', 'Headers must be up to 254 characters!', '[[regtime]]', '[[regtime]]'),
(2257, 1, 1, 'design_email_templates', 'save_error_text_subject', 'Subject is required and must be up to 254 characters!', '[[regtime]]', '[[regtime]]'),
(2258, 1, 1, 'design_email_templates', 'save_error_html_body', 'Html Body is required!', '[[regtime]]', '[[regtime]]'),
(2259, 1, 1, 'design_email_templates', 'save_error_text_body', 'Text Body is required!', '[[regtime]]', '[[regtime]]'),
(2260, 1, 1, 'design_email_templates', 'save_error_language_id', 'Language is required!', '[[regtime]]', '[[regtime]]'),
(2261, 1, 1, 'design_email_templates', 'text_preview', 'Preview', '[[regtime]]', '[[regtime]]'),
(2262, 1, 1, 'design_layout', 'heading_title', 'Layout &amp; Blocks Manager', '[[regtime]]', '[[regtime]]'),
(2263, 1, 1, 'design_layout', 'text_select_template', 'Select template: ', '[[regtime]]', '[[regtime]]'),
(2264, 1, 1, 'design_layout', 'text_delete_success', 'Success: Page Layout has been removed!', '[[regtime]]', '[[regtime]]'),
(2265, 1, 1, 'design_layout', 'text_delete_restricted', 'Error: Page Layout is restricted and can not be removed!', '[[regtime]]', '[[regtime]]'),
(2266, 1, 1, 'design_layout', 'text_success', 'Success: You have modified layout &amp; blocks!', '[[regtime]]', '[[regtime]]'),
(2267, 1, 1, 'design_layout', 'text_preview_generated', 'Preview Generated!', '[[regtime]]', '[[regtime]]'),
(2268, 1, 1, 'design_layout', 'text_click_here', 'Click here', '[[regtime]]', '[[regtime]]'),
(2269, 1, 1, 'design_layout', 'text_create_new_layout', 'Create New Page Layout', '[[regtime]]', '[[regtime]]'),
(2270, 1, 1, 'design_layout', 'entry_page_name', 'Page Name:', '[[regtime]]', '[[regtime]]'),
(2271, 1, 1, 'design_layout', 'entry_seo_keyword', 'SEO Keyword:', '[[regtime]]', '[[regtime]]'),
(2272, 1, 1, 'design_layout', 'entry_page_title', 'Page Title:', '[[regtime]]', '[[regtime]]'),
(2273, 1, 1, 'design_layout', 'entry_page_rt', 'Page Route:', '[[regtime]]', '[[regtime]]'),
(2274, 1, 1, 'design_layout', 'entry_key_parameter_name', 'Key Parameter Name:', '[[regtime]]', '[[regtime]]'),
(2275, 1, 1, 'design_layout', 'entry_key_parameter_value', 'Key Parameter Value:', '[[regtime]]', '[[regtime]]'),
(2276, 1, 1, 'design_layout', 'error_template', 'Template Name is Required!', '[[regtime]]', '[[regtime]]'),
(2277, 1, 1, 'design_layout', 'error_page_name', 'Page Name is Required!', '[[regtime]]', '[[regtime]]'),
(2278, 1, 1, 'design_layout', 'error_page_exists', 'Page Name "%s" is already exists.', '[[regtime]]', '[[regtime]]'),
(2279, 1, 1, 'design_layout', 'error_page_rt', 'Page Route is Required!', '[[regtime]]', '[[regtime]]'),
(2280, 1, 1, 'design_layout', 'error_key_parameter_name', 'Parameter Name is required when value exists.', '[[regtime]]', '[[regtime]]'),
(2281, 1, 1, 'design_layout', 'error_key_parameter_value', 'Parameter Value is required when name is set.', '[[regtime]]', '[[regtime]]'),
(2282, 1, 1, 'design_layout', 'error_seo_keyword', 'SEO-Keyword "%s" is already taken.', '[[regtime]]', '[[regtime]]'),
(2283, 1, 1, 'design_layout', 'error_page_parameters', 'Page with these rt and parameters is already exists.', '[[regtime]]', '[[regtime]]'),
(2284, 1, 1, 'design_menu', 'heading_title', 'Menu', '[[regtime]]', '[[regtime]]'),
(2285, 1, 1, 'design_menu', 'text_success', 'Success: You have modified menu!', '[[regtime]]', '[[regtime]]'),
(2286, 1, 1, 'design_menu', 'entry_item_id', 'Unique ID', '[[regtime]]', '[[regtime]]'),
(2287, 1, 1, 'design_menu', 'entry_item_icon', 'Icon', '[[regtime]]', '[[regtime]]'),
(2288, 1, 1, 'design_menu', 'entry_item_text', 'Text', '[[regtime]]', '[[regtime]]'),
(2289, 1, 1, 'design_menu', 'entry_item_url', 'Link<br /><span class="help">For external links add http:// or https:// in the beginning. You can also use relative URL such as ../subfolder/index.php</span>', '[[regtime]]', '[[regtime]]'),
(2290, 1, 1, 'design_menu', 'entry_item_target', 'Target<br/><span class="help">_self - opens the linked document in the same frame as it was clicked.<br>_blank - opens the linked document in a new window or tab</span>', '[[regtime]]', '[[regtime]]'),
(2291, 1, 1, 'design_menu', 'entry_parent_id', 'Parent', '[[regtime]]', '[[regtime]]'),
(2292, 1, 1, 'design_menu', 'entry_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(2293, 1, 1, 'design_menu', 'entry_link_type', 'Link Type', '[[regtime]]', '[[regtime]]'),
(2294, 1, 1, 'design_menu', 'text_select_parent_id', '- Root Menu -', '[[regtime]]', '[[regtime]]'),
(2295, 1, 1, 'design_menu', 'error_empty', 'Field cannot be Empty!', '[[regtime]]', '[[regtime]]'),
(2296, 1, 1, 'design_menu', 'error_non_unique', 'Item ID not unique!', '[[regtime]]', '[[regtime]]'),
(2297, 1, 1, 'design_menu', 'error_non_ascii', 'Only alphanumeric characters allowed for menu ID field!', '[[regtime]]', '[[regtime]]'),
(2298, 1, 1, 'design_menu', 'text_category_link_type', 'Category Page', '[[regtime]]', '[[regtime]]'),
(2299, 1, 1, 'design_menu', 'text_content_link_type', 'Content Page', '[[regtime]]', '[[regtime]]'),
(2300, 1, 1, 'design_menu', 'text_custom_link_type', 'Custom Link or URL', '[[regtime]]', '[[regtime]]'),
(2301, 1, 1, 'design_menu', 'entry_include_children_items', 'Include children items', '[[regtime]]', '[[regtime]]'),
(2302, 1, 1, 'design_template', 'heading_title', 'Template Manager', '[[regtime]]', '[[regtime]]'),
(2303, 1, 1, 'design_template', 'text_success', 'Success: You have set a new storefront template!', '[[regtime]]', '[[regtime]]'),
(2304, 1, 1, 'design_template', 'text_storefront_templates', 'Available Storefront Templates', '[[regtime]]', '[[regtime]]'),
(2305, 1, 1, 'design_template', 'text_edit_extension', 'Extension Settings', '[[regtime]]', '[[regtime]]'),
(2306, 1, 1, 'design_template', 'text_error', 'Error: Missing required parameter in your request!', '[[regtime]]', '[[regtime]]'),
(2307, 1, 1, 'design_template', 'error_permission', 'Warning: You do not have permission to modify templates!', '[[regtime]]', '[[regtime]]'),
(2308, 1, 1, 'error_error', 'heading_title', 'Application Error!', '[[regtime]]', '[[regtime]]'),
(2309, 1, 1, 'error_error', 'text_error', 'Please check error log for more information', '[[regtime]]', '[[regtime]]'),
(2310, 1, 1, 'error_login', 'heading_title', 'Login Error!', '[[regtime]]', '[[regtime]]'),
(2311, 1, 1, 'error_login', 'text_login', 'You are not logged in. You will be redirected to login page. If problem still presents try to clear cookie. However, your page must be opened in secure mode (https).', '[[regtime]]', '[[regtime]]'),
(2312, 1, 1, 'error_permission', 'heading_title', 'Permission Denied!', '[[regtime]]', '[[regtime]]'),
(2313, 1, 1, 'error_permission', 'text_permission', 'You do not have permission to access this page, please refer to your system administrator.', '[[regtime]]', '[[regtime]]'),
(2314, 1, 1, 'extension_extensions', 'heading_title', 'Extensions', '[[regtime]]', '[[regtime]]'),
(2315, 1, 1, 'extension_extensions', 'text_install', 'Install', '[[regtime]]', '[[regtime]]'),
(2316, 1, 1, 'extension_extensions', 'text_uninstall', 'Uninstall', '[[regtime]]', '[[regtime]]'),
(2317, 1, 1, 'extension_extensions', 'text_uninstall_delete', 'Uninstall/Delete', '[[regtime]]', '[[regtime]]'),
(2318, 1, 1, 'extension_extensions', 'text_uninstall_confirm', ' Please confirm you want to uninstall extension. All extension settings and related data might be deleted and lost. ', '[[regtime]]', '[[regtime]]'),
(2319, 1, 1, 'extension_extensions', 'text_delete', 'Delete', '[[regtime]]', '[[regtime]]'),
(2320, 1, 1, 'extension_extensions', 'text_enlarge', 'Click Image to Enlarge', '[[regtime]]', '[[regtime]]'),
(2321, 1, 1, 'extension_extensions', 'text_activate', 'Activate', '[[regtime]]', '[[regtime]]'),
(2322, 1, 1, 'extension_extensions', 'text_deactivate', 'Deactivate', '[[regtime]]', '[[regtime]]'),
(2323, 1, 1, 'extension_extensions', 'text_left', 'Left', '[[regtime]]', '[[regtime]]'),
(2324, 1, 1, 'extension_extensions', 'text_right', 'Right', '[[regtime]]', '[[regtime]]'),
(2325, 1, 1, 'extension_extensions', 'text_date_added', 'Added on', '[[regtime]]', '[[regtime]]'),
(2326, 1, 1, 'extension_extensions', 'column_icon', 'Icon', '[[regtime]]', '[[regtime]]'),
(2327, 1, 1, 'extension_extensions', 'column_id', 'Extension ID', '[[regtime]]', '[[regtime]]'),
(2328, 1, 1, 'extension_extensions', 'column_required', 'Required', '[[regtime]]', '[[regtime]]'),
(2329, 1, 1, 'extension_extensions', 'column_name', 'Extension Name', '[[regtime]]', '[[regtime]]'),
(2330, 1, 1, 'extension_extensions', 'column_position', 'Position', '[[regtime]]', '[[regtime]]'),
(2331, 1, 1, 'extension_extensions', 'column_update_date', 'Update Date', '[[regtime]]', '[[regtime]]'),
(2332, 1, 1, 'extension_extensions', 'column_category', 'Category', '[[regtime]]', '[[regtime]]'),
(2333, 1, 1, 'extension_extensions', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(2334, 1, 1, 'extension_extensions', 'column_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(2335, 1, 1, 'extension_extensions', 'column_action', 'Quick Actions', '[[regtime]]', '[[regtime]]'),
(2336, 1, 1, 'extension_extensions', 'error_permission', 'Warning: You do not have permission to modify extensions!', '[[regtime]]', '[[regtime]]'),
(2337, 1, 1, 'extension_extensions', 'error_required_field', 'Error: Please provide required fields. Nothing was updated! ', '[[regtime]]', '[[regtime]]'),
(2338, 1, 1, 'extension_extensions', 'error_payment_uninstall', 'Warning: Disable extension before uninstall!', '[[regtime]]', '[[regtime]]'),
(2339, 1, 1, 'extension_extensions', 'error_uninstall', 'Warning: Uninstall extension before delete!', '[[regtime]]', '[[regtime]]'),
(2340, 1, 1, 'extension_extensions', 'text_save_success', 'Success: You have modified extension settings!', '[[regtime]]', '[[regtime]]'),
(2341, 1, 1, 'extension_extensions', 'text_restore_success', 'Success: You have restored default extension settings!', '[[regtime]]', '[[regtime]]'),
(2342, 1, 1, 'extension_extensions', 'text_extensions_store', 'Get Extensions', '[[regtime]]', '[[regtime]]'),
(2343, 1, 1, 'extension_extensions', 'text_required', 'Required', '[[regtime]]', '[[regtime]]'),
(2344, 1, 1, 'extension_extensions', 'text_optional', 'Optional', '[[regtime]]', '[[regtime]]'),
(2345, 1, 1, 'extension_extensions', 'text_add_new', 'Install Extension', '[[regtime]]', '[[regtime]]'),
(2346, 1, 1, 'extension_extensions', 'text_search', 'Search', '[[regtime]]', '[[regtime]]'),
(2347, 1, 1, 'extension_extensions', 'text_search_for_extension', 'Search for Extension', '[[regtime]]', '[[regtime]]'),
(2348, 1, 1, 'extension_extensions', 'text_missing_extension', 'Extension %s:  Source can not be located! Please delete it and visit extension provider to get complete source and install it again', '[[regtime]]', '[[regtime]]'),
(2349, 1, 1, 'extension_extensions', 'text_broken_extension', 'Extension %s:  Source probably broken! Can''t find config.xml or main.php files. Please delete it and visit extension provider to get complete source and install it again', '[[regtime]]', '[[regtime]]'),
(2350, 1, 1, 'extension_extensions', 'text_extension_pagination', 'Extension(s) {start} to {end} of {total}', '[[regtime]]', '[[regtime]]'),
(2351, 1, 1, 'extension_extensions', 'text_per_page', 'per page', '[[regtime]]', '[[regtime]]'),
(2352, 1, 1, 'extension_extensions', 'text_error_in_ajax', 'Error in ajax call', '[[regtime]]', '[[regtime]]'),
(2353, 1, 1, 'extension_extensions', 'text_saved', 'Saved', '[[regtime]]', '[[regtime]]'),
(2354, 1, 1, 'extension_extensions', 'text_save', 'Save', '[[regtime]]', '[[regtime]]'),
(2355, 1, 1, 'extension_extensions', 'text_reset', 'Reset', '[[regtime]]', '[[regtime]]'),
(2356, 1, 1, 'extension_extensions', 'text_back', 'Back', '[[regtime]]', '[[regtime]]'),
(2357, 1, 1, 'extension_extensions', 'text_additional_settings', 'Additional settings', '[[regtime]]', '[[regtime]]'),
(2358, 1, 1, 'extension_extensions', 'text_reload', 'Reload', '[[regtime]]', '[[regtime]]'),
(2359, 1, 1, 'extension_extensions', 'text_version', 'Version', '[[regtime]]', '[[regtime]]'),
(2360, 1, 1, 'extension_extensions', 'text_installed_on', 'Installed on', '[[regtime]]', '[[regtime]]'),
(2361, 1, 1, 'extension_extensions', 'text_installed', 'Installed', '[[regtime]]', '[[regtime]]'),
(2362, 1, 1, 'extension_extensions', 'text_not_installed', 'Not Installed', '[[regtime]]', '[[regtime]]'),
(2363, 1, 1, 'extension_extensions', 'text_visit_repository', 'Please visit extension repository</a> to download extension', '[[regtime]]', '[[regtime]]'),
(2364, 1, 1, 'extension_extensions', 'text_license', 'License', '[[regtime]]', '[[regtime]]'),
(2365, 1, 1, 'extension_extensions', 'text_dependency', 'Dependency', '[[regtime]]', '[[regtime]]'),
(2366, 1, 1, 'extension_extensions', 'text_configuration_settings', 'Configuration Settings', '[[regtime]]', '[[regtime]]'),
(2367, 1, 1, 'extension_extensions', 'text_upgrade', 'Upgrade', '[[regtime]]', '[[regtime]]'),
(2368, 1, 1, 'extension_extensions', 'text_help', 'Help', '[[regtime]]', '[[regtime]]'),
(2369, 1, 1, 'extension_extensions', 'text_dependencies', 'Dependencies', '[[regtime]]', '[[regtime]]'),
(2370, 1, 1, 'extension_extensions', 'text_update_available', 'New version (%s) is available. <a href="%s">Click to update now.</a>', '[[regtime]]', '[[regtime]]'),
(2371, 1, 1, 'extension_extensions', 'text_delete_confirm', 'Are you sure you want to delete extension?', '[[regtime]]', '[[regtime]]'),
(2372, 1, 1, 'extension_extensions', 'error_config_load', 'Error: Could not load config for <b>%s</b>!', '[[regtime]]', '[[regtime]]'),
(2373, 1, 1, 'extension_extensions', 'error_required_extension', '<b>%s</b> extension cannot be installed: <b>%s</b> extension required', '[[regtime]]', '[[regtime]]'),
(2374, 1, 1, 'extension_extensions', 'error_required_phpmodule', '<b>%s</b> extension cannot be installed: <b>%s</b> php module required', '[[regtime]]', '[[regtime]]'),
(2375, 1, 1, 'extension_extensions', 'button_restore_defaults', 'Restore Default Settings', '[[regtime]]', '[[regtime]]'),
(2376, 1, 1, 'extension_extensions', 'additional_settings_confirm', 'To set additional settings of extension of another store you need to log in into control panel on another domain name. Ok? ', '[[regtime]]', '[[regtime]]'),
(2377, 1, 1, 'extension_extensions', 'error_no_help_file', 'Sorry, there is no help file for this extension.', '[[regtime]]', '[[regtime]]'),
(2378, 1, 1, 'extension_extensions', 'text_more_help', 'More help', '[[regtime]]', '[[regtime]]'),
(2379, 1, 1, 'extension_extensions', 'entry_total_type', 'Type', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(2380, 1, 1, 'extension_extensions', 'text_total', 'Total', '[[regtime]]', '[[regtime]]'),
(2381, 1, 1, 'extension_extensions', 'text_subtotal', 'Sub-total', '[[regtime]]', '[[regtime]]'),
(2382, 1, 1, 'extension_extensions', 'text_shipping', 'Shipping', '[[regtime]]', '[[regtime]]'),
(2383, 1, 1, 'extension_extensions', 'text_tax', 'Tax', '[[regtime]]', '[[regtime]]'),
(2384, 1, 1, 'extension_extensions', 'text_fee', 'Fee', '[[regtime]]', '[[regtime]]'),
(2385, 1, 1, 'extension_extensions', 'text_discount', 'Discount', '[[regtime]]', '[[regtime]]'),
(2386, 1, 1, 'extension_extensions', 'text_confirm_disable_dependants', 'Extension %s have dependants are: <br>%s<br> It will be disabled automatically too.<br> Do you confirm?', '[[regtime]]', '[[regtime]]'),
(2387, 1, 1, 'extension_extensions', 'text_status', 'Status:<span class="help">This is to control storefront extension status.</span>', '[[regtime]]', '[[regtime]]'),
(2388, 1, 1, 'extension_extensions', 'text_sort_order', 'Run Order:<span class="help">Number to set display position order for this extension in relation to other enabled extensions. (Sorting is from lower to higher number, ignoring 0 and empty values) </span>', '[[regtime]]', '[[regtime]]'),
(2389, 1, 1, 'extension_extensions', 'text_payment_minimum_total', 'Total Order Minimum:<span class="help">Minimum order amount to be reached to allow this payment</span>', '[[regtime]]', '[[regtime]]'),
(2390, 1, 1, 'extension_extensions', 'text_payment_maximum_total', 'Total Order Maximum:<span class="help">Maximum order amount to be reached to disallow this payment</span>', '[[regtime]]', '[[regtime]]'),
(2391, 1, 1, 'extension_extensions', 'text_payment_storefront_icon', 'Storefront Icon:<span class="help">Payment Icon to be displayed at checkout payment selection</span>', '[[regtime]]', '[[regtime]]'),
(2392, 1, 1, 'extension_extensions', 'text_shipping_storefront_icon', 'Storefront Icon:<span class="help">Shipping Icon to be displayed at checkout shipping selection</span>', '[[regtime]]', '[[regtime]]'),
(2393, 1, 1, 'extension_extensions', 'text_autoselect_payment', 'Auto Select:<span class="help">Streamlines the checkout process by automatically choosing a payment method when multiple options are available.</span>', '[[regtime]]', '[[regtime]]'),
(2394, 1, 1, 'extension_extensions', 'text_autoselect_shipping', 'Auto Select:<span class="help">Streamlines the checkout process by automatically choosing a delivery method when multiple options are available.</span>', '[[regtime]]', '[[regtime]]'),
(2395, 1, 1, 'extension_extensions', 'text_accept_payments_shipping', 'Select to restrict payments:<span class="help">If only specific payment methods are needed for this shipping method, select them here. If nothing selected, all available payment methods will be shown</span>', '[[regtime]]', '[[regtime]]'),
(2396, 1, 1, 'extension_extensions', 'text_ready_to_install', 'Ready to install', '[[regtime]]', '[[regtime]]'),
(2397, 1, 1, 'extension_extensions', 'button_install', 'Install', '[[regtime]]', '[[regtime]]'),
(2398, 1, 1, 'extension_extensions', 'error_dependencies', 'This extension cannot be enabled because required dependency missing or not enabled.', '[[regtime]]', '[[regtime]]'),
(2399, 1, 1, 'extension_extensions', 'button_howto', 'How To', '[[regtime]]', '[[regtime]]'),
(2400, 1, 1, 'extension_extensions', 'text_developer_site', 'External support site', '[[regtime]]', '[[regtime]]'),
(2401, 1, 1, 'extension_extensions', 'text_preview', 'Preview', '[[regtime]]', '[[regtime]]'),
(2402, 1, 1, 'extension_extensions', 'text_confirmation', 'Confirmation', '[[regtime]]', '[[regtime]]'),
(2403, 1, 1, 'extension_extensions', 'button_confirm', 'Confirm', '[[regtime]]', '[[regtime]]'),
(2404, 1, 1, 'extension_extensions', 'button_continue', 'Continue', '[[regtime]]', '[[regtime]]'),
(2405, 1, 1, 'extension_extensions', 'button_cancel', 'Cancel', '[[regtime]]', '[[regtime]]'),
(2406, 1, 1, 'extension_extensions', 'error_could_not_load_config', 'Error: Could not load config for <b>%s</b> (%s)!', '[[regtime]]', '[[regtime]]'),
(2407, 1, 1, 'extension_extensions', 'error_could_not_load_override', 'Error: Cannot load override template %s in extension %s!', '[[regtime]]', '[[regtime]]'),
(2408, 1, 1, 'extension_extensions', 'tab_general', 'General', '[[regtime]]', '[[regtime]]'),
(2409, 1, 1, 'extension_extensions', 'tab_additional_settings', 'Additional Settings', '[[regtime]]', '[[regtime]]'),
(2410, 1, 1, 'extension_extensions', 'text_more_extensions', 'More extensions are available for easy installation.', '[[regtime]]', '[[regtime]]'),
(2411, 1, 1, 'extension_extensions', 'text_support_expiration', 'Support is active until', '[[regtime]]', '[[regtime]]'),
(2412, 1, 1, 'extension_extensions', 'text_support_expired', 'Support expired', '[[regtime]]', '[[regtime]]'),
(2413, 1, 1, 'extension_extensions', 'text_license_expired', 'Extension support has expired or not connected to marketplace', '[[regtime]]', '[[regtime]]'),
(2414, 1, 1, 'extension_extensions', 'button_get_support', 'Get Support', '[[regtime]]', '[[regtime]]'),
(2415, 1, 1, 'extension_extensions', 'text_min_volume', 'Minimal order parcel size volume in (cubic %s) <span class="help">Minimal value for shipment option to be available for customer. This value is based on combined products sizes in the order</span>', '[[regtime]]', '[[regtime]]'),
(2416, 1, 1, 'extension_extensions', 'text_max_volume', 'Maximal order parcel size volume in (cubic %s) <span class="help">Maximum value for shipment option to be available for customer. This value is based on combined products sizes in the order</span>', '[[regtime]]', '[[regtime]]'),
(2417, 1, 1, 'extension_extensions', 'text_min_weight', 'Minimal Weight of Parcel (%s)', '[[regtime]]', '[[regtime]]'),
(2418, 1, 1, 'extension_extensions', 'text_max_weight', 'Maximum Weight of Parcel (%s)', '[[regtime]]', '[[regtime]]'),
(2419, 1, 1, 'extension_extensions', 'text_min_order_subtotal', 'Minimum Order Subtotal: <span class="help">Enter the minimum order subtotal value for shipment option to be available for customer. This field is optional.</span>', '[[regtime]]', '[[regtime]]'),
(2420, 1, 1, 'extension_extensions', 'text_max_order_subtotal', 'Maximum Order Subtotal: <span class="help">Enter the maximum order subtotal value for shipment option to be available for customer. This field is optional.</span>', '[[regtime]]', '[[regtime]]'),
(2421, 1, 1, 'extension_extensions', 'text_customer_groups', 'Allowed only for customer group(s):', '[[regtime]]', '[[regtime]]'),
(2422, 1, 1, 'extension_extensions', 'button_load_more_languages', 'Load More Languages', '[[regtime]]', '[[regtime]]'),
(2423, 1, 1, 'extension_extensions_store', 'heading_title', 'Extensions Marketplace', '[[regtime]]', '[[regtime]]'),
(2424, 1, 1, 'extension_extensions_store', 'text_install', 'Install', '[[regtime]]', '[[regtime]]'),
(2425, 1, 1, 'extension_extensions_store', 'text_uninstall', 'Uninstall', '[[regtime]]', '[[regtime]]'),
(2426, 1, 1, 'extension_extensions_store', 'text_uninstall_delete', 'Uninstall/Delete', '[[regtime]]', '[[regtime]]'),
(2427, 1, 1, 'extension_extensions_store', 'text_uninstall_confirm', ' Please confirm you want to uninstall extension [ %extension% ]. All extension settings and related data might be deleted and lost. ', '[[regtime]]', '[[regtime]]'),
(2428, 1, 1, 'extension_extensions_store', 'text_delete', 'Delete', '[[regtime]]', '[[regtime]]'),
(2429, 1, 1, 'extension_extensions_store', 'text_enlarge', 'Click Image to Enlarge', '[[regtime]]', '[[regtime]]'),
(2430, 1, 1, 'extension_extensions_store', 'text_activate', 'Activate', '[[regtime]]', '[[regtime]]'),
(2431, 1, 1, 'extension_extensions_store', 'text_deactivate', 'Deactivate', '[[regtime]]', '[[regtime]]'),
(2432, 1, 1, 'extension_extensions_store', 'text_left', 'Left', '[[regtime]]', '[[regtime]]'),
(2433, 1, 1, 'extension_extensions_store', 'text_right', 'Right', '[[regtime]]', '[[regtime]]'),
(2434, 1, 1, 'extension_extensions_store', 'text_date_added', 'Added on', '[[regtime]]', '[[regtime]]'),
(2435, 1, 1, 'extension_extensions_store', 'error_permission', 'Warning: You do not have permission to modify extensions!', '[[regtime]]', '[[regtime]]'),
(2436, 1, 1, 'extension_extensions_store', 'error_required_field', 'Warning: Please fill required fields! ', '[[regtime]]', '[[regtime]]'),
(2437, 1, 1, 'extension_extensions_store', 'error_payment_uninstall', 'Warning: Disable extension before uninstall!', '[[regtime]]', '[[regtime]]'),
(2438, 1, 1, 'extension_extensions_store', 'error_uninstall', 'Warning: Uninstall extension before delete!', '[[regtime]]', '[[regtime]]'),
(2439, 1, 1, 'extension_extensions_store', 'text_success', 'Success: You have modified extension settings!', '[[regtime]]', '[[regtime]]'),
(2440, 1, 1, 'extension_extensions_store', 'text_extensions_store', 'Extensions Marketplace', '[[regtime]]', '[[regtime]]'),
(2441, 1, 1, 'extension_extensions_store', 'text_required', 'Required', '[[regtime]]', '[[regtime]]'),
(2442, 1, 1, 'extension_extensions_store', 'text_optional', 'Optional', '[[regtime]]', '[[regtime]]'),
(2443, 1, 1, 'extension_extensions_store', 'text_add_new', 'Install Extension', '[[regtime]]', '[[regtime]]'),
(2444, 1, 1, 'extension_extensions_store', 'error_connect', 'Oops, Your AbanteCart cannot connect with extensions marketplace. Please see System->Error logs for details.', '[[regtime]]', '[[regtime]]'),
(2445, 1, 1, 'extension_extensions_store', 'text_sorting_review_asc', 'Review Count Low > High', '[[regtime]]', '[[regtime]]'),
(2446, 1, 1, 'extension_extensions_store', 'text_sorting_review_desc', 'Review Count High > Low', '[[regtime]]', '[[regtime]]'),
(2447, 1, 1, 'extension_extensions_store', 'text_sorting_price_asc', 'Price Low > High', '[[regtime]]', '[[regtime]]'),
(2448, 1, 1, 'extension_extensions_store', 'text_sorting_price_desc', 'Price High > Low', '[[regtime]]', '[[regtime]]'),
(2449, 1, 1, 'extension_extensions_store', 'text_sorting_rating_desc', 'Rating Highest', '[[regtime]]', '[[regtime]]'),
(2450, 1, 1, 'extension_extensions_store', 'text_sorting_rating_asc', 'Rating Lowest', '[[regtime]]', '[[regtime]]'),
(2451, 1, 1, 'extension_extensions_store', 'text_sorting_date_modified_asc', 'Date New To Old', '[[regtime]]', '[[regtime]]'),
(2452, 1, 1, 'extension_extensions_store', 'text_sorting_date_modified_desc', 'Date Old to New', '[[regtime]]', '[[regtime]]'),
(2453, 1, 1, 'extension_extensions_store', 'text_my_extensions', 'My Extensions', '[[regtime]]', '[[regtime]]'),
(2454, 1, 1, 'extension_extensions_store', 'text_my_account', 'My Account', '[[regtime]]', '[[regtime]]'),
(2455, 1, 1, 'extension_extensions_store', 'text_marketplace_site', 'Marketplace Site', '[[regtime]]', '[[regtime]]'),
(2456, 1, 1, 'extension_extensions_store', 'text_all_categories', 'All Categories', '[[regtime]]', '[[regtime]]'),
(2457, 1, 1, 'extension_extensions_store', 'text_connect', 'Connect', '[[regtime]]', '[[regtime]]'),
(2458, 1, 1, 'extension_extensions_store', 'text_marketplace_connect', 'Connect to the marketplace', '[[regtime]]', '[[regtime]]'),
(2459, 1, 1, 'extension_extensions_store', 'text_marketplace_extension', 'Extension preview & order ', '[[regtime]]', '[[regtime]]'),
(2460, 1, 1, 'extension_extensions_store', 'text_marketplace_buy', 'Get this extension now', '[[regtime]]', '[[regtime]]'),
(2461, 1, 1, 'extension_extensions_store', 'text_connected', 'Connected to the marketplace. Click to disconnect', '[[regtime]]', '[[regtime]]'),
(2462, 1, 1, 'extension_extensions_store', 'text_disconnect_confirm', 'Are you sure you want to disconnect?', '[[regtime]]', '[[regtime]]'),
(2463, 1, 1, 'extension_extensions_store', 'text_disconnect_success', 'This store was disconnected!', '[[regtime]]', '[[regtime]]'),
(2464, 1, 1, 'extension_extensions_store', 'text_connection_required', 'You need to connect AbanteCart to the Marketplace to see your extensions! Click "connect" button in the above panel.', '[[regtime]]', '[[regtime]]'),
(2465, 1, 1, 'extension_extensions_store', 'text_in_other_store', 'Extension for this order was installed in the other AbanteCart. Check your connected stores for history.', '[[regtime]]', '[[regtime]]'),
(2466, 1, 1, 'extension_extensions_store', 'text_no_purchase_or_not_connected', 'You have no purchases for this store or this store was disconnected from the Marketplace.', '[[regtime]]', '[[regtime]]'),
(2467, 1, 1, 'extension_extensions_store', 'text_no_extensions_loaded', 'No extensions are available. Check your selection or try again.', '[[regtime]]', '[[regtime]]'),
(2468, 1, 1, 'extension_extensions_store', 'text_compatibility', 'This extension is not confirmed to work with your version of AbanteCart. Contact extension developer to confirm compatibility.', '[[regtime]]', '[[regtime]]'),
(2469, 1, 1, 'extension_extensions_store', 'error_mp_connection', 'Oops, can not connect to AbanteCart MarketPlace. Please try to check later or ask your hosting service provider for help.', '[[regtime]]', '[[regtime]]'),
(2470, 1, 1, 'extension_extensions_store', 'text_search', 'search', '[[regtime]]', '[[regtime]]'),
(2471, 1, 1, 'extension_shipping', 'heading_title', 'Shipping', '[[regtime]]', '[[regtime]]'),
(2472, 1, 1, 'extension_shipping', 'text_install', 'Install', '[[regtime]]', '[[regtime]]'),
(2473, 1, 1, 'extension_shipping', 'text_uninstall', 'Uninstall', '[[regtime]]', '[[regtime]]'),
(2474, 1, 1, 'extension_shipping', 'column_name', 'Shipping Method', '[[regtime]]', '[[regtime]]'),
(2475, 1, 1, 'extension_shipping', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(2476, 1, 1, 'extension_shipping', 'column_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(2477, 1, 1, 'extension_shipping', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2478, 1, 1, 'extension_total', 'heading_title', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(2479, 1, 1, 'extension_total', 'text_install', 'Install', '[[regtime]]', '[[regtime]]'),
(2480, 1, 1, 'extension_total', 'text_uninstall', 'Uninstall', '[[regtime]]', '[[regtime]]'),
(2481, 1, 1, 'extension_total', 'column_name', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(2482, 1, 1, 'extension_total', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(2483, 1, 1, 'extension_total', 'column_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(2484, 1, 1, 'extension_total', 'column_calculation_order', 'Calculation Order', '[[regtime]]', '[[regtime]]'),
(2485, 1, 1, 'extension_total', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2486, 1, 1, 'localisation_country', 'heading_title', 'Countries', '[[regtime]]', '[[regtime]]'),
(2487, 1, 1, 'localisation_country', 'text_country', 'Country', '[[regtime]]', '[[regtime]]'),
(2488, 1, 1, 'localisation_country', 'text_success', 'Success: You have modified countries!', '[[regtime]]', '[[regtime]]'),
(2489, 1, 1, 'localisation_country', 'column_name', 'Country Name', '[[regtime]]', '[[regtime]]'),
(2490, 1, 1, 'localisation_country', 'column_iso_code_2', 'ISO Code (2)', '[[regtime]]', '[[regtime]]'),
(2491, 1, 1, 'localisation_country', 'column_iso_code_3', 'ISO Code (3)', '[[regtime]]', '[[regtime]]'),
(2492, 1, 1, 'localisation_country', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2493, 1, 1, 'localisation_country', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(2494, 1, 1, 'localisation_country', 'entry_status', 'Country Status:', '[[regtime]]', '[[regtime]]'),
(2495, 1, 1, 'localisation_country', 'entry_name', 'Country Name:', '[[regtime]]', '[[regtime]]'),
(2496, 1, 1, 'localisation_country', 'entry_iso_code_2', 'ISO Code (2):', '[[regtime]]', '[[regtime]]'),
(2497, 1, 1, 'localisation_country', 'entry_iso_code_3', 'ISO Code (3):', '[[regtime]]', '[[regtime]]'),
(2498, 1, 1, 'localisation_country', 'entry_address_format', 'Address Format:<br /><span class="help">\nFirst Name = {firstname}<br />\nLast Name = {lastname}<br />\nCompany = {company}<br />\nAddress 1 = {address_1}<br />\nAddress 2 = {address_2}<br />\nCity = {city}<br />\nPostcode = {postcode}<br />\nZone = {zone}<br />\nZone Code = {zone_code}<br />\nCountry = {country}</span>', '[[regtime]]', '[[regtime]]'),
(2499, 1, 1, 'localisation_country', 'error_permission', 'Warning: You do not have permission to modify countries!', '[[regtime]]', '[[regtime]]'),
(2500, 1, 1, 'localisation_country', 'error_name', 'Country Name must be between 2 and 128 characters!', '[[regtime]]', '[[regtime]]'),
(2501, 1, 1, 'localisation_country', 'error_default', 'Warning: This country cannot be deleted as it is currently assigned as the default store country!', '[[regtime]]', '[[regtime]]'),
(2502, 1, 1, 'localisation_country', 'error_store', 'Warning: This country cannot be deleted as it is currently assigned to %s stores!', '[[regtime]]', '[[regtime]]'),
(2503, 1, 1, 'localisation_country', 'error_address', 'Warning: This country cannot be deleted as it is currently assigned to %s address book entries!', '[[regtime]]', '[[regtime]]'),
(2504, 1, 1, 'localisation_country', 'error_zone', 'Warning: This country cannot be deleted as it is currently assigned to %s zones!', '[[regtime]]', '[[regtime]]'),
(2505, 1, 1, 'localisation_country', 'error_zone_to_location', 'Warning: This country cannot be deleted as it is currently assigned to %s zones to locations!', '[[regtime]]', '[[regtime]]'),
(2506, 1, 1, 'localisation_currency', 'heading_title', 'Currencies', '[[regtime]]', '[[regtime]]'),
(2507, 1, 1, 'localisation_currency', 'text_currency', 'Currency', '[[regtime]]', '[[regtime]]'),
(2508, 1, 1, 'localisation_currency', 'text_success', 'Success: You have modified currencies!', '[[regtime]]', '[[regtime]]'),
(2509, 1, 1, 'localisation_currency', 'column_title', 'Currency Title', '[[regtime]]', '[[regtime]]'),
(2510, 1, 1, 'localisation_currency', 'column_code', 'Code', '[[regtime]]', '[[regtime]]'),
(2511, 1, 1, 'localisation_currency', 'column_value', 'Value', '[[regtime]]', '[[regtime]]'),
(2512, 1, 1, 'localisation_currency', 'column_date_modified', 'Last Updated', '[[regtime]]', '[[regtime]]'),
(2513, 1, 1, 'localisation_currency', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(2514, 1, 1, 'localisation_currency', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2515, 1, 1, 'localisation_currency', 'entry_title', 'Currency Title:', '[[regtime]]', '[[regtime]]'),
(2516, 1, 1, 'localisation_currency', 'entry_code', 'Code:<br /><span class="help">Do not change if this is your default currency.</span>', '[[regtime]]', '[[regtime]]'),
(2517, 1, 1, 'localisation_currency', 'entry_value', 'Value:<br /><span class="help">Set to 1.00000 if this is your default currency.</span>', '[[regtime]]', '[[regtime]]'),
(2518, 1, 1, 'localisation_currency', 'entry_symbol_left', 'Symbol Left:', '[[regtime]]', '[[regtime]]'),
(2519, 1, 1, 'localisation_currency', 'entry_symbol_right', 'Symbol Right:', '[[regtime]]', '[[regtime]]'),
(2520, 1, 1, 'localisation_currency', 'entry_decimal_place', 'Decimal Places:', '[[regtime]]', '[[regtime]]'),
(2521, 1, 1, 'localisation_currency', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(2522, 1, 1, 'localisation_currency', 'error_permission', 'Warning: You do not have permission to modify currencies!', '[[regtime]]', '[[regtime]]'),
(2523, 1, 1, 'localisation_currency', 'error_title', 'Currency Title must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2524, 1, 1, 'localisation_currency', 'error_code', 'Currency Code must contain 3 characters!', '[[regtime]]', '[[regtime]]'),
(2525, 1, 1, 'localisation_currency', 'error_default', 'Warning: This currency cannot be deleted as it is currently assigned as the default store currency!', '[[regtime]]', '[[regtime]]'),
(2526, 1, 1, 'localisation_currency', 'error_store', 'Warning: This currency cannot be deleted as it is currently assigned to %s stores!', '[[regtime]]', '[[regtime]]'),
(2527, 1, 1, 'localisation_currency', 'error_order', 'Warning: This currency cannot be deleted as it is currently assigned to %s orders!', '[[regtime]]', '[[regtime]]'),
(2528, 1, 1, 'localisation_language', 'heading_title', 'Languages', '[[regtime]]', '[[regtime]]'),
(2529, 1, 1, 'localisation_language', 'text_language', 'Language', '[[regtime]]', '[[regtime]]'),
(2530, 1, 1, 'localisation_language', 'text_success', 'Success: You have modified languages!', '[[regtime]]', '[[regtime]]'),
(2531, 1, 1, 'localisation_language', 'column_name', 'Language Name', '[[regtime]]', '[[regtime]]'),
(2532, 1, 1, 'localisation_language', 'column_code', 'Code', '[[regtime]]', '[[regtime]]'),
(2533, 1, 1, 'localisation_language', 'column_sort_order', 'Sort Order', '[[regtime]]', '[[regtime]]'),
(2534, 1, 1, 'localisation_language', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2535, 1, 1, 'localisation_language', 'entry_name', 'Language Name:', '[[regtime]]', '[[regtime]]'),
(2536, 1, 1, 'localisation_language', 'entry_code', 'Code:<br /><span class="help">Do not change if this is your default language.</span>', '[[regtime]]', '[[regtime]]'),
(2537, 1, 1, 'localisation_language', 'entry_locale', 'Locale:', '[[regtime]]', '[[regtime]]'),
(2538, 1, 1, 'localisation_language', 'entry_image', 'Image:', '[[regtime]]', '[[regtime]]'),
(2539, 1, 1, 'localisation_language', 'entry_directory', 'Directory:', '[[regtime]]', '[[regtime]]'),
(2540, 1, 1, 'localisation_language', 'entry_filename', 'Filename:', '[[regtime]]', '[[regtime]]'),
(2541, 1, 1, 'localisation_language', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(2542, 1, 1, 'localisation_language', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(2543, 1, 1, 'localisation_language', 'error_permission', 'Warning: You do not have permission to modify languages!', '[[regtime]]', '[[regtime]]'),
(2544, 1, 1, 'localisation_language', 'error_name', 'Language Name must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2545, 1, 1, 'localisation_language', 'error_code', 'Language Code must at least 2 characters!', '[[regtime]]', '[[regtime]]'),
(2546, 1, 1, 'localisation_language', 'error_locale', 'Locale required!', '[[regtime]]', '[[regtime]]'),
(2547, 1, 1, 'localisation_language', 'error_image', 'Image Filename must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(2548, 1, 1, 'localisation_language', 'error_directory', 'Directory required!', '[[regtime]]', '[[regtime]]'),
(2549, 1, 1, 'localisation_language', 'error_filename', 'Filename must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(2550, 1, 1, 'localisation_language', 'error_default', 'Warning: This language cannot be deleted as it is currently assigned as the default store language!', '[[regtime]]', '[[regtime]]'),
(2551, 1, 1, 'localisation_language', 'error_admin', 'Warning: This Language cannot be deleted as it is currently assigned as the administration language!', '[[regtime]]', '[[regtime]]'),
(2552, 1, 1, 'localisation_language', 'error_store', 'Warning: This language cannot be deleted as it is currently assigned to %s stores!', '[[regtime]]', '[[regtime]]'),
(2553, 1, 1, 'localisation_language', 'error_order', 'Warning: This language cannot be deleted as it is currently assigned to %s orders!', '[[regtime]]', '[[regtime]]'),
(2554, 1, 1, 'localisation_language', 'language_edit_title', 'Edit Language Details', '[[regtime]]', '[[regtime]]'),
(2555, 1, 1, 'localisation_language', 'load_language_title', 'Load missing language data', '[[regtime]]', '[[regtime]]'),
(2556, 1, 1, 'localisation_language', 'entry_language_selector', 'Source Language: ', '[[regtime]]', '[[regtime]]'),
(2557, 1, 1, 'localisation_language', 'entry_translate_method_selector', 'Text translation method: ', '[[regtime]]', '[[regtime]]'),
(2558, 1, 1, 'localisation_language', 'load_language_note', 'NOTE: This operation might take few minutes to run. Do NOT close browser, leave or refresh the page!  ', '[[regtime]]', '[[regtime]]'),
(2559, 1, 1, 'localisation_language', 'create_language_note', 'NOTE: We recommend creating language as an extension. Check existing language extensions. If you still want to create new language manually, you need to add language Flag to  admin/language/[Language Directory]/flag.png and  storefront/language/[Language Directory]flag.png\n    After language is created load missing language data to translate or copy text content from source language.  ', '[[regtime]]', '[[regtime]]'),
(2560, 1, 1, 'localisation_language', 'button_load_language', 'Load', '[[regtime]]', '[[regtime]]'),
(2561, 1, 1, 'localisation_language', 'text_incomplete_tasks', 'Incomplete Tasks', '[[regtime]]', '[[regtime]]'),
(2562, 1, 1, 'localisation_language', 'text_task_id', 'Task ID:', '[[regtime]]', '[[regtime]]'),
(2563, 1, 1, 'localisation_language', 'text_title', 'Title:', '[[regtime]]', '[[regtime]]'),
(2564, 1, 1, 'localisation_language', 'text_last_time_run', 'Last Time Run:', '[[regtime]]', '[[regtime]]'),
(2565, 1, 1, 'localisation_language', 'text_date_added', 'Created:', '[[regtime]]', '[[regtime]]'),
(2566, 1, 1, 'localisation_language', 'text_starter_name', 'Created by:', '[[regtime]]', '[[regtime]]'),
(2567, 1, 1, 'localisation_language', 'text_restart', 'Restart', '[[regtime]]', '[[regtime]]'),
(2568, 1, 1, 'localisation_language', 'text_remove', 'Remove', '[[regtime]]', '[[regtime]]'),
(2569, 1, 1, 'localisation_language', 'text_task_title', 'Translation of Descriptions From %s to %s', '[[regtime]]', '[[regtime]]'),
(2570, 1, 1, 'localisation_language', 'error_nothing_to_do', 'Error: Please Set Source Language and Translation Method!', '[[regtime]]', '[[regtime]]'),
(2571, 1, 1, 'localisation_language', 'text_translate_override_existing', 'Note: All existing descriptions in target language will be replaced with new translation. You can disable overriding in <a href="%s">System->Settings->Store Details</a>.', '[[regtime]]', '[[regtime]]'),
(2572, 1, 1, 'localisation_language', 'text_copy_source_text', 'Copy Source Language Text', '[[regtime]]', '[[regtime]]'),
(2573, 1, 1, 'localisation_language', 'error_all_disabled', ' At least one language must be an active!', '[[regtime]]', '[[regtime]]'),
(2574, 1, 1, 'localisation_language_definitions', 'heading_title', 'Language Definitions', '[[regtime]]', '[[regtime]]'),
(2575, 1, 1, 'localisation_language_definitions', 'text_definition', 'Language Definition', '[[regtime]]', '[[regtime]]'),
(2576, 1, 1, 'localisation_language_definitions', 'text_success', 'Success: You have modified languages!', '[[regtime]]', '[[regtime]]'),
(2577, 1, 1, 'localisation_language_definitions', 'column_language', 'Language', '[[regtime]]', '[[regtime]]'),
(2578, 1, 1, 'localisation_language_definitions', 'column_key', 'Key', '[[regtime]]', '[[regtime]]'),
(2579, 1, 1, 'localisation_language_definitions', 'column_translation', 'Translation', '[[regtime]]', '[[regtime]]'),
(2580, 1, 1, 'localisation_language_definitions', 'column_block', 'Block', '[[regtime]]', '[[regtime]]'),
(2581, 1, 1, 'localisation_language_definitions', 'column_update_date', 'Update date', '[[regtime]]', '[[regtime]]'),
(2582, 1, 1, 'localisation_language_definitions', 'column_action', 'Actions', '[[regtime]]', '[[regtime]]'),
(2583, 1, 1, 'localisation_language_definitions', 'entry_language_key', 'Key', '[[regtime]]', '[[regtime]]'),
(2584, 1, 1, 'localisation_language_definitions', 'entry_language_value', 'Value', '[[regtime]]', '[[regtime]]'),
(2585, 1, 1, 'localisation_language_definitions', 'entry_translation', 'Translation', '[[regtime]]', '[[regtime]]'),
(2586, 1, 1, 'localisation_language_definitions', 'entry_block', 'Block', '[[regtime]]', '[[regtime]]'),
(2587, 1, 1, 'localisation_language_definitions', 'entry_section', 'Section', '[[regtime]]', '[[regtime]]'),
(2588, 1, 1, 'localisation_language_definitions', 'text_admin', 'Admin', '[[regtime]]', '[[regtime]]'),
(2589, 1, 1, 'localisation_language_definitions', 'text_storefront', 'Storefront', '[[regtime]]', '[[regtime]]'),
(2590, 1, 1, 'localisation_language_definitions', 'error_language_key', 'Language key required!', '[[regtime]]', '[[regtime]]'),
(2591, 1, 1, 'localisation_language_definitions', 'error_language_value', 'Translation required!', '[[regtime]]', '[[regtime]]'),
(2592, 1, 1, 'localisation_language_definitions', 'error_block', 'Block required!', '[[regtime]]', '[[regtime]]'),
(2593, 1, 1, 'localisation_language_definitions', 'error_section', 'Section required!', '[[regtime]]', '[[regtime]]'),
(2594, 1, 1, 'localisation_language_definitions', 'text_all_section', 'All Sections', '[[regtime]]', '[[regtime]]'),
(2595, 1, 1, 'localisation_language_definitions', 'text_all_languages', 'All Languages', '[[regtime]]', '[[regtime]]'),
(2596, 1, 1, 'localisation_language_definitions', 'error_already exists', 'Error!<br>Language definition with key "%s" and block "%s" for %s section already exists!<br>Click <a target="_blank" href="%s">this link</a> to view', '[[regtime]]', '[[regtime]]'),
(2597, 1, 1, 'localisation_length_class', 'heading_title', 'Length Classes', '[[regtime]]', '[[regtime]]'),
(2598, 1, 1, 'localisation_length_class', 'text_class', 'Length Class', '[[regtime]]', '[[regtime]]'),
(2599, 1, 1, 'localisation_length_class', 'text_success', 'Success: You have modified length classes!', '[[regtime]]', '[[regtime]]'),
(2600, 1, 1, 'localisation_length_class', 'column_title', 'Length Title', '[[regtime]]', '[[regtime]]'),
(2601, 1, 1, 'localisation_length_class', 'column_unit', 'Length Unit', '[[regtime]]', '[[regtime]]'),
(2602, 1, 1, 'localisation_length_class', 'column_value', 'Value', '[[regtime]]', '[[regtime]]'),
(2603, 1, 1, 'localisation_length_class', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2604, 1, 1, 'localisation_length_class', 'entry_title', 'Length Title:', '[[regtime]]', '[[regtime]]'),
(2605, 1, 1, 'localisation_length_class', 'entry_unit', 'Length Unit:', '[[regtime]]', '[[regtime]]'),
(2606, 1, 1, 'localisation_length_class', 'entry_value', 'Value:', '[[regtime]]', '[[regtime]]'),
(2607, 1, 1, 'localisation_length_class', 'error_permission', 'Warning: You do not have permission to modify length classes!', '[[regtime]]', '[[regtime]]'),
(2608, 1, 1, 'localisation_length_class', 'error_title', 'Length Title must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2609, 1, 1, 'localisation_length_class', 'error_unit', 'Length Unit must be between 1 and 4 characters!', '[[regtime]]', '[[regtime]]'),
(2610, 1, 1, 'localisation_length_class', 'error_default', 'Warning: This length class cannot be deleted as it is currently assigned as the default store length class!', '[[regtime]]', '[[regtime]]'),
(2611, 1, 1, 'localisation_length_class', 'error_product', 'Warning: This length class cannot be deleted as it is currently assigned to %s products!', '[[regtime]]', '[[regtime]]'),
(2612, 1, 1, 'localisation_length_class', 'error_iso_code', 'ISO-code must be 4 characters and must be unique!', '[[regtime]]', '[[regtime]]'),
(2613, 1, 1, 'localisation_length_class', 'entry_iso_code', 'ISO-code:', '[[regtime]]', '[[regtime]]'),
(2614, 1, 1, 'localisation_length_class', 'column_iso_code', 'ISO-code', '[[regtime]]', '[[regtime]]'),
(2615, 1, 1, 'localisation_location', 'heading_title', 'Locations', '[[regtime]]', '[[regtime]]'),
(2616, 1, 1, 'localisation_location', 'text_location', 'Location', '[[regtime]]', '[[regtime]]'),
(2617, 1, 1, 'localisation_location', 'text_location_zone', 'Location Zone', '[[regtime]]', '[[regtime]]'),
(2618, 1, 1, 'localisation_location', 'text_location_zones', 'Location Zones', '[[regtime]]', '[[regtime]]'),
(2619, 1, 1, 'localisation_location', 'text_success', 'Success: You have modified locations!', '[[regtime]]', '[[regtime]]'),
(2620, 1, 1, 'localisation_location', 'column_name', 'Location Name', '[[regtime]]', '[[regtime]]'),
(2621, 1, 1, 'localisation_location', 'column_description', 'Description', '[[regtime]]', '[[regtime]]'),
(2622, 1, 1, 'localisation_location', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2623, 1, 1, 'localisation_location', 'tab_details', 'Details', '[[regtime]]', '[[regtime]]'),
(2624, 1, 1, 'localisation_location', 'tab_locations', 'Location Zones', '[[regtime]]', '[[regtime]]'),
(2625, 1, 1, 'localisation_location', 'entry_name', 'Location Name:', '[[regtime]]', '[[regtime]]'),
(2626, 1, 1, 'localisation_location', 'entry_description', 'Description:', '[[regtime]]', '[[regtime]]'),
(2627, 1, 1, 'localisation_location', 'entry_country', 'Country:', '[[regtime]]', '[[regtime]]'),
(2628, 1, 1, 'localisation_location', 'entry_zone', 'Zone(s):', '[[regtime]]', '[[regtime]]'),
(2629, 1, 1, 'localisation_location', 'error_permission', 'Warning: You do not have permission to modify locations!', '[[regtime]]', '[[regtime]]'),
(2630, 1, 1, 'localisation_location', 'error_name', 'Location Name must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2631, 1, 1, 'localisation_location', 'error_description', 'Description Name must be between 2 and 255 characters!', '[[regtime]]', '[[regtime]]'),
(2632, 1, 1, 'localisation_location', 'error_tax_rate', 'Warning: This location cannot be deleted as it is currently assigned to one or more tax rates!', '[[regtime]]', '[[regtime]]'),
(2633, 1, 1, 'localisation_order_status', 'heading_title', 'Order Statuses', '[[regtime]]', '[[regtime]]'),
(2634, 1, 1, 'localisation_order_status', 'text_status', 'Order Status', '[[regtime]]', '[[regtime]]'),
(2635, 1, 1, 'localisation_order_status', 'text_success', 'Success: You have modified order statuses!', '[[regtime]]', '[[regtime]]'),
(2636, 1, 1, 'localisation_order_status', 'column_name', 'Order Status Name', '[[regtime]]', '[[regtime]]'),
(2637, 1, 1, 'localisation_order_status', 'column_text_id', 'Order Status Text ID', '[[regtime]]', '[[regtime]]'),
(2638, 1, 1, 'localisation_order_status', 'entry_text_id', 'Order Status Text ID:', '[[regtime]]', '[[regtime]]'),
(2639, 1, 1, 'localisation_order_status', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2640, 1, 1, 'localisation_order_status', 'entry_name', 'Order Status Name:', '[[regtime]]', '[[regtime]]'),
(2641, 1, 1, 'localisation_order_status', 'error_permission', 'Warning: You do not have permission to modify order statues!', '[[regtime]]', '[[regtime]]'),
(2642, 1, 1, 'localisation_order_status', 'error_name', 'Order Status Name must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2643, 1, 1, 'localisation_order_status', 'error_default', 'Warning: This order status cannot be deleted as it is currently assigned as the default store order status!', '[[regtime]]', '[[regtime]]'),
(2644, 1, 1, 'localisation_order_status', 'error_download', 'Warning: This order status cannot be deleted as it is currently assigned as the default download status!', '[[regtime]]', '[[regtime]]'),
(2645, 1, 1, 'localisation_order_status', 'error_store', 'Warning: This order status cannot be deleted as it is currently assigned to %s stores!', '[[regtime]]', '[[regtime]]'),
(2646, 1, 1, 'localisation_order_status', 'error_order', 'Warning: This order status cannot be deleted as it is currently assigned to %s orders!', '[[regtime]]', '[[regtime]]'),
(2647, 1, 1, 'localisation_order_status', 'error_nondeletable', 'Warning: This is important order status that is linked to payments. You can not delete this status.', '[[regtime]]', '[[regtime]]'),
(2648, 1, 1, 'localisation_order_status', 'error_status_text_id', 'Order Status Text Id must be Unique and between 2 and 32 latin characters!', '[[regtime]]', '[[regtime]]'),
(2649, 1, 1, 'localisation_stock_status', 'heading_title', 'Stock Statuses', '[[regtime]]', '[[regtime]]'),
(2650, 1, 1, 'localisation_stock_status', 'text_status', 'Stock Status', '[[regtime]]', '[[regtime]]'),
(2651, 1, 1, 'localisation_stock_status', 'text_success', 'Success: You have modified stock statuses!', '[[regtime]]', '[[regtime]]'),
(2652, 1, 1, 'localisation_stock_status', 'column_name', 'Stock Status Name', '[[regtime]]', '[[regtime]]'),
(2653, 1, 1, 'localisation_stock_status', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2654, 1, 1, 'localisation_stock_status', 'entry_name', 'Stock Status Name:', '[[regtime]]', '[[regtime]]'),
(2655, 1, 1, 'localisation_stock_status', 'error_permission', 'Warning: You do not have permission to modify stock statues!', '[[regtime]]', '[[regtime]]'),
(2656, 1, 1, 'localisation_stock_status', 'error_name', 'Stock Status Name must be between 2 and 128 characters!', '[[regtime]]', '[[regtime]]'),
(2657, 1, 1, 'localisation_stock_status', 'error_product', 'Warning: This stock status cannot be deleted as it is currently assigned to %s products!', '[[regtime]]', '[[regtime]]'),
(2658, 1, 1, 'localisation_tax_class', 'heading_title', 'Tax Classes', '[[regtime]]', '[[regtime]]'),
(2659, 1, 1, 'localisation_tax_class', 'text_class', 'Tax Class', '[[regtime]]', '[[regtime]]'),
(2660, 1, 1, 'localisation_tax_class', 'text_rate', 'Tax Rate', '[[regtime]]', '[[regtime]]'),
(2661, 1, 1, 'localisation_tax_class', 'text_success', 'Success: You have modified tax classes!', '[[regtime]]', '[[regtime]]'),
(2662, 1, 1, 'localisation_tax_class', 'column_title', 'Tax Class Title', '[[regtime]]', '[[regtime]]'),
(2663, 1, 1, 'localisation_tax_class', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2664, 1, 1, 'localisation_tax_class', 'tab_details', 'Details', '[[regtime]]', '[[regtime]]'),
(2665, 1, 1, 'localisation_tax_class', 'tab_rates', 'Rates', '[[regtime]]', '[[regtime]]'),
(2666, 1, 1, 'localisation_tax_class', 'entry_title', 'Tax Class Title:', '[[regtime]]', '[[regtime]]'),
(2667, 1, 1, 'localisation_tax_class', 'entry_description', 'Description visible to customers', '[[regtime]]', '[[regtime]]'),
(2668, 1, 1, 'localisation_tax_class', 'entry_location', 'Location', '[[regtime]]', '[[regtime]]'),
(2669, 1, 1, 'localisation_tax_class', 'entry_zone', 'Location zone', '[[regtime]]', '[[regtime]]'),
(2670, 1, 1, 'localisation_tax_class', 'entry_priority', 'Priority', '[[regtime]]', '[[regtime]]'),
(2671, 1, 1, 'localisation_tax_class', 'entry_rate', 'Tax Rate', '[[regtime]]', '[[regtime]]'),
(2672, 1, 1, 'localisation_tax_class', 'error_permission', 'Warning: You do not have permission to modify tax classes!', '[[regtime]]', '[[regtime]]'),
(2673, 1, 1, 'localisation_tax_class', 'error_tax_title', 'Tax Class Title must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2674, 1, 1, 'localisation_tax_class', 'error_rate', 'Tax Rate required!', '[[regtime]]', '[[regtime]]'),
(2675, 1, 1, 'localisation_tax_class', 'error_product', 'Warning: This tax class cannot be deleted as it is currently assigned to %s products!', '[[regtime]]', '[[regtime]]'),
(2676, 1, 1, 'localisation_tax_class', 'text_tax_all_zones', 'all location zones', '[[regtime]]', '[[regtime]]'),
(2677, 1, 1, 'localisation_tax_class', 'entry_tax_rate_threshold', 'Apply tax if<br /><span class="help">Apply this tax only if, taxed amount (product, shipping, subtotal, etc.) is ...</span>', '[[regtime]]', '[[regtime]]'),
(2678, 1, 1, 'localisation_tax_class', 'entry_tax_exempt_groups', 'Tax Exempt Groups<br /><span class="help">Select customer groups to exempt from this tax</span>', '[[regtime]]', '[[regtime]]'),
(2679, 1, 1, 'localisation_tax_class', 'text_absolute', 'Absolute', '[[regtime]]', '[[regtime]]'),
(2680, 1, 1, 'localisation_tax_class', 'text_percent', 'Percent', '[[regtime]]', '[[regtime]]'),
(2681, 1, 1, 'localisation_weight_class', 'heading_title', 'Weight Classes', '[[regtime]]', '[[regtime]]'),
(2682, 1, 1, 'localisation_weight_class', 'text_class', 'Weight Class', '[[regtime]]', '[[regtime]]'),
(2683, 1, 1, 'localisation_weight_class', 'text_success', 'Success: You have modified weight classes!', '[[regtime]]', '[[regtime]]'),
(2684, 1, 1, 'localisation_weight_class', 'column_title', 'Weight Title', '[[regtime]]', '[[regtime]]'),
(2685, 1, 1, 'localisation_weight_class', 'column_unit', 'Weight Unit', '[[regtime]]', '[[regtime]]'),
(2686, 1, 1, 'localisation_weight_class', 'column_value', 'Value', '[[regtime]]', '[[regtime]]'),
(2687, 1, 1, 'localisation_weight_class', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2688, 1, 1, 'localisation_weight_class', 'entry_title', 'Weight Title:', '[[regtime]]', '[[regtime]]'),
(2689, 1, 1, 'localisation_weight_class', 'entry_unit', 'Weight Unit:', '[[regtime]]', '[[regtime]]'),
(2690, 1, 1, 'localisation_weight_class', 'entry_value', 'Value:', '[[regtime]]', '[[regtime]]'),
(2691, 1, 1, 'localisation_weight_class', 'error_permission', 'Warning: You do not have permission to modify weight classes!', '[[regtime]]', '[[regtime]]'),
(2692, 1, 1, 'localisation_weight_class', 'error_title', 'Weight Title must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2693, 1, 1, 'localisation_weight_class', 'error_unit', 'Weight Unit must be between 1 and 4 characters!', '[[regtime]]', '[[regtime]]'),
(2694, 1, 1, 'localisation_weight_class', 'error_default', 'Warning: This weight class cannot be deleted as it is currently assigned as the default store weight class!', '[[regtime]]', '[[regtime]]'),
(2695, 1, 1, 'localisation_weight_class', 'error_product', 'Warning: This weight class cannot be deleted as it is currently assigned to %s products!', '[[regtime]]', '[[regtime]]'),
(2696, 1, 1, 'localisation_weight_class', 'error_iso_code', 'ISO-code must be 4 characters and must be unique!', '[[regtime]]', '[[regtime]]'),
(2697, 1, 1, 'localisation_weight_class', 'entry_iso_code', 'ISO-code:', '[[regtime]]', '[[regtime]]'),
(2698, 1, 1, 'localisation_weight_class', 'column_iso_code', 'ISO-code', '[[regtime]]', '[[regtime]]'),
(2699, 1, 1, 'localisation_zone', 'heading_title', 'Zones', '[[regtime]]', '[[regtime]]'),
(2700, 1, 1, 'localisation_zone', 'text_zone', 'Zone', '[[regtime]]', '[[regtime]]'),
(2701, 1, 1, 'localisation_zone', 'text_success', 'Success: You have modified zones!', '[[regtime]]', '[[regtime]]'),
(2702, 1, 1, 'localisation_zone', 'column_name', 'Zone Name', '[[regtime]]', '[[regtime]]'),
(2703, 1, 1, 'localisation_zone', 'column_code', 'Zone Code', '[[regtime]]', '[[regtime]]'),
(2704, 1, 1, 'localisation_zone', 'column_country', 'Country', '[[regtime]]', '[[regtime]]'),
(2705, 1, 1, 'localisation_zone', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2706, 1, 1, 'localisation_zone', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(2707, 1, 1, 'localisation_zone', 'entry_status', 'Zone Status:', '[[regtime]]', '[[regtime]]'),
(2708, 1, 1, 'localisation_zone', 'entry_name', 'Zone Name:', '[[regtime]]', '[[regtime]]'),
(2709, 1, 1, 'localisation_zone', 'entry_code', 'Zone Code:', '[[regtime]]', '[[regtime]]'),
(2710, 1, 1, 'localisation_zone', 'entry_country', 'Country:', '[[regtime]]', '[[regtime]]'),
(2711, 1, 1, 'localisation_zone', 'text_select_country', '- Select Country -', '[[regtime]]', '[[regtime]]'),
(2712, 1, 1, 'localisation_zone', 'error_permission', 'Warning: You do not have permission to modify zones!', '[[regtime]]', '[[regtime]]'),
(2713, 1, 1, 'localisation_zone', 'error_name', 'Zone Name must be between 2 and 128 characters!', '[[regtime]]', '[[regtime]]'),
(2714, 1, 1, 'localisation_zone', 'error_default', 'Warning: This zone cannot be deleted as it is currently assigned as the default store zone!', '[[regtime]]', '[[regtime]]'),
(2715, 1, 1, 'localisation_zone', 'error_store', 'Warning: This zone cannot be deleted as it is currently assigned to %s stores!', '[[regtime]]', '[[regtime]]'),
(2716, 1, 1, 'localisation_zone', 'error_address', 'Warning: This zone cannot be deleted as it is currently assigned to %s address book entries!', '[[regtime]]', '[[regtime]]'),
(2717, 1, 1, 'localisation_zone', 'error_zone_to_location', 'Warning: This zone cannot be deleted as it is currently assigned to %s zones to locations!', '[[regtime]]', '[[regtime]]'),
(2718, 1, 1, 'mail_customer', 'text_subject', '%s - Your Account has been activated!', '[[regtime]]', '[[regtime]]'),
(2719, 1, 1, 'mail_customer', 'text_welcome', 'Welcome and thank you for registering at %s!', '[[regtime]]', '[[regtime]]'),
(2720, 1, 1, 'mail_customer', 'text_login', 'Your account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:', '[[regtime]]', '[[regtime]]'),
(2721, 1, 1, 'mail_customer', 'text_services', 'Once you logging in, you will be able to access, your wishlist, order history, printing invoices and editing your account information.', '[[regtime]]', '[[regtime]]'),
(2722, 1, 1, 'mail_customer', 'text_thanks', 'Thank you,', '[[regtime]]', '[[regtime]]'),
(2723, 1, 1, 'mail_order', 'text_subject', '%s - Order Update %s', '[[regtime]]', '[[regtime]]'),
(2724, 1, 1, 'mail_order', 'text_order', 'Order ID:', '[[regtime]]', '[[regtime]]'),
(2725, 1, 1, 'mail_order', 'text_date_added', 'Date Ordered:', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(2726, 1, 1, 'mail_order', 'text_order_status', 'Your order has been updated to the following status:', '[[regtime]]', '[[regtime]]'),
(2727, 1, 1, 'mail_order', 'text_comment', 'The comments for your order are:', '[[regtime]]', '[[regtime]]'),
(2728, 1, 1, 'mail_order', 'text_invoice', 'To view your order click on the link below:', '[[regtime]]', '[[regtime]]'),
(2729, 1, 1, 'mail_order', 'text_footer', 'Please reply to this email if you have any questions.', '[[regtime]]', '[[regtime]]'),
(2730, 1, 1, 'report_customer_online', 'heading_title', 'Customers Online', '[[regtime]]', '[[regtime]]'),
(2731, 1, 1, 'report_customer_online', 'column_customer', 'Customer Name', '[[regtime]]', '[[regtime]]'),
(2732, 1, 1, 'report_customer_online', 'column_ip', 'Customer IP', '[[regtime]]', '[[regtime]]'),
(2733, 1, 1, 'report_customer_online', 'column_time', 'Last Accessed', '[[regtime]]', '[[regtime]]'),
(2734, 1, 1, 'report_customer_online', 'column_url', 'Url Accessed', '[[regtime]]', '[[regtime]]'),
(2735, 1, 1, 'report_customer_online', 'text_referer', 'Referer:', '[[regtime]]', '[[regtime]]'),
(2736, 1, 1, 'report_customer_orders', 'heading_title', 'Customer Orders', '[[regtime]]', '[[regtime]]'),
(2737, 1, 1, 'report_customer_orders', 'column_customer_id', 'Customer ID', '[[regtime]]', '[[regtime]]'),
(2738, 1, 1, 'report_customer_orders', 'column_customer', 'Customer Name', '[[regtime]]', '[[regtime]]'),
(2739, 1, 1, 'report_customer_orders', 'column_group', 'Customer Group', '[[regtime]]', '[[regtime]]'),
(2740, 1, 1, 'report_customer_orders', 'column_order_count', 'Orders Count', '[[regtime]]', '[[regtime]]'),
(2741, 1, 1, 'report_customer_orders', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(2742, 1, 1, 'report_customer_transactions', 'heading_title', 'Customer Balance History', '[[regtime]]', '[[regtime]]'),
(2743, 1, 1, 'report_customer_transactions', 'column_transaction_date', 'Transaction Date', '[[regtime]]', '[[regtime]]'),
(2744, 1, 1, 'report_customer_transactions', 'column_customer', 'Customer Name', '[[regtime]]', '[[regtime]]'),
(2745, 1, 1, 'report_customer_transactions', 'column_created_by', 'Created By', '[[regtime]]', '[[regtime]]'),
(2746, 1, 1, 'report_customer_transactions', 'column_debit', 'Debit', '[[regtime]]', '[[regtime]]'),
(2747, 1, 1, 'report_customer_transactions', 'column_credit', 'Credit', '[[regtime]]', '[[regtime]]'),
(2748, 1, 1, 'report_customer_transactions', 'column_transaction_type', 'Transaction Type', '[[regtime]]', '[[regtime]]'),
(2749, 1, 1, 'report_purchased', 'heading_title', 'Products Purchased Report', '[[regtime]]', '[[regtime]]'),
(2750, 1, 1, 'report_purchased', 'column_name', 'Product Name', '[[regtime]]', '[[regtime]]'),
(2751, 1, 1, 'report_purchased', 'column_model', 'Model', '[[regtime]]', '[[regtime]]'),
(2752, 1, 1, 'report_purchased', 'column_quantity', 'Quantity', '[[regtime]]', '[[regtime]]'),
(2753, 1, 1, 'report_purchased', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(2754, 1, 1, 'report_sale_coupons', 'heading_title', 'Discounts Report', '[[regtime]]', '[[regtime]]'),
(2755, 1, 1, 'report_sale_coupons', 'column_coupon_name', 'Discount/Coupon Name', '[[regtime]]', '[[regtime]]'),
(2756, 1, 1, 'report_sale_coupons', 'column_code', 'Code', '[[regtime]]', '[[regtime]]'),
(2757, 1, 1, 'report_sale_coupons', 'column_orders', 'No. Orders', '[[regtime]]', '[[regtime]]'),
(2758, 1, 1, 'report_sale_coupons', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(2759, 1, 1, 'report_sale_coupons', 'column_discount_total', 'Total Discount', '[[regtime]]', '[[regtime]]'),
(2760, 1, 1, 'report_sale_coupons', 'entry_date_start', 'Date Start:', '[[regtime]]', '[[regtime]]'),
(2761, 1, 1, 'report_sale_coupons', 'entry_date_end', 'Date End:', '[[regtime]]', '[[regtime]]'),
(2762, 1, 1, 'report_sale_orders', 'heading_title', 'Sales Report', '[[regtime]]', '[[regtime]]'),
(2763, 1, 1, 'report_sale_orders', 'text_year', 'Years', '[[regtime]]', '[[regtime]]'),
(2764, 1, 1, 'report_sale_orders', 'text_month', 'Months', '[[regtime]]', '[[regtime]]'),
(2765, 1, 1, 'report_sale_orders', 'text_week', 'Weeks', '[[regtime]]', '[[regtime]]'),
(2766, 1, 1, 'report_sale_orders', 'text_day', 'Days', '[[regtime]]', '[[regtime]]'),
(2767, 1, 1, 'report_sale_orders', 'text_all_status', 'All Statuses', '[[regtime]]', '[[regtime]]'),
(2768, 1, 1, 'report_sale_orders', 'column_date_start', 'Date Start', '[[regtime]]', '[[regtime]]'),
(2769, 1, 1, 'report_sale_orders', 'column_date_end', 'Date End', '[[regtime]]', '[[regtime]]'),
(2770, 1, 1, 'report_sale_orders', 'column_orders', 'No. Orders', '[[regtime]]', '[[regtime]]'),
(2771, 1, 1, 'report_sale_orders', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(2772, 1, 1, 'report_sale_orders', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(2773, 1, 1, 'report_sale_orders', 'entry_date_start', 'Date Start:', '[[regtime]]', '[[regtime]]'),
(2774, 1, 1, 'report_sale_orders', 'entry_date_end', 'Date End:', '[[regtime]]', '[[regtime]]'),
(2775, 1, 1, 'report_sale_orders', 'entry_group', 'Group By:', '[[regtime]]', '[[regtime]]'),
(2776, 1, 1, 'report_sale_shipping', 'heading_title', 'Shipping Report', '[[regtime]]', '[[regtime]]'),
(2777, 1, 1, 'report_sale_shipping', 'text_year', 'Years', '[[regtime]]', '[[regtime]]'),
(2778, 1, 1, 'report_sale_shipping', 'text_month', 'Months', '[[regtime]]', '[[regtime]]'),
(2779, 1, 1, 'report_sale_shipping', 'text_week', 'Weeks', '[[regtime]]', '[[regtime]]'),
(2780, 1, 1, 'report_sale_shipping', 'text_day', 'Days', '[[regtime]]', '[[regtime]]'),
(2781, 1, 1, 'report_sale_shipping', 'text_all_status', 'All Statuses', '[[regtime]]', '[[regtime]]'),
(2782, 1, 1, 'report_sale_shipping', 'column_date_start', 'Date Start', '[[regtime]]', '[[regtime]]'),
(2783, 1, 1, 'report_sale_shipping', 'column_date_end', 'Date End', '[[regtime]]', '[[regtime]]'),
(2784, 1, 1, 'report_sale_shipping', 'column_orders', 'No. Orders', '[[regtime]]', '[[regtime]]'),
(2785, 1, 1, 'report_sale_shipping', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(2786, 1, 1, 'report_sale_shipping', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(2787, 1, 1, 'report_sale_shipping', 'entry_date_start', 'Date Start:', '[[regtime]]', '[[regtime]]'),
(2788, 1, 1, 'report_sale_shipping', 'entry_date_end', 'Date End:', '[[regtime]]', '[[regtime]]'),
(2789, 1, 1, 'report_sale_shipping', 'entry_group', 'Group By:', '[[regtime]]', '[[regtime]]'),
(2790, 1, 1, 'report_sale_taxes', 'heading_title', 'Taxes Report', '[[regtime]]', '[[regtime]]'),
(2791, 1, 1, 'report_sale_taxes', 'text_year', 'Years', '[[regtime]]', '[[regtime]]'),
(2792, 1, 1, 'report_sale_taxes', 'text_month', 'Months', '[[regtime]]', '[[regtime]]'),
(2793, 1, 1, 'report_sale_taxes', 'text_week', 'Weeks', '[[regtime]]', '[[regtime]]'),
(2794, 1, 1, 'report_sale_taxes', 'text_day', 'Days', '[[regtime]]', '[[regtime]]'),
(2795, 1, 1, 'report_sale_taxes', 'text_all_status', 'All Statuses', '[[regtime]]', '[[regtime]]'),
(2796, 1, 1, 'report_sale_taxes', 'column_date_start', 'Date Start', '[[regtime]]', '[[regtime]]'),
(2797, 1, 1, 'report_sale_taxes', 'column_date_end', 'Date End', '[[regtime]]', '[[regtime]]'),
(2798, 1, 1, 'report_sale_taxes', 'column_orders', 'No. Orders', '[[regtime]]', '[[regtime]]'),
(2799, 1, 1, 'report_sale_taxes', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(2800, 1, 1, 'report_sale_taxes', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(2801, 1, 1, 'report_sale_taxes', 'entry_date_start', 'Date Start:', '[[regtime]]', '[[regtime]]'),
(2802, 1, 1, 'report_sale_taxes', 'entry_date_end', 'Date End:', '[[regtime]]', '[[regtime]]'),
(2803, 1, 1, 'report_sale_taxes', 'entry_group', 'Group By:', '[[regtime]]', '[[regtime]]'),
(2804, 1, 1, 'report_viewed', 'heading_title', 'Products Viewed Report', '[[regtime]]', '[[regtime]]'),
(2805, 1, 1, 'report_viewed', 'text_success', 'Success: You have reset the product viewed report!', '[[regtime]]', '[[regtime]]'),
(2806, 1, 1, 'report_viewed', 'column_product_id', 'Product ID', '[[regtime]]', '[[regtime]]'),
(2807, 1, 1, 'report_viewed', 'column_name', 'Product Name', '[[regtime]]', '[[regtime]]'),
(2808, 1, 1, 'report_viewed', 'column_model', 'Model', '[[regtime]]', '[[regtime]]'),
(2809, 1, 1, 'report_viewed', 'column_sku', 'SKU', '[[regtime]]', '[[regtime]]'),
(2810, 1, 1, 'report_viewed', 'column_category', 'Category', '[[regtime]]', '[[regtime]]'),
(2811, 1, 1, 'report_viewed', 'column_viewed', 'Viewed', '[[regtime]]', '[[regtime]]'),
(2812, 1, 1, 'report_viewed', 'column_percent', 'Percent', '[[regtime]]', '[[regtime]]'),
(2813, 1, 1, 'sale_contact', 'text_send_email', 'Send Mail', '[[regtime]]', '[[regtime]]'),
(2814, 1, 1, 'sale_contact', 'text_send_sms', 'Send SMS', '[[regtime]]', '[[regtime]]'),
(2815, 1, 1, 'sale_contact', 'text_success', 'Your message has been successfully sent!', '[[regtime]]', '[[regtime]]'),
(2816, 1, 1, 'sale_contact', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(2817, 1, 1, 'sale_contact', 'text_custom_send', 'Manualy selected customers', '[[regtime]]', '[[regtime]]'),
(2818, 1, 1, 'sale_contact', 'text_all_subscribers', 'All Subscribers', '[[regtime]]', '[[regtime]]'),
(2819, 1, 1, 'sale_contact', 'text_subscribers_only', 'Newsletter Subscribers Only (non-customers)', '[[regtime]]', '[[regtime]]'),
(2820, 1, 1, 'sale_contact', 'text_customers_only', 'All Customers', '[[regtime]]', '[[regtime]]'),
(2821, 1, 1, 'sale_contact', 'entry_store', 'From store:<span class="help">Store email address to send email from. Value is set in store settings</span>', '[[regtime]]', '[[regtime]]'),
(2822, 1, 1, 'sale_contact', 'text_customers_who_ordered', 'To customers who ordered selected products', '[[regtime]]', '[[regtime]]'),
(2823, 1, 1, 'sale_contact', 'entry_to', 'To:<span class="help">List of customers to receive this message. NOTE: Large customer lists will require long time to be processed and might require alternative methods. Refer to your web and email server configurations</span>', '[[regtime]]', '[[regtime]]'),
(2824, 1, 1, 'sale_contact', 'text_customers_from_lookup', 'Start typing customer name to look up and select', '[[regtime]]', '[[regtime]]'),
(2825, 1, 1, 'sale_contact', 'text_products_from_lookup', 'Start typing product name to look up and select', '[[regtime]]', '[[regtime]]'),
(2826, 1, 1, 'sale_contact', 'entry_subject', 'Subject:', '[[regtime]]', '[[regtime]]'),
(2827, 1, 1, 'sale_contact', 'entry_message', 'Message body:', '[[regtime]]', '[[regtime]]'),
(2828, 1, 1, 'sale_contact', 'error_permission', 'Warning: You do not have permission to send emails!', '[[regtime]]', '[[regtime]]'),
(2829, 1, 1, 'sale_contact', 'error_subject', 'Email subject is required!', '[[regtime]]', '[[regtime]]'),
(2830, 1, 1, 'sale_contact', 'error_message_email', 'Email message body is required!', '[[regtime]]', '[[regtime]]'),
(2831, 1, 1, 'sale_contact', 'error_message_sms', 'SMS message body is required!', '[[regtime]]', '[[regtime]]'),
(2832, 1, 1, 'sale_contact', 'error_recipients', 'Recipients list, subscribers or products ordered are required!', '[[regtime]]', '[[regtime]]'),
(2833, 1, 1, 'sale_contact', 'error_not_sent', 'Error: No emails were sent! Please see error log for details.', '[[regtime]]', '[[regtime]]'),
(2834, 1, 1, 'sale_contact', 'text_unsubscribe', 'This email was sent to %s, because your email preferences are set to receive newsletters. Click <a href="%s">here to Unsubscribe</a>. ', '[[regtime]]', '[[regtime]]'),
(2835, 1, 1, 'sale_contact', 'text_total_to_be_sent', '(Total to be sent to: %s )', '[[regtime]]', '[[regtime]]'),
(2836, 1, 1, 'sale_contact', 'text_select_products', '- Select Products -', '[[regtime]]', '[[regtime]]'),
(2837, 1, 1, 'sale_contact', 'text_select_customers', '- Select Customers -', '[[regtime]]', '[[regtime]]'),
(2838, 1, 1, 'sale_contact', 'text_email', 'Email', '[[regtime]]', '[[regtime]]'),
(2839, 1, 1, 'sale_contact', 'text_sms', 'SMS', '[[regtime]]', '[[regtime]]'),
(2840, 1, 1, 'sale_contact', 'text_incomplete_tasks', 'Incomplete Tasks', '[[regtime]]', '[[regtime]]'),
(2841, 1, 1, 'sale_contact', 'text_task_id', 'Task ID:', '[[regtime]]', '[[regtime]]'),
(2842, 1, 1, 'sale_contact', 'text_last_time_run', 'Last Time Run:', '[[regtime]]', '[[regtime]]'),
(2843, 1, 1, 'sale_contact', 'text_date_added', 'Created:', '[[regtime]]', '[[regtime]]'),
(2844, 1, 1, 'sale_contact', 'text_subject', 'Subject:', '[[regtime]]', '[[regtime]]'),
(2845, 1, 1, 'sale_contact', 'text_message', 'Message:', '[[regtime]]', '[[regtime]]'),
(2846, 1, 1, 'sale_contact', 'text_starter_name', 'Created by:', '[[regtime]]', '[[regtime]]'),
(2847, 1, 1, 'sale_contact', 'text_restart', 'Restart', '[[regtime]]', '[[regtime]]'),
(2848, 1, 1, 'sale_contact', 'text_remove', 'Remove', '[[regtime]]', '[[regtime]]'),
(2849, 1, 1, 'sale_contact', 'error_email_no_recipients', 'Attention! Message will not be sent.', '[[regtime]]', '[[regtime]]'),
(2850, 1, 1, 'sale_contact', 'error_sms_no_recipients', 'Attention! No customers with mobile phone numbers. ', '[[regtime]]', '[[regtime]]'),
(2851, 1, 1, 'sale_contact', 'text_attention_recipients_count', 'Attention! The message will be sent to %s customers.', '[[regtime]]', '[[regtime]]'),
(2852, 1, 1, 'sale_contact', 'text_success_abort', 'Task interrupted successfully.', '[[regtime]]', '[[regtime]]'),
(2853, 1, 1, 'sale_contact', 'text_success_sent', '%s messages have been sent.', '[[regtime]]', '[[regtime]]'),
(2854, 1, 1, 'sale_contact', 'text_task_failed', 'Some errors occured during task process. Please see log for details or restart this task.', '[[regtime]]', '[[regtime]]'),
(2855, 1, 1, 'sale_contact', 'text_sent', ' %s of %s messages are sent', '[[regtime]]', '[[regtime]]'),
(2856, 1, 1, 'sale_coupon', 'heading_title', 'Coupons', '[[regtime]]', '[[regtime]]'),
(2857, 1, 1, 'sale_coupon', 'text_coupon', 'Coupon', '[[regtime]]', '[[regtime]]'),
(2858, 1, 1, 'sale_coupon', 'text_success', 'Success: You have modified coupons!', '[[regtime]]', '[[regtime]]'),
(2859, 1, 1, 'sale_coupon', 'text_percent', 'Percentage', '[[regtime]]', '[[regtime]]'),
(2860, 1, 1, 'sale_coupon', 'text_amount', 'Fixed Amount', '[[regtime]]', '[[regtime]]'),
(2861, 1, 1, 'sale_coupon', 'column_name', 'Coupon Name', '[[regtime]]', '[[regtime]]'),
(2862, 1, 1, 'sale_coupon', 'column_code', 'Code', '[[regtime]]', '[[regtime]]'),
(2863, 1, 1, 'sale_coupon', 'column_discount', 'Discount', '[[regtime]]', '[[regtime]]'),
(2864, 1, 1, 'sale_coupon', 'column_date_start', 'Date Start', '[[regtime]]', '[[regtime]]'),
(2865, 1, 1, 'sale_coupon', 'column_date_end', 'Date End', '[[regtime]]', '[[regtime]]'),
(2866, 1, 1, 'sale_coupon', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(2867, 1, 1, 'sale_coupon', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2868, 1, 1, 'sale_coupon', 'entry_name', 'Coupon Name:', '[[regtime]]', '[[regtime]]'),
(2869, 1, 1, 'sale_coupon', 'entry_description', 'Coupon Description:', '[[regtime]]', '[[regtime]]'),
(2870, 1, 1, 'sale_coupon', 'entry_code', 'Code:<br /><span class="help">The code the customer enters to get the discount</span>', '[[regtime]]', '[[regtime]]'),
(2871, 1, 1, 'sale_coupon', 'entry_type', 'Type:<br /><span class="help">Percentage or Fixed Amount</span>', '[[regtime]]', '[[regtime]]'),
(2872, 1, 1, 'sale_coupon', 'entry_discount', 'Discount:', '[[regtime]]', '[[regtime]]'),
(2873, 1, 1, 'sale_coupon', 'entry_logged', 'Customer Login:<br /><span class="help">Customer must be logged in to use the coupon.</span>', '[[regtime]]', '[[regtime]]'),
(2874, 1, 1, 'sale_coupon', 'entry_shipping', 'Free Shipping:', '[[regtime]]', '[[regtime]]'),
(2875, 1, 1, 'sale_coupon', 'entry_total', 'Total Amount:<br/><span class="help">The sub-total amount that must reached before the coupon is valid.</span>', '[[regtime]]', '[[regtime]]'),
(2876, 1, 1, 'sale_coupon', 'entry_category', 'Categories:<br/><span class="help">Apply Coupon When Products From One Of Selected Categories.</span>', '[[regtime]]', '[[regtime]]'),
(2877, 1, 1, 'sale_coupon', 'entry_product', 'Products:<br/><span class="help">Apply Coupon When Cart Contains One Of Selected Products.</span>', '[[regtime]]', '[[regtime]]'),
(2878, 1, 1, 'sale_coupon', 'entry_date_start', 'Date Start:', '[[regtime]]', '[[regtime]]'),
(2879, 1, 1, 'sale_coupon', 'entry_date_end', 'Date End:', '[[regtime]]', '[[regtime]]'),
(2880, 1, 1, 'sale_coupon', 'entry_uses_total', 'Uses Per Coupon:<br /><span class="help">The maximum number of times the coupon can be used by any customer. Leave blank for unlimited</span>', '[[regtime]]', '[[regtime]]'),
(2881, 1, 1, 'sale_coupon', 'entry_uses_customer', 'Uses Per Customer:<br /><span class="help">The maximum number of times the coupon can be used by a single customer. Leave blank for unlimited</span>', '[[regtime]]', '[[regtime]]'),
(2882, 1, 1, 'sale_coupon', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(2883, 1, 1, 'sale_coupon', 'entry_total_coupon_usage', 'Total Coupon Usage:<br /><span class="help">Count of all orders placed using this coupon</span>', '[[regtime]]', '[[regtime]]'),
(2884, 1, 1, 'sale_coupon', 'error_permission', 'Warning: You do not have permission to modify coupons!', '[[regtime]]', '[[regtime]]'),
(2885, 1, 1, 'sale_coupon', 'error_name', 'Coupon Name must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(2886, 1, 1, 'sale_coupon', 'error_description', 'Coupon Description must be between 2 characters!', '[[regtime]]', '[[regtime]]'),
(2887, 1, 1, 'sale_coupon', 'error_code', 'Code must be between 2 and 10 characters!', '[[regtime]]', '[[regtime]]'),
(2888, 1, 1, 'sale_coupon', 'error_date', 'Please set date range!', '[[regtime]]', '[[regtime]]'),
(2889, 1, 1, 'sale_coupon', 'text_select_category', '- Select Category -', '[[regtime]]', '[[regtime]]'),
(2890, 1, 1, 'sale_coupon', 'text_or', 'OR', '[[regtime]]', '[[regtime]]'),
(2891, 1, 1, 'sale_coupon', 'text_and', 'AND', '[[regtime]]', '[[regtime]]'),
(2892, 1, 1, 'sale_customer', 'heading_title', 'Customers', '[[regtime]]', '[[regtime]]'),
(2893, 1, 1, 'sale_customer', 'text_customer', 'Customer', '[[regtime]]', '[[regtime]]'),
(2894, 1, 1, 'sale_customer', 'text_success', 'Success: You have modified customers!', '[[regtime]]', '[[regtime]]'),
(2895, 1, 1, 'sale_customer', 'text_approved', 'You have approved %s account!', '[[regtime]]', '[[regtime]]'),
(2896, 1, 1, 'sale_customer', 'tab_customer_address', 'Address', '[[regtime]]', '[[regtime]]'),
(2897, 1, 1, 'sale_customer', 'text_customer_addresses', 'Customer Addresses', '[[regtime]]', '[[regtime]]'),
(2898, 1, 1, 'sale_customer', 'text_add_address', 'Add New Address', '[[regtime]]', '[[regtime]]'),
(2899, 1, 1, 'sale_customer', 'button_add', 'Add', '[[regtime]]', '[[regtime]]'),
(2900, 1, 1, 'sale_customer', 'column_id', 'ID', '[[regtime]]', '[[regtime]]'),
(2901, 1, 1, 'sale_customer', 'column_name', 'Customer Name', '[[regtime]]', '[[regtime]]'),
(2902, 1, 1, 'sale_customer', 'column_email', 'E-Mail', '[[regtime]]', '[[regtime]]'),
(2903, 1, 1, 'sale_customer', 'column_customer_group', 'Customer Group', '[[regtime]]', '[[regtime]]'),
(2904, 1, 1, 'sale_customer', 'column_group', 'Group', '[[regtime]]', '[[regtime]]'),
(2905, 1, 1, 'sale_customer', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(2906, 1, 1, 'sale_customer', 'column_approved', 'Approved', '[[regtime]]', '[[regtime]]'),
(2907, 1, 1, 'sale_customer', 'column_date_added', 'Date Added', '[[regtime]]', '[[regtime]]'),
(2908, 1, 1, 'sale_customer', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2909, 1, 1, 'sale_customer', 'entry_loginname', 'Login Name:', '[[regtime]]', '[[regtime]]'),
(2910, 1, 1, 'sale_customer', 'entry_firstname', 'First Name:', '[[regtime]]', '[[regtime]]'),
(2911, 1, 1, 'sale_customer', 'entry_lastname', 'Last Name:', '[[regtime]]', '[[regtime]]'),
(2912, 1, 1, 'sale_customer', 'entry_email', 'E-Mail:', '[[regtime]]', '[[regtime]]'),
(2913, 1, 1, 'sale_customer', 'entry_telephone', 'Telephone:', '[[regtime]]', '[[regtime]]'),
(2914, 1, 1, 'sale_customer', 'entry_fax', 'Fax:', '[[regtime]]', '[[regtime]]'),
(2915, 1, 1, 'sale_customer', 'entry_newsletter', 'Newsletter:', '[[regtime]]', '[[regtime]]'),
(2916, 1, 1, 'sale_customer', 'entry_customer_group', 'Customer Group:', '[[regtime]]', '[[regtime]]'),
(2917, 1, 1, 'sale_customer', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(2918, 1, 1, 'sale_customer', 'entry_approved', 'Approved:', '[[regtime]]', '[[regtime]]'),
(2919, 1, 1, 'sale_customer', 'entry_password', 'Password:', '[[regtime]]', '[[regtime]]'),
(2920, 1, 1, 'sale_customer', 'entry_confirm', 'Confirm:', '[[regtime]]', '[[regtime]]'),
(2921, 1, 1, 'sale_customer', 'entry_company', 'Company:', '[[regtime]]', '[[regtime]]'),
(2922, 1, 1, 'sale_customer', 'entry_address_1', 'Address 1:', '[[regtime]]', '[[regtime]]'),
(2923, 1, 1, 'sale_customer', 'entry_address_2', 'Address 2:', '[[regtime]]', '[[regtime]]'),
(2924, 1, 1, 'sale_customer', 'entry_city', 'City:', '[[regtime]]', '[[regtime]]'),
(2925, 1, 1, 'sale_customer', 'entry_postcode', 'Postcode:', '[[regtime]]', '[[regtime]]'),
(2926, 1, 1, 'sale_customer', 'entry_country', 'Country:', '[[regtime]]', '[[regtime]]'),
(2927, 1, 1, 'sale_customer', 'entry_country_id', 'Country:', '[[regtime]]', '[[regtime]]'),
(2928, 1, 1, 'sale_customer', 'entry_zone', 'Region / State:', '[[regtime]]', '[[regtime]]'),
(2929, 1, 1, 'sale_customer', 'error_permission', 'Warning: You do not have permission to modify customers!', '[[regtime]]', '[[regtime]]'),
(2930, 1, 1, 'sale_customer', 'error_loginname', 'Login name must be alphanumeric only and between 5 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(2931, 1, 1, 'sale_customer', 'error_loginname_notunique', 'This login name is not available. Try different login name!', '[[regtime]]', '[[regtime]]'),
(2932, 1, 1, 'sale_customer', 'error_firstname', 'First Name must be between 1 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2933, 1, 1, 'sale_customer', 'error_lastname', 'Last Name must be between 1 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2934, 1, 1, 'sale_customer', 'error_email', 'E-Mail Address does not appear to be valid!', '[[regtime]]', '[[regtime]]'),
(2935, 1, 1, 'sale_customer', 'error_telephone', 'Telephone must be between 3 and 32 numeric only characters!', '[[regtime]]', '[[regtime]]'),
(2936, 1, 1, 'sale_customer', 'error_password', 'Password must be between 3 and 20 characters!', '[[regtime]]', '[[regtime]]'),
(2937, 1, 1, 'sale_customer', 'error_confirm', 'Password and password confirmation do not match!', '[[regtime]]', '[[regtime]]'),
(2938, 1, 1, 'sale_customer', 'error_address_firstname', 'First Name must be between 1 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2939, 1, 1, 'sale_customer', 'error_address_lastname', 'Last Name must be between 1 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(2940, 1, 1, 'sale_customer', 'error_address_1', 'Address must be between 3 and 128 characters!', '[[regtime]]', '[[regtime]]'),
(2941, 1, 1, 'sale_customer', 'error_city', 'City must be between 3 and 128 characters!', '[[regtime]]', '[[regtime]]'),
(2942, 1, 1, 'sale_customer', 'error_country', 'Please select a country!', '[[regtime]]', '[[regtime]]'),
(2943, 1, 1, 'sale_customer', 'error_zone', 'Please select a region / state!', '[[regtime]]', '[[regtime]]'),
(2944, 1, 1, 'sale_customer', 'text_select_approved', '- Select Approved -', '[[regtime]]', '[[regtime]]'),
(2945, 1, 1, 'sale_customer', 'text_select_group', '- Select Group -', '[[regtime]]', '[[regtime]]'),
(2946, 1, 1, 'sale_customer', 'tab_customer_details', 'Customer details', '[[regtime]]', '[[regtime]]'),
(2947, 1, 1, 'sale_customer', 'tab_transactions', 'Account Balance History', '[[regtime]]', '[[regtime]]'),
(2948, 1, 1, 'sale_customer', 'heading_title_transactions', 'Account Balance History', '[[regtime]]', '[[regtime]]'),
(2949, 1, 1, 'sale_customer', 'column_create_date', 'Date Created', '[[regtime]]', '[[regtime]]'),
(2950, 1, 1, 'sale_customer', 'column_created_by', 'Created By', '[[regtime]]', '[[regtime]]'),
(2951, 1, 1, 'sale_customer', 'column_debit', 'Debit', '[[regtime]]', '[[regtime]]'),
(2952, 1, 1, 'sale_customer', 'column_credit', 'Credit', '[[regtime]]', '[[regtime]]'),
(2953, 1, 1, 'sale_customer', 'column_transaction_type', 'Transaction Type', '[[regtime]]', '[[regtime]]'),
(2954, 1, 1, 'sale_customer', 'text_balance', 'Balance:', '[[regtime]]', '[[regtime]]'),
(2955, 1, 1, 'sale_customer', 'text_last_login', 'Last Log-in:', '[[regtime]]', '[[regtime]]'),
(2956, 1, 1, 'sale_customer', 'text_never', 'Never', '[[regtime]]', '[[regtime]]'),
(2957, 1, 1, 'sale_customer', 'popup_title_info', 'Transaction information', '[[regtime]]', '[[regtime]]'),
(2958, 1, 1, 'sale_customer', 'popup_title_insert', 'Insert New Transaction', '[[regtime]]', '[[regtime]]'),
(2959, 1, 1, 'sale_customer', 'entry_credit', 'Credit (increase balance)', '[[regtime]]', '[[regtime]]'),
(2960, 1, 1, 'sale_customer', 'entry_debit', 'Debit (decrease balance)', '[[regtime]]', '[[regtime]]'),
(2961, 1, 1, 'sale_customer', 'entry_transaction_type', 'Transaction Type: ', '[[regtime]]', '[[regtime]]'),
(2962, 1, 1, 'sale_customer', 'entry_other_type', 'Add New Custom Transaction Type: ', '[[regtime]]', '[[regtime]]'),
(2963, 1, 1, 'sale_customer', 'text_other_type_placeholder', 'type new name here ', '[[regtime]]', '[[regtime]]'),
(2964, 1, 1, 'sale_customer', 'text_option_other_type', 'Other... ', '[[regtime]]', '[[regtime]]'),
(2965, 1, 1, 'sale_customer', 'entry_transaction_description', 'Description (for customer):', '[[regtime]]', '[[regtime]]'),
(2966, 1, 1, 'sale_customer', 'entry_transaction_comment', 'Comment (for internal use):', '[[regtime]]', '[[regtime]]'),
(2967, 1, 1, 'sale_customer', 'entry_update_date', 'Update Date:', '[[regtime]]', '[[regtime]]'),
(2968, 1, 1, 'sale_customer', 'entry_create_date', 'Create Date:', '[[regtime]]', '[[regtime]]'),
(2969, 1, 1, 'sale_customer', 'error_transaction_type', 'Error: Please fill transaction type form field.', '[[regtime]]', '[[regtime]]'),
(2970, 1, 1, 'sale_customer', 'error_empty_debit_credit', 'Error: Please fill debit or credit value for customer transaction.', '[[regtime]]', '[[regtime]]'),
(2971, 1, 1, 'sale_customer', 'error_incorrect_debit_credit', 'Error: debit or credit value cannot be greater than 99999999999.9999', '[[regtime]]', '[[regtime]]'),
(2972, 1, 1, 'sale_customer', 'text_transaction_success', 'Success: You have modified transaction!', '[[regtime]]', '[[regtime]]'),
(2973, 1, 1, 'sale_customer', 'text_edit_address', 'Edit Address', '[[regtime]]', '[[regtime]]'),
(2974, 1, 1, 'sale_customer', 'entry_default', 'Default Address:', '[[regtime]]', '[[regtime]]'),
(2975, 1, 1, 'sale_customer', 'error_delete_default', 'Error: Default address cannot be deleted!', '[[regtime]]', '[[regtime]]'),
(2976, 1, 1, 'sale_customer', 'error_delete_last', 'Error: you must have at least one address!', '[[regtime]]', '[[regtime]]'),
(2977, 1, 1, 'sale_customer', 'entry_date_added', 'Date Added:', '[[regtime]]', '[[regtime]]'),
(2978, 1, 1, 'sale_customer', 'entry_date_modified', 'Date Modified:', '[[regtime]]', '[[regtime]]'),
(2979, 1, 1, 'sale_customer', 'warning_actonbehalf_additional_store', 'To act on behalf of customer in additional store you should to login into another store''s admin side. Continue?', '[[regtime]]', '[[regtime]]'),
(2980, 1, 1, 'sale_customer', 'entry_notify', 'Notify Customer:', '[[regtime]]', '[[regtime]]'),
(2981, 1, 1, 'sale_customer', 'text_transaction_notification_subject', 'New transaction has been posted to your %s account', '[[regtime]]', '[[regtime]]'),
(2982, 1, 1, 'sale_customer', 'text_transaction_notification_message', 'New transaction has been posted to your %s account in the amount of %s. For more details, login to %s account', '[[regtime]]', '[[regtime]]'),
(2983, 1, 1, 'sale_customer', 'text_total_order', 'Total Orders:', '[[regtime]]', '[[regtime]]'),
(2984, 1, 1, 'sale_customer', 'text_register_date', 'Register Date:', '[[regtime]]', '[[regtime]]'),
(2985, 1, 1, 'sale_customer', 'error_email_exists', 'Customer with this email address already exists!', '[[regtime]]', '[[regtime]]'),
(2986, 1, 1, 'sale_customer_group', 'heading_title', 'Customer Group', '[[regtime]]', '[[regtime]]'),
(2987, 1, 1, 'sale_customer_group', 'breadcrumb_title', 'Customer Groups', '[[regtime]]', '[[regtime]]'),
(2988, 1, 1, 'sale_customer_group', 'text_success', 'Success: You have modified customer groups!', '[[regtime]]', '[[regtime]]'),
(2989, 1, 1, 'sale_customer_group', 'column_name', 'Customer Group Name', '[[regtime]]', '[[regtime]]'),
(2990, 1, 1, 'sale_customer_group', 'column_tax_exempt', 'Tax Exempt', '[[regtime]]', '[[regtime]]'),
(2991, 1, 1, 'sale_customer_group', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(2992, 1, 1, 'sale_customer_group', 'entry_name', 'Customer Group Name:', '[[regtime]]', '[[regtime]]'),
(2993, 1, 1, 'sale_customer_group', 'entry_tax_exempt', 'Exempt from all taxes:', '[[regtime]]', '[[regtime]]'),
(2994, 1, 1, 'sale_customer_group', 'error_permission', 'Warning: You do not have permission to modify customer groups!', '[[regtime]]', '[[regtime]]'),
(2995, 1, 1, 'sale_customer_group', 'error_name', 'Customer Group Name must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(2996, 1, 1, 'sale_customer_group', 'error_default', 'Warning: This customer group cannot be deleted as it is currently assigned as the default store customer group!', '[[regtime]]', '[[regtime]]'),
(2997, 1, 1, 'sale_customer_group', 'error_store', 'Warning: This customer group cannot be deleted as it is currently assigned to %s stores!', '[[regtime]]', '[[regtime]]'),
(2998, 1, 1, 'sale_customer_group', 'error_customer', 'Warning: This customer group cannot be deleted as it is currently assigned to %s customers!', '[[regtime]]', '[[regtime]]'),
(2999, 1, 1, 'sale_order', 'heading_title', 'Orders', '[[regtime]]', '[[regtime]]'),
(3000, 1, 1, 'sale_order', 'edit_title_details', 'Edit Order Details', '[[regtime]]', '[[regtime]]'),
(3001, 1, 1, 'sale_order', 'edit_title_shipping', 'Edit Shipping Address', '[[regtime]]', '[[regtime]]'),
(3002, 1, 1, 'sale_order', 'edit_title_payment', 'Edit Payment Address', '[[regtime]]', '[[regtime]]'),
(3003, 1, 1, 'sale_order', 'title_payment_details', 'Payment Details', '[[regtime]]', '[[regtime]]'),
(3004, 1, 1, 'sale_order', 'text_success', 'Success: Order details have been updated!', '[[regtime]]', '[[regtime]]'),
(3005, 1, 1, 'sale_order', 'text_invoice', 'Invoice', '[[regtime]]', '[[regtime]]'),
(3006, 1, 1, 'sale_order', 'text_order_id', 'Order ID:', '[[regtime]]', '[[regtime]]'),
(3007, 1, 1, 'sale_order', 'text_invoice_id', 'Invoice No.:', '[[regtime]]', '[[regtime]]'),
(3008, 1, 1, 'sale_order', 'text_date_added', 'Invoice Date:', '[[regtime]]', '[[regtime]]'),
(3009, 1, 1, 'sale_order', 'text_telephone', 'Telephone', '[[regtime]]', '[[regtime]]'),
(3010, 1, 1, 'sale_order', 'text_fax', 'Fax', '[[regtime]]', '[[regtime]]'),
(3011, 1, 1, 'sale_order', 'text_select_country', '- Select Country -', '[[regtime]]', '[[regtime]]'),
(3012, 1, 1, 'sale_order', 'text_to', 'To', '[[regtime]]', '[[regtime]]'),
(3013, 1, 1, 'sale_order', 'text_ship_to', 'Ship To (if different address)', '[[regtime]]', '[[regtime]]'),
(3014, 1, 1, 'sale_order', 'text_missing_orders', 'Missing Orders', '[[regtime]]', '[[regtime]]'),
(3015, 1, 1, 'sale_order', 'text_wait', 'Please Wait!', '[[regtime]]', '[[regtime]]'),
(3016, 1, 1, 'sale_order', 'column_order', 'Order ID', '[[regtime]]', '[[regtime]]'),
(3017, 1, 1, 'sale_order', 'column_name', 'Customer Name', '[[regtime]]', '[[regtime]]'),
(3018, 1, 1, 'sale_order', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(3019, 1, 1, 'sale_order', 'column_date_added', 'Date Added', '[[regtime]]', '[[regtime]]'),
(3020, 1, 1, 'sale_order', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(3021, 1, 1, 'sale_order', 'column_product', 'Product', '[[regtime]]', '[[regtime]]'),
(3022, 1, 1, 'sale_order', 'column_model', 'Model', '[[regtime]]', '[[regtime]]'),
(3023, 1, 1, 'sale_order', 'column_quantity', 'Quantity', '[[regtime]]', '[[regtime]]'),
(3024, 1, 1, 'sale_order', 'column_price', 'Unit Price', '[[regtime]]', '[[regtime]]'),
(3025, 1, 1, 'sale_order', 'column_sku', 'SKU', '[[regtime]]', '[[regtime]]'),
(3026, 1, 1, 'sale_order', 'column_download', 'Download Name', '[[regtime]]', '[[regtime]]'),
(3027, 1, 1, 'sale_order', 'column_file', 'File', '[[regtime]]', '[[regtime]]'),
(3028, 1, 1, 'sale_order', 'column_remaining', 'Remaining', '[[regtime]]', '[[regtime]]'),
(3029, 1, 1, 'sale_order', 'column_expire_date', 'Expire Date', '[[regtime]]', '[[regtime]]'),
(3030, 1, 1, 'sale_order', 'column_mask', 'Mask', '[[regtime]]', '[[regtime]]'),
(3031, 1, 1, 'sale_order', 'column_notify', 'Customer Notified', '[[regtime]]', '[[regtime]]'),
(3032, 1, 1, 'sale_order', 'column_comment', 'Customer''s order comment', '[[regtime]]', '[[regtime]]'),
(3033, 1, 1, 'sale_order', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(3034, 1, 1, 'sale_order', 'entry_order_id', 'Order ID:', '[[regtime]]', '[[regtime]]'),
(3035, 1, 1, 'sale_order', 'entry_invoice_id', 'Invoice ID:', '[[regtime]]', '[[regtime]]'),
(3036, 1, 1, 'sale_order', 'entry_customer', 'Customer:', '[[regtime]]', '[[regtime]]'),
(3037, 1, 1, 'sale_order', 'entry_firstname', 'First Name:', '[[regtime]]', '[[regtime]]'),
(3038, 1, 1, 'sale_order', 'entry_lastname', 'Last Name:', '[[regtime]]', '[[regtime]]'),
(3039, 1, 1, 'sale_order', 'entry_customer_group', 'Customer Group:', '[[regtime]]', '[[regtime]]'),
(3040, 1, 1, 'sale_order', 'entry_email', 'E-Mail:', '[[regtime]]', '[[regtime]]'),
(3041, 1, 1, 'sale_order', 'entry_ip', 'IP Address:', '[[regtime]]', '[[regtime]]'),
(3042, 1, 1, 'sale_order', 'entry_telephone', 'Telephone:', '[[regtime]]', '[[regtime]]'),
(3043, 1, 1, 'sale_order', 'entry_fax', 'Fax:', '[[regtime]]', '[[regtime]]'),
(3044, 1, 1, 'sale_order', 'entry_store_name', 'Store Name:', '[[regtime]]', '[[regtime]]'),
(3045, 1, 1, 'sale_order', 'entry_store_url', 'Store Url:', '[[regtime]]', '[[regtime]]'),
(3046, 1, 1, 'sale_order', 'entry_date_added', 'Date Added:', '[[regtime]]', '[[regtime]]'),
(3047, 1, 1, 'sale_order', 'entry_shipping_method', 'Shipping Method:', '[[regtime]]', '[[regtime]]'),
(3048, 1, 1, 'sale_order', 'entry_payment_method', 'Payment Method:', '[[regtime]]', '[[regtime]]'),
(3049, 1, 1, 'sale_order', 'entry_total', 'Original Order Total:', '[[regtime]]', '[[regtime]]'),
(3050, 1, 1, 'sale_order', 'entry_order_status', 'Order Status:', '[[regtime]]', '[[regtime]]'),
(3051, 1, 1, 'sale_order', 'entry_comment', 'Comment:', '[[regtime]]', '[[regtime]]'),
(3052, 1, 1, 'sale_order', 'entry_company', 'Company:', '[[regtime]]', '[[regtime]]'),
(3053, 1, 1, 'sale_order', 'entry_address_1', 'Address 1:', '[[regtime]]', '[[regtime]]'),
(3054, 1, 1, 'sale_order', 'entry_address_2', 'Address 2:', '[[regtime]]', '[[regtime]]'),
(3055, 1, 1, 'sale_order', 'entry_postcode', 'ZIP/Post Code:', '[[regtime]]', '[[regtime]]'),
(3056, 1, 1, 'sale_order', 'entry_city', 'City:', '[[regtime]]', '[[regtime]]'),
(3057, 1, 1, 'sale_order', 'entry_zone', 'Region / State:', '[[regtime]]', '[[regtime]]'),
(3058, 1, 1, 'sale_order', 'entry_zone_code', 'Region / State Code:', '[[regtime]]', '[[regtime]]'),
(3059, 1, 1, 'sale_order', 'entry_country', 'Country:', '[[regtime]]', '[[regtime]]'),
(3060, 1, 1, 'sale_order', 'entry_status', 'Order Status:', '[[regtime]]', '[[regtime]]'),
(3061, 1, 1, 'sale_order', 'entry_notify', 'Notify Customer:', '[[regtime]]', '[[regtime]]'),
(3062, 1, 1, 'sale_order', 'entry_append', 'Append Comments:', '[[regtime]]', '[[regtime]]'),
(3063, 1, 1, 'sale_order', 'entry_add_product', 'Add Available Product:', '[[regtime]]', '[[regtime]]'),
(3064, 1, 1, 'sale_order', 'error_permission', 'Warning: You do not have permission to modify orders!', '[[regtime]]', '[[regtime]]'),
(3065, 1, 1, 'sale_order', 'error_order_load', 'Warning: No order with such ID!', '[[regtime]]', '[[regtime]]'),
(3066, 1, 1, 'sale_order', 'text_order_summary', 'Order Summary', '[[regtime]]', '[[regtime]]'),
(3067, 1, 1, 'sale_order', 'tab_order_details', 'Order Details', '[[regtime]]', '[[regtime]]'),
(3068, 1, 1, 'sale_order', 'tab_address', 'Order Address', '[[regtime]]', '[[regtime]]'),
(3069, 1, 1, 'sale_order', 'tab_history', 'Status & Comments', '[[regtime]]', '[[regtime]]'),
(3070, 1, 1, 'sale_order', 'tab_files', 'Order Files', '[[regtime]]', '[[regtime]]'),
(3071, 1, 1, 'sale_order', 'tab_payment_details', 'Payment Details', '[[regtime]]', '[[regtime]]'),
(3072, 1, 1, 'sale_order', 'edit_title_files', 'Edit Order Files', '[[regtime]]', '[[regtime]]'),
(3073, 1, 1, 'sale_order', 'text_missing_file', 'Missing File', '[[regtime]]', '[[regtime]]'),
(3074, 1, 1, 'sale_order', 'order_download_history', 'Download History', '[[regtime]]', '[[regtime]]'),
(3075, 1, 1, 'sale_order', 'text_time', 'Time', '[[regtime]]', '[[regtime]]'),
(3076, 1, 1, 'sale_order', 'text_filename', 'Filename', '[[regtime]]', '[[regtime]]'),
(3077, 1, 1, 'sale_order', 'text_mask', 'Mask', '[[regtime]]', '[[regtime]]'),
(3078, 1, 1, 'sale_order', 'text_download_percent', 'Download Percents', '[[regtime]]', '[[regtime]]'),
(3079, 1, 1, 'sale_order', 'text_download_expired', 'Date Expired', '[[regtime]]', '[[regtime]]'),
(3080, 1, 1, 'sale_order', 'text_download_remaining_count', 'Remaining Count', '[[regtime]]', '[[regtime]]'),
(3081, 1, 1, 'sale_order', 'text_order_status_required', 'Order Status "%s" Required', '[[regtime]]', '[[regtime]]'),
(3082, 1, 1, 'sale_order', 'text_select_product', '- Select Product -', '[[regtime]]', '[[regtime]]'),
(3083, 1, 1, 'sale_order', 'text_push_download', '- Push Download -', '[[regtime]]', '[[regtime]]'),
(3084, 1, 1, 'sale_order', 'text_add_product_to_order', 'Add Product to Order #%s', '[[regtime]]', '[[regtime]]'),
(3085, 1, 1, 'sale_order', 'text_edit_order_product', 'Edit Product', '[[regtime]]', '[[regtime]]'),
(3086, 1, 1, 'sale_order', 'attention_check_total', 'Note: Order product details has changed. Total was recalculated automatically. Review is required.', '[[regtime]]', '[[regtime]]'),
(3087, 1, 1, 'sale_order', 'text_order_total_add', 'Add new amount to total calculation', '[[regtime]]', '[[regtime]]'),
(3088, 1, 1, 'sale_order', 'text_order_total_title', 'Title to show', '[[regtime]]', '[[regtime]]'),
(3089, 1, 1, 'sale_order', 'text_order_total_amount', 'Amount', '[[regtime]]', '[[regtime]]'),
(3090, 1, 1, 'sale_order', 'text_recalc', 'Recalculate using settings', '[[regtime]]', '[[regtime]]'),
(3091, 1, 1, 'sale_order', 'entry_im', 'IM:', '[[regtime]]', '[[regtime]]'),
(3092, 1, 1, 'sale_order', 'entry_stock_locations', 'Stock Locations:', '[[regtime]]', '[[regtime]]'),
(3093, 1, 1, 'sale_order', 'edit_title_map', 'On the map', '[[regtime]]', '[[regtime]]'),
(3094, 1, 1, 'sale_order', 'text_enable_google_map', 'To view addresses on the interactive Google map provide Google API key in the general settings', '[[regtime]]', '[[regtime]]'),
(3095, 1, 1, 'setting_setting', 'heading_title', 'Settings', '[[regtime]]', '[[regtime]]'),
(3096, 1, 1, 'setting_setting', 'column_store_alias', 'Store', '[[regtime]]', '[[regtime]]'),
(3097, 1, 1, 'setting_setting', 'column_group', 'Group', '[[regtime]]', '[[regtime]]'),
(3098, 1, 1, 'setting_setting', 'column_key', 'Key', '[[regtime]]', '[[regtime]]'),
(3099, 1, 1, 'setting_setting', 'column_value', 'Value', '[[regtime]]', '[[regtime]]'),
(3100, 1, 1, 'setting_setting', 'text_success', 'Success: You have successfully saved your settings!', '[[regtime]]', '[[regtime]]'),
(3101, 1, 1, 'setting_setting', 'text_image_manager', 'Image Manager', '[[regtime]]', '[[regtime]]'),
(3102, 1, 1, 'setting_setting', 'text_select_group', '- Select Group -', '[[regtime]]', '[[regtime]]'),
(3103, 1, 1, 'setting_setting', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(3104, 1, 1, 'setting_setting', 'text_edit_store_settings', 'Edit Settings:', '[[regtime]]', '[[regtime]]'),
(3105, 1, 1, 'setting_setting', 'text_edit_template_settings', 'Edit Template Settings:', '[[regtime]]', '[[regtime]]'),
(3106, 1, 1, 'setting_setting', 'text_common_template_settings', 'Template Selection', '[[regtime]]', '[[regtime]]'),
(3107, 1, 1, 'setting_setting', 'text_edit_store', 'Edit Store', '[[regtime]]', '[[regtime]]'),
(3108, 1, 1, 'setting_setting', 'text_mail', 'Inner Mailer', '[[regtime]]', '[[regtime]]'),
(3109, 1, 1, 'setting_setting', 'text_smtp', 'SMTP', '[[regtime]]', '[[regtime]]'),
(3110, 1, 1, 'setting_setting', 'text_native', 'Native ( sendmail binary and options "sendmail_path" setting of php.ini)', '[[regtime]]', '[[regtime]]'),
(3111, 1, 1, 'setting_setting', 'text_dsn', 'Take from system/config.php', '[[regtime]]', '[[regtime]]'),
(3112, 1, 1, 'setting_setting', 'text_dsn_description', 'Mailer combines a <a target="_blank" href="https://en.wikipedia.org/wiki/Data_source_name">DSN</a> from config.php file. Please read <a target="_blank" href="https://abantecart.atlassian.net/wiki/spaces/AD/pages/7372837/Mail+Settings">our documentation</a> for details  ', '[[regtime]]', '[[regtime]]'),
(3113, 1, 1, 'setting_setting', 'tab_all', 'All', '[[regtime]]', '[[regtime]]'),
(3114, 1, 1, 'setting_setting', 'entry_name', 'Store Name:', '[[regtime]]', '[[regtime]]'),
(3115, 1, 1, 'setting_setting', 'entry_url', 'Store URL:<br /><span class="help">Include the full URL to your store. Make sure to add ''/'' at the end. Example: http://www.yourdomain.com/path/</span>', '[[regtime]]', '[[regtime]]'),
(3116, 1, 1, 'setting_setting', 'entry_owner', 'Store Owner:', '[[regtime]]', '[[regtime]]'),
(3117, 1, 1, 'setting_setting', 'entry_address', 'Address:', '[[regtime]]', '[[regtime]]'),
(3118, 1, 1, 'setting_setting', 'entry_email', 'E-Mail:', '[[regtime]]', '[[regtime]]'),
(3119, 1, 1, 'setting_setting', 'entry_alert_emails', 'Additional Alert E-Mails:<br /><span class="help">Any additional emails you want to receive the alert email, in addition to the main store email. (comma separated)</span>', '[[regtime]]', '[[regtime]]'),
(3120, 1, 1, 'setting_setting', 'error_alert_emails', 'Alert E-Mails must be valid and comma-separated!', '[[regtime]]', '[[regtime]]'),
(3121, 1, 1, 'setting_setting', 'entry_telephone', 'Telephone:', '[[regtime]]', '[[regtime]]'),
(3122, 1, 1, 'setting_setting', 'entry_fax', 'Fax:', '[[regtime]]', '[[regtime]]'),
(3123, 1, 1, 'setting_setting', 'entry_title', 'Title:<br /><span class="help">This is displayed in storefront browser title</span>', '[[regtime]]', '[[regtime]]'),
(3124, 1, 1, 'setting_setting', 'entry_meta_description', 'Meta Tag Description:<br /><span class="help">Storefront main page meta tag description</span>', '[[regtime]]', '[[regtime]]'),
(3125, 1, 1, 'setting_setting', 'entry_meta_keywords', 'Meta Keywords:<br /><span class="help">Storefront main page meta tag keywords (comma separated)</span>', '[[regtime]]', '[[regtime]]'),
(3126, 1, 1, 'setting_setting', 'entry_description', 'Welcome Message:', '[[regtime]]', '[[regtime]]'),
(3127, 1, 1, 'setting_setting', 'entry_template', 'Template:<span class="help">Storefront template. This can be main or extension template</span>', '[[regtime]]', '[[regtime]]'),
(3128, 1, 1, 'setting_setting', 'entry_admin_template', 'Control Panel Template:', '[[regtime]]', '[[regtime]]'),
(3129, 1, 1, 'setting_setting', 'entry_country', 'Country:', '[[regtime]]', '[[regtime]]'),
(3130, 1, 1, 'setting_setting', 'entry_zone', 'Region / State:', '[[regtime]]', '[[regtime]]'),
(3131, 1, 1, 'setting_setting', 'entry_language', 'Storefront Language:', '[[regtime]]', '[[regtime]]'),
(3132, 1, 1, 'setting_setting', 'entry_admin_language', 'Administration Language: <span class="help">NOTE: works if no user preferred language is found in the browser</span>', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(3133, 1, 1, 'setting_setting', 'entry_currency', 'Base Currency:<span class="help">This is a base currency for all stores. Do not change if you do not understand what will happen. Warning: Changing of base currency will not change your base prices for products. You will need to review and adjust all the prices if needed. Base currency exchange rate will be set to 1.00 and all other currencies exchange rates will be adjusted in respect to new base currency.</span>', '[[regtime]]', '[[regtime]]'),
(3134, 1, 1, 'setting_setting', 'entry_currency_auto', 'Auto Update Currency:<br /><span class="help">Set your store to automatically update currencies daily.</span>', '[[regtime]]', '[[regtime]]'),
(3135, 1, 1, 'setting_setting', 'entry_weight_class', 'Weight Class:', '[[regtime]]', '[[regtime]]'),
(3136, 1, 1, 'setting_setting', 'entry_length_class', 'Length Class:', '[[regtime]]', '[[regtime]]'),
(3137, 1, 1, 'setting_setting', 'entry_auto_translate_status', 'Autotranslate Status:<br /><span class="help">This enabled translation of missing text definitions or language specific data if text values are missing for used language.</span>', '[[regtime]]', '[[regtime]]'),
(3138, 1, 1, 'setting_setting', 'entry_translate_src_lang_code', 'Source language for translation:<br /><span class="help">Select source language to be used for autotranslation.</span>', '[[regtime]]', '[[regtime]]'),
(3139, 1, 1, 'setting_setting', 'entry_translate_method', 'Text Translation Method:<br /><span class="help">Select method you want to use for translation. Default method is a straight copy of source language text</span>', '[[regtime]]', '[[regtime]]'),
(3140, 1, 1, 'setting_setting', 'entry_translate_override_existing', 'Override if source language text was changed:<br /><span class="help">If set, text in all languages will be replaced with new translation if source language text is edited. NOTE: Can cause many translations.</span>', '[[regtime]]', '[[regtime]]'),
(3141, 1, 1, 'setting_setting', 'entry_warn_lang_text_missing', 'Warn for missing language text:<br /><span class="help">Get warning message if missing language text is detected.</span>', '[[regtime]]', '[[regtime]]'),
(3142, 1, 1, 'setting_setting', 'entry_tax', 'Display Prices With Tax:', '[[regtime]]', '[[regtime]]'),
(3143, 1, 1, 'setting_setting', 'entry_tax_store', 'Default Store Tax Rate:', '[[regtime]]', '[[regtime]]'),
(3144, 1, 1, 'setting_setting', 'entry_tax_store_0', 'No Tax', '[[regtime]]', '[[regtime]]'),
(3145, 1, 1, 'setting_setting', 'entry_tax_store_1', 'Store Default Zone', '[[regtime]]', '[[regtime]]'),
(3146, 1, 1, 'setting_setting', 'entry_tax_customer', 'Use Customer Tax Address:', '[[regtime]]', '[[regtime]]'),
(3147, 1, 1, 'setting_setting', 'entry_tax_customer_0', 'Shipping Address', '[[regtime]]', '[[regtime]]'),
(3148, 1, 1, 'setting_setting', 'entry_tax_customer_1', 'Billing Address', '[[regtime]]', '[[regtime]]'),
(3149, 1, 1, 'setting_setting', 'entry_invoice', 'Invoice Start No.:<br /><span class="help">Set the starting number the invoices will begin from.</span>', '[[regtime]]', '[[regtime]]'),
(3150, 1, 1, 'setting_setting', 'entry_invoice_prefix', 'Invoice Prefix:<br /><span class="help">Set the invoice prefix e.g. IN/001</span>', '[[regtime]]', '[[regtime]]'),
(3151, 1, 1, 'setting_setting', 'entry_customer_group', 'Customer Group:<br /><span class="help">Default customer group.</span>', '[[regtime]]', '[[regtime]]'),
(3152, 1, 1, 'setting_setting', 'entry_customer_price', 'Login Display Prices:<br /><span class="help">Show prices even if customer is not logged in.</span>', '[[regtime]]', '[[regtime]]'),
(3153, 1, 1, 'setting_setting', 'entry_customer_approval', 'Review New Registrations:<br /><span class="help">If enabled, do not allow new customer to login until their account has been approved.</span>', '[[regtime]]', '[[regtime]]'),
(3154, 1, 1, 'setting_setting', 'entry_prevent_email_as_login', 'Require Login Name:<br /><span class="help">To improve security, require customers to create unique login name instead of using email address as login name. If set to ON, existing customers will be asked to create new login name at the first login. If OFF, login name is set as customer email address.</span>', '[[regtime]]', '[[regtime]]'),
(3155, 1, 1, 'setting_setting', 'entry_guest_checkout', 'Guest Checkout:<br /><span class="help">Allow customers to checkout without creating an account. This will not be available when a downloadable product is in the shopping cart.</span>', '[[regtime]]', '[[regtime]]'),
(3156, 1, 1, 'setting_setting', 'entry_account', 'Account Terms:<br /><span class="help">Forces people to agree to terms before an account can be created.</span>', '[[regtime]]', '[[regtime]]'),
(3157, 1, 1, 'setting_setting', 'entry_checkout', 'Checkout Terms:<br /><span class="help">Forces people to agree to terms before an a customer can checkout.</span>', '[[regtime]]', '[[regtime]]'),
(3158, 1, 1, 'setting_setting', 'entry_order_status', 'Order Status:<br /><span class="help">Set the default order status when an order is processed.</span>', '[[regtime]]', '[[regtime]]'),
(3159, 1, 1, 'setting_setting', 'entry_customer_cancelation_order_status', 'Allow Customer to Cancel Order on Status:', '[[regtime]]', '[[regtime]]'),
(3160, 1, 1, 'setting_setting', 'entry_stock_display', 'Display Stock Quantity:<br /><span class="help">Display stock quantity on the product page.</span>', '[[regtime]]', '[[regtime]]'),
(3161, 1, 1, 'setting_setting', 'entry_nostock_autodisable', 'No Stock Auto Disable:<br /><span class="help">Disable your product or option value for view if stock drops to 0. Message notification will be send </span>', '[[regtime]]', '[[regtime]]'),
(3162, 1, 1, 'setting_setting', 'entry_stock_checkout', 'Default Stock Checkout:<br /><span class="help">Set default setting to allow customers checkout even if the products are out of stock</span>', '[[regtime]]', '[[regtime]]'),
(3163, 1, 1, 'setting_setting', 'entry_stock_status', 'Default Pre-Order Stock Status:<br /><span class="help">Default setting for Pre-order status message for product. Used on product edit page.</span>', '[[regtime]]', '[[regtime]]'),
(3164, 1, 1, 'setting_setting', 'entry_logo', 'Store Logo:', '[[regtime]]', '[[regtime]]'),
(3165, 1, 1, 'setting_setting', 'entry_mail_logo', 'Email Logo:', '[[regtime]]', '[[regtime]]'),
(3166, 1, 1, 'setting_setting', 'entry_icon', 'Icon:<br /><span class="help">The icon can be a PNG or ICON type that is 16px x 16px.</span>', '[[regtime]]', '[[regtime]]'),
(3167, 1, 1, 'setting_setting', 'entry_width', 'Width:', '[[regtime]]', '[[regtime]]'),
(3168, 1, 1, 'setting_setting', 'entry_height', 'Height:', '[[regtime]]', '[[regtime]]'),
(3169, 1, 1, 'setting_setting', 'entry_image_thumb', 'Product Image Thumb Size:', '[[regtime]]', '[[regtime]]'),
(3170, 1, 1, 'setting_setting', 'entry_image_thumb_width', 'Product Image Thumb Width:', '[[regtime]]', '[[regtime]]'),
(3171, 1, 1, 'setting_setting', 'entry_image_thumb_height', 'Product Image Thumb Height:', '[[regtime]]', '[[regtime]]'),
(3172, 1, 1, 'setting_setting', 'entry_image_popup', 'Product Image Popup Size:', '[[regtime]]', '[[regtime]]'),
(3173, 1, 1, 'setting_setting', 'entry_image_popup_width', 'Large Window Preview Width:', '[[regtime]]', '[[regtime]]'),
(3174, 1, 1, 'setting_setting', 'entry_image_popup_height', 'Large Window Preview Height:', '[[regtime]]', '[[regtime]]'),
(3175, 1, 1, 'setting_setting', 'entry_image_category', 'Category List Size:', '[[regtime]]', '[[regtime]]'),
(3176, 1, 1, 'setting_setting', 'entry_image_category_width', 'Category List Width:', '[[regtime]]', '[[regtime]]'),
(3177, 1, 1, 'setting_setting', 'entry_image_category_height', 'Category List Height:', '[[regtime]]', '[[regtime]]'),
(3178, 1, 1, 'setting_setting', 'entry_image_manufacturer_width', 'Brand Icon List Width:', '[[regtime]]', '[[regtime]]'),
(3179, 1, 1, 'setting_setting', 'entry_image_manufacturer_height', 'Brand Icon List Height:', '[[regtime]]', '[[regtime]]'),
(3180, 1, 1, 'setting_setting', 'entry_image_product', 'Product List Size:', '[[regtime]]', '[[regtime]]'),
(3181, 1, 1, 'setting_setting', 'entry_image_product_height', 'Product List Height:<br /><span class="help">This is to control height of a preview image in the listing pages of admin and other places in the storefront. Note, this setting is shared between admin and default storefront template.</span>', '[[regtime]]', '[[regtime]]'),
(3182, 1, 1, 'setting_setting', 'entry_image_product_width', 'Product List Width:<br /><span class="help">This is to control width of a preview image in the listing pages of admin and other places in the storefront. Note, this setting is shared between admin and default storefront template.</span>', '[[regtime]]', '[[regtime]]'),
(3183, 1, 1, 'setting_setting', 'entry_image_additional', 'Additional Product Image Size:', '[[regtime]]', '[[regtime]]'),
(3184, 1, 1, 'setting_setting', 'entry_image_additional_width', 'Additional Product Image Width:', '[[regtime]]', '[[regtime]]'),
(3185, 1, 1, 'setting_setting', 'entry_image_additional_height', 'Additional Product Image Height:', '[[regtime]]', '[[regtime]]'),
(3186, 1, 1, 'setting_setting', 'entry_image_related', 'Related Product Image Size:', '[[regtime]]', '[[regtime]]'),
(3187, 1, 1, 'setting_setting', 'entry_image_related_width', 'Related Product Image Width:', '[[regtime]]', '[[regtime]]'),
(3188, 1, 1, 'setting_setting', 'entry_image_related_height', 'Related Product Image Height:', '[[regtime]]', '[[regtime]]'),
(3189, 1, 1, 'setting_setting', 'entry_image_cart', 'Cart Image Size:', '[[regtime]]', '[[regtime]]'),
(3190, 1, 1, 'setting_setting', 'entry_image_cart_width', 'Cart Image Width:', '[[regtime]]', '[[regtime]]'),
(3191, 1, 1, 'setting_setting', 'entry_image_cart_height', 'Cart Image Height:', '[[regtime]]', '[[regtime]]'),
(3192, 1, 1, 'setting_setting', 'entry_image_grid', 'Grid Image Size:', '[[regtime]]', '[[regtime]]'),
(3193, 1, 1, 'setting_setting', 'entry_image_grid_width', 'Grid Image Width:<br /><span class="help">This is to control width of a very small preview image in the listing grids of admin and other places in the storefront. Note, this setting is shared between admin and default storefront template.</span>', '[[regtime]]', '[[regtime]]'),
(3194, 1, 1, 'setting_setting', 'entry_image_grid_height', 'Grid Image Height:<br /><span class="help">This is to control height of a very small preview image in the listing grids of admin and other places in the storefront. Note, this setting is shared between admin and default storefront template.</span>', '[[regtime]]', '[[regtime]]'),
(3195, 1, 1, 'setting_setting', 'entry_alert_mail', 'Alert Mail:<br /><span class="help">Send a email to the store owner when a new order is created.</span>', '[[regtime]]', '[[regtime]]'),
(3196, 1, 1, 'setting_setting', 'entry_download', 'Allow Downloads:', '[[regtime]]', '[[regtime]]'),
(3197, 1, 1, 'setting_setting', 'entry_download_status', 'Download Order Status:<br /><span class="help">Set the order status the customers order must reach before they are allowed to access their downloadable products.</span>', '[[regtime]]', '[[regtime]]'),
(3198, 1, 1, 'setting_setting', 'entry_mail_transporting', 'Mail Transporting:', '[[regtime]]', '[[regtime]]'),
(3199, 1, 1, 'setting_setting', 'text_native_mail_description', 'Mailer uses the sendmail binary and options configured in the sendmail_path setting of php.ini. ', '[[regtime]]', '[[regtime]]'),
(3200, 1, 1, 'setting_setting', 'entry_smtp_host', 'SMTP Host:<br /><span class="help">Use ssl://smtp.yourdomain.com for secure smtp connection', '[[regtime]]', '[[regtime]]'),
(3201, 1, 1, 'setting_setting', 'entry_smtp_username', 'SMTP Username:', '[[regtime]]', '[[regtime]]'),
(3202, 1, 1, 'setting_setting', 'entry_smtp_password', 'SMTP Password:', '[[regtime]]', '[[regtime]]'),
(3203, 1, 1, 'setting_setting', 'entry_smtp_port', 'SMTP Port:', '[[regtime]]', '[[regtime]]'),
(3204, 1, 1, 'setting_setting', 'entry_smtp_timeout', 'SMTP Timeout:', '[[regtime]]', '[[regtime]]'),
(3205, 1, 1, 'setting_setting', 'entry_ssl', 'Use SSL:<br /><span class="help">To use SSL check with your host if a SSL certificate is installed.</span>', '[[regtime]]', '[[regtime]]'),
(3206, 1, 1, 'setting_setting', 'entry_session_ttl', 'Control Panel Session Expiration:<br /><span class="help">This value controls time interval in minutes before you will be asked to login again due to no activity. For strict idle timeout behavior, disable Keep Long Session.</span>', '[[regtime]]', '[[regtime]]'),
(3207, 1, 1, 'setting_setting', 'entry_admin_background_autorefresh', 'Keep Long Session:<br /><span class="help">Enable periodic background requests for admin notifications and system checks. Disable this to prevent background refresh from extending active session. After changing this setting, you may see a one-time re-login prompt.</span>', '[[regtime]]', '[[regtime]]'),
(3208, 1, 1, 'setting_setting', 'entry_encryption', 'Encryption Key:<br /><span class="help">Setting migrated to config file starting in v1.2.1.</span>', '[[regtime]]', '[[regtime]]'),
(3209, 1, 1, 'setting_setting', 'entry_seo_url', 'Use SEO URL''s:<br /><span class="help">To use SEO URL''s apache module mod-rewrite must be installed and you need to rename the htaccess.txt to .htaccess. Note: If abantecart not installed in the root of domain must be changed rewriteBase rule inside .htaccess file.</span>', '[[regtime]]', '[[regtime]]'),
(3210, 1, 1, 'setting_setting', 'entry_retina_enable', 'Generate high-res (retina) images:<br /><span class="help">To use this apache module mod-rewrite must be installed and you need to rename the htaccess.txt to .htaccess. Note: If abantecart not installed in the root of domain must be changed rewriteBase rule inside .htaccess file. <br>After enabling should clear the cache images. </span>', '[[regtime]]', '[[regtime]]'),
(3211, 1, 1, 'setting_setting', 'entry_image_quality', 'Jpeg Images Compression Level', '[[regtime]]', '[[regtime]]'),
(3212, 1, 1, 'setting_setting', 'entry_compression', 'Output Compression Level:<br /><span class="help">GZIP for more efficient transfer to requesting clients. Compression level must be between 0 - 9</span>', '[[regtime]]', '[[regtime]]'),
(3213, 1, 1, 'setting_setting', 'entry_error_display', 'Display Errors:<br /><span class="help">Set to yes if you want to see the exceptions and errors</span>', '[[regtime]]', '[[regtime]]'),
(3214, 1, 1, 'setting_setting', 'entry_error_log', 'Log Errors:<br /><span class="help">Set to yes if you want to save the exceptions and errors to the log</span>', '[[regtime]]', '[[regtime]]'),
(3215, 1, 1, 'setting_setting', 'entry_enable_reviews', 'Enable Reviews:<br /><span class="help"></span>', '[[regtime]]', '[[regtime]]'),
(3216, 1, 1, 'setting_setting', 'entry_cache_enable', 'Cache enabled:<br /><span class="help">Please be careful when disable caching. Cached pages will not be re-created and site might start loading slow. </span>', '[[regtime]]', '[[regtime]]'),
(3217, 1, 1, 'setting_setting', 'text_setting_cache_drivers', ' Currently using cache <b>%s</b> driver. Other drivers available for configuration are <i>%s</i> ', '[[regtime]]', '[[regtime]]'),
(3218, 1, 1, 'setting_setting', 'entry_storefront_api_status', 'Storefront API status:', '[[regtime]]', '[[regtime]]'),
(3219, 1, 1, 'setting_setting', 'entry_storefront_api_key', 'Storefront API Key:<br /><span class="help">Set this key to provide restricted (more secure) access to storefront API.</span>', '[[regtime]]', '[[regtime]]'),
(3220, 1, 1, 'setting_setting', 'entry_storefront_api_stock_check', 'Storefront API Stock Access:<br /><span class="help">Enable if you allow storefront API to check stock availability</span>', '[[regtime]]', '[[regtime]]'),
(3221, 1, 1, 'setting_setting', 'entry_admin_api_status', 'Admin API status:', '[[regtime]]', '[[regtime]]'),
(3222, 1, 1, 'setting_setting', 'entry_admin_api_key', 'Admin API Key:<br /><span class="help">Set this key to provide restricted (more secure) access to admin API.</span>', '[[regtime]]', '[[regtime]]'),
(3223, 1, 1, 'setting_setting', 'entry_admin_access_ip_list', 'Admin API Access IPs:<br /><span class="help">Provide list of IPs (comma separated) that will be allowed to access admin API. Other IPs will be blocked</span>', '[[regtime]]', '[[regtime]]'),
(3224, 1, 1, 'setting_setting', 'entry_upload_max_size', 'Resource Library Upload Max File Size, kB', '[[regtime]]', '[[regtime]]'),
(3225, 1, 1, 'setting_setting', 'entry_debug', 'Show Debug Info:<br /><span class="help">Set this ON if you want to see the execution details and show debug details.</span>', '[[regtime]]', '[[regtime]]'),
(3226, 1, 1, 'setting_setting', 'entry_debug_0', 'Off', '[[regtime]]', '[[regtime]]'),
(3227, 1, 1, 'setting_setting', 'entry_debug_1', 'Show', '[[regtime]]', '[[regtime]]'),
(3228, 1, 1, 'setting_setting', 'entry_debug_2', 'Log', '[[regtime]]', '[[regtime]]'),
(3229, 1, 1, 'setting_setting', 'entry_debug_level', 'Debug Level:<br /><span class="help">Select the depth of the details you need to see in the debug output.</span>', '[[regtime]]', '[[regtime]]'),
(3230, 1, 1, 'setting_setting', 'entry_debug_level_0', 'Level 0 - no logs , only exception errors ', '[[regtime]]', '[[regtime]]'),
(3231, 1, 1, 'setting_setting', 'entry_debug_level_1', 'Level 1 - errors and warnings', '[[regtime]]', '[[regtime]]'),
(3232, 1, 1, 'setting_setting', 'entry_debug_level_2', 'Level 2 - #1 + mysql site load, php file execution time and page elements load time ', '[[regtime]]', '[[regtime]]'),
(3233, 1, 1, 'setting_setting', 'entry_debug_level_3', 'Level 3 - #2 + basic logs and stack of execution', '[[regtime]]', '[[regtime]]'),
(3234, 1, 1, 'setting_setting', 'entry_debug_level_4', 'Level 4 - #3 + dump mysql statements ', '[[regtime]]', '[[regtime]]'),
(3235, 1, 1, 'setting_setting', 'entry_debug_level_5', 'Level 5 - #4 + intermediate variable ', '[[regtime]]', '[[regtime]]'),
(3236, 1, 1, 'setting_setting', 'entry_template_debug', 'Template debug:<br /><span class="help">Enable this setting if you need to check issues with template in storefront and control panel.</span>', '[[regtime]]', '[[regtime]]'),
(3237, 1, 1, 'setting_setting', 'entry_error_filename', 'Error Log Filename:<br /><span class="help">This is a file where errors are saved.</span>', '[[regtime]]', '[[regtime]]'),
(3238, 1, 1, 'setting_setting', 'entry_shipping_session', 'Use Shipping Session:<br /><span class="help">Saves shipping quotes to session to avoid re-quoting unnecessarily. Quotes will only be re-quoted if cart or address is changed.</span>', '[[regtime]]', '[[regtime]]'),
(3239, 1, 1, 'setting_setting', 'entry_catalog_limit', 'Default Items per Page (Storefront):<br /><span class="help">Sets how many storefront items are shown per page (products, categories, etc)</span>', '[[regtime]]', '[[regtime]]'),
(3240, 1, 1, 'setting_setting', 'entry_admin_limit', 'Default Items per Page (Admin):<br /><span class="help">Sets how many admin items are shown per page in listing grids (orders, customers, etc)</span>', '[[regtime]]', '[[regtime]]'),
(3241, 1, 1, 'setting_setting', 'entry_bestseller_limit', 'Number of Items In Bestseller Block ', '[[regtime]]', '[[regtime]]'),
(3242, 1, 1, 'setting_setting', 'entry_featured_limit', 'Number of Items In Featured Block ', '[[regtime]]', '[[regtime]]'),
(3243, 1, 1, 'setting_setting', 'entry_latest_limit', 'Number of Items In Latest Block ', '[[regtime]]', '[[regtime]]'),
(3244, 1, 1, 'setting_setting', 'entry_special_limit', 'Number of Items In Special Block ', '[[regtime]]', '[[regtime]]'),
(3245, 1, 1, 'setting_setting', 'entry_content_limit', 'Number of Items In Content Blocks ', '[[regtime]]', '[[regtime]]'),
(3246, 1, 1, 'setting_setting', 'entry_cart_weight', 'Display Weight on Cart Page:<br /><span class="help">Show the cart weight on the cart page</span>', '[[regtime]]', '[[regtime]]'),
(3247, 1, 1, 'setting_setting', 'entry_reviews', 'Post Reviews:<br /><span class="help">Restrict who can post review for the products</span>', '[[regtime]]', '[[regtime]]'),
(3248, 1, 1, 'setting_setting', 'entry_maintenance', 'Maintenance Mode:<br /><span class="help">Prevents customers from browsing your store. They will instead see a maintenance message. If logged in as admin, you will see the store as normal.</span>', '[[regtime]]', '[[regtime]]'),
(3249, 1, 1, 'setting_setting', 'entry_voicecontrol', 'Voice Control:<br /><span class="help">Enable admin voice control to activate voice commands feature. Currently only supported in Chrome version 25 or later.</span>', '[[regtime]]', '[[regtime]]'),
(3250, 1, 1, 'setting_setting', 'entry_help_links', 'Help Links:<br /><span class="help">If you want to see Help Icons and links to AbanteCart site. This will help you learn about features and how to use them. If you advanced user and do not want to see these help icons, you can disable.</span>', '[[regtime]]', '[[regtime]]'),
(3251, 1, 1, 'setting_setting', 'entry_show_tree_data', 'Enable Tree Grid:<br /><span class="help">Enables admin grids to show parent/children types in one grid listing. NOTE: Pagination and multi-actions are disabled for these grids</span>', '[[regtime]]', '[[regtime]]'),
(3252, 1, 1, 'setting_setting', 'entry_cart_ajax', 'Same Page Add To Cart:<br /><span class="help">This will enable AJAX add to cart feature. Product can be added to cart without redirecting to cart page</span>', '[[regtime]]', '[[regtime]]'),
(3253, 1, 1, 'setting_setting', 'entry_storefront_width', 'Storefront Site Width:<br /><span class="help">Example: 100% or 1000px </span>', '[[regtime]]', '[[regtime]]'),
(3254, 1, 1, 'setting_setting', 'entry_admin_width', 'Admin Site Width:<br /><span class="help">Example: 100% or 1000px </span>', '[[regtime]]', '[[regtime]]'),
(3255, 1, 1, 'setting_setting', 'entry_total_order_maximum', 'Maximum order amount allowed:<br /><span class="help">Prevent checkout with large order sub-total amounts. 0 = NO LIMIT</span>', '[[regtime]]', '[[regtime]]'),
(3256, 1, 1, 'setting_setting', 'entry_total_order_minimum', 'Minimum order amount:<br /><span class="help">Prevent checkout if order sub-total does not reach minimum amount set. 0 = NO MINIMUM</span>', '[[regtime]]', '[[regtime]]'),
(3257, 1, 1, 'setting_setting', 'entry_system_check', 'System Check:<br /><span class="help">Enable this setting if you want to check your system condition in respect to AbanteCart functionality. System issues effecting AbanteCart will be reported as messages visible in admin.</span>', '[[regtime]]', '[[regtime]]'),
(3258, 1, 1, 'setting_setting', 'button_add_store', 'New Store', '[[regtime]]', '[[regtime]]'),
(3259, 1, 1, 'setting_setting', 'error_permission', 'Warning: You do not have permission to modify settings!', '[[regtime]]', '[[regtime]]'),
(3260, 1, 1, 'setting_setting', 'error_loginname', 'Login name must be alphanumeric only and between 5 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(3261, 1, 1, 'setting_setting', 'error_loginname_notunique', 'This login name is not available. Try different login name!', '[[regtime]]', '[[regtime]]'),
(3262, 1, 1, 'setting_setting', 'error_name', 'Store Name must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(3263, 1, 1, 'setting_setting', 'error_url', 'Valid Store URL required!', '[[regtime]]', '[[regtime]]'),
(3264, 1, 1, 'setting_setting', 'error_title', 'Title must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(3265, 1, 1, 'setting_setting', 'error_owner', 'Store Owner must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(3266, 1, 1, 'setting_setting', 'error_address', 'Store Address must be between 10 and 256 characters!', '[[regtime]]', '[[regtime]]'),
(3267, 1, 1, 'setting_setting', 'error_email', 'E-Mail Address does not appear to be valid!', '[[regtime]]', '[[regtime]]'),
(3268, 1, 1, 'setting_setting', 'error_telephone', 'Telephone must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(3269, 1, 1, 'setting_setting', 'error_image_thumb', 'Product Image Thumb Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3270, 1, 1, 'setting_setting', 'error_image_popup', 'Product Image Popup Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3271, 1, 1, 'setting_setting', 'error_image_category', 'Category List Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3272, 1, 1, 'setting_setting', 'error_image_manufacturer', 'Brand Icon List Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3273, 1, 1, 'setting_setting', 'error_image_product', 'Product List Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3274, 1, 1, 'setting_setting', 'error_image_additional', 'Additional Product Image Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3275, 1, 1, 'setting_setting', 'error_image_related', 'Related Product Image Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3276, 1, 1, 'setting_setting', 'error_image_cart', 'Cart Image Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3277, 1, 1, 'setting_setting', 'error_image_grid', 'Grid Image Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3278, 1, 1, 'setting_setting', 'error_error_filename', 'Error Log Filename required!', '[[regtime]]', '[[regtime]]'),
(3279, 1, 1, 'setting_setting', 'error_required_data', 'Required Data has not been entered. Check for field errors!', '[[regtime]]', '[[regtime]]'),
(3280, 1, 1, 'setting_setting', 'error_uploaded_image', 'Uploaded file %s is not image or broken!', '[[regtime]]', '[[regtime]]'),
(3281, 1, 1, 'setting_setting', 'error_limit', 'Limit required!', '[[regtime]]', '[[regtime]]'),
(3282, 1, 1, 'setting_setting', 'text_front', 'Store Front', '[[regtime]]', '[[regtime]]'),
(3283, 1, 1, 'setting_setting', 'text_admin', 'Admin', '[[regtime]]', '[[regtime]]'),
(3284, 1, 1, 'setting_setting', 'error_mail', 'Please fill required fields for smtp-protocol!', '[[regtime]]', '[[regtime]]'),
(3285, 1, 1, 'setting_setting', 'text_sorting_sort_order_asc', 'Product''s Sort Order Low &gt; High', '[[regtime]]', '[[regtime]]'),
(3286, 1, 1, 'setting_setting', 'text_sorting_name_asc', 'Name A - Z', '[[regtime]]', '[[regtime]]'),
(3287, 1, 1, 'setting_setting', 'text_sorting_name_desc', 'Name Z - A', '[[regtime]]', '[[regtime]]'),
(3288, 1, 1, 'setting_setting', 'text_sorting_price_asc', 'Price Low &gt; High', '[[regtime]]', '[[regtime]]'),
(3289, 1, 1, 'setting_setting', 'text_sorting_price_desc', 'Price High &gt; Low', '[[regtime]]', '[[regtime]]'),
(3290, 1, 1, 'setting_setting', 'text_sorting_rating_asc', 'Rating Lowest', '[[regtime]]', '[[regtime]]'),
(3291, 1, 1, 'setting_setting', 'text_sorting_rating_desc', 'Rating Highest', '[[regtime]]', '[[regtime]]'),
(3292, 1, 1, 'setting_setting', 'text_sorting_date_asc', 'Date Old &gt; New', '[[regtime]]', '[[regtime]]'),
(3293, 1, 1, 'setting_setting', 'text_sorting_date_desc', 'Date New &gt; Old', '[[regtime]]', '[[regtime]]'),
(3294, 1, 1, 'setting_setting', 'entry_product_default_sort_order', 'Sort Products as default by:', '[[regtime]]', '[[regtime]]'),
(3295, 1, 1, 'setting_setting', 'entry_zero_customer_balance', 'Show Zero Customer Balance:<br /><span class="help">Note: Enable/disable display of balance message if customer account balance is 0</span>', '[[regtime]]', '[[regtime]]'),
(3296, 1, 1, 'setting_setting', 'entry_shipping_tax_estimate', 'Shipping and Tax Estimate:<br /><span class="help">Allow customers to get quick shipping and tax estimate in the shopping cart.</span>', '[[regtime]]', '[[regtime]]'),
(3297, 1, 1, 'setting_setting', 'entry_coupon_on_cart_page', 'Coupon on shopping cart page:<br /><span class="help">Allow customers to enter coupon code and see discount in the shopping cart.</span>', '[[regtime]]', '[[regtime]]'),
(3298, 1, 1, 'setting_setting', 'entry_google_analytics', 'Google Analytics 4 tag ID:<br /><span class="help">Add your <a href="https://support.google.com/analytics/answer/9539598?hl=en" target="_blank">Google Analytics tag ID</a> to enable site activity tracking. This also enables ecommerce activity tracking. You must enable ecommerce tracking in google on the profile settings page for your website</span>', '[[regtime]]', '[[regtime]]'),
(3299, 1, 1, 'setting_setting', 'entry_google_api_key', 'Google Maps and Places API Key:<br /><span class="help">Enter your Google Maps and Places API key to show addresses on the map and enable address autocomplete in storefront address forms. This key is used on storefront pages and is exposed client-side, so restrict it by allowed domain(s) and/or IP address in Google Cloud Console.</span>', '[[regtime]]', '[[regtime]]'),
(3300, 1, 1, 'setting_setting', 'entry_google_address_autocomplete', 'Address Autocomplete (Google Places):<br /><span class="help">Enable or disable Google Places API address autocomplete in storefront address forms. Requires Google API Key.</span>', '[[regtime]]', '[[regtime]]'),
(3301, 1, 1, 'setting_setting', 'entry_viewed_products_limit', 'Viewed products limit:', '[[regtime]]', '[[regtime]]'),
(3302, 1, 1, 'setting_setting', 'entry_viewed_products_image_width', 'Viewed products image width:', '[[regtime]]', '[[regtime]]'),
(3303, 1, 1, 'setting_setting', 'entry_viewed_products_image_height', 'Viewed products image height:', '[[regtime]]', '[[regtime]]'),
(3304, 1, 1, 'setting_setting', 'entry_ssl_url', 'Secure Store URL:<br /><span class="help">Include the full SSL URL(HTTPS) to your store. Make sure to add ''/'' at the end. Example: https://www.yourdomain.com/path/</span>', '[[regtime]]', '[[regtime]]'),
(3305, 1, 1, 'setting_setting', 'error_ssl_url', 'Valid Secure URL required!', '[[regtime]]', '[[regtime]]'),
(3306, 1, 1, 'setting_setting', 'entry_customer_email_activation', 'Email Activation for New Customers:<br /><span class="help">Don''t allow new customer to login until their account has been confirmed by activation link sent via email. For this to work, make sure "Approve New Customers" is set to OFF.</span>', '[[regtime]]', '[[regtime]]'),
(3307, 1, 1, 'setting_setting', 'text_clone_template', 'Clone Template With AbanteCart Developer Tools', '[[regtime]]', '[[regtime]]'),
(3308, 1, 1, 'setting_setting', 'text_set_template', 'Set this template for the storefront', '[[regtime]]', '[[regtime]]'),
(3309, 1, 1, 'setting_setting', 'entry_embed_status', 'Enable Storefront Embed:', '[[regtime]]', '[[regtime]]'),
(3310, 1, 1, 'setting_setting', 'entry_embed_click_action', 'Embed Click Action:', '[[regtime]]', '[[regtime]]'),
(3311, 1, 1, 'setting_setting', 'text_embed_click_action_modal', 'Same page Modal Dialog', '[[regtime]]', '[[regtime]]'),
(3312, 1, 1, 'setting_setting', 'text_embed_click_action_new_window', 'Open new page in new tab', '[[regtime]]', '[[regtime]]'),
(3313, 1, 1, 'setting_setting', 'text_embed_click_action_same_window', 'Open new page in same window', '[[regtime]]', '[[regtime]]'),
(3314, 1, 1, 'setting_setting', 'entry_account_create_captcha', 'Captcha on create account form :<br /><span class="help">Prevent spam/robot account creation with enabling human verification captcha</span>', '[[regtime]]', '[[regtime]]'),
(3315, 1, 1, 'setting_setting', 'entry_recaptcha_site_key', 'Google reCAPTCHA Site Key:<br /><span class="help">Add <a href="https://www.google.com/recaptcha" target="_blank">Google reCAPTCHA v2</a> to help your visitors with better captcha entry. If you enable reCAPTCHA site/secret keys, Google reCAPTCHA v2 will be activated instead of default AbanteCart captcha image</span>', '[[regtime]]', '[[regtime]]'),
(3316, 1, 1, 'setting_setting', 'entry_recaptcha_secret_key', 'Google reCAPTCHA Secret Key:<br /><span class="help">Add <a href="https://www.google.com/recaptcha" target="_blank">Google reCAPTCHA v2</a> to help your visitors with better captcha entry. If you enable reCAPTCHA site/secret keys, Google reCAPTCHA v2 will be activated instead of default AbanteCart captcha image</span>', '[[regtime]]', '[[regtime]]'),
(3317, 1, 1, 'setting_setting', 'text_setting_php_exceed', 'This value can not exceed your php.ini directive %s (<=%s)', '[[regtime]]', '[[regtime]]'),
(3318, 1, 1, 'setting_setting', 'text_setting_session_ttl_autorefresh_note', 'Idle timeout works as expected when <b>Keep Long Session</b> is turned OFF.', '[[regtime]]', '[[regtime]]'),
(3319, 1, 1, 'setting_setting', 'entry_start_order_id', 'Order Start No.:<br /><span class="help">Set the starting number the orders will begin from.</span>', '[[regtime]]', '[[regtime]]'),
(3320, 1, 1, 'setting_setting', 'error_start_order_id', 'Order start number must be a numeric!', '[[regtime]]', '[[regtime]]'),
(3321, 1, 1, 'setting_setting', 'error_starting_invoice_id', 'Invoice start number must be a numeric!', '[[regtime]]', '[[regtime]]'),
(3322, 1, 1, 'setting_setting', 'entry_expire_order_days', 'Incomplete Order Expiration:<br /><span class="help">This value controls time interval in days before incomplete orders will be deleted. Empty value means that no orders will be to deleted.</span>', '[[regtime]]', '[[regtime]]'),
(3323, 1, 1, 'setting_setting', 'error_expire_order_days', 'Incomplete Order Expiration value must be a numeric!', '[[regtime]]', '[[regtime]]'),
(3324, 1, 1, 'setting_setting', 'text_storefront', 'Storefront', '[[regtime]]', '[[regtime]]'),
(3325, 1, 1, 'setting_setting', 'text_im_driver', 'Driver', '[[regtime]]', '[[regtime]]'),
(3326, 1, 1, 'setting_setting', 'text_im_protocol', 'IM Protocol', '[[regtime]]', '[[regtime]]'),
(3327, 1, 1, 'setting_setting', 'entry_sms_driver', 'SMS Provider', '[[regtime]]', '[[regtime]]'),
(3328, 1, 1, 'setting_setting', 'entry_sms_driver_tooltip', 'Select an extension for SMS service provider', '[[regtime]]', '[[regtime]]'),
(3329, 1, 1, 'setting_setting', 'entry_storefront_status_tooltip', 'Enable SMS for customers', '[[regtime]]', '[[regtime]]'),
(3330, 1, 1, 'setting_setting', 'entry_admin_status_tooltip', 'Enable SMS for administrators', '[[regtime]]', '[[regtime]]'),
(3331, 1, 1, 'setting_setting', 'text_no_driver', ' No IM Driver Found', '[[regtime]]', '[[regtime]]'),
(3332, 1, 1, 'setting_setting', 'text_im_settings_attention', 'These settings are for instant messages sent automatically during AbanteCart events in storefront and admin. ', '[[regtime]]', '[[regtime]]'),
(3333, 1, 1, 'setting_setting', 'entry_task_api_key', 'Tasks API Key:<br/><span class="help">This is a secret key to allow AbanteCart to run scheduled processes from the browser with /task.php file. If not set, tasks will not run via browser.<br/>NOTE: This API Key is not required for running tasks command line.</span>', '[[regtime]]', '[[regtime]]'),
(3334, 1, 1, 'setting_setting', 'entry_duplicate_contact_us', 'Duplicate Contact Enquiries to Messages', '[[regtime]]', '[[regtime]]'),
(3335, 1, 1, 'setting_setting', 'entry_tax_class', 'Default Tax Class:<br/><span class="help">Default value will be taken as default value for tax class of new creating product.</span>', '[[regtime]]', '[[regtime]]'),
(3336, 1, 1, 'setting_setting', 'entry_account_recaptcha_v3', 'Enable reCaptcha v3', '[[regtime]]', '[[regtime]]'),
(3337, 1, 1, 'setting_setting', 'text_review_disable', 'Do not allow', '[[regtime]]', '[[regtime]]'),
(3338, 1, 1, 'setting_setting', 'text_review_allow_all', 'Any customer or visitor', '[[regtime]]', '[[regtime]]'),
(3339, 1, 1, 'setting_setting', 'text_review_allow_only_registered', 'Registered Customer', '[[regtime]]', '[[regtime]]'),
(3340, 1, 1, 'setting_setting', 'text_review_allow_who_purchase', 'Customer with verified order', '[[regtime]]', '[[regtime]]'),
(3341, 1, 1, 'setting_setting', 'entry_display_reviews', 'Display Reviews:', '[[regtime]]', '[[regtime]]'),
(3342, 1, 1, 'setting_setting', 'entry_city', 'City:', '[[regtime]]', '[[regtime]]'),
(3343, 1, 1, 'setting_setting', 'entry_postcode', 'Postal Code:', '[[regtime]]', '[[regtime]]'),
(3344, 1, 1, 'setting_setting', 'entry_latitude', 'Latitude:', '[[regtime]]', '[[regtime]]'),
(3345, 1, 1, 'setting_setting', 'entry_longitude', 'Longitude:', '[[regtime]]', '[[regtime]]'),
(3346, 1, 1, 'setting_setting', 'entry_opening_hours', 'Opening Hours:', '[[regtime]]', '[[regtime]]'),
(3347, 1, 1, 'setting_setting', 'error_postcode', 'Postal code is required', '[[regtime]]', '[[regtime]]'),
(3348, 1, 1, 'setting_setting', 'error_city', 'City name is required', '[[regtime]]', '[[regtime]]'),
(3349, 1, 1, 'setting_setting', 'entry_image_resize_fill_color', 'Color of fill for image resize<br/><span class="help">Color that will be filled into empty areas during image resizing from rectangle into square</span>', '[[regtime]]', '[[regtime]]'),
(3350, 1, 1, 'setting_setting', 'warning_https_store_url', 'To maintain correct platform functionality in all browsers and maintain data security, HTTPS protocol is required. All requests should be sent to HTTPS', '[[regtime]]', '[[regtime]]'),
(3351, 1, 1, 'setting_setting', 'entry_default_logo', 'Default Store Logo:', '[[regtime]]', '[[regtime]]'),
(3352, 1, 1, 'setting_setting', 'entry_default_mail_logo', 'Default Email Logo:', '[[regtime]]', '[[regtime]]'),
(3353, 1, 1, 'setting_setting', 'entry_phone_validation_pattern', 'Phone Validation Regex Pattern:', '[[regtime]]', '[[regtime]]'),
(3354, 1, 1, 'setting_setting', 'entry_cron_command', 'Crontab in Linux command <span class="help">Run command crontab -e with the same Linux user running a web server for the AbanteCart. In the editor add the command</span>', '[[regtime]]', '[[regtime]]'),
(3355, 1, 1, 'setting_setting', 'entry_fast_checkout_allow_coupon', 'Allow Coupon Entry at Checkout <br /><span class="help">Enable coupon entry by customers and guests</span>', '[[regtime]]', '[[regtime]]'),
(3356, 1, 1, 'setting_setting', 'entry_fast_checkout_payment_address_equal_shipping', 'Require Payment Address Be the same as Shipping Address', '[[regtime]]', '[[regtime]]'),
(3357, 1, 1, 'setting_setting', 'entry_fast_checkout_require_phone_number', 'Require Phone Number at Checkout <br /><span class="help">When enabled, this setting requires customers or guests to provide a phone number during the checkout process.</span>', '[[regtime]]', '[[regtime]]'),
(3358, 1, 1, 'setting_setting', 'entry_fast_checkout_create_account', 'Guest Checkout Create Account <br /><span class="help">Offer the guest to create an account at the end of the checkout. This is transparent to guests and email will be sent with the login details.</span>', '[[regtime]]', '[[regtime]]'),
(3359, 1, 1, 'setting_setting', 'entry_fast_checkout_buy_now_status', ' Show "Buy Now" Button ', '[[regtime]]', '[[regtime]]'),
(3360, 1, 1, 'setting_setting', 'entry_fast_checkout_show_order_comment_field', 'Show order comment field<br/><span class="help">Comment textarea will be shown during checkout process</span>', '[[regtime]]', '[[regtime]]'),
(3361, 1, 1, 'setting_setting', 'entry_unauth_customer', 'Allow returning customers to browse:<br /><span class="help">Unauthenticated customers returning to the site will be able to browse products, add to cart, and wishlist.</span>', '[[regtime]]', '[[regtime]]'),
(3362, 1, 1, 'setting_store', 'heading_title', 'Store Details', '[[regtime]]', '[[regtime]]'),
(3363, 1, 1, 'setting_store', 'text_success', 'Success: You have modified settings!', '[[regtime]]', '[[regtime]]'),
(3364, 1, 1, 'setting_store', 'text_image_manager', 'Image Manager', '[[regtime]]', '[[regtime]]'),
(3365, 1, 1, 'setting_store', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(3366, 1, 1, 'setting_store', 'text_edit_store', 'Edit Store:', '[[regtime]]', '[[regtime]]'),
(3367, 1, 1, 'setting_store', 'entry_name', 'Store Name:<br /><span class="help">Copied to settings and shown on a storefront section.</span>', '[[regtime]]', '[[regtime]]'),
(3368, 1, 1, 'setting_store', 'entry_url', '            Store URL:<br /><span class="help">Include the full URL to your store. Make sure to add ''/'' at the end. Example: http://www.yourdomain.com/path/<br /><br />Don''t use directories to create a new store. You should always point another domain or sub domain to your hosting.</span>', '[[regtime]]', '[[regtime]]'),
(3369, 1, 1, 'setting_store', 'entry_ssl', 'Use SSL:<br /><span class="help">To use SSL check with your host if a SSL certificate is installed.</span>', '[[regtime]]', '[[regtime]]'),
(3370, 1, 1, 'setting_store', 'entry_title', 'Title:', '[[regtime]]', '[[regtime]]'),
(3371, 1, 1, 'setting_store', 'entry_meta_description', 'Meta Tag Description:', '[[regtime]]', '[[regtime]]'),
(3372, 1, 1, 'setting_store', 'entry_template', 'Template:', '[[regtime]]', '[[regtime]]'),
(3373, 1, 1, 'setting_store', 'entry_description', 'Welcome Message:', '[[regtime]]', '[[regtime]]'),
(3374, 1, 1, 'setting_store', 'entry_country', 'Country:', '[[regtime]]', '[[regtime]]'),
(3375, 1, 1, 'setting_store', 'entry_zone', 'Region / State:', '[[regtime]]', '[[regtime]]'),
(3376, 1, 1, 'setting_store', 'entry_language', 'Language:', '[[regtime]]', '[[regtime]]'),
(3377, 1, 1, 'setting_store', 'entry_status', '            Store Status<br /><span class="help">Store status in a storefront. Status OFF will direct to default store. Use Maintenance Mode setting to set temporary store maintenance message</span>', '[[regtime]]', '[[regtime]]'),
(3378, 1, 1, 'setting_store', 'entry_alias', 'Name Alias<br /><span class="help">Store Name Alias. If left blank, will be based on shortened name</span>', '[[regtime]]', '[[regtime]]'),
(3379, 1, 1, 'setting_store', 'button_add_store', 'New Store', '[[regtime]]', '[[regtime]]'),
(3380, 1, 1, 'setting_store', 'button_delete_store', 'Delete Store', '[[regtime]]', '[[regtime]]'),
(3381, 1, 1, 'setting_store', 'button_edit_settings', 'Edit Settings', '[[regtime]]', '[[regtime]]'),
(3382, 1, 1, 'setting_store', 'error_permission', 'Warning: You do not have permission to modify stores!', '[[regtime]]', '[[regtime]]'),
(3383, 1, 1, 'setting_store', 'error_name', 'Store Name must be between 3 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(3384, 1, 1, 'setting_store', 'error_url', 'Store URL required!', '[[regtime]]', '[[regtime]]'),
(3385, 1, 1, 'setting_store', 'error_title', 'Title must be between 3 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(3386, 1, 1, 'setting_store', 'error_image_thumb', 'Product Image Thumb Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3387, 1, 1, 'setting_store', 'error_image_popup', 'Product Image Popup Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3388, 1, 1, 'setting_store', 'error_image_category', 'Category List Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3389, 1, 1, 'setting_store', 'error_image_product', 'Product List Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3390, 1, 1, 'setting_store', 'error_image_additional', 'Additional Product Image Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3391, 1, 1, 'setting_store', 'error_image_related', 'Related Product Image Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3392, 1, 1, 'setting_store', 'error_image_cart', 'Cart Image Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3393, 1, 1, 'setting_store', 'error_image_grid', 'Grid Image Size dimensions required!', '[[regtime]]', '[[regtime]]'),
(3394, 1, 1, 'setting_store', 'error_store', 'Warning: This Store cannot be deleted as it is currently assigned to %s orders!', '[[regtime]]', '[[regtime]]'),
(3395, 1, 1, 'setting_store', 'error_required_data', 'Required Data has not been entered. Check for field errors!', '[[regtime]]', '[[regtime]]'),
(3396, 1, 1, 'setting_store', 'error_limit', 'Limit required!', '[[regtime]]', '[[regtime]]'),
(3397, 1, 1, 'setting_store', 'entry_clone_store', ' Copy Settings:<br/><span class="help">You can select copy of all settings from some existing store</span> ', '[[regtime]]', '[[regtime]]'),
(3398, 1, 1, 'setting_store', 'entry_ssl_url', 'Secure Store URL:<br /><span class="help">Include the full SSL URL(HTTPS) to your store. Make sure to add ''/'' at the end. Example: https://www.yourdomain.com/path/</span>', '[[regtime]]', '[[regtime]]'),
(3399, 1, 1, 'setting_store', 'error_ssl_url', 'Secure URL required!', '[[regtime]]', '[[regtime]]'),
(3400, 1, 1, 'tool_backup', 'heading_title', 'Backup / Restore / Load', '[[regtime]]', '[[regtime]]'),
(3401, 1, 1, 'tool_backup', 'text_backup', 'Download Backup', '[[regtime]]', '[[regtime]]'),
(3402, 1, 1, 'tool_backup', 'text_success_backup', 'Success: You have successfully created backup file!', '[[regtime]]', '[[regtime]]'),
(3403, 1, 1, 'tool_backup', 'text_success', 'Success: You have successfully imported your database!', '[[regtime]]', '[[regtime]]'),
(3404, 1, 1, 'tool_backup', 'text_success_xml', 'Success: You have successfully imported your xml!', '[[regtime]]', '[[regtime]]'),
(3405, 1, 1, 'tool_backup', 'entry_restore', 'Restore from sql or xml file:', '[[regtime]]', '[[regtime]]'),
(3406, 1, 1, 'tool_backup', 'entry_tables', 'Backup Tables:', '[[regtime]]', '[[regtime]]'),
(3407, 1, 1, 'tool_backup', 'entry_loadxml', 'Load XML-file:', '[[regtime]]', '[[regtime]]'),
(3408, 1, 1, 'tool_backup', 'tab_backup', 'Backup', '[[regtime]]', '[[regtime]]'),
(3409, 1, 1, 'tool_backup', 'tab_restore', 'Restore', '[[regtime]]', '[[regtime]]'),
(3410, 1, 1, 'tool_backup', 'tab_loadxml', 'Layout and dataset load XML', '[[regtime]]', '[[regtime]]'),
(3411, 1, 1, 'tool_backup', 'error_permission', 'Warning: You do not have permission to modify backups!', '[[regtime]]', '[[regtime]]'),
(3412, 1, 1, 'tool_backup', 'error_nothing_to_do', 'Warning: Please set what you want to backup or import!', '[[regtime]]', '[[regtime]]'),
(3413, 1, 1, 'tool_backup', 'error_empty', 'Warning: The file you uploaded was empty or had wrong file type!', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(3414, 1, 1, 'tool_backup', 'error_upload', 'Warning: The file was not uploaded. Check post_max_size or file_upload directives of your php.ini file. ', '[[regtime]]', '[[regtime]]'),
(3415, 1, 1, 'tool_backup', 'error_xml', 'Warning: The file you uploaded does not loaded as XML! Please, see log-file for details', '[[regtime]]', '[[regtime]]'),
(3416, 1, 1, 'tool_backup', 'entry_backup_code', 'Backup Code (%s)<br/><span class="help">Sub-directories with code files excluding dynamic files such as cache, log files, images, resources etc </span>', '[[regtime]]', '[[regtime]]'),
(3417, 1, 1, 'tool_backup', 'entry_backup_content', 'Backup Content (%s)<br/><span class="help">Sub-directories with dynamic files such as images, downloads, resources etc </span>', '[[regtime]]', '[[regtime]]'),
(3418, 1, 1, 'tool_backup', 'entry_compress_backup', 'Compress Backup Directory  %s ?<br/><span class="help">Archive *.tar.gz will be created.<br/> Note: it could to take a long time. Otherwise you can disable compression and find your backup in folder %s</span>', '[[regtime]]', '[[regtime]]'),
(3419, 1, 1, 'tool_backup', 'button_backup_now', 'Backup Now', '[[regtime]]', '[[regtime]]'),
(3420, 1, 1, 'tool_backup', 'button_load', 'Load', '[[regtime]]', '[[regtime]]'),
(3421, 1, 1, 'tool_backup', 'button_backup_schedule', 'Schedule Backup', '[[regtime]]', '[[regtime]]'),
(3422, 1, 1, 'tool_backup', 'text_success_scheduled', 'Success: You have successfully created scheduled backup task! <a href="%s">See details</a>', '[[regtime]]', '[[regtime]]'),
(3423, 1, 1, 'tool_backup', 'text_fail_note', 'NOTE: This process execution depends on your AbanteCart data size as well as your server virtual memory size. If process terminates with errors, check directory %s permissions to be set to -rw-rw-rw and <a href="http://php.net/manual/en/ini.core.php#ini.memory-limit" target="_blank">[PHP memory setting]</a>. Increase memory setting or run backup manually if process still fail.', '[[regtime]]', '[[regtime]]'),
(3424, 1, 1, 'tool_backup', 'backup_complete_text_file', 'To download backup-file please visit <a href="#admin#rt=tool/install_upgrade_history">Install/Upgrade History</a> ', '[[regtime]]', '[[regtime]]'),
(3425, 1, 1, 'tool_backup', 'backup_complete_text_dir', 'Directory with backup-files is %s</a> ', '[[regtime]]', '[[regtime]]'),
(3426, 1, 1, 'tool_cache', 'heading_title', 'Cache Management', '[[regtime]]', '[[regtime]]'),
(3427, 1, 1, 'tool_cache', 'text_success', 'Success: You have successfully deleted the cache data!', '[[regtime]]', '[[regtime]]'),
(3428, 1, 1, 'tool_cache', 'text_configuration', 'Configuration', '[[regtime]]', '[[regtime]]'),
(3429, 1, 1, 'tool_cache', 'text_layouts_blocks', 'Layouts &amp; Blocks', '[[regtime]]', '[[regtime]]'),
(3430, 1, 1, 'tool_cache', 'text_flexyforms', 'Flexy Forms', '[[regtime]]', '[[regtime]]'),
(3431, 1, 1, 'tool_cache', 'text_images', 'Images', '[[regtime]]', '[[regtime]]'),
(3432, 1, 1, 'tool_cache', 'text_products', 'Products', '[[regtime]]', '[[regtime]]'),
(3433, 1, 1, 'tool_cache', 'text_categories', 'Categories', '[[regtime]]', '[[regtime]]'),
(3434, 1, 1, 'tool_cache', 'text_manufacturers', 'Brands', '[[regtime]]', '[[regtime]]'),
(3435, 1, 1, 'tool_cache', 'text_localisations', 'Localisations', '[[regtime]]', '[[regtime]]'),
(3436, 1, 1, 'tool_cache', 'text_error_log', 'Error Log', '[[regtime]]', '[[regtime]]'),
(3437, 1, 1, 'tool_cache', 'text_clear_cache', 'Clear Selected Cache', '[[regtime]]', '[[regtime]]'),
(3438, 1, 1, 'tool_cache', 'text_clear_all_cache', 'Clear all data', '[[regtime]]', '[[regtime]]'),
(3439, 1, 1, 'tool_cache', 'desc_configuration', 'System and store configurations', '[[regtime]]', '[[regtime]]'),
(3440, 1, 1, 'tool_cache', 'desc_layouts_blocks', 'Pages, page layouts, blocks', '[[regtime]]', '[[regtime]]'),
(3441, 1, 1, 'tool_cache', 'desc_flexyforms', 'Flexy forms data', '[[regtime]]', '[[regtime]]'),
(3442, 1, 1, 'tool_cache', 'desc_images', 'Image thumbnails', '[[regtime]]', '[[regtime]]'),
(3443, 1, 1, 'tool_cache', 'desc_products', 'Product data', '[[regtime]]', '[[regtime]]'),
(3444, 1, 1, 'tool_cache', 'desc_categories', 'Category data', '[[regtime]]', '[[regtime]]'),
(3445, 1, 1, 'tool_cache', 'desc_manufacturers', 'Brand data', '[[regtime]]', '[[regtime]]'),
(3446, 1, 1, 'tool_cache', 'desc_localisations', 'Currency, Language, Country, Zone, Length, Weight, &amp; other', '[[regtime]]', '[[regtime]]'),
(3447, 1, 1, 'tool_cache', 'desc_error_log', 'Error Log', '[[regtime]]', '[[regtime]]'),
(3448, 1, 1, 'tool_cache', 'column_type', 'Cache Type', '[[regtime]]', '[[regtime]]'),
(3449, 1, 1, 'tool_cache', 'column_description', 'Description', '[[regtime]]', '[[regtime]]'),
(3450, 1, 1, 'tool_cache', 'text_install_upgrade_history', 'Install/Upgrade History', '[[regtime]]', '[[regtime]]'),
(3451, 1, 1, 'tool_cache', 'desc_install_upgrade_history', 'Clear All Install/Upgrade History', '[[regtime]]', '[[regtime]]'),
(3452, 1, 1, 'tool_cache', 'text_edits_history', 'Text Edits History', '[[regtime]]', '[[regtime]]'),
(3453, 1, 1, 'tool_cache', 'desc_edits_history', 'Clear All Text Edits History', '[[regtime]]', '[[regtime]]'),
(3454, 1, 1, 'tool_cache', 'text_clear_session_data', 'Clear All Session Data', '[[regtime]]', '[[regtime]]'),
(3455, 1, 1, 'tool_cache', 'desc_clear_session_data', 'All session data will be deleted. All users will be logged out of the system, and shopping process session data older than 3 days will be removed.', '[[regtime]]', '[[regtime]]'),
(3456, 1, 1, 'tool_datasets_manager', 'heading_title', 'Datasets Manager', '[[regtime]]', '[[regtime]]'),
(3457, 1, 1, 'tool_datasets_manager', 'text_success', 'Success: You have modified message list!', '[[regtime]]', '[[regtime]]'),
(3458, 1, 1, 'tool_datasets_manager', 'column_id', ' Id ', '[[regtime]]', '[[regtime]]'),
(3459, 1, 1, 'tool_datasets_manager', 'column_name', ' Dataset Name ', '[[regtime]]', '[[regtime]]'),
(3460, 1, 1, 'tool_datasets_manager', 'column_key', ' Dataset Key', '[[regtime]]', '[[regtime]]'),
(3461, 1, 1, 'tool_datasets_manager', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(3462, 1, 1, 'tool_datasets_manager', 'text_dataset_name', ' Dataset Name', '[[regtime]]', '[[regtime]]'),
(3463, 1, 1, 'tool_datasets_manager', 'text_dataset_key', ' Dataset Key', '[[regtime]]', '[[regtime]]'),
(3464, 1, 1, 'tool_datasets_manager', 'text_dataset_properties', ' Dataset Properties', '[[regtime]]', '[[regtime]]'),
(3465, 1, 1, 'tool_datasets_manager', 'text_dataset_column_properties', ' Dataset Column Properties', '[[regtime]]', '[[regtime]]'),
(3466, 1, 1, 'tool_datasets_manager', 'text_dataset_column_definition', ' Dataset Columns', '[[regtime]]', '[[regtime]]'),
(3467, 1, 1, 'tool_datasets_manager', 'text_num_rows', ' Dataset Row Count', '[[regtime]]', '[[regtime]]'),
(3468, 1, 1, 'tool_datasets_manager', 'text_popup_title', ' Information About Dataset', '[[regtime]]', '[[regtime]]'),
(3469, 1, 1, 'tool_datasets_manager', 'text_confirm', 'Confirm?', '[[regtime]]', '[[regtime]]'),
(3470, 1, 1, 'tool_datasets_manager', 'text_date', 'Date', '[[regtime]]', '[[regtime]]'),
(3471, 1, 1, 'tool_datasets_manager', 'text_show', 'Show', '[[regtime]]', '[[regtime]]'),
(3472, 1, 1, 'tool_datasets_manager', 'text_repeats', 'Number of repetitions:', '[[regtime]]', '[[regtime]]'),
(3473, 1, 1, 'tool_error_log', 'heading_title', 'Error Log', '[[regtime]]', '[[regtime]]'),
(3474, 1, 1, 'tool_error_log', 'text_success', 'Success: You have successfully cleared your error log!', '[[regtime]]', '[[regtime]]'),
(3475, 1, 1, 'tool_error_log', 'text_file_tail', 'Due to large size of the log file, only last 500Kb of data can be viewed in here.<br>To view complete log, get it from your server directly.Path:       ', '[[regtime]]', '[[regtime]]'),
(3476, 1, 1, 'tool_error_log', 'text_file_error', ' File does not exists or not readable! ', '[[regtime]]', '[[regtime]]'),
(3477, 1, 1, 'tool_files', 'heading_title', 'File Uploads', '[[regtime]]', '[[regtime]]'),
(3478, 1, 1, 'tool_files', 'column_date_added', 'Date Added', '[[regtime]]', '[[regtime]]'),
(3479, 1, 1, 'tool_files', 'column_path', 'File', '[[regtime]]', '[[regtime]]'),
(3480, 1, 1, 'tool_files', 'column_section', 'Section', '[[regtime]]', '[[regtime]]'),
(3481, 1, 1, 'tool_files', 'text_download', 'to download file', '[[regtime]]', '[[regtime]]'),
(3482, 1, 1, 'tool_global_search', 'heading_title', 'Global Search Results', '[[regtime]]', '[[regtime]]'),
(3483, 1, 1, 'tool_global_search', 'no_results_message', 'Sorry, but we have no results.', '[[regtime]]', '[[regtime]]'),
(3484, 1, 1, 'tool_global_search', 'error_permission', 'Warning: You do not have permission to search!', '[[regtime]]', '[[regtime]]'),
(3485, 1, 1, 'tool_global_search', 'text_orders', 'Orders', '[[regtime]]', '[[regtime]]'),
(3486, 1, 1, 'tool_global_search', 'text_customers', 'Customers', '[[regtime]]', '[[regtime]]'),
(3487, 1, 1, 'tool_global_search', 'text_downloads', 'Downloads', '[[regtime]]', '[[regtime]]'),
(3488, 1, 1, 'tool_global_search', 'text_product_categories', 'Product Categories', '[[regtime]]', '[[regtime]]'),
(3489, 1, 1, 'tool_global_search', 'text_products', 'Products', '[[regtime]]', '[[regtime]]'),
(3490, 1, 1, 'tool_global_search', 'text_reviews', 'Reviews', '[[regtime]]', '[[regtime]]'),
(3491, 1, 1, 'tool_global_search', 'text_manufacturers', 'Brands', '[[regtime]]', '[[regtime]]'),
(3492, 1, 1, 'tool_global_search', 'text_languages', 'Languages', '[[regtime]]', '[[regtime]]'),
(3493, 1, 1, 'tool_global_search', 'text_pages', 'Pages', '[[regtime]]', '[[regtime]]'),
(3494, 1, 1, 'tool_global_search', 'text_settings', 'Settings', '[[regtime]]', '[[regtime]]'),
(3495, 1, 1, 'tool_global_search', 'text_messages', 'Messages', '[[regtime]]', '[[regtime]]'),
(3496, 1, 1, 'tool_global_search', 'text_extensions', 'Extensions', '[[regtime]]', '[[regtime]]'),
(3497, 1, 1, 'tool_global_search', 'text_commands', 'Quick Commands', '[[regtime]]', '[[regtime]]'),
(3498, 1, 1, 'tool_global_search', 'text_contents', 'Content Pages', '[[regtime]]', '[[regtime]]'),
(3499, 1, 1, 'tool_import_export', 'import_export_title', 'Import & Export', '[[regtime]]', '[[regtime]]'),
(3500, 1, 1, 'tool_import_export', 'import_wizard_title', 'Import Data Wizard', '[[regtime]]', '[[regtime]]'),
(3501, 1, 1, 'tool_import_export', 'tab_import', 'Import', '[[regtime]]', '[[regtime]]'),
(3502, 1, 1, 'tool_import_export', 'tab_import_wizard', 'Import Wizard', '[[regtime]]', '[[regtime]]'),
(3503, 1, 1, 'tool_import_export', 'tab_export', 'Export', '[[regtime]]', '[[regtime]]'),
(3504, 1, 1, 'tool_import_export', 'text_tables', 'Tables', '[[regtime]]', '[[regtime]]'),
(3505, 1, 1, 'tool_import_export', 'text_options', 'Options', '[[regtime]]', '[[regtime]]'),
(3506, 1, 1, 'tool_import_export', 'text_file_format', 'File Format: ', '[[regtime]]', '[[regtime]]'),
(3507, 1, 1, 'tool_import_export', 'text_file_name', 'File Name: ', '[[regtime]]', '[[regtime]]'),
(3508, 1, 1, 'tool_import_export', 'text_load_file', 'Upload Import File', '[[regtime]]', '[[regtime]]'),
(3509, 1, 1, 'tool_import_export', 'text_load_file_notes', 'You can upload CSV or Text file to import data. For data structure, you can follow proprietary format (see export) or free format. <br/> For data with the free format, you will need to map data elements manually or use JSON map. <br/>Only product, categories and brands/manufacturers supported for free format import. <br/>Action column can be included to instruct import to ''insert'', ''update'' or ''delete''. Default action is update_or_insert. ', '[[regtime]]', '[[regtime]]'),
(3510, 1, 1, 'tool_import_export', 'text_import_wizard_notes', 'Select a destination table and corresponding database field to each provided import data column. If no field is selected, input column data will be ignored. <br/> <b>Note:</b> Language and store specific data values will be assigned to current content store & language selected', '[[regtime]]', '[[regtime]]'),
(3511, 1, 1, 'tool_import_export', 'text_records_to_be_loaded', 'There will be %s records loaded and processed in this import!', '[[regtime]]', '[[regtime]]'),
(3512, 1, 1, 'tool_import_export', 'text_import_task_title', 'Running Import Process', '[[regtime]]', '[[regtime]]'),
(3513, 1, 1, 'tool_import_export', 'text_load', 'Load', '[[regtime]]', '[[regtime]]'),
(3514, 1, 1, 'tool_import_export', 'text_import_loaded', 'Total loaded: ', '[[regtime]]', '[[regtime]]'),
(3515, 1, 1, 'tool_import_export', 'text_file_field', 'File to import:<br><span class="help">Supported formats for import files: CSV, TXT</span>', '[[regtime]]', '[[regtime]]'),
(3516, 1, 1, 'tool_import_export', 'text_id_range_from', 'ID range from: ', '[[regtime]]', '[[regtime]]'),
(3517, 1, 1, 'tool_import_export', 'text_to', 'to: ', '[[regtime]]', '[[regtime]]'),
(3518, 1, 1, 'tool_import_export', 'text_csv_delimiter', 'CSV/TXT delimiter: ', '[[regtime]]', '[[regtime]]'),
(3519, 1, 1, 'tool_import_export', 'text_export_note_csv_delimiter', '<span class="help">All fields will be enclosed in double quotes.</span>', '[[regtime]]', '[[regtime]]'),
(3520, 1, 1, 'tool_import_export', 'text_import_note_csv_delimiter', '<span class="help">All fields must be enclosed in double quotes.</span>', '[[regtime]]', '[[regtime]]'),
(3521, 1, 1, 'tool_import_export', 'text_test_mode', 'Run in a test mode <br><span class="help">It is recommended to run data import in a test mode first to see if any issues are present.</span>', '[[regtime]]', '[[regtime]]'),
(3522, 1, 1, 'tool_import_export', 'text_import_file_col', 'Import File Column', '[[regtime]]', '[[regtime]]'),
(3523, 1, 1, 'tool_import_export', 'text_import_file_data', 'Import Data Sample', '[[regtime]]', '[[regtime]]'),
(3524, 1, 1, 'tool_import_export', 'text_destination_col', 'Select destination table', '[[regtime]]', '[[regtime]]'),
(3525, 1, 1, 'tool_import_export', 'text_import_update_on', 'Update if exists', '[[regtime]]', '[[regtime]]'),
(3526, 1, 1, 'tool_import_export', 'text_import_split', 'Split data by', '[[regtime]]', '[[regtime]]'),
(3527, 1, 1, 'tool_import_export', 'title_export_map', 'Select, copy and save this mapping for future use.', '[[regtime]]', '[[regtime]]'),
(3528, 1, 1, 'tool_import_export', 'text_export_map', 'Export mapping', '[[regtime]]', '[[regtime]]'),
(3529, 1, 1, 'tool_import_export', 'title_load_map', 'Post to the field below pre-saved mapping data', '[[regtime]]', '[[regtime]]'),
(3530, 1, 1, 'tool_import_export', 'text_load_map', 'Load mapping', '[[regtime]]', '[[regtime]]'),
(3531, 1, 1, 'tool_import_export', 'error_file_format', 'Unsupported import file format!', '[[regtime]]', '[[regtime]]'),
(3532, 1, 1, 'tool_import_export', 'error_xml_import', 'Error during import XML file!', '[[regtime]]', '[[regtime]]'),
(3533, 1, 1, 'tool_import_export', 'error_csv_import', 'Error during import CSV/TXT file! Please check fields delimiter.', '[[regtime]]', '[[regtime]]'),
(3534, 1, 1, 'tool_import_export', 'error_data_corrupted', 'Data is empty or corrupted.', '[[regtime]]', '[[regtime]]'),
(3535, 1, 1, 'tool_import_export', 'error_file_empty', 'File is empty.', '[[regtime]]', '[[regtime]]'),
(3536, 1, 1, 'tool_import_export', 'error_writable_backup', 'Backup directory needs to be writable for CSV/TXT export to work.', '[[regtime]]', '[[regtime]]'),
(3537, 1, 1, 'tool_import_export', 'text_updated', 'Updated: ', '[[regtime]]', '[[regtime]]'),
(3538, 1, 1, 'tool_import_export', 'text_created', 'Created: ', '[[regtime]]', '[[regtime]]'),
(3539, 1, 1, 'tool_import_export', 'text_errors', 'Errors: ', '[[regtime]]', '[[regtime]]'),
(3540, 1, 1, 'tool_import_export', 'text_show_details', 'Show details', '[[regtime]]', '[[regtime]]'),
(3541, 1, 1, 'tool_import_export', 'text_no_children', 'No child items', '[[regtime]]', '[[regtime]]'),
(3542, 1, 1, 'tool_import_export', 'text_some_errors', 'There are some errors.', '[[regtime]]', '[[regtime]]'),
(3543, 1, 1, 'tool_import_export', 'text_test_completed', 'Test run completed. Total SQL queries: ', '[[regtime]]', '[[regtime]]'),
(3544, 1, 1, 'tool_import_export', 'text_sort_by', 'Sort by: ', '[[regtime]]', '[[regtime]]'),
(3545, 1, 1, 'tool_import_export', 'error_table_selection', 'No import destination table or fields selected!', '[[regtime]]', '[[regtime]]'),
(3546, 1, 1, 'tool_import_export', 'error_required_selection', 'Missing required data field ''%s'' for destination table!', '[[regtime]]', '[[regtime]]'),
(3547, 1, 1, 'tool_import_export', 'error_tmp_dir_non_writable', 'Temporary Directory %s is not writable! Please change permissions to proceed.', '[[regtime]]', '[[regtime]]'),
(3548, 1, 1, 'tool_import_export', 'error_empty_request', 'Empty request.', '[[regtime]]', '[[regtime]]'),
(3549, 1, 1, 'tool_import_export', 'text_complete_import', 'Import Process has been completed. %s row(s) processed.', '[[regtime]]', '[[regtime]]'),
(3550, 1, 1, 'tool_import_export', 'text_complete_import_with_errors', '%s row(s) with errors.', '[[regtime]]', '[[regtime]]'),
(3551, 1, 1, 'tool_import_export', 'text_see_log', 'For more details see <a href="%s" target="_blank">log file %s</a>', '[[regtime]]', '[[regtime]]'),
(3552, 1, 1, 'tool_import_export', 'text_success_abort', 'Task interrupted successfully.', '[[regtime]]', '[[regtime]]'),
(3553, 1, 1, 'tool_import_export', 'button_schedule_import', 'Schedule Import', '[[regtime]]', '[[regtime]]'),
(3554, 1, 1, 'tool_import_export', 'text_success_scheduled', 'Success: You have successfully created scheduled import task! <a href="%s">See details</a>', '[[regtime]]', '[[regtime]]'),
(3555, 1, 1, 'tool_install_upgrade_history', 'heading_title', 'install/Upgrade History', '[[regtime]]', '[[regtime]]'),
(3556, 1, 1, 'tool_install_upgrade_history', 'column_type', ' Type', '[[regtime]]', '[[regtime]]'),
(3557, 1, 1, 'tool_install_upgrade_history', 'column_date_added', ' Date Added', '[[regtime]]', '[[regtime]]'),
(3558, 1, 1, 'tool_install_upgrade_history', 'column_name', ' Package Key ', '[[regtime]]', '[[regtime]]'),
(3559, 1, 1, 'tool_install_upgrade_history', 'column_version', ' Version ', '[[regtime]]', '[[regtime]]'),
(3560, 1, 1, 'tool_install_upgrade_history', 'column_backup_date', ' Backup Date', '[[regtime]]', '[[regtime]]'),
(3561, 1, 1, 'tool_install_upgrade_history', 'column_backup_file', ' Backup File ', '[[regtime]]', '[[regtime]]'),
(3562, 1, 1, 'tool_install_upgrade_history', 'column_user', ' User Name', '[[regtime]]', '[[regtime]]'),
(3563, 1, 1, 'tool_install_upgrade_history', 'text_download', ' to download file', '[[regtime]]', '[[regtime]]'),
(3564, 1, 1, 'tool_install_upgrade_history', 'text_delete_history', ' Delete History', '[[regtime]]', '[[regtime]]'),
(3565, 1, 1, 'tool_install_upgrade_history', 'text_delete_success', ' Your Install/Upgrade History has been deleted successfully.', '[[regtime]]', '[[regtime]]'),
(3566, 1, 1, 'tool_message_manager', 'heading_title', 'Message Manager', '[[regtime]]', '[[regtime]]'),
(3567, 1, 1, 'tool_message_manager', 'text_success', 'Success: You have modified message list!', '[[regtime]]', '[[regtime]]'),
(3568, 1, 1, 'tool_message_manager', 'column_title', 'Message Title', '[[regtime]]', '[[regtime]]'),
(3569, 1, 1, 'tool_message_manager', 'column_create_date', 'Date', '[[regtime]]', '[[regtime]]'),
(3570, 1, 1, 'tool_message_manager', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(3571, 1, 1, 'tool_message_manager', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(3572, 1, 1, 'tool_message_manager', 'entry_error', 'Critical', '[[regtime]]', '[[regtime]]'),
(3573, 1, 1, 'tool_message_manager', 'entry_warning', 'Warning', '[[regtime]]', '[[regtime]]'),
(3574, 1, 1, 'tool_message_manager', 'entry_notice', 'Notice', '[[regtime]]', '[[regtime]]'),
(3575, 1, 1, 'tool_message_manager', 'error_permission', 'Warning: You do not have permission to modify message list!', '[[regtime]]', '[[regtime]]'),
(3576, 1, 1, 'tool_message_manager', 'error_name', 'Message title must be between 3 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(3577, 1, 1, 'tool_message_manager', 'text_show', 'Show', '[[regtime]]', '[[regtime]]'),
(3578, 1, 1, 'tool_message_manager', 'text_not_found', 'Ooops. We can''t find this message.', '[[regtime]]', '[[regtime]]'),
(3579, 1, 1, 'tool_message_manager', 'text_status', 'Message status: ', '[[regtime]]', '[[regtime]]'),
(3580, 1, 1, 'tool_message_manager', 'text_date', 'Date:', '[[regtime]]', '[[regtime]]'),
(3581, 1, 1, 'tool_message_manager', 'text_repeats', 'Number of repetitions:', '[[regtime]]', '[[regtime]]'),
(3582, 1, 1, 'tool_message_manager', 'text_warning', 'warning', '[[regtime]]', '[[regtime]]'),
(3583, 1, 1, 'tool_message_manager', 'text_error', 'critical', '[[regtime]]', '[[regtime]]'),
(3584, 1, 1, 'tool_message_manager', 'text_notice', 'notice', '[[regtime]]', '[[regtime]]'),
(3585, 1, 1, 'tool_message_manager', 'text_delete', 'delete', '[[regtime]]', '[[regtime]]'),
(3586, 1, 1, 'tool_message_manager', 'text_close', 'close', '[[regtime]]', '[[regtime]]'),
(3587, 1, 1, 'tool_message_manager', 'text_confirm', 'Confirm?', '[[regtime]]', '[[regtime]]'),
(3588, 1, 1, 'tool_message_manager', 'text_linktext', ' this link', '[[regtime]]', '[[regtime]]'),
(3589, 1, 1, 'tool_message_manager', 'text_notifier_title', ' You Have %s New Message(s)', '[[regtime]]', '[[regtime]]'),
(3590, 1, 1, 'tool_migration', 'heading_title', 'Cart Migration', '[[regtime]]', '[[regtime]]'),
(3591, 1, 1, 'tool_migration', 'heading_title_step_one', ' - Step 1', '[[regtime]]', '[[regtime]]'),
(3592, 1, 1, 'tool_migration', 'heading_title_step_two', ' - Step 2', '[[regtime]]', '[[regtime]]'),
(3593, 1, 1, 'tool_migration', 'heading_title_step_three', ' - Finish', '[[regtime]]', '[[regtime]]'),
(3594, 1, 1, 'tool_migration', 'text_description', '            Migration tool allow you import data from another carts.<br>Note: AbanteCart support import for mysql only for now.<br> Press start migration button to continue... ', '[[regtime]]', '[[regtime]]'),
(3595, 1, 1, 'tool_migration', 'text_success', 'Success: You data successfully transfeerd to Abantecart!', '[[regtime]]', '[[regtime]]'),
(3596, 1, 1, 'tool_migration', 'text_cart_info', '            Source Cart Info<span class="help">Source shopping cart application details.</span>', '[[regtime]]', '[[regtime]]'),
(3597, 1, 1, 'tool_migration', 'text_db_info', '            Database Info<span class="help">Note: AbanteCart support import for mysql only for now.</span>', '[[regtime]]', '[[regtime]]'),
(3598, 1, 1, 'tool_migration', 'entry_cart_type', 'Source cart type:', '[[regtime]]', '[[regtime]]'),
(3599, 1, 1, 'tool_migration', 'entry_cart_url', 'Source cart URL:', '[[regtime]]', '[[regtime]]'),
(3600, 1, 1, 'tool_migration', 'entry_db_host', 'Database Host:', '[[regtime]]', '[[regtime]]'),
(3601, 1, 1, 'tool_migration', 'entry_db_user', 'Database User:', '[[regtime]]', '[[regtime]]'),
(3602, 1, 1, 'tool_migration', 'entry_db_password', 'Password:', '[[regtime]]', '[[regtime]]'),
(3603, 1, 1, 'tool_migration', 'entry_db_name', 'Database Name:', '[[regtime]]', '[[regtime]]'),
(3604, 1, 1, 'tool_migration', 'entry_db_prefix', 'Database Prefix:', '[[regtime]]', '[[regtime]]'),
(3605, 1, 1, 'tool_migration', 'entry_cart_select', ' - select cart type - ', '[[regtime]]', '[[regtime]]'),
(3606, 1, 1, 'tool_migration', 'entry_cart_osc', 'Oscommerce 2.2RC2', '[[regtime]]', '[[regtime]]'),
(3607, 1, 1, 'tool_migration', 'entry_cart_oscmax', 'OscMAX', '[[regtime]]', '[[regtime]]'),
(3608, 1, 1, 'tool_migration', 'entry_cart_zen', 'ZenCart 1.3.9h', '[[regtime]]', '[[regtime]]'),
(3609, 1, 1, 'tool_migration', 'entry_cart_cre', 'CRE Loaded 6.4.1 STD', '[[regtime]]', '[[regtime]]'),
(3610, 1, 1, 'tool_migration', 'entry_cart_opencart', 'OpenCart 1.4.9', '[[regtime]]', '[[regtime]]'),
(3611, 1, 1, 'tool_migration', 'entry_migrate_data', 'Select data to migrate', '[[regtime]]', '[[regtime]]'),
(3612, 1, 1, 'tool_migration', 'entry_migrate_data_categories', 'Categories', '[[regtime]]', '[[regtime]]'),
(3613, 1, 1, 'tool_migration', 'entry_migrate_data_products', 'Products, Categories, Brands', '[[regtime]]', '[[regtime]]'),
(3614, 1, 1, 'tool_migration', 'entry_migrate_data_customers', 'Customers', '[[regtime]]', '[[regtime]]'),
(3615, 1, 1, 'tool_migration', 'entry_migrate_data_orders', 'Orders', '[[regtime]]', '[[regtime]]'),
(3616, 1, 1, 'tool_migration', 'entry_erase_existing_data', 'Erase existing data?', '[[regtime]]', '[[regtime]]'),
(3617, 1, 1, 'tool_migration', 'button_start_migration', 'Start Migration', '[[regtime]]', '[[regtime]]'),
(3618, 1, 1, 'tool_migration', 'button_continue', 'Continue', '[[regtime]]', '[[regtime]]'),
(3619, 1, 1, 'tool_migration', 'button_back', 'Back', '[[regtime]]', '[[regtime]]'),
(3620, 1, 1, 'tool_migration', 'button_cancel', 'Cancel', '[[regtime]]', '[[regtime]]'),
(3621, 1, 1, 'tool_migration', 'error_permission', 'Warning: You do not have permission to perform migration!', '[[regtime]]', '[[regtime]]'),
(3622, 1, 1, 'tool_migration', 'error_db_host', 'Host required!', '[[regtime]]', '[[regtime]]'),
(3623, 1, 1, 'tool_migration', 'error_db_user', 'User required!', '[[regtime]]', '[[regtime]]'),
(3624, 1, 1, 'tool_migration', 'error_db_name', 'Database Name required!', '[[regtime]]', '[[regtime]]'),
(3625, 1, 1, 'tool_migration', 'error_db_connection', '            Error: Could not connect to the database please make sure the database server, username and password is correct!', '[[regtime]]', '[[regtime]]'),
(3626, 1, 1, 'tool_migration', 'error_db_not_exist', 'Error: Database does not exist!', '[[regtime]]', '[[regtime]]'),
(3627, 1, 1, 'tool_migration', 'error_cart_type', 'Error: Please select cart type!', '[[regtime]]', '[[regtime]]'),
(3628, 1, 1, 'tool_migration', 'error_cart_url', 'Error: Cart URL required!', '[[regtime]]', '[[regtime]]'),
(3629, 1, 1, 'tool_migration', 'error_cart_not_supported', 'Warning: Chosen cart not supported now!', '[[regtime]]', '[[regtime]]'),
(3630, 1, 1, 'tool_migration', 'error_migrate_data', 'Error: Please select at least one item!', '[[regtime]]', '[[regtime]]'),
(3631, 1, 1, 'tool_migration', 'text_no_customers', 'Note: No one customer was imported.', '[[regtime]]', '[[regtime]]'),
(3632, 1, 1, 'tool_migration', 'text_no_products', 'Note: No one product was imported.', '[[regtime]]', '[[regtime]]'),
(3633, 1, 1, 'tool_migration', 'text_no_orders', 'Note: No one order was imported.', '[[regtime]]', '[[regtime]]'),
(3634, 1, 1, 'tool_migration', 'text_no_brands', 'Note: No one brand was imported.', '[[regtime]]', '[[regtime]]'),
(3635, 1, 1, 'tool_migration', 'text_no_categories', 'Note: No one product category was imported.', '[[regtime]]', '[[regtime]]'),
(3636, 1, 1, 'tool_migration', 'error_empty_source_cart', 'Warning: Chosen source cart is empty! Please check database and table prefix.', '[[regtime]]', '[[regtime]]'),
(3637, 1, 1, 'tool_migration', 'text_finished', 'Migration has finished.', '[[regtime]]', '[[regtime]]'),
(3638, 1, 1, 'tool_package_installer', 'text_success', ' Success: Package was installed successfully. ', '[[regtime]]', '[[regtime]]'),
(3639, 1, 1, 'tool_package_installer', 'heading_title', 'Package Installer', '[[regtime]]', '[[regtime]]'),
(3640, 1, 1, 'tool_package_installer', 'heading_title_license', 'Package License Agreement', '[[regtime]]', '[[regtime]]'),
(3641, 1, 1, 'tool_package_installer', 'heading_title_ftp', 'FTP access parameters', '[[regtime]]', '[[regtime]]'),
(3642, 1, 1, 'tool_package_installer', 'heading_title_download', 'Package Loading', '[[regtime]]', '[[regtime]]'),
(3643, 1, 1, 'tool_package_installer', 'text_preloading', ' Package file %file% will be downloaded.', '[[regtime]]', '[[regtime]]'),
(3644, 1, 1, 'tool_package_installer', 'text_loading', 'Downloading file. Size: %s .<br/>It might take few seconds depending on your connection.', '[[regtime]]', '[[regtime]]'),
(3645, 1, 1, 'tool_package_installer', 'text_key_hint', 'Enter Installation Key Here', '[[regtime]]', '[[regtime]]'),
(3646, 1, 1, 'tool_package_installer', 'text_ftp_user', ' FTP User Name: ', '[[regtime]]', '[[regtime]]'),
(3647, 1, 1, 'tool_package_installer', 'text_ftp_password', ' FTP User Password: ', '[[regtime]]', '[[regtime]]'),
(3648, 1, 1, 'tool_package_installer', 'text_ftp_host', ' FTP Host:', '[[regtime]]', '[[regtime]]'),
(3649, 1, 1, 'tool_package_installer', 'text_i_agree', ' I agree to the license ', '[[regtime]]', '[[regtime]]'),
(3650, 1, 1, 'tool_package_installer', 'text_agree', ' Agree ', '[[regtime]]', '[[regtime]]'),
(3651, 1, 1, 'tool_package_installer', 'text_retry', ' Retry ', '[[regtime]]', '[[regtime]]'),
(3652, 1, 1, 'tool_package_installer', 'text_disagree', ' Disagree ', '[[regtime]]', '[[regtime]]'),
(3653, 1, 1, 'tool_package_installer', 'text_download_error', ' We are sorry, but error occurred while uploading the file.</br>Try one more time.</br>If problem persist download file in your order history and install manually. ', '[[regtime]]', '[[regtime]]'),
(3654, 1, 1, 'tool_package_installer', 'text_continue', ' Continue ', '[[regtime]]', '[[regtime]]'),
(3655, 1, 1, 'tool_package_installer', 'text_disclaimer_heading', ' Disclaimer ', '[[regtime]]', '[[regtime]]'),
(3656, 1, 1, 'tool_package_installer', 'text_disclaimer', ' <h3>Dear AbanteCart customer,</h3><br>\nYou are about to install third party extension to your AbanteCart.<br><br>\nPlease read and understand this disclaimer about third party extension that you about to install.<br><br>\nThird party extensions and services  are provided by third party vendors.<br><br>\nAlthough, AbanteCart validate quality of extensions and services provided by third party, AbanterCart does not guaranty that all third party extension work correctly or will not cause any conflicts in the system.\nAbanteCart members and affiliates are in no way liable or responsible for claims made related to the products or services provided by third party vendors. AbanteCart does not guarantee the quality of third party extensions or services.  Please direct your inquiries regarding third party extensions or services to the appropriate third party vendor.\nIf you have concern about any third party provider please contact AbanteCart at <a href="https://www.abantecart.com/contact-us" target="_blank">https://www.abantecart.com/contact-us</a><br><br>\nSincerely,<br>\nAbanteCart<br>\nIdeal OpenSource Ecommerce Solution ', '[[regtime]]', '[[regtime]]'),
(3657, 1, 1, 'tool_package_installer', 'warning_ftp', ' Warning: Some directory or file does not have write permission (<span id="see_details">see more details</span>)<br>You can change permissions on your server or<br>use ftp access to your server for installation (usually, hosting provider sends this info via email or you can manage it in hosting control tools)<br> ', '[[regtime]]', '[[regtime]]'),
(3658, 1, 1, 'tool_package_installer', 'warning_already_installed', '<p class="success">You already have %EXTENSION% extension installed! If you want to proceed and upgrade, please confirm.</p>', '[[regtime]]', '[[regtime]]'),
(3659, 1, 1, 'tool_package_installer', 'warning_already_installed_uninstall', 'You already have this extension "%EXTENSION%" installed! If you want to proceed to reinstall, please uninstall and delete extension first.', '[[regtime]]', '[[regtime]]'),
(3660, 1, 1, 'tool_package_installer', 'error_pack_file_not_found', 'Error: Can not extract extension from the archive to %s. Check <a href="#admin#rt=tool/error_log" target="_blank">log</a> for errors ', '[[regtime]]', '[[regtime]]'),
(3661, 1, 1, 'tool_package_installer', 'error_mp', ' Marketplace error: ', '[[regtime]]', '[[regtime]]'),
(3662, 1, 1, 'tool_package_installer', 'error_repository', ' Error: Cannot download file. Repository error or invalid extension key. Try one more time. If problem persist download file in your order history and install manually. ', '[[regtime]]', '[[regtime]]'),
(3663, 1, 1, 'tool_package_installer', 'error_ftp_user', ' Error: FTP User Name is empty. ', '[[regtime]]', '[[regtime]]'),
(3664, 1, 1, 'tool_package_installer', 'error_ftp_password', ' Error: FTP User Password is empty. ', '[[regtime]]', '[[regtime]]'),
(3665, 1, 1, 'tool_package_installer', 'error_ftp_connect', ' Error: Can''t connect to ftp-server ', '[[regtime]]', '[[regtime]]'),
(3666, 1, 1, 'tool_package_installer', 'error_ftp_login', ' Error: Can''t login to ftp-server. Invalid Username or Password. ', '[[regtime]]', '[[regtime]]'),
(3667, 1, 1, 'tool_package_installer', 'error_ftp_path', ' Error: Can''t find root directory of AbanteCart by FTP path.<br>Try leave it empty for automatic search. ', '[[regtime]]', '[[regtime]]'),
(3668, 1, 1, 'tool_package_installer', 'error_ftp_path_array', ' Error: Can''t automatic recognize root directory of AbanteCart in FTP-mode.<br>Please fill FTP-path form field.<br>Path suggestions are:  ', '[[regtime]]', '[[regtime]]'),
(3669, 1, 1, 'tool_package_installer', 'error_dir_permission', ' Can''t to save file because directory is not writable: ', '[[regtime]]', '[[regtime]]'),
(3670, 1, 1, 'tool_package_installer', 'error_package_structure', ' Error: Probably package is broken. Structure of package error. ', '[[regtime]]', '[[regtime]]'),
(3671, 1, 1, 'tool_package_installer', 'error_package_config_xml', ' Error: Cannot locate file package.xml inside of extracted extension. Possibly extension was not extracted correctly. Check <a href="#admin#rt=tool/error_log" target="_blank">log</a> for errors ', '[[regtime]]', '[[regtime]]'),
(3672, 1, 1, 'tool_package_installer', 'error_package_config2', ' Error: Can''t find installation mode in package.xml inside package. ', '[[regtime]]', '[[regtime]]'),
(3673, 1, 1, 'tool_package_installer', 'error_package_info_not_exists', ' Error: Can''t find package session info about this download. ', '[[regtime]]', '[[regtime]]'),
(3674, 1, 1, 'tool_package_installer', 'error_unpack', ' Error: Can''t unpack package "%PACKAGE%" after download. Archive error. See error log for details. ', '[[regtime]]', '[[regtime]]'),
(3675, 1, 1, 'tool_package_installer', 'error_move', ' Error: Can''t move package code after unpacking. Please try check write permissions of directory: ', '[[regtime]]', '[[regtime]]'),
(3676, 1, 1, 'tool_package_installer', 'error_install_mode', ' Error: Can''t install extension "%package%" because it already installed. You need deinstall and delete it first or get package for upgrade. ', '[[regtime]]', '[[regtime]]'),
(3677, 1, 1, 'tool_package_installer', 'error_install_mode2', ' Error: Can''t upgrade extension "%package%" because it not installed. You need get package for install. ', '[[regtime]]', '[[regtime]]'),
(3678, 1, 1, 'tool_package_installer', 'error_version_compatibility', ' Error: Can''t install package. Your cart version is <b>%CURRENT_VERSION%</b>. Version(s) <b>%VERSIONS%</b>  required. ', '[[regtime]]', '[[regtime]]'),
(3679, 1, 1, 'tool_package_installer', 'error_package_version_compatibility', ' Error: Can''t upgrade package. Newer package version is already installed. ', '[[regtime]]', '[[regtime]]'),
(3680, 1, 1, 'tool_package_installer', 'error_install', ' Error: Can''t install package. Please see System -> Error Log for details. ', '[[regtime]]', '[[regtime]]'),
(3681, 1, 1, 'tool_package_installer', 'error_core_version', ' Error: You have AbanteCart version %VERSION% installed.<br>This upgrade package only for versions lower than  ', '[[regtime]]', '[[regtime]]'),
(3682, 1, 1, 'tool_package_installer', 'text_interrupt', ' Interrupt ', '[[regtime]]', '[[regtime]]'),
(3683, 1, 1, 'tool_package_installer', 'confirm_version_incompatibility', ' Current copy of this extension is not verified for your version of AbanteCart (v%s).<br>Extension build is specified for AbanteCart v%s.<br>\n		This is not a problem, but if you notice issues or incompatibility, please contact extension developer. ', '[[regtime]]', '[[regtime]]'),
(3684, 1, 1, 'tool_package_installer', 'error_move_ftp', ' Error: Can''t move package code after unpacking. Probably FTP path is incorrect.<br>Also, please, try to check write permissions of directory: ', '[[regtime]]', '[[regtime]]'),
(3685, 1, 1, 'tool_package_installer', 'text_network_install', ' Network Install ', '[[regtime]]', '[[regtime]]'),
(3686, 1, 1, 'tool_package_installer', 'text_extension_upload', ' Extension Upload ', '[[regtime]]', '[[regtime]]'),
(3687, 1, 1, 'tool_package_installer', 'error_archive_extension', ' Error: Only .tar.gz files supported. ', '[[regtime]]', '[[regtime]]'),
(3688, 1, 1, 'tool_package_installer', 'entry_upload_file', ' Upload file: ', '[[regtime]]', '[[regtime]]'),
(3689, 1, 1, 'tool_package_installer', 'entry_upload_url', ' Insert URL: ', '[[regtime]]', '[[regtime]]'),
(3690, 1, 1, 'tool_package_installer', 'error_move_backup', ' Error: Can''t backup files before upgrade. Check write permissions of directory: ', '[[regtime]]', '[[regtime]]'),
(3691, 1, 1, 'tool_package_installer', 'text_core_upgrade_title', ' Abantecart Core Upgrade ', '[[regtime]]', '[[regtime]]'),
(3692, 1, 1, 'tool_package_installer', 'text_core_upgrade_attention', ' Attention!\nAbanteCart is about to be upgraded to version %s!\n ', '[[regtime]]', '[[regtime]]'),
(3693, 1, 1, 'tool_package_installer', 'text_core_upgrade_warning', ' There is no undo after starting upgrade process.\nComplete database and code backup is highly recommended.\nTest upgrade on non-live sites first. Upgrade on live sites should be done only after testing. ', '[[regtime]]', '[[regtime]]'),
(3694, 1, 1, 'tool_package_installer', 'text_upgrade_now', ' Upgrade Now! ', '[[regtime]]', '[[regtime]]'),
(3695, 1, 1, 'tool_package_installer', 'error_additional_help_text', ' Stuck? Not a problem. You can install extensions another way. Check <a href="http://docs.abantecart.com/pages/extensions/install.html#FTPinstall" target="_blank">this help link</a> ', '[[regtime]]', '[[regtime]]'),
(3696, 1, 1, 'tool_package_installer', 'error_notconnected', ' Can not upgrade or install extensions from the marketplace. This store is not authenticated/connected. Please authenticate and connect to the <a href="%s">marketplace</a> ', '[[regtime]]', '[[regtime]]'),
(3697, 1, 1, 'tool_rl_manager', 'heading_title', 'Media Resource Library Manager', '[[regtime]]', '[[regtime]]'),
(3698, 1, 1, 'tool_rl_manager', 'text_rl_latest', 'Latest added resources', '[[regtime]]', '[[regtime]]'),
(3699, 1, 1, 'tool_rl_manager', 'text_rl_type', 'resource type', '[[regtime]]', '[[regtime]]'),
(3700, 1, 1, 'tool_rl_manager', 'entry_type_name', 'Resource Type Key<br/><span class="help">This resource type key/name value can not be changed</span>', '[[regtime]]', '[[regtime]]'),
(3701, 1, 1, 'tool_rl_manager', 'entry_default_directory', 'Resource directory<br/><span class="help">Directory locating resource for this type. If changed, existing resources will not be accessible and will need to be copied to new directory!</span>', '[[regtime]]', '[[regtime]]'),
(3702, 1, 1, 'tool_rl_manager', 'entry_default_icon', 'Default icon<br/><span class="help">Icon image to be shown in the listing of resources (Location: /image/... ).</span>', '[[regtime]]', '[[regtime]]'),
(3703, 1, 1, 'tool_rl_manager', 'entry_file_types', 'Allowed file extensions<br/><span class="help">Regex with a list of allowed file extensions for this resource type</span>', '[[regtime]]', '[[regtime]]'),
(3704, 1, 1, 'tool_rl_manager', 'text_success', 'Success: You have updated resource type!', '[[regtime]]', '[[regtime]]'),
(3705, 1, 1, 'tool_rl_manager', 'error_missing_type_id', 'Error: Missing resource type ID!', '[[regtime]]', '[[regtime]]'),
(3706, 1, 1, 'tool_rl_manager', 'error_type_name', 'Error: Resource type name needs to be between 2 and 40 characters', '[[regtime]]', '[[regtime]]'),
(3707, 1, 1, 'tool_rl_manager', 'error_default_directory', 'Error: Resource type directory needs to be between 2 and 64 characters', '[[regtime]]', '[[regtime]]'),
(3708, 1, 1, 'tool_rl_manager', 'error_default_icon', 'Error: Resource type icon needs to be between 2 and 64 characters', '[[regtime]]', '[[regtime]]'),
(3709, 1, 1, 'tool_rl_manager', 'error_file_types', 'Error: Resource type file extensions regex needs to be between 2 and 40 characters', '[[regtime]]', '[[regtime]]'),
(3710, 1, 1, 'tool_task', 'heading_title', 'Scheduled Tasks', '[[regtime]]', '[[regtime]]'),
(3711, 1, 1, 'tool_task', 'column_id', ' Id', '[[regtime]]', '[[regtime]]'),
(3712, 1, 1, 'tool_task', 'column_date_created', ' Date Created', '[[regtime]]', '[[regtime]]'),
(3713, 1, 1, 'tool_task', 'column_name', ' Name ', '[[regtime]]', '[[regtime]]'),
(3714, 1, 1, 'tool_task', 'column_status', ' Status ', '[[regtime]]', '[[regtime]]'),
(3715, 1, 1, 'tool_task', 'column_start_time', ' Start Time', '[[regtime]]', '[[regtime]]'),
(3716, 1, 1, 'tool_task', 'text_stuck', ' Stuck', '[[regtime]]', '[[regtime]]'),
(3717, 1, 1, 'tool_task', 'text_ready', ' Ready', '[[regtime]]', '[[regtime]]'),
(3718, 1, 1, 'tool_task', 'text_running', ' Running', '[[regtime]]', '[[regtime]]'),
(3719, 1, 1, 'tool_task', 'text_scheduled', ' Scheduled', '[[regtime]]', '[[regtime]]'),
(3720, 1, 1, 'tool_task', 'text_disabled', ' Disabled', '[[regtime]]', '[[regtime]]'),
(3721, 1, 1, 'tool_task', 'text_failed', ' Failed', '[[regtime]]', '[[regtime]]'),
(3722, 1, 1, 'tool_task', 'text_incomplete', ' Incomplete', '[[regtime]]', '[[regtime]]'),
(3723, 1, 1, 'tool_task', 'text_completed', ' Completed', '[[regtime]]', '[[regtime]]'),
(3724, 1, 1, 'tool_task', 'text_restart', ' Restart Task', '[[regtime]]', '[[regtime]]'),
(3725, 1, 1, 'tool_task', 'text_run', ' Run Task', '[[regtime]]', '[[regtime]]'),
(3726, 1, 1, 'tool_task', 'text_task_started', ' Task started', '[[regtime]]', '[[regtime]]'),
(3727, 1, 1, 'tool_task', 'text_task_not_found', ' Task not Found.', '[[regtime]]', '[[regtime]]'),
(3728, 1, 1, 'tool_task', 'text_empty_task', ' Task does not contains steps. Removed.', '[[regtime]]', '[[regtime]]'),
(3729, 1, 1, 'tool_task', 'text_forbidden_to_restart', ' Forbidden To restart!', '[[regtime]]', '[[regtime]]'),
(3730, 1, 1, 'tool_updater', 'heading_title', 'Update manager', '[[regtime]]', '[[regtime]]'),
(3731, 1, 1, 'tool_updater', 'text_checkupdates', 'check for updates', '[[regtime]]', '[[regtime]]'),
(3732, 1, 1, 'tool_updater', 'column_name', 'Extension Name', '[[regtime]]', '[[regtime]]'),
(3733, 1, 1, 'tool_updater', 'column_type', 'Type', '[[regtime]]', '[[regtime]]'),
(3734, 1, 1, 'tool_updater', 'column_category', 'Category', '[[regtime]]', '[[regtime]]'),
(3735, 1, 1, 'tool_updater', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(3736, 1, 1, 'tool_updater', 'column_version', 'Current version', '[[regtime]]', '[[regtime]]'),
(3737, 1, 1, 'tool_updater', 'column_new_version', 'New version', '[[regtime]]', '[[regtime]]'),
(3738, 1, 1, 'tool_updater', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(3739, 1, 1, 'tool_updater', 'text_success', 'Success: Extensions was successfully updated!', '[[regtime]]', '[[regtime]]'),
(3740, 1, 1, 'tool_updater', 'text_update', 'Update', '[[regtime]]', '[[regtime]]'),
(3741, 1, 1, 'tool_updater', 'entry_restore_exts', 'Restore Backuped extension:', '[[regtime]]', '[[regtime]]'),
(3742, 1, 1, 'tool_updater', 'entry_update', 'Updates:', '[[regtime]]', '[[regtime]]'),
(3743, 1, 1, 'tool_updater', 'error_permission', 'Warning: You do not have permission to modify directory: ', '[[regtime]]', '[[regtime]]'),
(3744, 1, 1, 'tool_updater', 'warning_server', 'Server with updates is inaccesible.', '[[regtime]]', '[[regtime]]'),
(3745, 1, 1, 'tool_updater', 'text_notice_title', 'Update Notice for %EXTENSION%', '[[regtime]]', '[[regtime]]'),
(3746, 1, 1, 'tool_updater', 'text_notice_text', 'New version of extension "%EXTENSION%" is available. Please, go to %LINK% and upgrade it.', '[[regtime]]', '[[regtime]]'),
(3747, 1, 1, 'tool_updater', 'warning_updates', 'Can''t get information about updates.', '[[regtime]]', '[[regtime]]'),
(3748, 1, 1, 'tool_updater', 'error_empty', 'Warning: The file you uploaded was empty!', '[[regtime]]', '[[regtime]]'),
(3749, 1, 1, 'tool_updater', 'error_exts_list', 'Warning: Extension list is not array!', '[[regtime]]', '[[regtime]]'),
(3750, 1, 1, 'tool_updater', 'text_nothing_todo', ' Your''s extensions are up to date. Nothing to do. ', '[[regtime]]', '[[regtime]]'),
(3751, 1, 1, 'tool_updater', 'text_connect', 'Connect', '[[regtime]]', '[[regtime]]'),
(3752, 1, 1, 'tool_updater', 'text_marketplace_connect', 'Connect to the marketplace', '[[regtime]]', '[[regtime]]'),
(3753, 1, 1, 'tool_updater', 'text_marketplace_connect_your_store', 'Please Connect Your Store to the Marketplace', '[[regtime]]', '[[regtime]]'),
(3754, 1, 1, 'tool_updater', 'text_note', 'Note: Update available only for connected stores with purchased history.', '[[regtime]]', '[[regtime]]'),
(3755, 1, 1, 'total_balance', 'heading_title', 'Balance', '[[regtime]]', '[[regtime]]'),
(3756, 1, 1, 'total_balance', 'total_name', 'Balance', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(3757, 1, 1, 'total_balance', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(3758, 1, 1, 'total_balance', 'text_success', 'Success: You have modified total balance!', '[[regtime]]', '[[regtime]]'),
(3759, 1, 1, 'total_balance', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3760, 1, 1, 'total_balance', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(3761, 1, 1, 'total_balance', 'entry_calculation_order', 'Calculation Order:', '[[regtime]]', '[[regtime]]'),
(3762, 1, 1, 'total_balance', 'error_permission', 'Warning: You do not have permission to modify total balance!', '[[regtime]]', '[[regtime]]'),
(3763, 1, 1, 'total_coupon', 'heading_title', 'Coupon', '[[regtime]]', '[[regtime]]'),
(3764, 1, 1, 'total_coupon', 'total_name', 'Coupon', '[[regtime]]', '[[regtime]]'),
(3765, 1, 1, 'total_coupon', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(3766, 1, 1, 'total_coupon', 'text_success', 'Success: You have modified total coupon!', '[[regtime]]', '[[regtime]]'),
(3767, 1, 1, 'total_coupon', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3768, 1, 1, 'total_coupon', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(3769, 1, 1, 'total_coupon', 'entry_calculation_order', 'Calculation Order:', '[[regtime]]', '[[regtime]]'),
(3770, 1, 1, 'total_coupon', 'error_permission', 'Warning: You do not have permission to modify total coupon!', '[[regtime]]', '[[regtime]]'),
(3771, 1, 1, 'total_discount', 'heading_title', 'Discount', '[[regtime]]', '[[regtime]]'),
(3772, 1, 1, 'total_discount', 'total_name', 'Discount', '[[regtime]]', '[[regtime]]'),
(3773, 1, 1, 'total_discount', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(3774, 1, 1, 'total_discount', 'text_success', 'Success: You have modified total Discount!', '[[regtime]]', '[[regtime]]'),
(3775, 1, 1, 'total_discount', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3776, 1, 1, 'total_discount', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(3777, 1, 1, 'total_discount', 'entry_calculation_order', 'Calculation Order:', '[[regtime]]', '[[regtime]]'),
(3778, 1, 1, 'total_discount', 'error_permission', 'Warning: You do not have permission to modify total Discount!', '[[regtime]]', '[[regtime]]'),
(3779, 1, 1, 'total_handling', 'heading_title', 'Handling Fee', '[[regtime]]', '[[regtime]]'),
(3780, 1, 1, 'total_handling', 'total_name', 'Handling Fee', '[[regtime]]', '[[regtime]]'),
(3781, 1, 1, 'total_handling', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(3782, 1, 1, 'total_handling', 'text_success', 'Success: You have updated total handling fee!', '[[regtime]]', '[[regtime]]'),
(3783, 1, 1, 'total_handling', 'entry_total', 'Order Total:<span class="help">Minimum order amount to be reached to apply the fee. If customer order total will exceed this amount, handling fee will not be applied. This value is overridden with payment specific setting.</span>', '[[regtime]]', '[[regtime]]'),
(3784, 1, 1, 'total_handling', 'entry_total_placeholder', 'Order Amount', '[[regtime]]', '[[regtime]]'),
(3785, 1, 1, 'total_handling', 'entry_fee', 'Fee:<span class="help">Fee to be added to order total if minimum amount condition is not met. This amount is overridden by payment specific setting</span>', '[[regtime]]', '[[regtime]]'),
(3786, 1, 1, 'total_handling', 'entry_payment_fee', 'Fee:<span class="help">Fee to be added to order total if minimum sub-total amount condition is not met. This amount override main fee setting</span>', '[[regtime]]', '[[regtime]]'),
(3787, 1, 1, 'total_handling', 'entry_payment', 'Payment:<span class="help">Select a specific payment you need to add the fee to. These settings will override the main settings if payment is used by customer.</span>', '[[regtime]]', '[[regtime]]'),
(3788, 1, 1, 'total_handling', 'entry_order_subtotal', 'Order Sub-Total:<span class="help">Minimum order sub-total amount to be reached to apply the fee. This overrides main setting</span>', '[[regtime]]', '[[regtime]]'),
(3789, 1, 1, 'total_handling', 'entry_tax', 'Tax Class:<span class="help">Select if you need tax to be applied on-top of the handling fee</span>', '[[regtime]]', '[[regtime]]'),
(3790, 1, 1, 'total_handling', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3791, 1, 1, 'total_handling', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(3792, 1, 1, 'total_handling', 'entry_calculation_order', 'Calculation Order:', '[[regtime]]', '[[regtime]]'),
(3793, 1, 1, 'total_handling', 'error_permission', 'Warning: You do not have permission to modify total handling fee!', '[[regtime]]', '[[regtime]]'),
(3794, 1, 1, 'total_handling', 'error_number', 'Warning: Order total and handling fee must be a numbers!', '[[regtime]]', '[[regtime]]'),
(3795, 1, 1, 'total_low_order_fee', 'heading_title', 'Low Order Fee', '[[regtime]]', '[[regtime]]'),
(3796, 1, 1, 'total_low_order_fee', 'total_name', 'Low Order Fee', '[[regtime]]', '[[regtime]]'),
(3797, 1, 1, 'total_low_order_fee', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(3798, 1, 1, 'total_low_order_fee', 'text_success', 'Success: You have modified total low order fee!', '[[regtime]]', '[[regtime]]'),
(3799, 1, 1, 'total_low_order_fee', 'entry_total', 'Order Total:', '[[regtime]]', '[[regtime]]'),
(3800, 1, 1, 'total_low_order_fee', 'entry_fee', 'Fee:', '[[regtime]]', '[[regtime]]'),
(3801, 1, 1, 'total_low_order_fee', 'entry_tax', 'Tax Class:', '[[regtime]]', '[[regtime]]'),
(3802, 1, 1, 'total_low_order_fee', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3803, 1, 1, 'total_low_order_fee', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(3804, 1, 1, 'total_low_order_fee', 'entry_calculation_order', 'Calculation Order:', '[[regtime]]', '[[regtime]]'),
(3805, 1, 1, 'total_low_order_fee', 'error_permission', 'Warning: You do not have permission to modify total low order fee!', '[[regtime]]', '[[regtime]]'),
(3806, 1, 1, 'total_shipping', 'heading_title', 'Shipping', '[[regtime]]', '[[regtime]]'),
(3807, 1, 1, 'total_shipping', 'total_name', 'Shipping', '[[regtime]]', '[[regtime]]'),
(3808, 1, 1, 'total_shipping', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(3809, 1, 1, 'total_shipping', 'text_success', 'Success: You have modified total shipping!', '[[regtime]]', '[[regtime]]'),
(3810, 1, 1, 'total_shipping', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3811, 1, 1, 'total_shipping', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(3812, 1, 1, 'total_shipping', 'entry_calculation_order', 'Calculation Order:', '[[regtime]]', '[[regtime]]'),
(3813, 1, 1, 'total_shipping', 'error_permission', 'Warning: You do not have permission to modify total shipping!', '[[regtime]]', '[[regtime]]'),
(3814, 1, 1, 'total_sub_total', 'heading_title', 'Sub-Total', '[[regtime]]', '[[regtime]]'),
(3815, 1, 1, 'total_sub_total', 'total_name', 'Sub-Total', '[[regtime]]', '[[regtime]]'),
(3816, 1, 1, 'total_sub_total', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(3817, 1, 1, 'total_sub_total', 'text_success', 'Success: You have modified total sub-total!', '[[regtime]]', '[[regtime]]'),
(3818, 1, 1, 'total_sub_total', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3819, 1, 1, 'total_sub_total', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(3820, 1, 1, 'total_sub_total', 'entry_calculation_order', 'Calculation Order:', '[[regtime]]', '[[regtime]]'),
(3821, 1, 1, 'total_sub_total', 'error_permission', 'Warning: You do not have permission to modify total sub-total!', '[[regtime]]', '[[regtime]]'),
(3822, 1, 1, 'total_tax', 'heading_title', 'Taxes', '[[regtime]]', '[[regtime]]'),
(3823, 1, 1, 'total_tax', 'total_name', 'Taxes', '[[regtime]]', '[[regtime]]'),
(3824, 1, 1, 'total_tax', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(3825, 1, 1, 'total_tax', 'text_success', 'Success: You have modified total taxes!', '[[regtime]]', '[[regtime]]'),
(3826, 1, 1, 'total_tax', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3827, 1, 1, 'total_tax', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(3828, 1, 1, 'total_tax', 'entry_calculation_order', 'Calculation Order:', '[[regtime]]', '[[regtime]]'),
(3829, 1, 1, 'total_tax', 'error_permission', 'Warning: You do not have permission to modify total taxes!', '[[regtime]]', '[[regtime]]'),
(3830, 1, 1, 'total_total', 'heading_title', 'Total', '[[regtime]]', '[[regtime]]'),
(3831, 1, 1, 'total_total', 'total_name', 'Total', '[[regtime]]', '[[regtime]]'),
(3832, 1, 1, 'total_total', 'text_total', 'Order Totals', '[[regtime]]', '[[regtime]]'),
(3833, 1, 1, 'total_total', 'text_success', 'Success: You have modified total total!', '[[regtime]]', '[[regtime]]'),
(3834, 1, 1, 'total_total', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3835, 1, 1, 'total_total', 'entry_sort_order', 'Sort Order:', '[[regtime]]', '[[regtime]]'),
(3836, 1, 1, 'total_total', 'entry_calculation_order', 'Calculation Order:', '[[regtime]]', '[[regtime]]'),
(3837, 1, 1, 'total_total', 'error_permission', 'Warning: You do not have permission to modify total total!', '[[regtime]]', '[[regtime]]'),
(3838, 1, 1, 'user_user', 'heading_title', 'Users', '[[regtime]]', '[[regtime]]'),
(3839, 1, 1, 'user_user', 'text_edit_details', 'Edit Profile Details', '[[regtime]]', '[[regtime]]'),
(3840, 1, 1, 'user_user', 'text_user', 'User', '[[regtime]]', '[[regtime]]'),
(3841, 1, 1, 'user_user', 'text_success', 'Success: You have modified users!', '[[regtime]]', '[[regtime]]'),
(3842, 1, 1, 'user_user', 'text_success_details', 'Success: You have modified your profile!', '[[regtime]]', '[[regtime]]'),
(3843, 1, 1, 'user_user', 'column_username', 'Username', '[[regtime]]', '[[regtime]]'),
(3844, 1, 1, 'user_user', 'column_group', 'Group', '[[regtime]]', '[[regtime]]'),
(3845, 1, 1, 'user_user', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(3846, 1, 1, 'user_user', 'column_date_added', 'Date Added', '[[regtime]]', '[[regtime]]'),
(3847, 1, 1, 'user_user', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(3848, 1, 1, 'user_user', 'entry_username', 'Username:', '[[regtime]]', '[[regtime]]'),
(3849, 1, 1, 'user_user', 'entry_password', 'Password:', '[[regtime]]', '[[regtime]]'),
(3850, 1, 1, 'user_user', 'entry_confirm', 'Confirm:', '[[regtime]]', '[[regtime]]'),
(3851, 1, 1, 'user_user', 'entry_firstname', 'First Name:', '[[regtime]]', '[[regtime]]'),
(3852, 1, 1, 'user_user', 'entry_lastname', 'Last Name:', '[[regtime]]', '[[regtime]]'),
(3853, 1, 1, 'user_user', 'entry_email', 'E-Mail:', '[[regtime]]', '[[regtime]]'),
(3854, 1, 1, 'user_user', 'entry_user_group', 'User Group:', '[[regtime]]', '[[regtime]]'),
(3855, 1, 1, 'user_user', 'entry_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(3856, 1, 1, 'user_user', 'entry_ims', 'Notifications', '[[regtime]]', '[[regtime]]'),
(3857, 1, 1, 'user_user', 'entry_captcha', 'Enter the code in the box below:', '[[regtime]]', '[[regtime]]'),
(3858, 1, 1, 'user_user', 'error_permission', 'Warning: You do not have permission to modify users!', '[[regtime]]', '[[regtime]]'),
(3859, 1, 1, 'user_user', 'error_account', 'Warning: You can not delete your own account!', '[[regtime]]', '[[regtime]]'),
(3860, 1, 1, 'user_user', 'error_username', 'Username must be between 2 and 20 characters and must be unique!', '[[regtime]]', '[[regtime]]'),
(3861, 1, 1, 'user_user', 'error_password', 'Password must be more than 3 characters!', '[[regtime]]', '[[regtime]]'),
(3862, 1, 1, 'user_user', 'error_confirm', 'Password and password confirmation do not match!', '[[regtime]]', '[[regtime]]'),
(3863, 1, 1, 'user_user', 'error_firstname', 'First Name must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(3864, 1, 1, 'user_user', 'error_lastname', 'Last Name must be between 2 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(3865, 1, 1, 'user_user', 'error_email', 'E-Mail Address does not appear to be valid!', '[[regtime]]', '[[regtime]]'),
(3866, 1, 1, 'user_user', 'error_captcha', 'Human Verification Failed!', '[[regtime]]', '[[regtime]]'),
(3867, 1, 1, 'user_user', 'error_user_group', 'You have no permissions to change user group.', '[[regtime]]', '[[regtime]]'),
(3868, 1, 1, 'user_user', 'text_select_group', '- Select Group -', '[[regtime]]', '[[regtime]]'),
(3869, 1, 1, 'user_user', 'entry_im_email', 'E-Mail:<span class="help">One or more comma separated email addresses</span>', '[[regtime]]', '[[regtime]]'),
(3870, 1, 1, 'user_user', 'entry_im_sms', 'Mobile Phone:<span class="help">Phone number in international format. ex. +14566887777</span>', '[[regtime]]', '[[regtime]]'),
(3871, 1, 1, 'user_user', 'text_edit_im', 'Edit Notifications', '[[regtime]]', '[[regtime]]'),
(3872, 1, 1, 'user_user', 'text_sendpoints', 'Notification settings', '[[regtime]]', '[[regtime]]'),
(3873, 1, 1, 'user_user', 'text_change_im_addresses', 'Edit Notification Addresses for this SendPoint', '[[regtime]]', '[[regtime]]'),
(3874, 1, 1, 'user_user_group', 'heading_title', 'User Groups', '[[regtime]]', '[[regtime]]'),
(3875, 1, 1, 'user_user_group', 'text_group', 'User Group', '[[regtime]]', '[[regtime]]'),
(3876, 1, 1, 'user_user_group', 'text_success', 'Success: You have modified user groups!', '[[regtime]]', '[[regtime]]'),
(3877, 1, 1, 'user_user_group', 'text_success_group_added', 'Success: You have created user group successfully!', '[[regtime]]', '[[regtime]]'),
(3878, 1, 1, 'user_user_group', 'text_go_to_page', 'Go to Page', '[[regtime]]', '[[regtime]]'),
(3879, 1, 1, 'user_user_group', 'text_delete_confirm', ' Delete User Group?', '[[regtime]]', '[[regtime]]'),
(3880, 1, 1, 'user_user_group', 'column_name', 'User Group Name', '[[regtime]]', '[[regtime]]'),
(3881, 1, 1, 'user_user_group', 'column_action', 'Action', '[[regtime]]', '[[regtime]]'),
(3882, 1, 1, 'user_user_group', 'entry_name', 'User Group Name:', '[[regtime]]', '[[regtime]]'),
(3883, 1, 1, 'user_user_group', 'column_controller', 'Controller', '[[regtime]]', '[[regtime]]'),
(3884, 1, 1, 'user_user_group', 'column_access', 'Access', '[[regtime]]', '[[regtime]]'),
(3885, 1, 1, 'user_user_group', 'column_modify', 'Modify', '[[regtime]]', '[[regtime]]'),
(3886, 1, 1, 'user_user_group', 'error_permission', 'Warning: You do not have permission to modify user groups!', '[[regtime]]', '[[regtime]]'),
(3887, 1, 1, 'user_user_group', 'error_name', 'User Group Name must be between 2 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(3888, 1, 1, 'user_user_group', 'error_user', 'Warning: This user group cannot be deleted as it is currently assigned to %s users!', '[[regtime]]', '[[regtime]]'),
(3889, 1, 0, '2checkout_2checkout', 'text_title', 'Credit Card / Debit Card (2Checkout)', '[[regtime]]', '[[regtime]]'),
(3890, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_name', 'Avatax integration', '[[regtime]]', '[[regtime]]'),
(3891, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_address_validation_error', 'We failed to verify your shipping address. Please check and correct address below.', '[[regtime]]', '[[regtime]]'),
(3892, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_text_tax_exemption', 'Tax Exemption details', '[[regtime]]', '[[regtime]]'),
(3893, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_exemption_number', 'Tax Exemption Certificate Number', '[[regtime]]', '[[regtime]]'),
(3894, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_entity_use_code', 'Tax Exemption Customer Usage Type ', '[[regtime]]', '[[regtime]]'),
(3895, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_status', 'Current Exempt Status', '[[regtime]]', '[[regtime]]'),
(3896, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_status_pending', 'Pending Review', '[[regtime]]', '[[regtime]]'),
(3897, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_status_declined', 'Declined', '[[regtime]]', '[[regtime]]'),
(3898, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_status_approved', 'Approved', '[[regtime]]', '[[regtime]]'),
(3899, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_review_number_title', 'Customer Avatax Exemption Number needs to be reviewed!', '[[regtime]]', '[[regtime]]'),
(3900, 1, 0, 'avatax_integration_avatax_integration', 'avatax_integration_review_number_message', 'Please review customer''s tax exemption number. Visit #admin#rt=sale/avatax_customer_data&customer_id=%s', '[[regtime]]', '[[regtime]]'),
(3901, 1, 0, 'cardconnect_cardconnect', 'text_title', 'Credit Card / Debit Card (Via CardConnect)', '[[regtime]]', '[[regtime]]'),
(3902, 1, 0, 'cardconnect_cardconnect', 'text_credit_card', 'Credit Card Details', '[[regtime]]', '[[regtime]]'),
(3903, 1, 0, 'cardconnect_cardconnect', 'text_wait', 'Please wait!', '[[regtime]]', '[[regtime]]'),
(3904, 1, 0, 'cardconnect_cardconnect', 'entry_cc_owner', 'Name on the card:', '[[regtime]]', '[[regtime]]'),
(3905, 1, 0, 'cardconnect_cardconnect', 'entry_cc_number', 'Card Number:', '[[regtime]]', '[[regtime]]'),
(3906, 1, 0, 'cardconnect_cardconnect', 'entry_cc_expire_date', 'Card Expiry Date:', '[[regtime]]', '[[regtime]]'),
(3907, 1, 0, 'cardconnect_cardconnect', 'entry_cc_cvv2', 'Card Security Code', '[[regtime]]', '[[regtime]]'),
(3908, 1, 0, 'cardconnect_cardconnect', 'entry_cc_cvv2_short', '(CVV2 ?)', '[[regtime]]', '[[regtime]]'),
(3909, 1, 0, 'cardconnect_cardconnect', 'entry_what_cvv2', 'What is CVV2?', '[[regtime]]', '[[regtime]]'),
(3910, 1, 0, 'cardconnect_cardconnect', 'entry_cc_type', 'Card Type', '[[regtime]]', '[[regtime]]'),
(3911, 1, 0, 'cardconnect_cardconnect', 'entry_cc_save', 'Save', '[[regtime]]', '[[regtime]]'),
(3912, 1, 0, 'cardconnect_cardconnect', 'entry_cc_save_details', 'Credit Card details will be securely saved by CardConnect', '[[regtime]]', '[[regtime]]'),
(3913, 1, 0, 'cardconnect_cardconnect', 'entry_billing_address', 'for billing Address', '[[regtime]]', '[[regtime]]'),
(3914, 1, 0, 'cardconnect_cardconnect', 'entry_edit', 'Edit', '[[regtime]]', '[[regtime]]'),
(3915, 1, 0, 'cardconnect_cardconnect', 'text_saved_credit_card', 'Select saved credit card', '[[regtime]]', '[[regtime]]'),
(3916, 1, 0, 'cardconnect_cardconnect', 'text_delete_saved_credit_card', 'Delete card', '[[regtime]]', '[[regtime]]'),
(3917, 1, 0, 'cardconnect_cardconnect', 'text_new_credit_card', 'New card', '[[regtime]]', '[[regtime]]'),
(3918, 1, 0, 'cardconnect_cardconnect', 'error_incorrect_number', 'Invalid Credit Card Number', '[[regtime]]', '[[regtime]]'),
(3919, 1, 0, 'cardconnect_cardconnect', 'error_incorrect_name', 'Invalid Card Owner Name', '[[regtime]]', '[[regtime]]'),
(3920, 1, 0, 'cardconnect_cardconnect', 'error_incorrect_expiration', 'Invalid Card Expiration Date', '[[regtime]]', '[[regtime]]'),
(3921, 1, 0, 'cardconnect_cardconnect', 'error_incorrect_cvv', 'Invalid Card CVV', '[[regtime]]', '[[regtime]]'),
(3922, 1, 0, 'cardconnect_cardconnect', 'error_system', 'Apologies, we have encounter system error. Please try again or contact site administrator!', '[[regtime]]', '[[regtime]]'),
(3923, 1, 0, 'default_authorizenet_default_authorizenet', 'text_title', 'Credit Card / Debit Card (Via Authorize.Net)', '[[regtime]]', '[[regtime]]'),
(3924, 1, 0, 'default_authorizenet_default_authorizenet', 'text_credit_card', 'Credit Card Details', '[[regtime]]', '[[regtime]]'),
(3925, 1, 0, 'default_authorizenet_default_authorizenet', 'text_wait', 'Please wait!', '[[regtime]]', '[[regtime]]'),
(3926, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_cc_owner', 'Name on the card:', '[[regtime]]', '[[regtime]]'),
(3927, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_cc_number', 'Card Number:', '[[regtime]]', '[[regtime]]'),
(3928, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_cc_expire_date', 'Card Expiry Date:', '[[regtime]]', '[[regtime]]'),
(3929, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_cc_cvv2', 'Card Security Code', '[[regtime]]', '[[regtime]]'),
(3930, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_cc_cvv2_short', '(CVV2 ?)', '[[regtime]]', '[[regtime]]'),
(3931, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_what_cvv2', 'What is CVV2?', '[[regtime]]', '[[regtime]]'),
(3932, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_cc_type', 'Card Type', '[[regtime]]', '[[regtime]]'),
(3933, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_cc_save', 'Save', '[[regtime]]', '[[regtime]]'),
(3934, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_cc_save_details', 'Credit Card details will be securely saved by Stipe', '[[regtime]]', '[[regtime]]'),
(3935, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_billing_address', 'for billing Address', '[[regtime]]', '[[regtime]]'),
(3936, 1, 0, 'default_authorizenet_default_authorizenet', 'entry_edit', 'Edit', '[[regtime]]', '[[regtime]]'),
(3937, 1, 0, 'default_authorizenet_default_authorizenet', 'text_saved_credit_card', 'Select saved credit card', '[[regtime]]', '[[regtime]]'),
(3938, 1, 0, 'default_authorizenet_default_authorizenet', 'text_delete_saved_credit_card', 'Delete card', '[[regtime]]', '[[regtime]]'),
(3939, 1, 0, 'default_authorizenet_default_authorizenet', 'text_new_credit_card', 'New card', '[[regtime]]', '[[regtime]]'),
(3940, 1, 0, 'default_authorizenet_default_authorizenet', 'error_incorrect_number', 'Invalid Credit Card Number', '[[regtime]]', '[[regtime]]'),
(3941, 1, 0, 'default_authorizenet_default_authorizenet', 'error_incorrect_name', 'Invalid Card Owner Name', '[[regtime]]', '[[regtime]]'),
(3942, 1, 0, 'default_authorizenet_default_authorizenet', 'error_incorrect_expiration', 'Invalid Card Expiration Date', '[[regtime]]', '[[regtime]]'),
(3943, 1, 0, 'default_authorizenet_default_authorizenet', 'error_incorrect_cvv', 'Invalid Card CVV', '[[regtime]]', '[[regtime]]'),
(3944, 1, 0, 'default_authorizenet_default_authorizenet', 'error_system', 'Apologies, we have encounter system error. Please try again or contact site administrator!', '[[regtime]]', '[[regtime]]'),
(3945, 1, 0, 'default_banktransfer_default_banktransfer', 'text_title', 'Bank Transfer', '[[regtime]]', '[[regtime]]'),
(3946, 1, 0, 'default_banktransfer_default_banktransfer', 'text_instructions', 'Follow instructions to make your payment: ', '[[regtime]]', '[[regtime]]'),
(3947, 1, 0, 'default_banktransfer_default_banktransfer', 'text_payment', 'Your order will not ship or completed until payment is received.', '[[regtime]]', '[[regtime]]'),
(3948, 1, 0, 'default_banktransfer_default_banktransfer', 'text_minimum_notmet', 'Order total minimum is not met for bank transfer payment.', '[[regtime]]', '[[regtime]]'),
(3949, 1, 0, 'default_cheque_default_cheque', 'text_title', 'Cheque / Money Order', '[[regtime]]', '[[regtime]]'),
(3950, 1, 0, 'default_cheque_default_cheque', 'text_payable', 'Make Check Payable To: ', '[[regtime]]', '[[regtime]]'),
(3951, 1, 0, 'default_cheque_default_cheque', 'text_address', 'Send To: ', '[[regtime]]', '[[regtime]]'),
(3952, 1, 0, 'default_cheque_default_cheque', 'text_payment', 'Your order will not ship until we receive payment.', '[[regtime]]', '[[regtime]]'),
(3953, 1, 0, 'default_cheque_default_cheque', 'text_wait', 'Please wait!', '[[regtime]]', '[[regtime]]'),
(3954, 1, 0, 'default_cod_default_cod', 'text_title', 'Cash On Delivery', '[[regtime]]', '[[regtime]]'),
(3955, 1, 0, 'default_cod_default_cod', 'text_note', 'Payment needs to be established upon delivery or pickup of the product', '[[regtime]]', '[[regtime]]'),
(3956, 1, 0, 'default_cod_default_cod', 'text_wait', 'Please wait!', '[[regtime]]', '[[regtime]]'),
(3957, 1, 0, 'default_fedex_default_fedex', 'text_title', 'Fedex', '[[regtime]]', '[[regtime]]'),
(3958, 1, 0, 'default_fedex_default_fedex', 'text_description', 'Fedex', '[[regtime]]', '[[regtime]]'),
(3959, 1, 0, 'default_fedex_default_fedex', 'fedex_error_empty_postcode', 'Error: Empty postal code.', '[[regtime]]', '[[regtime]]'),
(3960, 1, 0, 'default_fedex_default_fedex', 'fedex_error_no_service', 'Service is not available in your area. Check if your shipping address is correct', '[[regtime]]', '[[regtime]]'),
(3961, 1, 0, 'default_flat_rate_shipping_default_flat_rate_shipping', 'text_title', 'Flat Rate', '[[regtime]]', '[[regtime]]'),
(3962, 1, 0, 'default_flat_rate_shipping_default_flat_rate_shipping', 'text_description', 'Flat Shipping Rate', '[[regtime]]', '[[regtime]]'),
(3963, 1, 0, 'default_free_shipping_default_free_shipping', 'text_title', 'Free Shipping', '[[regtime]]', '[[regtime]]'),
(3964, 1, 0, 'default_free_shipping_default_free_shipping', 'text_description', 'Free Shipping', '[[regtime]]', '[[regtime]]'),
(3965, 1, 0, 'default_liqpay_default_liqpay', 'text_title', 'Credit Card / Debit Card (LiqPay)', '[[regtime]]', '[[regtime]]'),
(3966, 1, 0, 'default_local_delivery_default_local_delivery', 'text_title', 'Local Delivery', '[[regtime]]', '[[regtime]]'),
(3967, 1, 0, 'default_local_delivery_default_local_delivery', 'text_description', 'Local Delivery', '[[regtime]]', '[[regtime]]'),
(3968, 1, 0, 'default_local_delivery_default_local_delivery', 'error_telephone', 'Please set your telephone number', '[[regtime]]', '[[regtime]]'),
(3969, 1, 0, 'default_local_delivery_default_local_delivery', 'text_apply', 'Apply', '[[regtime]]', '[[regtime]]'),
(3970, 1, 0, 'default_parcelforce_48_default_parcelforce_48', 'text_title', 'Parcelforce 48', '[[regtime]]', '[[regtime]]'),
(3971, 1, 0, 'default_parcelforce_48_default_parcelforce_48', 'text_description', 'Parcelforce 48', '[[regtime]]', '[[regtime]]'),
(3972, 1, 0, 'default_parcelforce_48_default_parcelforce_48', 'text_weight', 'Weight:', '[[regtime]]', '[[regtime]]'),
(3973, 1, 0, 'default_parcelforce_48_default_parcelforce_48', 'text_insurance', 'Insured upto:', '[[regtime]]', '[[regtime]]'),
(3974, 1, 0, 'default_parcelforce_48_default_parcelforce_48', 'text_time', 'Estimated Time: Within 48 Hours', '[[regtime]]', '[[regtime]]'),
(3975, 1, 0, 'default_per_item_shipping_default_per_item_shipping', 'text_title', 'Per Item', '[[regtime]]', '[[regtime]]'),
(3976, 1, 0, 'default_per_item_shipping_default_per_item_shipping', 'text_description', 'Per Item Shipping Rate', '[[regtime]]', '[[regtime]]'),
(3977, 1, 0, 'default_royal_mail_default_royal_mail', 'text_title', 'Royal Mail', '[[regtime]]', '[[regtime]]'),
(3978, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_weight', 'Weight:', '[[regtime]]', '[[regtime]]'),
(3979, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_insurance', 'Insured upto:', '[[regtime]]', '[[regtime]]'),
(3980, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_eta', 'Estimated Time:', '[[regtime]]', '[[regtime]]'),
(3981, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_1st_class', '1st Class®', '[[regtime]]', '[[regtime]]'),
(3982, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_2nd_class', '2nd Class®', '[[regtime]]', '[[regtime]]'),
(3983, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tracked24', 'Tracked 24®', '[[regtime]]', '[[regtime]]'),
(3984, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_tracked48', 'Tracked 48®', '[[regtime]]', '[[regtime]]'),
(3985, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_mail24', 'Mail 24®', '[[regtime]]', '[[regtime]]'),
(3986, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_mail48', 'Mail 48®', '[[regtime]]', '[[regtime]]'),
(3987, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_sameday', 'Sameday®', '[[regtime]]', '[[regtime]]'),
(3988, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_special_delivery_guaranteed', 'Special Delivery Guaranteed®', '[[regtime]]', '[[regtime]]'),
(3989, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_economy', 'Standard Economy', '[[regtime]]', '[[regtime]]'),
(3990, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_standard_priority', 'Standard Priority', '[[regtime]]', '[[regtime]]'),
(3991, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_signed', 'Signed', '[[regtime]]', '[[regtime]]'),
(3992, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_signed', 'Tracked Signed', '[[regtime]]', '[[regtime]]'),
(3993, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked', 'Tracked', '[[regtime]]', '[[regtime]]'),
(3994, 1, 0, 'default_royal_mail_default_royal_mail', 'default_royal_mail_intl_tracked_heavier', 'Tracked Heavier', '[[regtime]]', '[[regtime]]'),
(3995, 1, 0, 'default_store_pickup_default_store_pickup', 'text_title', 'Pickup', '[[regtime]]', '[[regtime]]'),
(3996, 1, 0, 'default_store_pickup_default_store_pickup', 'text_description', 'Pickup From Store', '[[regtime]]', '[[regtime]]'),
(3997, 1, 0, 'default_textmarketer_default_textmarketer', 'entry_sms', 'Mobile Phone (SMS Notification)', '[[regtime]]', '[[regtime]]'),
(3998, 1, 0, 'default_textmarketer_default_textmarketer', 'default_textmarketer_protocol_title', ' SMS ', '[[regtime]]', '[[regtime]]'),
(3999, 1, 0, 'default_twilio_default_twilio', 'entry_sms', ' Mobile Phone (SMS Notification) ', '[[regtime]]', '[[regtime]]'),
(4000, 1, 0, 'default_twilio_default_twilio', 'default_twilio_protocol_title', ' SMS ', '[[regtime]]', '[[regtime]]'),
(4001, 1, 0, 'default_weight_default_weight', 'text_title', 'Weight Based Shipping', '[[regtime]]', '[[regtime]]'),
(4002, 1, 0, 'default_weight_default_weight', 'text_weight', 'Weight:', '[[regtime]]', '[[regtime]]'),
(4003, 1, 0, 'forms_manager_default_email', 'default_subject', 'No subject', '[[regtime]]', '[[regtime]]'),
(4004, 1, 0, 'forms_manager_default_email', 'text_default_email_title', 'Form has been submitted', '[[regtime]]', '[[regtime]]'),
(4005, 1, 0, 'forms_manager_default_email', 'text_error_message', 'There were some errors in the process.', '[[regtime]]', '[[regtime]]'),
(4006, 1, 0, 'forms_manager_default_email', 'text_success_message', 'Form was submitted successfully!', '[[regtime]]', '[[regtime]]'),
(4007, 1, 0, 'forms_manager_default_email', 'error_required', 'This field is required!', '[[regtime]]', '[[regtime]]'),
(4008, 1, 0, 'forms_manager_forms_manager', 'error_required', 'This field is required!', '[[regtime]]', '[[regtime]]'),
(4009, 1, 0, 'forms_manager_forms_manager', 'error_email_not_valid', 'Not valid email format.', '[[regtime]]', '[[regtime]]'),
(4010, 1, 0, 'forms_manager_forms_manager', 'error_number_not_valid', 'Not valid number format.', '[[regtime]]', '[[regtime]]'),
(4011, 1, 0, 'forms_manager_forms_manager', 'error_phone_not_valid', 'Not valid phone format.', '[[regtime]]', '[[regtime]]'),
(4012, 1, 0, 'forms_manager_forms_manager', 'error_captcha_not_valid', 'Human verification has failed! Please try agan.', '[[regtime]]', '[[regtime]]'),
(4013, 1, 0, 'forms_manager_forms_manager', 'error_file_extension', 'Only files with extension(s) %s is(are) allowed!', '[[regtime]]', '[[regtime]]'),
(4014, 1, 0, 'forms_manager_forms_manager', 'error_min_file_size', 'Minimum file size for upload is %s Mb.', '[[regtime]]', '[[regtime]]'),
(4015, 1, 0, 'forms_manager_forms_manager', 'error_max_file_size', 'Maximum file size for upload is %s Mb.', '[[regtime]]', '[[regtime]]'),
(4016, 1, 0, 'novator_novator', 'novator_name', 'Novator', '[[regtime]]', '[[regtime]]'),
(4017, 1, 0, 'novator_novator', 'text_categories', 'Categories', '[[regtime]]', '[[regtime]]'),
(4018, 1, 0, 'novator_novator', 'text_ratings', 'Ratings', '[[regtime]]', '[[regtime]]'),
(4019, 1, 0, 'novator_novator', 'text_brands', 'Brands', '[[regtime]]', '[[regtime]]'),
(4020, 1, 0, 'novator_novator', 'text_per_page', 'Per Page', '[[regtime]]', '[[regtime]]'),
(4021, 1, 0, 'novator_novator', 'percentage_review', 'of buyers have recommended this.', '[[regtime]]', '[[regtime]]'),
(4022, 1, 0, 'paypal_commerce_paypal_commerce', 'text_title', 'Paypal', '[[regtime]]', '[[regtime]]'),
(4023, 1, 0, 'paypal_commerce_paypal_commerce', 'text_credit_card', 'Credit Card Details', '[[regtime]]', '[[regtime]]'),
(4024, 1, 0, 'paypal_commerce_paypal_commerce', 'text_wait', 'Please wait!', '[[regtime]]', '[[regtime]]'),
(4025, 1, 0, 'paypal_commerce_paypal_commerce', 'error_system', 'Apologies, we have encounter system error. Please try again or contact site administrator!', '[[regtime]]', '[[regtime]]'),
(4026, 1, 0, 'paypal_commerce_paypal_commerce', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4027, 1, 0, 'paypal_commerce_paypal_commerce', 'paypal_commerce_loading', 'Loading...', '[[regtime]]', '[[regtime]]'),
(4028, 1, 0, 'paypal_commerce_paypal_commerce', 'paypal_commerce_table_invoice', 'Invoice', '[[regtime]]', '[[regtime]]'),
(4029, 1, 0, 'paypal_commerce_paypal_commerce', 'paypal_commerce_table_paid', 'Paid', '[[regtime]]', '[[regtime]]'),
(4030, 1, 0, 'paypal_commerce_paypal_commerce', 'text_paypal_commerce_cancel', 'Cancel', '[[regtime]]', '[[regtime]]'),
(4031, 1, 0, 'paypal_commerce_paypal_commerce', 'text_paypal_commerce_continue', 'Continue', '[[regtime]]', '[[regtime]]'),
(4032, 1, 0, 'paypal_commerce_paypal_commerce', 'paypal_commerce_text_download_pdf', ' Download PDF Invoice ', '[[regtime]]', '[[regtime]]'),
(4033, 1, 0, 'paypal_commerce_paypal_commerce', 'paypal_commerce_error_transaction', 'Sorry, your transaction could not be processed', '[[regtime]]', '[[regtime]]'),
(4034, 1, 0, 'paypal_commerce_paypal_commerce', 'paypal_commerce_error_denied', 'Payment Authorization Denied', '[[regtime]]', '[[regtime]]'),
(4035, 1, 0, 'paypal_commerce_paypal_commerce', 'paypal_commerce_error_declined', 'Payment declined', '[[regtime]]', '[[regtime]]'),
(4036, 1, 0, 'paypal_commerce_paypal_commerce', 'paypal_commerce_required_options_warning', 'Please select all required product options before using PayPal.', '[[regtime]]', '[[regtime]]'),
(4037, 1, 0, 'paypal_commerce_paypal_commerce', 'paypal_commerce_3ds_failed', '3D Secure authentication failed or is unavailable. Payment not captured.', '[[regtime]]', '[[regtime]]'),
(4038, 1, 0, 'sola_sola', 'text_title', 'Credit or Debit Card (Processed securely by Sola)', '[[regtime]]', '[[regtime]]'),
(4039, 1, 0, 'sola_sola', 'text_credit_card', 'Credit Card Details', '[[regtime]]', '[[regtime]]'),
(4040, 1, 0, 'sola_sola', 'text_account_number', 'ACH Account Number', '[[regtime]]', '[[regtime]]'),
(4041, 1, 0, 'sola_sola', 'sola_text_your_name', 'Your Name', '[[regtime]]', '[[regtime]]'),
(4042, 1, 0, 'sola_sola', 'sola_text_routing_number', 'Routing Number', '[[regtime]]', '[[regtime]]'),
(4043, 1, 0, 'sola_sola', 'sola_text_check_ach', 'Check (ACH)', '[[regtime]]', '[[regtime]]'),
(4044, 1, 0, 'sola_sola', 'sola_text_ebt', 'EBT Online', '[[regtime]]', '[[regtime]]'),
(4045, 1, 0, 'sola_sola', 'sola_text_ebt_number', 'EBT Card Number', '[[regtime]]', '[[regtime]]'),
(4046, 1, 0, 'sola_sola', 'sola_pinpad_error', 'Oops. Something went wrong. (%s)', '[[regtime]]', '[[regtime]]'),
(4047, 1, 0, 'sola_sola', 'sola_pinpad_error_accu200', 'Cancelled', '[[regtime]]', '[[regtime]]'),
(4048, 1, 0, 'sola_sola', 'sola_pinpad_error_accu400', 'inactivity timeout', '[[regtime]]', '[[regtime]]'),
(4049, 1, 0, 'sola_sola', 'sola_pinpad_error_accu600', 'Invalid Data received by Terminal', '[[regtime]]', '[[regtime]]'),
(4050, 1, 0, 'sola_sola', 'sola_pinpad_error_accu710', 'Terminal Security Issue', '[[regtime]]', '[[regtime]]'),
(4051, 1, 0, 'sola_sola', 'sola_pinpad_error_accu720', 'Terminal Communication Issue', '[[regtime]]', '[[regtime]]'),
(4052, 1, 0, 'sola_sola', 'sola_pinpad_error_accu730', 'Terminal Internal Error', '[[regtime]]', '[[regtime]]'),
(4053, 1, 0, 'sola_sola', 'sola_pinpad_error_accu800', 'General Error Encountered', '[[regtime]]', '[[regtime]]'),
(4054, 1, 0, 'sola_sola', 'sola_ebt_declined', 'EBT card declined', '[[regtime]]', '[[regtime]]'),
(4055, 1, 0, 'stripe_stripe', 'text_title', 'Credit Card / Debit Card (Via Stripe)', '[[regtime]]', '[[regtime]]'),
(4056, 1, 0, 'stripe_stripe', 'text_credit_card', 'Credit Card Details', '[[regtime]]', '[[regtime]]'),
(4057, 1, 0, 'stripe_stripe', 'text_wait', 'Please wait!', '[[regtime]]', '[[regtime]]'),
(4058, 1, 0, 'stripe_stripe', 'entry_cc_owner', 'Name on the card:', '[[regtime]]', '[[regtime]]'),
(4059, 1, 0, 'stripe_stripe', 'entry_cc_number', 'Card Number:', '[[regtime]]', '[[regtime]]'),
(4060, 1, 0, 'stripe_stripe', 'entry_cc_save', 'Save', '[[regtime]]', '[[regtime]]'),
(4061, 1, 0, 'stripe_stripe', 'entry_cc_save_details', 'Credit Card details will be securely saved by Stripe', '[[regtime]]', '[[regtime]]'),
(4062, 1, 0, 'stripe_stripe', 'entry_billing_address', 'for billing address', '[[regtime]]', '[[regtime]]'),
(4063, 1, 0, 'stripe_stripe', 'entry_edit', 'Edit', '[[regtime]]', '[[regtime]]'),
(4064, 1, 0, 'stripe_stripe', 'text_saved_credit_card', 'Select saved credit card', '[[regtime]]', '[[regtime]]'),
(4065, 1, 0, 'stripe_stripe', 'text_delete_saved_credit_card', 'Delete card', '[[regtime]]', '[[regtime]]'),
(4066, 1, 0, 'stripe_stripe', 'text_new_credit_card', 'New card', '[[regtime]]', '[[regtime]]'),
(4067, 1, 0, 'stripe_stripe', 'error_incorrect_number', 'Invalid Credit Card Number', '[[regtime]]', '[[regtime]]'),
(4068, 1, 0, 'stripe_stripe', 'error_incorrect_name', 'Invalid Card Owner Name', '[[regtime]]', '[[regtime]]'),
(4069, 1, 0, 'stripe_stripe', 'error_incorrect_expiration', 'Invalid Card Expiration Date', '[[regtime]]', '[[regtime]]'),
(4070, 1, 0, 'stripe_stripe', 'error_incorrect_cvv', 'Invalid Card CVV', '[[regtime]]', '[[regtime]]'),
(4071, 1, 0, 'stripe_stripe', 'error_system', 'Apologies, we have encounter system error. Please try again or contact site administrator!', '[[regtime]]', '[[regtime]]'),
(4072, 1, 0, 'stripe_stripe', 'error_payment_method', 'Please try again or choose another payment method', '[[regtime]]', '[[regtime]]'),
(4073, 1, 0, 'stripe_stripe', 'stripe_error_guest_subscription', 'You need to <a href="%s">create an account</a> to complete your subscription!', '[[regtime]]', '[[regtime]]'),
(4074, 1, 0, 'ups_ups', 'ups_text_title', 'United Parcel Service', '[[regtime]]', '[[regtime]]'),
(4075, 1, 0, 'ups_ups', 'ups_text_weight', 'Weight:', '[[regtime]]', '[[regtime]]'),
(4076, 1, 0, 'ups_ups', 'ups_text_us_origin_01', 'UPS Next Day Air', '[[regtime]]', '[[regtime]]'),
(4077, 1, 0, 'ups_ups', 'ups_text_us_origin_02', 'UPS 2nd Day Air', '[[regtime]]', '[[regtime]]'),
(4078, 1, 0, 'ups_ups', 'ups_text_us_origin_03', 'UPS Ground', '[[regtime]]', '[[regtime]]'),
(4079, 1, 0, 'ups_ups', 'ups_text_us_origin_07', 'UPS Worldwide Express', '[[regtime]]', '[[regtime]]'),
(4080, 1, 0, 'ups_ups', 'ups_text_us_origin_08', 'UPS Worldwide Expedited', '[[regtime]]', '[[regtime]]'),
(4081, 1, 0, 'ups_ups', 'ups_text_us_origin_11', 'UPS Standard', '[[regtime]]', '[[regtime]]'),
(4082, 1, 0, 'ups_ups', 'ups_text_us_origin_12', 'UPS 3 Day Select', '[[regtime]]', '[[regtime]]'),
(4083, 1, 0, 'ups_ups', 'ups_text_us_origin_13', 'UPS Next Day Air Saver', '[[regtime]]', '[[regtime]]'),
(4084, 1, 0, 'ups_ups', 'ups_text_us_origin_14', 'UPS Next Day Air Early A.M.', '[[regtime]]', '[[regtime]]'),
(4085, 1, 0, 'ups_ups', 'ups_text_us_origin_54', 'UPS Worldwide Express Plus', '[[regtime]]', '[[regtime]]'),
(4086, 1, 0, 'ups_ups', 'ups_text_us_origin_59', 'UPS 2nd Day Air A.M.', '[[regtime]]', '[[regtime]]'),
(4087, 1, 0, 'ups_ups', 'ups_text_us_origin_65', 'UPS Saver', '[[regtime]]', '[[regtime]]'),
(4088, 1, 0, 'ups_ups', 'ups_text_ca_origin_01', 'UPS Express', '[[regtime]]', '[[regtime]]'),
(4089, 1, 0, 'ups_ups', 'ups_text_ca_origin_02', 'UPS Expedited', '[[regtime]]', '[[regtime]]'),
(4090, 1, 0, 'ups_ups', 'ups_text_ca_origin_07', 'UPS Worldwide Express', '[[regtime]]', '[[regtime]]'),
(4091, 1, 0, 'ups_ups', 'ups_text_ca_origin_08', 'UPS Worldwide Expedited', '[[regtime]]', '[[regtime]]'),
(4092, 1, 0, 'ups_ups', 'ups_text_ca_origin_11', 'UPS Standard', '[[regtime]]', '[[regtime]]'),
(4093, 1, 0, 'ups_ups', 'ups_text_ca_origin_12', 'UPS 3 Day Select', '[[regtime]]', '[[regtime]]'),
(4094, 1, 0, 'ups_ups', 'ups_text_ca_origin_13', 'UPS Saver', '[[regtime]]', '[[regtime]]'),
(4095, 1, 0, 'ups_ups', 'ups_text_ca_origin_14', 'UPS Express Early A.M.', '[[regtime]]', '[[regtime]]'),
(4096, 1, 0, 'ups_ups', 'ups_text_ca_origin_54', 'UPS Worldwide Express Plus', '[[regtime]]', '[[regtime]]'),
(4097, 1, 0, 'ups_ups', 'ups_text_ca_origin_65', 'UPS Saver', '[[regtime]]', '[[regtime]]'),
(4098, 1, 0, 'ups_ups', 'ups_text_eu_origin_07', 'UPS Worldwide Express', '[[regtime]]', '[[regtime]]'),
(4099, 1, 0, 'ups_ups', 'ups_text_eu_origin_08', 'UPS Worldwide Expedited', '[[regtime]]', '[[regtime]]'),
(4100, 1, 0, 'ups_ups', 'ups_text_eu_origin_11', 'UPS Standard', '[[regtime]]', '[[regtime]]'),
(4101, 1, 0, 'ups_ups', 'ups_text_eu_origin_54', 'UPS Worldwide Express Plus', '[[regtime]]', '[[regtime]]'),
(4102, 1, 0, 'ups_ups', 'ups_text_eu_origin_65', 'UPS Saver', '[[regtime]]', '[[regtime]]'),
(4103, 1, 0, 'ups_ups', 'ups_text_eu_origin_82', 'UPS Today Standard', '[[regtime]]', '[[regtime]]'),
(4104, 1, 0, 'ups_ups', 'ups_text_eu_origin_83', 'UPS Today Dedicated Courier', '[[regtime]]', '[[regtime]]'),
(4105, 1, 0, 'ups_ups', 'ups_text_eu_origin_84', 'UPS Today Intercity', '[[regtime]]', '[[regtime]]'),
(4106, 1, 0, 'ups_ups', 'ups_text_eu_origin_85', 'UPS Today Express', '[[regtime]]', '[[regtime]]'),
(4107, 1, 0, 'ups_ups', 'ups_text_eu_origin_86', 'UPS Today Express Saver', '[[regtime]]', '[[regtime]]'),
(4108, 1, 0, 'ups_ups', 'ups_text_eu_origin_01', 'UPS Next Day Air', '[[regtime]]', '[[regtime]]'),
(4109, 1, 0, 'ups_ups', 'ups_text_eu_origin_02', 'UPS 2nd Day Air', '[[regtime]]', '[[regtime]]'),
(4110, 1, 0, 'ups_ups', 'ups_text_eu_origin_03', 'UPS Ground', '[[regtime]]', '[[regtime]]'),
(4111, 1, 0, 'ups_ups', 'ups_text_eu_origin_14', 'UPS Next Day Air Early A.M.', '[[regtime]]', '[[regtime]]'),
(4112, 1, 0, 'ups_ups', 'ups_text_mx_origin_07', 'UPS Express', '[[regtime]]', '[[regtime]]'),
(4113, 1, 0, 'ups_ups', 'ups_text_mx_origin_08', 'UPS Expedited', '[[regtime]]', '[[regtime]]'),
(4114, 1, 0, 'ups_ups', 'ups_text_mx_origin_54', 'UPS Express Plus', '[[regtime]]', '[[regtime]]'),
(4115, 1, 0, 'ups_ups', 'ups_text_mx_origin_65', 'UPS Saver', '[[regtime]]', '[[regtime]]'),
(4116, 1, 0, 'ups_ups', 'ups_text_other_origin_07', 'UPS Express', '[[regtime]]', '[[regtime]]'),
(4117, 1, 0, 'ups_ups', 'ups_text_other_origin_08', 'UPS Worldwide Expedited', '[[regtime]]', '[[regtime]]'),
(4118, 1, 0, 'ups_ups', 'ups_text_other_origin_11', 'UPS Standard', '[[regtime]]', '[[regtime]]'),
(4119, 1, 0, 'ups_ups', 'ups_text_other_origin_54', 'UPS Worldwide Express Plus', '[[regtime]]', '[[regtime]]'),
(4120, 1, 0, 'ups_ups', 'ups_text_other_origin_65', 'UPS Saver', '[[regtime]]', '[[regtime]]'),
(4121, 1, 0, 'usps_usps', 'text_title', 'United States Postal Service', '[[regtime]]', '[[regtime]]'),
(4122, 1, 0, 'usps_usps', 'text_weight', 'Weight:', '[[regtime]]', '[[regtime]]'),
(4123, 1, 0, 'usps_usps', 'text_eta', 'Estimated Time:', '[[regtime]]', '[[regtime]]'),
(4124, 1, 0, 'usps_usps', 'usps_track', 'Track USPS Shipment', '[[regtime]]', '[[regtime]]'),
(4125, 1, 0, 'usps_usps', 'text_domestic_0', 'First-Class', '[[regtime]]', '[[regtime]]'),
(4126, 1, 0, 'usps_usps', 'text_domestic_1', 'Priority Mail', '[[regtime]]', '[[regtime]]'),
(4127, 1, 0, 'usps_usps', 'text_domestic_2', 'Priority Mail Express', '[[regtime]]', '[[regtime]]'),
(4128, 1, 0, 'usps_usps', 'text_domestic_3', 'Parcel Select', '[[regtime]]', '[[regtime]]'),
(4129, 1, 0, 'usps_usps', 'text_domestic_4', 'Bound Printed Matter', '[[regtime]]', '[[regtime]]'),
(4130, 1, 0, 'usps_usps', 'text_domestic_5', 'Media Mail', '[[regtime]]', '[[regtime]]'),
(4131, 1, 0, 'usps_usps', 'text_domestic_6', 'Library Mail', '[[regtime]]', '[[regtime]]'),
(4132, 1, 0, 'usps_usps', 'text_domestic_7', 'USPS Ground Advantage', '[[regtime]]', '[[regtime]]'),
(4133, 1, 0, 'usps_usps', 'text_domestic_12', 'First-Class Postcard Stamped', '[[regtime]]', '[[regtime]]'),
(4134, 1, 0, 'usps_usps', 'text_domestic_13', 'Express Mail Flat-Rate Envelope', '[[regtime]]', '[[regtime]]'),
(4135, 1, 0, 'usps_usps', 'text_domestic_16', 'Priority Mail Flat-Rate Envelope', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(4136, 1, 0, 'usps_usps', 'text_domestic_17', 'Priority Mail Regular Flat-Rate Box', '[[regtime]]', '[[regtime]]'),
(4137, 1, 0, 'usps_usps', 'text_domestic_18', 'Priority Mail Keys and IDs', '[[regtime]]', '[[regtime]]'),
(4138, 1, 0, 'usps_usps', 'text_domestic_19', 'First-Class Keys and IDs', '[[regtime]]', '[[regtime]]'),
(4139, 1, 0, 'usps_usps', 'text_domestic_22', 'Priority Mail Flat-Rate Large Box', '[[regtime]]', '[[regtime]]'),
(4140, 1, 0, 'usps_usps', 'text_domestic_23', 'Express Mail Sunday/Holiday', '[[regtime]]', '[[regtime]]'),
(4141, 1, 0, 'usps_usps', 'text_domestic_25', 'Express Mail Flat-Rate Envelope Sunday/Holiday', '[[regtime]]', '[[regtime]]'),
(4142, 1, 0, 'usps_usps', 'text_domestic_27', 'Express Mail Flat-Rate Envelope Hold For Pickup', '[[regtime]]', '[[regtime]]'),
(4143, 1, 0, 'usps_usps', 'text_domestic_28', 'Priority Mail Small Flat-Rate Box', '[[regtime]]', '[[regtime]]'),
(4144, 1, 0, 'usps_usps', 'text_international_1', 'Priority Mail Express International', '[[regtime]]', '[[regtime]]'),
(4145, 1, 0, 'usps_usps', 'text_international_2', 'Priority Mail International', '[[regtime]]', '[[regtime]]'),
(4146, 1, 0, 'usps_usps', 'text_international_3', 'Global Express Guaranteed (GXG)', '[[regtime]]', '[[regtime]]'),
(4147, 1, 0, 'usps_usps', 'text_international_4', 'First-Class Package International Service', '[[regtime]]', '[[regtime]]'),
(4148, 1, 0, 'usps_usps', 'text_international_5', 'Global Express Guaranteed Document used', '[[regtime]]', '[[regtime]]'),
(4149, 1, 0, 'usps_usps', 'text_international_6', 'Global Express Guaranteed Non-Document Rectangular shape', '[[regtime]]', '[[regtime]]'),
(4150, 1, 0, 'usps_usps', 'text_international_7', 'Global Express Guaranteed Non-Document Non-Rectangular', '[[regtime]]', '[[regtime]]'),
(4151, 1, 0, 'usps_usps', 'text_international_8', 'Priority Mail Flat Rate Envelope', '[[regtime]]', '[[regtime]]'),
(4152, 1, 0, 'usps_usps', 'text_international_9', 'Priority Mail Flat Rate Box', '[[regtime]]', '[[regtime]]'),
(4153, 1, 0, 'usps_usps', 'text_international_10', 'Express Mail International Flat Rate Envelope', '[[regtime]]', '[[regtime]]'),
(4154, 1, 0, 'usps_usps', 'text_international_11', 'Priority Mail Large Flat Rate Box', '[[regtime]]', '[[regtime]]'),
(4155, 1, 0, 'usps_usps', 'text_international_12', 'Global Express Guaranteed Envelope', '[[regtime]]', '[[regtime]]'),
(4156, 1, 0, 'usps_usps', 'text_international_13', 'First Class Mail International Letters', '[[regtime]]', '[[regtime]]'),
(4157, 1, 0, 'usps_usps', 'text_international_14', 'First Class Mail International Flats', '[[regtime]]', '[[regtime]]'),
(4158, 1, 0, 'usps_usps', 'text_international_15', 'First Class Mail International Parcels', '[[regtime]]', '[[regtime]]'),
(4159, 1, 0, 'usps_usps', 'text_international_16', 'Priority Mail Small Flat Rate Box', '[[regtime]]', '[[regtime]]'),
(4160, 1, 0, 'usps_usps', 'text_international_21', 'Postcards', '[[regtime]]', '[[regtime]]'),
(4161, 1, 0, 'account_account', 'heading_title', 'My Account', '[[regtime]]', '[[regtime]]'),
(4162, 1, 0, 'account_account', 'text_account_dashboard', 'Account Dashboard', '[[regtime]]', '[[regtime]]'),
(4163, 1, 0, 'account_account', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4164, 1, 0, 'account_account', 'text_my_account', 'My Account', '[[regtime]]', '[[regtime]]'),
(4165, 1, 0, 'account_account', 'text_my_orders', 'My Orders', '[[regtime]]', '[[regtime]]'),
(4166, 1, 0, 'account_account', 'text_my_notifications', 'Notifications', '[[regtime]]', '[[regtime]]'),
(4167, 1, 0, 'account_account', 'text_information', 'Edit account details', '[[regtime]]', '[[regtime]]'),
(4168, 1, 0, 'account_account', 'text_password', 'Change password', '[[regtime]]', '[[regtime]]'),
(4169, 1, 0, 'account_account', 'text_address', 'Manage Address Book', '[[regtime]]', '[[regtime]]'),
(4170, 1, 0, 'account_account', 'text_history', 'Order history', '[[regtime]]', '[[regtime]]'),
(4171, 1, 0, 'account_account', 'text_transactions', 'Balance History', '[[regtime]]', '[[regtime]]'),
(4172, 1, 0, 'account_account', 'text_download', 'Downloads', '[[regtime]]', '[[regtime]]'),
(4173, 1, 0, 'account_account', 'text_newsletter', 'Newsletter Subscription', '[[regtime]]', '[[regtime]]'),
(4174, 1, 0, 'account_account', 'text_account_wishlist', 'My wish list', '[[regtime]]', '[[regtime]]'),
(4175, 1, 0, 'account_address', 'heading_title', 'Address Book', '[[regtime]]', '[[regtime]]'),
(4176, 1, 0, 'account_address', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4177, 1, 0, 'account_address', 'text_address_book', 'Address Book Entries', '[[regtime]]', '[[regtime]]'),
(4178, 1, 0, 'account_address', 'text_edit_address', 'Edit Address', '[[regtime]]', '[[regtime]]'),
(4179, 1, 0, 'account_address', 'text_insert', 'Your address has been successfully inserted', '[[regtime]]', '[[regtime]]'),
(4180, 1, 0, 'account_address', 'text_update', 'Your address has been successfully updated', '[[regtime]]', '[[regtime]]'),
(4181, 1, 0, 'account_address', 'text_delete', 'Your address has been successfully deleted', '[[regtime]]', '[[regtime]]'),
(4182, 1, 0, 'account_address', 'error_delete', 'Error: you must have at least one address!', '[[regtime]]', '[[regtime]]'),
(4183, 1, 0, 'account_address', 'error_default', 'Error: you can not delete your default address!', '[[regtime]]', '[[regtime]]'),
(4184, 1, 0, 'account_create', 'heading_title', 'Create Account', '[[regtime]]', '[[regtime]]'),
(4185, 1, 0, 'account_create', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4186, 1, 0, 'account_create', 'text_create', 'Register', '[[regtime]]', '[[regtime]]'),
(4187, 1, 0, 'account_create', 'text_account_already', 'If you already have an account with us, please login at the <a style="text-decoration: underline" href="%s">login page</a>.', '[[regtime]]', '[[regtime]]'),
(4188, 1, 0, 'account_create', 'text_your_details', 'Your Personal Details', '[[regtime]]', '[[regtime]]'),
(4189, 1, 0, 'account_create', 'text_your_address', 'Your Address', '[[regtime]]', '[[regtime]]'),
(4190, 1, 0, 'account_create', 'text_newsletter', 'Newsletter', '[[regtime]]', '[[regtime]]'),
(4191, 1, 0, 'account_create', 'text_your_password', 'Your Password', '[[regtime]]', '[[regtime]]'),
(4192, 1, 0, 'account_create', 'text_login_details', 'Login Details', '[[regtime]]', '[[regtime]]'),
(4193, 1, 0, 'account_create', 'text_agree', 'I have read and agree to the', '[[regtime]]', '[[regtime]]'),
(4194, 1, 0, 'account_create', 'entry_firstname', 'First Name:', '[[regtime]]', '[[regtime]]'),
(4195, 1, 0, 'account_create', 'entry_lastname', 'Last Name:', '[[regtime]]', '[[regtime]]'),
(4196, 1, 0, 'account_create', 'entry_email', 'E-Mail:', '[[regtime]]', '[[regtime]]'),
(4197, 1, 0, 'account_create', 'entry_newsletter', 'Subscribe:', '[[regtime]]', '[[regtime]]'),
(4198, 1, 0, 'account_create', 'entry_password', 'Password:', '[[regtime]]', '[[regtime]]'),
(4199, 1, 0, 'account_create', 'entry_confirm', 'Password Confirm:', '[[regtime]]', '[[regtime]]'),
(4200, 1, 0, 'account_create', 'error_exists', 'Error: E-Mail Address is already registered!', '[[regtime]]', '[[regtime]]'),
(4201, 1, 0, 'account_create', 'error_loginname_notunique', 'This login name is not available. Try different login name!', '[[regtime]]', '[[regtime]]'),
(4202, 1, 0, 'account_create', 'error_email_exists', 'Email Address is Already Exists!', '[[regtime]]', '[[regtime]]'),
(4203, 1, 0, 'account_create', 'error_telephone', 'Telephone must be between 3 and 32 numeric only characters!', '[[regtime]]', '[[regtime]]'),
(4204, 1, 0, 'account_create', 'error_password', 'Password must be between 4 and 20 characters!', '[[regtime]]', '[[regtime]]'),
(4205, 1, 0, 'account_create', 'error_confirm', 'Password confirmation does not match password!', '[[regtime]]', '[[regtime]]'),
(4206, 1, 0, 'account_create', 'error_agree', 'Error: You must agree to the %s!', '[[regtime]]', '[[regtime]]'),
(4207, 1, 0, 'account_create', 'text_full_register', 'Become a customer and register with your details', '[[regtime]]', '[[regtime]]'),
(4208, 1, 0, 'account_create', 'text_subscribe_register', 'Become a newsletter subscriber', '[[regtime]]', '[[regtime]]'),
(4209, 1, 0, 'account_create', 'text_success_subscribe_heading', 'You have subscribed successfully!', '[[regtime]]', '[[regtime]]'),
(4210, 1, 0, 'account_create', 'text_success_subscribe', 'Success: Your newsletter subscription has been successfully created!', '[[regtime]]', '[[regtime]]'),
(4211, 1, 0, 'account_create', 'error_subscriber_exists', 'Our records indicate that you have an account with us. Please login to your account to manage your newsletter subscription.', '[[regtime]]', '[[regtime]]'),
(4212, 1, 0, 'account_create', 'text_new_customer', 'New customer registration approval is pending', '[[regtime]]', '[[regtime]]'),
(4213, 1, 0, 'account_create', 'text_pending_customer_approval', 'Customer %s has registered with new account. Action of approval is required! Click to view #admin#rt=sale/customer/update&customer_id=%s', '[[regtime]]', '[[regtime]]'),
(4214, 1, 0, 'account_create', 'text_pending_subscriber_approval', 'Subscriber %s has registered with new account. Action of approval is required! Click to view #admin#rt=sale/customer/update&customer_id=%s', '[[regtime]]', '[[regtime]]'),
(4215, 1, 0, 'account_download', 'heading_title', 'Account Downloads', '[[regtime]]', '[[regtime]]'),
(4216, 1, 0, 'account_download', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4217, 1, 0, 'account_download', 'text_downloads', 'Downloads', '[[regtime]]', '[[regtime]]'),
(4218, 1, 0, 'account_download', 'text_order', 'Order ID:', '[[regtime]]', '[[regtime]]'),
(4219, 1, 0, 'account_download', 'text_date_added', 'Date Added:', '[[regtime]]', '[[regtime]]'),
(4220, 1, 0, 'account_download', 'text_date_purchased', 'Date Purchased:', '[[regtime]]', '[[regtime]]'),
(4221, 1, 0, 'account_download', 'text_name', 'Name:', '[[regtime]]', '[[regtime]]'),
(4222, 1, 0, 'account_download', 'text_remaining', 'Remaining:', '[[regtime]]', '[[regtime]]'),
(4223, 1, 0, 'account_download', 'text_size', 'Size:', '[[regtime]]', '[[regtime]]'),
(4224, 1, 0, 'account_download', 'text_download', 'Download', '[[regtime]]', '[[regtime]]'),
(4225, 1, 0, 'account_download', 'text_error', 'You have not made any previous downloadable orders!', '[[regtime]]', '[[regtime]]'),
(4226, 1, 0, 'account_download', 'text_expire_date', 'Expire Date:', '[[regtime]]', '[[regtime]]'),
(4227, 1, 0, 'account_download', 'text_expired', 'Expired', '[[regtime]]', '[[regtime]]'),
(4228, 1, 0, 'account_download', 'text_pending', 'Pending', '[[regtime]]', '[[regtime]]'),
(4229, 1, 0, 'account_download', 'text_unavailable', 'Unavailable', '[[regtime]]', '[[regtime]]'),
(4230, 1, 0, 'account_download', 'text_reached_limit', 'Reached Limit', '[[regtime]]', '[[regtime]]'),
(4231, 1, 0, 'account_download', 'error_download_not_exists', 'Requested file does not exists!', '[[regtime]]', '[[regtime]]'),
(4232, 1, 0, 'account_edit', 'heading_title', 'My Account Information', '[[regtime]]', '[[regtime]]'),
(4233, 1, 0, 'account_edit', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4234, 1, 0, 'account_edit', 'text_edit', 'Edit Information', '[[regtime]]', '[[regtime]]'),
(4235, 1, 0, 'account_edit', 'text_your_details', 'Your Personal Details', '[[regtime]]', '[[regtime]]'),
(4236, 1, 0, 'account_edit', 'text_success', 'Success: Your account has been successfully updated.', '[[regtime]]', '[[regtime]]'),
(4237, 1, 0, 'account_edit', 'entry_loginname', 'Login Name:', '[[regtime]]', '[[regtime]]'),
(4238, 1, 0, 'account_edit', 'entry_firstname', 'First Name:', '[[regtime]]', '[[regtime]]'),
(4239, 1, 0, 'account_edit', 'entry_lastname', 'Last Name:', '[[regtime]]', '[[regtime]]'),
(4240, 1, 0, 'account_edit', 'entry_date_of_birth', 'Date Of Birth:', '[[regtime]]', '[[regtime]]'),
(4241, 1, 0, 'account_edit', 'entry_email', 'E-Mail:', '[[regtime]]', '[[regtime]]'),
(4242, 1, 0, 'account_edit', 'entry_telephone', 'Telephone:', '[[regtime]]', '[[regtime]]'),
(4243, 1, 0, 'account_edit', 'entry_fax', 'Fax:', '[[regtime]]', '[[regtime]]'),
(4244, 1, 0, 'account_edit', 'error_exists', 'Error: E-Mail address is already registered!', '[[regtime]]', '[[regtime]]'),
(4245, 1, 0, 'account_edit', 'error_loginname', 'Login name must be alphanumeric only and between 5 and 64 characters!', '[[regtime]]', '[[regtime]]'),
(4246, 1, 0, 'account_edit', 'error_loginname_notunique', 'This login name is not available. Try different login name!', '[[regtime]]', '[[regtime]]'),
(4247, 1, 0, 'account_edit', 'error_firstname', 'First Name must be between 1 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(4248, 1, 0, 'account_edit', 'error_lastname', 'Last Name must be between 1 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(4249, 1, 0, 'account_edit', 'error_email', 'E-Mail Address does not appear to be valid!', '[[regtime]]', '[[regtime]]'),
(4250, 1, 0, 'account_edit', 'error_telephone', 'Telephone must be between 3 and 32 numeric only characters!', '[[regtime]]', '[[regtime]]'),
(4251, 1, 0, 'account_edit', 'loginname_update_required', 'Your login name is the same as your email. To keep your account protected, please create a new unique login name', '[[regtime]]', '[[regtime]]'),
(4252, 1, 0, 'account_forgotten', 'heading_title', 'Forgot Your Password?', '[[regtime]]', '[[regtime]]'),
(4253, 1, 0, 'account_forgotten', 'heading_title_loginname', 'Forgot Your Login Name?', '[[regtime]]', '[[regtime]]'),
(4254, 1, 0, 'account_forgotten', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4255, 1, 0, 'account_forgotten', 'text_forgotten', 'Forgotten Password', '[[regtime]]', '[[regtime]]'),
(4256, 1, 0, 'account_forgotten', 'text_your_email', 'Your E-Mail Address', '[[regtime]]', '[[regtime]]'),
(4257, 1, 0, 'account_forgotten', 'text_email', 'Enter the e-mail address associated with your account. Click submit to have your password emailed to you', '[[regtime]]', '[[regtime]]'),
(4258, 1, 0, 'account_forgotten', 'text_loginname_email', 'Enter the login name and e-mail address associated with your account. Click submit to request password reset', '[[regtime]]', '[[regtime]]'),
(4259, 1, 0, 'account_forgotten', 'text_lastname_email', 'Enter the last name and e-mail address associated with your account. Click submit to have your login name emailed to you', '[[regtime]]', '[[regtime]]'),
(4260, 1, 0, 'account_forgotten', 'text_success', 'Success: Password reset link has been sent to your e-mail address.', '[[regtime]]', '[[regtime]]'),
(4261, 1, 0, 'account_forgotten', 'text_success_loginname', 'Success: Your login name reminder has been sent to your e-mail address.', '[[regtime]]', '[[regtime]]'),
(4262, 1, 0, 'account_forgotten', 'entry_loginname', 'Login Name:', '[[regtime]]', '[[regtime]]'),
(4263, 1, 0, 'account_forgotten', 'entry_lastname', 'Last Name:', '[[regtime]]', '[[regtime]]'),
(4264, 1, 0, 'account_forgotten', 'entry_email', 'E-Mail Address:', '[[regtime]]', '[[regtime]]'),
(4265, 1, 0, 'account_forgotten', 'error_email', 'Error: The Email address was not provided or not found in our records, please try again!', '[[regtime]]', '[[regtime]]'),
(4266, 1, 0, 'account_forgotten', 'error_loginname', 'Error: The Login name was not provided or not found in our records, please try again!', '[[regtime]]', '[[regtime]]'),
(4267, 1, 0, 'account_forgotten', 'error_lastname', 'Error: The Last name was not provided or not found in our records, please try again!', '[[regtime]]', '[[regtime]]'),
(4268, 1, 0, 'account_forgotten', 'error_not_found', 'Error: No records found matching information your provided, please check your information and try again!', '[[regtime]]', '[[regtime]]'),
(4269, 1, 0, 'account_forgotten', 'text_forgotten_loginname', 'Forgotten Login Name', '[[regtime]]', '[[regtime]]'),
(4270, 1, 0, 'account_history', 'heading_title', 'My Order History', '[[regtime]]', '[[regtime]]'),
(4271, 1, 0, 'account_history', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4272, 1, 0, 'account_history', 'text_history', 'Order History', '[[regtime]]', '[[regtime]]'),
(4273, 1, 0, 'account_history', 'text_order', 'Order ID:', '[[regtime]]', '[[regtime]]'),
(4274, 1, 0, 'account_history', 'text_status', 'Status:', '[[regtime]]', '[[regtime]]'),
(4275, 1, 0, 'account_history', 'text_date_added', 'Date Added:', '[[regtime]]', '[[regtime]]'),
(4276, 1, 0, 'account_history', 'text_customer', 'Customer:', '[[regtime]]', '[[regtime]]'),
(4277, 1, 0, 'account_history', 'text_products', 'Products:', '[[regtime]]', '[[regtime]]'),
(4278, 1, 0, 'account_history', 'text_total', 'Total:', '[[regtime]]', '[[regtime]]'),
(4279, 1, 0, 'account_history', 'text_error', 'You have not made any previous orders!', '[[regtime]]', '[[regtime]]'),
(4280, 1, 0, 'account_login', 'heading_title', 'Account Login', '[[regtime]]', '[[regtime]]'),
(4281, 1, 0, 'account_login', 'text_account', 'Register Account', '[[regtime]]', '[[regtime]]'),
(4282, 1, 0, 'account_login', 'text_login', 'Login', '[[regtime]]', '[[regtime]]'),
(4283, 1, 0, 'account_login', 'text_i_am_new_customer', 'I am a new customer.', '[[regtime]]', '[[regtime]]'),
(4284, 1, 0, 'account_login', 'text_checkout', 'Checkout Options:', '[[regtime]]', '[[regtime]]'),
(4285, 1, 0, 'account_login', 'text_guest', 'Guest Checkout', '[[regtime]]', '[[regtime]]'),
(4286, 1, 0, 'account_login', 'text_create_account', 'By creating an account you will be able to shop faster, be up to date on an order''s status, and keep track of the orders you have previously made.', '[[regtime]]', '[[regtime]]'),
(4287, 1, 0, 'account_login', 'text_returning_customer', 'Returning Customer', '[[regtime]]', '[[regtime]]'),
(4288, 1, 0, 'account_login', 'text_i_am_returning_customer', 'I am a returning customer.', '[[regtime]]', '[[regtime]]'),
(4289, 1, 0, 'account_login', 'text_forgotten_login', 'Forgot your login?', '[[regtime]]', '[[regtime]]'),
(4290, 1, 0, 'account_login', 'text_forgotten_password', 'Forgot your password?', '[[regtime]]', '[[regtime]]'),
(4291, 1, 0, 'account_login', 'entry_loginname', 'Login Name:', '[[regtime]]', '[[regtime]]'),
(4292, 1, 0, 'account_login', 'entry_email_address', 'E-Mail Address:', '[[regtime]]', '[[regtime]]'),
(4293, 1, 0, 'account_login', 'entry_password', 'Password:', '[[regtime]]', '[[regtime]]'),
(4294, 1, 0, 'account_login', 'error_login', 'Error: Incorrect login or password provided.', '[[regtime]]', '[[regtime]]'),
(4295, 1, 0, 'account_login', 'text_success_activated', 'Success: Your account was activated successfully. Please login with your credentials.', '[[regtime]]', '[[regtime]]'),
(4296, 1, 0, 'account_login', 'text_already_activated', 'Your account is already activated. Please login with your credentials.', '[[regtime]]', '[[regtime]]'),
(4297, 1, 0, 'account_login', 'text_resend_activation_email', 'Error: Your email address was not yet confirmed. To resend new confirmation email please click this <a href=" %s ">link</a>', '[[regtime]]', '[[regtime]]'),
(4298, 1, 0, 'account_login', 'welcome_unauth_customer', 'Welcome %s, please login to your account or <a href="%s">continue browsing as a guest</a>', '[[regtime]]', '[[regtime]]'),
(4299, 1, 0, 'account_logout', 'heading_title', 'Account Logout', '[[regtime]]', '[[regtime]]'),
(4300, 1, 0, 'account_logout', 'text_message', '<p>You have been logged off your account. It is now safe to leave the computer.</p><p>Your shopping cart has been saved, the items inside it will be restored whenever you log back into your account.</p>', '[[regtime]]', '[[regtime]]'),
(4301, 1, 0, 'account_logout', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4302, 1, 0, 'account_logout', 'text_logout', 'Logout', '[[regtime]]', '[[regtime]]'),
(4303, 1, 0, 'account_newsletter', 'heading_title', 'Newsletter Subscription', '[[regtime]]', '[[regtime]]'),
(4304, 1, 0, 'account_newsletter', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4305, 1, 0, 'account_newsletter', 'text_newsletter', 'Newsletter', '[[regtime]]', '[[regtime]]'),
(4306, 1, 0, 'account_newsletter', 'text_success', 'Success: Your newsletter subscription has been successfully updated!', '[[regtime]]', '[[regtime]]'),
(4307, 1, 0, 'account_newsletter', 'entry_newsletter', 'Subscribe:', '[[regtime]]', '[[regtime]]'),
(4308, 1, 0, 'account_newsletter', 'text_customer_registration', 'Customer Registration', '[[regtime]]', '[[regtime]]'),
(4309, 1, 0, 'account_newsletter', 'entry_captcha', 'Enter code: ', '[[regtime]]', '[[regtime]]'),
(4310, 1, 0, 'account_newsletter', 'error_captcha', 'Human verification has failed! Please try agan.', '[[regtime]]', '[[regtime]]'),
(4311, 1, 0, 'account_notification', 'heading_title', 'Notifications and Newsletter', '[[regtime]]', '[[regtime]]'),
(4312, 1, 0, 'account_notification', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4313, 1, 0, 'account_notification', 'text_notifications', 'Notifications', '[[regtime]]', '[[regtime]]'),
(4314, 1, 0, 'account_notification', 'text_success', 'Success: Your notification settings has been successfully updated!', '[[regtime]]', '[[regtime]]'),
(4315, 1, 0, 'account_notification', 'text_sendpoint', 'Notifications', '[[regtime]]', '[[regtime]]'),
(4316, 1, 0, 'account_order_details', 'heading_title', 'Order Details', '[[regtime]]', '[[regtime]]'),
(4317, 1, 0, 'account_order_details', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4318, 1, 0, 'account_order_details', 'text_history', 'Order History', '[[regtime]]', '[[regtime]]'),
(4319, 1, 0, 'account_order_details', 'text_invoice', 'Invoice', '[[regtime]]', '[[regtime]]'),
(4320, 1, 0, 'account_order_details', 'text_invoice_id', 'Invoice ID', '[[regtime]]', '[[regtime]]'),
(4321, 1, 0, 'account_order_details', 'text_order_id', 'Order ID', '[[regtime]]', '[[regtime]]'),
(4322, 1, 0, 'account_order_details', 'text_email', 'E-Mail', '[[regtime]]', '[[regtime]]'),
(4323, 1, 0, 'account_order_details', 'text_telephone', 'Telephone', '[[regtime]]', '[[regtime]]'),
(4324, 1, 0, 'account_order_details', 'text_mobile_phone', 'Mobile Phone:', '[[regtime]]', '[[regtime]]'),
(4325, 1, 0, 'account_order_details', 'text_fax', 'Fax', '[[regtime]]', '[[regtime]]'),
(4326, 1, 0, 'account_order_details', 'text_shipping_address', 'Shipping Address', '[[regtime]]', '[[regtime]]'),
(4327, 1, 0, 'account_order_details', 'text_shipping_method', 'Shipping Method', '[[regtime]]', '[[regtime]]'),
(4328, 1, 0, 'account_order_details', 'text_payment_address', 'Payment Address', '[[regtime]]', '[[regtime]]'),
(4329, 1, 0, 'account_order_details', 'text_payment_method', 'Payment Method', '[[regtime]]', '[[regtime]]'),
(4330, 1, 0, 'account_order_details', 'text_order_history', 'Order History', '[[regtime]]', '[[regtime]]'),
(4331, 1, 0, 'account_order_details', 'text_product', 'Product', '[[regtime]]', '[[regtime]]'),
(4332, 1, 0, 'account_order_details', 'text_model', 'Model', '[[regtime]]', '[[regtime]]'),
(4333, 1, 0, 'account_order_details', 'text_sku', 'SKU', '[[regtime]]', '[[regtime]]'),
(4334, 1, 0, 'account_order_details', 'text_quantity', 'Quantity', '[[regtime]]', '[[regtime]]'),
(4335, 1, 0, 'account_order_details', 'text_price', 'Unit Price', '[[regtime]]', '[[regtime]]'),
(4336, 1, 0, 'account_order_details', 'text_total', 'Total', '[[regtime]]', '[[regtime]]'),
(4337, 1, 0, 'account_order_details', 'text_comment', 'Order Comments', '[[regtime]]', '[[regtime]]'),
(4338, 1, 0, 'account_order_details', 'text_image', 'Image', '[[regtime]]', '[[regtime]]'),
(4339, 1, 0, 'account_order_details', 'text_error', 'The order you have requested could not be found!', '[[regtime]]', '[[regtime]]'),
(4340, 1, 0, 'account_order_details', 'column_date_added', 'Date Added', '[[regtime]]', '[[regtime]]'),
(4341, 1, 0, 'account_order_details', 'column_status', 'Status', '[[regtime]]', '[[regtime]]'),
(4342, 1, 0, 'account_order_details', 'column_comment', 'Customer''s order comment', '[[regtime]]', '[[regtime]]'),
(4343, 1, 0, 'account_order_details', 'text_order_cancelation', 'Request Cancellation of Order', '[[regtime]]', '[[regtime]]'),
(4344, 1, 0, 'account_order_details', 'text_request_cancellation_from_customer', 'Request an Order cancellation from Customer ', '[[regtime]]', '[[regtime]]'),
(4345, 1, 0, 'account_order_details', 'text_order_cancelation_confirm', 'Your cancellation request may not be made in some cases, for example, when the goods have been shipped. Continue?', '[[regtime]]', '[[regtime]]'),
(4346, 1, 0, 'account_order_details', 'text_order_cancelation_success', 'Order cancellation request has been submitted', '[[regtime]]', '[[regtime]]'),
(4347, 1, 0, 'account_order_details', 'text_order_cancelation_message_title', 'Order #%s cancellation request', '[[regtime]]', '[[regtime]]'),
(4348, 1, 0, 'account_order_details', 'text_order_cancelation_message_body', 'Customer %s has requested order cancellation for order #%s . To review go to %s', '[[regtime]]', '[[regtime]]'),
(4349, 1, 0, 'account_order_details', 'error_email', 'E-Mail Address does not appear to be valid!', '[[regtime]]', '[[regtime]]'),
(4350, 1, 0, 'account_order_details', 'error_order_id', 'Order ID is required field!', '[[regtime]]', '[[regtime]]'),
(4351, 1, 0, 'account_password', 'heading_title', 'Change Password', '[[regtime]]', '[[regtime]]'),
(4352, 1, 0, 'account_password', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4353, 1, 0, 'account_password', 'text_password', 'To update your password, please provide current and new password details', '[[regtime]]', '[[regtime]]'),
(4354, 1, 0, 'account_password', 'text_success', 'Success: Your password has been successfully updated.', '[[regtime]]', '[[regtime]]'),
(4355, 1, 0, 'account_password', 'entry_current_password', 'Current Password:', '[[regtime]]', '[[regtime]]'),
(4356, 1, 0, 'account_password', 'entry_password', 'New Password:', '[[regtime]]', '[[regtime]]'),
(4357, 1, 0, 'account_password', 'entry_confirm', 'New Password Confirm:', '[[regtime]]', '[[regtime]]'),
(4358, 1, 0, 'account_password', 'error_current_password', 'Your current password is incorrect! Please try again.', '[[regtime]]', '[[regtime]]'),
(4359, 1, 0, 'account_password', 'error_password', 'Password must be between 4 and 20 characters!', '[[regtime]]', '[[regtime]]'),
(4360, 1, 0, 'account_password', 'error_confirm', 'Password confirmation does not match password!', '[[regtime]]', '[[regtime]]'),
(4361, 1, 0, 'account_success', 'heading_title', 'Your Account Has Been Created!', '[[regtime]]', '[[regtime]]'),
(4362, 1, 0, 'account_success', 'text_message', '<p>Congratulations! Your new account has been successfully created!</p> <p>You can now take advantage of member privileges to enhance your online shopping experience with us.</p> <p>If you have ANY questions about the operation of this online shop, please email the store owner.</p> <p>A confirmation has been sent to the provided email address. If you have not received it within the hour, please <a href="%s">contact us</a>.</p>', '[[regtime]]', '[[regtime]]'),
(4363, 1, 0, 'account_success', 'text_approval', '<p>Thank you for registering with %s!</p><p>You will be notified by email once your account has been activated by the store owner.</p><p>If you have ANY questions about the operation of this online shop, please <a href="%s">contact the store owner</a>.</p>', '[[regtime]]', '[[regtime]]'),
(4364, 1, 0, 'account_success', 'heading_title_activation', 'Your Account Has Been Created But Activation Required. Please Follow instructions.', '[[regtime]]', '[[regtime]]'),
(4365, 1, 0, 'account_success', 'text_activate', '<p>Thank you for registering with %s!</p><p>You will be notified via email with your account activation instructions. You must click the link provided in the email to activate your account. If you do not receive email, please check in your junk or spam folders. </p><p>If you have ANY questions about the operation of this online shop, please <a href="%s">contact the store owner</a>.</p>', '[[regtime]]', '[[regtime]]'),
(4366, 1, 0, 'account_success', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4367, 1, 0, 'account_success', 'text_success', 'Success', '[[regtime]]', '[[regtime]]'),
(4368, 1, 0, 'account_transactions', 'heading_title', 'Balance History', '[[regtime]]', '[[regtime]]'),
(4369, 1, 0, 'account_transactions', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4370, 1, 0, 'account_transactions', 'text_transactions', 'Balance History', '[[regtime]]', '[[regtime]]'),
(4371, 1, 0, 'account_transactions', 'text_order', 'Order Number', '[[regtime]]', '[[regtime]]'),
(4372, 1, 0, 'account_transactions', 'text_transaction_id', 'ID', '[[regtime]]', '[[regtime]]'),
(4373, 1, 0, 'account_transactions', 'text_transaction_type', 'Type', '[[regtime]]', '[[regtime]]'),
(4374, 1, 0, 'account_transactions', 'text_transaction_description', 'Description', '[[regtime]]', '[[regtime]]'),
(4375, 1, 0, 'account_transactions', 'text_date_added', 'Date Created', '[[regtime]]', '[[regtime]]'),
(4376, 1, 0, 'account_transactions', 'text_debit', 'Debit', '[[regtime]]', '[[regtime]]'),
(4377, 1, 0, 'account_transactions', 'text_credit', 'Credit', '[[regtime]]', '[[regtime]]'),
(4378, 1, 0, 'account_transactions', 'text_total', 'Total', '[[regtime]]', '[[regtime]]'),
(4379, 1, 0, 'account_transactions', 'text_error', 'You have no balance history yet.', '[[regtime]]', '[[regtime]]'),
(4380, 1, 0, 'account_unsubscribe', 'heading_title', 'Your Has Been successfully unsubscribed !', '[[regtime]]', '[[regtime]]'),
(4381, 1, 0, 'account_unsubscribe', 'text_message', 'You have been successfully unsubscribed from email communications.', '[[regtime]]', '[[regtime]]'),
(4382, 1, 0, 'account_unsubscribe', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4383, 1, 0, 'account_unsubscribe', 'text_success', 'Success', '[[regtime]]', '[[regtime]]'),
(4384, 1, 0, 'account_wishlist', 'heading_title', 'My wish list', '[[regtime]]', '[[regtime]]'),
(4385, 1, 0, 'account_wishlist', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4386, 1, 0, 'account_wishlist', 'text_empty_wishlist', 'Wish list is empty', '[[regtime]]', '[[regtime]]'),
(4387, 1, 0, 'account_wishlist', 'button_cart', 'View Cart', '[[regtime]]', '[[regtime]]'),
(4388, 1, 0, 'account_wishlist', 'button_continue', 'Continue Shopping', '[[regtime]]', '[[regtime]]'),
(4389, 1, 0, 'account_wishlist', 'column_image', 'Image', '[[regtime]]', '[[regtime]]'),
(4390, 1, 0, 'account_wishlist', 'column_name', 'Name', '[[regtime]]', '[[regtime]]'),
(4391, 1, 0, 'account_wishlist', 'column_model', 'Model', '[[regtime]]', '[[regtime]]'),
(4392, 1, 0, 'account_wishlist', 'column_added', 'Added to wish list', '[[regtime]]', '[[regtime]]'),
(4393, 1, 0, 'account_wishlist', 'column_price', 'Unit Price', '[[regtime]]', '[[regtime]]'),
(4394, 1, 0, 'account_wishlist', 'column_actions', 'Actions', '[[regtime]]', '[[regtime]]'),
(4395, 1, 0, 'blocks_bestseller', 'heading_title', 'Bestsellers', '[[regtime]]', '[[regtime]]'),
(4396, 1, 0, 'blocks_bestseller', 'heading_subtitle', 'See Best Selling Products', '[[regtime]]', '[[regtime]]'),
(4397, 1, 0, 'blocks_bestseller', 'text_stars', '%s out of 5 Stars!', '[[regtime]]', '[[regtime]]'),
(4398, 1, 0, 'blocks_cart', 'heading_title', 'Shopping Cart', '[[regtime]]', '[[regtime]]'),
(4399, 1, 0, 'blocks_cart', 'text_subtotal', 'Sub-Total:', '[[regtime]]', '[[regtime]]'),
(4400, 1, 0, 'blocks_cart', 'text_empty', '0 items', '[[regtime]]', '[[regtime]]'),
(4401, 1, 0, 'blocks_cart', 'text_confirm', 'Confirm?', '[[regtime]]', '[[regtime]]'),
(4402, 1, 0, 'blocks_cart', 'text_remove', 'Remove', '[[regtime]]', '[[regtime]]'),
(4403, 1, 0, 'blocks_cart', 'text_view', 'View Cart', '[[regtime]]', '[[regtime]]'),
(4404, 1, 0, 'blocks_cart', 'text_checkout', 'Checkout', '[[regtime]]', '[[regtime]]'),
(4405, 1, 0, 'blocks_cart', 'text_items', 'Items', '[[regtime]]', '[[regtime]]'),
(4406, 1, 0, 'blocks_category', 'heading_title', 'Categories', '[[regtime]]', '[[regtime]]'),
(4407, 1, 0, 'blocks_content', 'heading_title', 'Information', '[[regtime]]', '[[regtime]]'),
(4408, 1, 0, 'blocks_content', 'text_contact', 'Contact Us', '[[regtime]]', '[[regtime]]'),
(4409, 1, 0, 'blocks_content', 'text_sitemap', 'Site Map', '[[regtime]]', '[[regtime]]'),
(4410, 1, 0, 'blocks_content', 'heading_title_new', 'New publications', '[[regtime]]', '[[regtime]]'),
(4411, 1, 0, 'blocks_currency', 'heading_title', 'Currency', '[[regtime]]', '[[regtime]]'),
(4412, 1, 0, 'blocks_featured', 'heading_title', 'Featured', '[[regtime]]', '[[regtime]]'),
(4413, 1, 0, 'blocks_featured', 'heading_subtitle', 'See Our Most featured Products', '[[regtime]]', '[[regtime]]'),
(4414, 1, 0, 'blocks_featured', 'text_stars', '%s out of 5 Stars!', '[[regtime]]', '[[regtime]]'),
(4415, 1, 0, 'blocks_language', 'heading_title', 'Language', '[[regtime]]', '[[regtime]]'),
(4416, 1, 0, 'blocks_latest', 'heading_title', 'Latest Products', '[[regtime]]', '[[regtime]]'),
(4417, 1, 0, 'blocks_latest', 'heading_subtitle', 'See New Products', '[[regtime]]', '[[regtime]]'),
(4418, 1, 0, 'blocks_latest', 'text_stars', '%s out of 5 Stars!', '[[regtime]]', '[[regtime]]'),
(4419, 1, 0, 'blocks_manufacturer', 'heading_title', 'Brands', '[[regtime]]', '[[regtime]]'),
(4420, 1, 0, 'blocks_menu', 'heading_title', 'Main Menu', '[[regtime]]', '[[regtime]]'),
(4421, 1, 0, 'blocks_newsletter_signup', 'heading_title', 'Newsletter Signup', '[[regtime]]', '[[regtime]]'),
(4422, 1, 0, 'blocks_newsletter_signup', 'text_signup', 'Sign up to Our Newsletter &amp; get attractive Offers by subscribing to our newsletters.', '[[regtime]]', '[[regtime]]'),
(4423, 1, 0, 'blocks_newsletter_signup', 'text_sign_in', 'Sign In', '[[regtime]]', '[[regtime]]'),
(4424, 1, 0, 'blocks_newsletter_signup', 'text_subscribe', 'Subscribe to Newsletter', '[[regtime]]', '[[regtime]]'),
(4425, 1, 0, 'blocks_newsletter_signup', 'button_subscribe', 'Subscribe', '[[regtime]]', '[[regtime]]'),
(4426, 1, 0, 'blocks_order_summary', 'heading_title', 'Order Summary', '[[regtime]]', '[[regtime]]'),
(4427, 1, 0, 'blocks_order_summary', 'text_subtotal', 'Sub-Total:', '[[regtime]]', '[[regtime]]'),
(4428, 1, 0, 'blocks_order_summary', 'text_empty', '0 items', '[[regtime]]', '[[regtime]]'),
(4429, 1, 0, 'blocks_order_summary', 'text_confirm', 'Confirm?', '[[regtime]]', '[[regtime]]'),
(4430, 1, 0, 'blocks_order_summary', 'text_remove', 'Remove', '[[regtime]]', '[[regtime]]'),
(4431, 1, 0, 'blocks_order_summary', 'text_view', 'View Cart', '[[regtime]]', '[[regtime]]'),
(4432, 1, 0, 'blocks_order_summary', 'text_checkout', 'Checkout', '[[regtime]]', '[[regtime]]'),
(4433, 1, 0, 'blocks_order_summary', 'text_items', 'Items', '[[regtime]]', '[[regtime]]'),
(4434, 1, 0, 'blocks_search', 'heading_title', 'Search', '[[regtime]]', '[[regtime]]'),
(4435, 1, 0, 'blocks_search', 'text_keyword', 'Search Keywords', '[[regtime]]', '[[regtime]]'),
(4436, 1, 0, 'blocks_search', 'text_advanced', 'Advanced Search', '[[regtime]]', '[[regtime]]'),
(4437, 1, 0, 'blocks_search', 'text_category', 'All Categories', '[[regtime]]', '[[regtime]]'),
(4438, 1, 0, 'blocks_special', 'heading_title', 'Specials', '[[regtime]]', '[[regtime]]'),
(4439, 1, 0, 'blocks_special', 'heading_subtitle', 'See Products On Sale', '[[regtime]]', '[[regtime]]'),
(4440, 1, 0, 'blocks_special', 'text_stars', '%s out of 5 Stars!', '[[regtime]]', '[[regtime]]'),
(4441, 1, 0, 'blocks_store_hours', 'heading_title', 'Store Hours', '[[regtime]]', '[[regtime]]'),
(4442, 1, 0, 'blocks_store_hours', 'closed', 'Closed', '[[regtime]]', '[[regtime]]'),
(4443, 1, 0, 'blocks_store_hours', 'open', 'Open', '[[regtime]]', '[[regtime]]'),
(4444, 1, 0, 'blocks_store_hours', 'sunday', 'Sunday', '[[regtime]]', '[[regtime]]'),
(4445, 1, 0, 'blocks_store_hours', 'monday', 'Monday', '[[regtime]]', '[[regtime]]'),
(4446, 1, 0, 'blocks_store_hours', 'tuesday', 'Tuesday', '[[regtime]]', '[[regtime]]'),
(4447, 1, 0, 'blocks_store_hours', 'wednesday', 'Wednesday', '[[regtime]]', '[[regtime]]'),
(4448, 1, 0, 'blocks_store_hours', 'thursday', 'Thursday', '[[regtime]]', '[[regtime]]'),
(4449, 1, 0, 'blocks_store_hours', 'friday', 'Friday', '[[regtime]]', '[[regtime]]'),
(4450, 1, 0, 'blocks_store_hours', 'saturday', 'Saturday', '[[regtime]]', '[[regtime]]'),
(4451, 1, 0, 'blocks_viewed', 'text_recently_viewed', 'Recently Viewed', '[[regtime]]', '[[regtime]]'),
(4452, 1, 0, 'checkout_cart', 'heading_title', 'Shopping Cart', '[[regtime]]', '[[regtime]]'),
(4453, 1, 0, 'checkout_cart', 'text_basket', 'Cart', '[[regtime]]', '[[regtime]]'),
(4454, 1, 0, 'checkout_cart', 'text_sub_total', 'Sub-Total:', '[[regtime]]', '[[regtime]]'),
(4455, 1, 0, 'checkout_cart', 'text_weight', 'Cart Weight:', '[[regtime]]', '[[regtime]]'),
(4456, 1, 0, 'checkout_cart', 'text_error', 'Your shopping cart is empty!', '[[regtime]]', '[[regtime]]'),
(4457, 1, 0, 'checkout_cart', 'column_remove', 'Remove', '[[regtime]]', '[[regtime]]'),
(4458, 1, 0, 'checkout_cart', 'column_image', 'Image', '[[regtime]]', '[[regtime]]'),
(4459, 1, 0, 'checkout_cart', 'column_name', 'Name', '[[regtime]]', '[[regtime]]'),
(4460, 1, 0, 'checkout_cart', 'column_model', 'Model', '[[regtime]]', '[[regtime]]'),
(4461, 1, 0, 'checkout_cart', 'column_sku', 'SKU', '[[regtime]]', '[[regtime]]'),
(4462, 1, 0, 'checkout_cart', 'column_quantity', 'Quantity', '[[regtime]]', '[[regtime]]'),
(4463, 1, 0, 'checkout_cart', 'column_price', 'Unit Price', '[[regtime]]', '[[regtime]]'),
(4464, 1, 0, 'checkout_cart', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(4465, 1, 0, 'checkout_cart', 'text_continue_shopping', 'Continue Shopping', '[[regtime]]', '[[regtime]]'),
(4466, 1, 0, 'checkout_cart', 'text_coupon_codes', 'Apply Coupon Code', '[[regtime]]', '[[regtime]]'),
(4467, 1, 0, 'checkout_cart', 'text_estimate_shipping_tax', 'Estimate Shipping & Taxes', '[[regtime]]', '[[regtime]]'),
(4468, 1, 0, 'checkout_cart', 'text_estimate_country', 'Country and State', '[[regtime]]', '[[regtime]]'),
(4469, 1, 0, 'checkout_cart', 'text_estimate_postcode', 'ZIP/Post Code', '[[regtime]]', '[[regtime]]'),
(4470, 1, 0, 'checkout_cart', 'button_text_estimate', 'Estimate', '[[regtime]]', '[[regtime]]'),
(4471, 1, 0, 'checkout_cart', 'text_estimate_shipments', 'Shipments', '[[regtime]]', '[[regtime]]'),
(4472, 1, 0, 'checkout_cart', 'error_coupon', 'Error: Coupon is either invalid, expired or reached it''s usage limit!', '[[regtime]]', '[[regtime]]'),
(4473, 1, 0, 'checkout_cart', 'error_stock', 'Products marked with *** are not available in the desired quantity or out of stock!', '[[regtime]]', '[[regtime]]'),
(4474, 1, 0, 'checkout_cart', 'error_required_options', 'Please select all required options!', '[[regtime]]', '[[regtime]]'),
(4475, 1, 0, 'checkout_cart', 'error_order_minimum', 'Your order sub-total amount does not meet minimum amount of %s required. Please add more products to your cart!', '[[regtime]]', '[[regtime]]'),
(4476, 1, 0, 'checkout_cart', 'error_order_maximum', 'Your order sub-total amount exceeds maximum amount of %s allowed per order. Please remove some items from your cart!', '[[regtime]]', '[[regtime]]'),
(4477, 1, 0, 'checkout_cart', 'error_empty_file_data', 'File data is corrupted or empty.', '[[regtime]]', '[[regtime]]'),
(4478, 1, 0, 'checkout_cart', 'error_empty_file_name', 'File name is empty!', '[[regtime]]', '[[regtime]]'),
(4479, 1, 0, 'checkout_cart', 'error_file_extension', 'Only files with extension(s) %s is(are) allowed!', '[[regtime]]', '[[regtime]]'),
(4480, 1, 0, 'checkout_cart', 'error_min_file_size', 'Minimum file size for upload is %s Kb.', '[[regtime]]', '[[regtime]]'),
(4481, 1, 0, 'checkout_cart', 'error_max_file_size', 'Maximum file size for upload is %s Kb.', '[[regtime]]', '[[regtime]]'),
(4482, 1, 0, 'checkout_cart', 'text_coupon_success', 'Success: Your coupon discount has been applied!', '[[regtime]]', '[[regtime]]'),
(4483, 1, 0, 'checkout_cart', 'text_coupon_removal', 'Success: Coupon has been removed!', '[[regtime]]', '[[regtime]]'),
(4484, 1, 0, 'checkout_cart', 'error_quantity_maximum', 'Allowed product''s quantity exceeds. Quantity was set to maximum.', '[[regtime]]', '[[regtime]]'),
(4485, 1, 0, 'checkout_cart', 'error_quantity_minimum', 'Allowed product''s quantity is below minimum required. Quantity was set to minimum amount.', '[[regtime]]', '[[regtime]]'),
(4486, 1, 0, 'checkout_fast_checkout', 'text_basket', 'Cart', '[[regtime]]', '[[regtime]]'),
(4487, 1, 0, 'checkout_fast_checkout', 'text_edit_basket', 'Edit Cart', '[[regtime]]', '[[regtime]]'),
(4488, 1, 0, 'checkout_fast_checkout', 'text_accept_agree', 'By clicking Confirm Order, you accept and agree to all terms of', '[[regtime]]', '[[regtime]]'),
(4489, 1, 0, 'checkout_fast_checkout', 'text_cart_items', 'Items in your cart', '[[regtime]]', '[[regtime]]'),
(4490, 1, 0, 'checkout_fast_checkout', 'text_shipping', 'Shipping ', '[[regtime]]', '[[regtime]]'),
(4491, 1, 0, 'checkout_fast_checkout', 'text_edit_shipping', 'Edit Shipping', '[[regtime]]', '[[regtime]]'),
(4492, 1, 0, 'checkout_fast_checkout', 'text_payment', 'Payment', '[[regtime]]', '[[regtime]]'),
(4493, 1, 0, 'checkout_fast_checkout', 'text_edit_payment', 'Edit Payment', '[[regtime]]', '[[regtime]]'),
(4494, 1, 0, 'checkout_fast_checkout', 'text_confirm', 'Confirm', '[[regtime]]', '[[regtime]]'),
(4495, 1, 0, 'checkout_fast_checkout', 'text_shipping_address', 'Shipping Address', '[[regtime]]', '[[regtime]]'),
(4496, 1, 0, 'checkout_fast_checkout', 'text_shipping_method', 'Shipping Method', '[[regtime]]', '[[regtime]]'),
(4497, 1, 0, 'checkout_fast_checkout', 'text_payment_address', 'Payment Address', '[[regtime]]', '[[regtime]]'),
(4498, 1, 0, 'checkout_fast_checkout', 'text_payment_method', 'Payment Method', '[[regtime]]', '[[regtime]]'),
(4499, 1, 0, 'checkout_fast_checkout', 'text_change', 'Change', '[[regtime]]', '[[regtime]]'),
(4500, 1, 0, 'checkout_fast_checkout', 'text_comment', 'Your Comments', '[[regtime]]', '[[regtime]]'),
(4501, 1, 0, 'checkout_fast_checkout', 'text_discount', 'Discount Coupon', '[[regtime]]', '[[regtime]]'),
(4502, 1, 0, 'checkout_fast_checkout', 'column_product', 'Product', '[[regtime]]', '[[regtime]]'),
(4503, 1, 0, 'checkout_fast_checkout', 'column_model', 'Model', '[[regtime]]', '[[regtime]]'),
(4504, 1, 0, 'checkout_fast_checkout', 'column_quantity', 'Quantity', '[[regtime]]', '[[regtime]]'),
(4505, 1, 0, 'checkout_fast_checkout', 'column_price', 'Price', '[[regtime]]', '[[regtime]]'),
(4506, 1, 0, 'checkout_fast_checkout', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(4507, 1, 0, 'checkout_fast_checkout', 'text_add_coupon', 'Edit Coupon', '[[regtime]]', '[[regtime]]'),
(4508, 1, 0, 'checkout_fast_checkout', 'fast_checkout_name', 'Fast Checkout', '[[regtime]]', '[[regtime]]'),
(4509, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_fast_checkout_title', 'Fast Checkout', '[[regtime]]', '[[regtime]]'),
(4510, 1, 0, 'checkout_fast_checkout', 'heading_title', 'Fast Checkout', '[[regtime]]', '[[regtime]]'),
(4511, 1, 0, 'checkout_fast_checkout', 'fast_checkout_buy_now', 'Buy Now', '[[regtime]]', '[[regtime]]'),
(4512, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_incorrect_request', 'Oops! Incorrect request.', '[[regtime]]', '[[regtime]]'),
(4513, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_handler', 'Unable to locate payment handler! Please check files %s or %s', '[[regtime]]', '[[regtime]]'),
(4514, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_no_handler', 'No payment processor available.', '[[regtime]]', '[[regtime]]'),
(4515, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_unknown_payment', 'Unknown payment!', '[[regtime]]', '[[regtime]]'),
(4516, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_unexpected', 'Unexpected error has occurred! Please try again.', '[[regtime]]', '[[regtime]]'),
(4517, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_unexpected_log', 'Unexpected error has occurred. Unable to build order data based on array: %s', '[[regtime]]', '[[regtime]]'),
(4518, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_handler_object', 'Unable to confirm order. Payment handler is not object.', '[[regtime]]', '[[regtime]]'),
(4519, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_system_issue', 'Oops! System issue. Contact site administrator.', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(4520, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_no_payment', 'No payments are available.', '[[regtime]]', '[[regtime]]'),
(4521, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_product_option', 'Product option error. %s', '[[regtime]]', '[[regtime]]'),
(4522, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_no_address', 'No addresses found in your account! Please add an address in your account.', '[[regtime]]', '[[regtime]]'),
(4523, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_low_balance', 'You do not have sufficient account balance for this order!', '[[regtime]]', '[[regtime]]'),
(4524, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_balance_pay', 'There is a issue processing account credit payment! Please try again.', '[[regtime]]', '[[regtime]]'),
(4525, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_payment_address', 'Payment address is missing or not selected.', '[[regtime]]', '[[regtime]]'),
(4526, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_payment_unavailable', 'Payment is not available in your location.', '[[regtime]]', '[[regtime]]'),
(4527, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_shipping_address', 'Delivery address is missing or not selected.', '[[regtime]]', '[[regtime]]'),
(4528, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_shipping_method', 'Delivery method was not selected.', '[[regtime]]', '[[regtime]]'),
(4529, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_phone', 'Your contact phone number is not provided.', '[[regtime]]', '[[regtime]]'),
(4530, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_owner', 'Your name is not provided.', '[[regtime]]', '[[regtime]]'),
(4531, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_email', 'Your email is not provided or invalid.', '[[regtime]]', '[[regtime]]'),
(4532, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_card_number', 'Credit card number is not provided.', '[[regtime]]', '[[regtime]]'),
(4533, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_cvv', 'CVV number is not provided.', '[[regtime]]', '[[regtime]]'),
(4534, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_expire', 'Credit cart expiration date is not provided or invalid.', '[[regtime]]', '[[regtime]]'),
(4535, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_balance_apply', 'Credit cart expiration date is not provided or invalid.', '[[regtime]]', '[[regtime]]'),
(4536, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_account_created', 'Account has been created and login instruction sent to your email.', '[[regtime]]', '[[regtime]]'),
(4537, 1, 0, 'checkout_fast_checkout', 'fast_checkout_mail_login_password', 'Your Login Name: %s <br>Your Password: %s', '[[regtime]]', '[[regtime]]'),
(4538, 1, 0, 'checkout_fast_checkout', 'fast_checkout_order_success_message', 'Success! Your order has been successfully created!', '[[regtime]]', '[[regtime]]'),
(4539, 1, 0, 'checkout_fast_checkout', 'fast_checkout_order_processing_message', 'Success! Order now processing!', '[[regtime]]', '[[regtime]]'),
(4540, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_payment_address', 'Payment Address', '[[regtime]]', '[[regtime]]'),
(4541, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_shipping_address', 'Delivery Address', '[[regtime]]', '[[regtime]]'),
(4542, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_select_shipping_method', 'Choose a delivery method', '[[regtime]]', '[[regtime]]'),
(4543, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_pay_with', 'Pay With:', '[[regtime]]', '[[regtime]]'),
(4544, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_credit_card', 'Credit Card', '[[regtime]]', '[[regtime]]'),
(4545, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_account_credit', 'Account Credit (%s)', '[[regtime]]', '[[regtime]]'),
(4546, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_pay', 'Pay', '[[regtime]]', '[[regtime]]'),
(4547, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_enter_cc_details', 'Enter Credit Card details below', '[[regtime]]', '[[regtime]]'),
(4548, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_your_balance', 'Your account credit balance is', '[[regtime]]', '[[regtime]]'),
(4549, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_pay_from_balance', 'Pay %s with credit', '[[regtime]]', '[[regtime]]'),
(4550, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_telephone_placeholder', 'Contact telephone Number Ex. +1.212.555.5555', '[[regtime]]', '[[regtime]]'),
(4551, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_same_as_shipping_address', 'Same for delivery', '[[regtime]]', '[[regtime]]'),
(4552, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_enter_address', 'Continue', '[[regtime]]', '[[regtime]]'),
(4553, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_card_number', 'Card number', '[[regtime]]', '[[regtime]]'),
(4554, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_bill_me_monthly', 'Bill me monthly', '[[regtime]]', '[[regtime]]'),
(4555, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_create_account', 'Create account', '[[regtime]]', '[[regtime]]'),
(4556, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_please_login', 'Please Login with details below', '[[regtime]]', '[[regtime]]'),
(4557, 1, 0, 'checkout_fast_checkout', 'fast_checkout_button_login', 'LOGIN', '[[regtime]]', '[[regtime]]'),
(4558, 1, 0, 'checkout_fast_checkout', 'fast_checkout_button_reset_login', 'Register / Reset login', '[[regtime]]', '[[regtime]]'),
(4559, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_login', 'Login', '[[regtime]]', '[[regtime]]'),
(4560, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_logout', 'Logout', '[[regtime]]', '[[regtime]]'),
(4561, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_address', 'Address', '[[regtime]]', '[[regtime]]'),
(4562, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_new_customer', 'I am new customer', '[[regtime]]', '[[regtime]]'),
(4563, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_loading', 'Loading...', '[[regtime]]', '[[regtime]]'),
(4564, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_order_is_completed', 'Order is completed!', '[[regtime]]', '[[regtime]]'),
(4565, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_thank_you', 'Thank you for your order!', '[[regtime]]', '[[regtime]]'),
(4566, 1, 0, 'checkout_fast_checkout', 'fast_checkout_button_start_download', 'Start Download', '[[regtime]]', '[[regtime]]'),
(4567, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_order_downloads', 'Order Downloads', '[[regtime]]', '[[regtime]]'),
(4568, 1, 0, 'checkout_fast_checkout', 'fast_checkout_button_order_details', 'Order Details', '[[regtime]]', '[[regtime]]'),
(4569, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_select_delivery', 'Please select the delivery options', '[[regtime]]', '[[regtime]]'),
(4570, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_select_payment', 'Please select the payment option', '[[regtime]]', '[[regtime]]'),
(4571, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_order_download_pending', 'Product download in your order is not yet available. Please wait for order verification!', '[[regtime]]', '[[regtime]]'),
(4572, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_info_duplicate_order', 'It looks like you just placed a different order. <a href="%s">See order details</a>', '[[regtime]]', '[[regtime]]'),
(4573, 1, 0, 'checkout_fast_checkout', 'fast_checkout_email_start_download', 'You can access your download(s) with the link below.', '[[regtime]]', '[[regtime]]'),
(4574, 1, 0, 'checkout_fast_checkout', 'fast_checkout_email_order_downloads', 'You can access order downloads with the link below.', '[[regtime]]', '[[regtime]]'),
(4575, 1, 0, 'checkout_fast_checkout', 'fast_checkout_download_subject', 'Your order download.', '[[regtime]]', '[[regtime]]'),
(4576, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_apply', 'Apply', '[[regtime]]', '[[regtime]]'),
(4577, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_remove', 'Remove', '[[regtime]]', '[[regtime]]'),
(4578, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_coupon_code', 'Enter coupon code', '[[regtime]]', '[[regtime]]'),
(4579, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_order_comment', 'Add the order comment', '[[regtime]]', '[[regtime]]'),
(4580, 1, 0, 'checkout_fast_checkout', 'fast_checkout_error_coupon', 'Coupon is invalid or expired!', '[[regtime]]', '[[regtime]]'),
(4581, 1, 0, 'checkout_fast_checkout', 'fast_checkout_back_to_cart', 'Back to Cart', '[[regtime]]', '[[regtime]]'),
(4582, 1, 0, 'checkout_fast_checkout', 'fast_checkout_order_summary', 'Order Summary', '[[regtime]]', '[[regtime]]'),
(4583, 1, 0, 'checkout_fast_checkout', 'fast_checkout_no_shipments_available', 'No shipments are available.', '[[regtime]]', '[[regtime]]'),
(4584, 1, 0, 'checkout_fast_checkout', 'fast_checkout_telephone_placeholder', 'Your phone number', '[[regtime]]', '[[regtime]]'),
(4585, 1, 0, 'checkout_fast_checkout', 'fast_checkout_email_placeholder', 'Your email', '[[regtime]]', '[[regtime]]'),
(4586, 1, 0, 'checkout_fast_checkout', 'button_history', 'History', '[[regtime]]', '[[regtime]]'),
(4587, 1, 0, 'checkout_fast_checkout', 'error_postcode', 'Postcode incorrect', '[[regtime]]', '[[regtime]]'),
(4588, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_comment_placeholder', 'Add an order comment', '[[regtime]]', '[[regtime]]'),
(4589, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_not_enough_stock', 'Not Enough Stock', '[[regtime]]', '[[regtime]]'),
(4590, 1, 0, 'checkout_fast_checkout', 'order_confirm', 'Order Confirm', '[[regtime]]', '[[regtime]]'),
(4591, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_login_or_email', 'Login name or Email Address', '[[regtime]]', '[[regtime]]'),
(4592, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_password', 'Password', '[[regtime]]', '[[regtime]]'),
(4593, 1, 0, 'checkout_fast_checkout', 'fast_checkout_text_authenticating', 'Authenticating ... ', '[[regtime]]', '[[regtime]]'),
(4594, 1, 0, 'checkout_fast_checkout', 'text_message_account', '<p>Your order #%s has been created!</p>\n			<p>You can view your order details by going to the <a href="%s">invoice page</a>.</p>\n			<p>Please direct any questions you have to the <a href="%s">store owner</a>.</p>\n			<p>Thank you for shopping with us!</p>', '[[regtime]]', '[[regtime]]'),
(4595, 1, 0, 'checkout_fast_checkout', 'text_message_guest', '<p>Your order has been successfully processed!</p>\n			<p>You can view your order details by going to the <a href="%s">invoice page</a>.</p>\n			<p>Please direct any questions you have to the <a href="%s">store owner</a>.</p>\n			<p>Thank you for shopping with us!</p>', '[[regtime]]', '[[regtime]]'),
(4596, 1, 0, 'checkout_fast_checkout', 'text_guest', 'Guest Checkout', '[[regtime]]', '[[regtime]]'),
(4597, 1, 0, 'checkout_fast_checkout', 'text_success', 'Success', '[[regtime]]', '[[regtime]]'),
(4598, 1, 0, 'checkout_fast_checkout', 'text_message_failed_order', 'Oops! We have experienced some issue with your transaction. Your order will be verified manually by administrator.', '[[regtime]]', '[[regtime]]'),
(4599, 1, 0, 'checkout_fast_checkout', 'text_title_failed_order_to_admin', 'Failed order #%s', '[[regtime]]', '[[regtime]]'),
(4600, 1, 0, 'checkout_fast_checkout', 'text_message_failed_order_to_admin', 'Failed or missing response from payment verification. Manual verification is required!', '[[regtime]]', '[[regtime]]'),
(4601, 1, 0, 'checkout_fast_checkout', 'text_see_more_cart_products', 'See more cart products', '[[regtime]]', '[[regtime]]'),
(4602, 1, 0, 'checkout_fast_checkout', 'warning_order_changed', 'Order has been changed. Please review your cart.', '[[regtime]]', '[[regtime]]'),
(4603, 1, 0, 'checkout_fast_checkout', 'text_add_address', 'Add Address', '[[regtime]]', '[[regtime]]'),
(4604, 1, 0, 'common_footer', 'text_powered_by', 'Powered By ', '[[regtime]]', '[[regtime]]'),
(4605, 1, 0, 'common_header', 'text_home', 'Home', '[[regtime]]', '[[regtime]]'),
(4606, 1, 0, 'common_header', 'text_special', 'Special Offers', '[[regtime]]', '[[regtime]]'),
(4607, 1, 0, 'common_header', 'text_contact', 'Contact', '[[regtime]]', '[[regtime]]'),
(4608, 1, 0, 'common_header', 'text_sitemap', 'Sitemap', '[[regtime]]', '[[regtime]]'),
(4609, 1, 0, 'common_header', 'text_bookmark', 'Bookmark', '[[regtime]]', '[[regtime]]'),
(4610, 1, 0, 'common_header', 'text_account', 'Account', '[[regtime]]', '[[regtime]]'),
(4611, 1, 0, 'common_header', 'text_login', 'Login', '[[regtime]]', '[[regtime]]'),
(4612, 1, 0, 'common_header', 'text_logout', 'Logoff', '[[regtime]]', '[[regtime]]'),
(4613, 1, 0, 'common_header', 'text_cart', 'Cart', '[[regtime]]', '[[regtime]]'),
(4614, 1, 0, 'common_header', 'text_checkout', 'Checkout', '[[regtime]]', '[[regtime]]'),
(4615, 1, 0, 'common_header', 'text_keyword', 'Keywords', '[[regtime]]', '[[regtime]]'),
(4616, 1, 0, 'common_header', 'text_advanced', 'Advanced Search', '[[regtime]]', '[[regtime]]'),
(4617, 1, 0, 'common_header', 'text_category', 'All Categories', '[[regtime]]', '[[regtime]]'),
(4618, 1, 0, 'common_header', 'entry_search', 'Search:', '[[regtime]]', '[[regtime]]'),
(4619, 1, 0, 'common_header', 'text_welcome', 'Welcome back', '[[regtime]]', '[[regtime]]'),
(4620, 1, 0, 'common_header', 'text_not', 'Not', '[[regtime]]', '[[regtime]]'),
(4621, 1, 0, 'common_header', 'text_login_or_register', 'Login or register', '[[regtime]]', '[[regtime]]'),
(4622, 1, 0, 'common_im', 'im_text_notification', ' Notification ', '[[regtime]]', '[[regtime]]'),
(4623, 1, 0, 'common_im', 'im_error_mail_address', ' Email Address %s is not valid! ', '[[regtime]]', '[[regtime]]'),
(4624, 1, 0, 'common_im', 'im_protocol_email_title', ' E-mail ', '[[regtime]]', '[[regtime]]'),
(4625, 1, 0, 'common_im', 'im_protocol_sms_title', ' SMS ', '[[regtime]]', '[[regtime]]'),
(4626, 1, 0, 'common_im', 'im_protocol_sms_empty_warn', ' SMS notifications are not possible. Mobile number is not saved in your account records. ', '[[regtime]]', '[[regtime]]'),
(4627, 1, 0, 'common_im', 'im_sendpoint_name_order_update', ' Order Update ', '[[regtime]]', '[[regtime]]'),
(4628, 1, 0, 'common_im', 'im_sendpoint_name_order_update_note', ' Select to receive notifications about your orders'' updates.', '[[regtime]]', '[[regtime]]'),
(4629, 1, 0, 'common_im', 'im_order_update_text_to_admin', ' Order #%s has been updated! Order status ID %s', '[[regtime]]', '[[regtime]]'),
(4630, 1, 0, 'common_im', 'im_order_update_text_to_customer', ' Your order #%s Updated. New Order Status is %s ', '[[regtime]]', '[[regtime]]'),
(4631, 1, 0, 'common_im', 'im_new_order_text_to_admin', ' New Order #%s has been placed!', '[[regtime]]', '[[regtime]]'),
(4632, 1, 0, 'common_im', 'im_new_customer_text_to_admin', ' New Customer #%s %s has been registered!', '[[regtime]]', '[[regtime]]'),
(4633, 1, 0, 'common_im', 'im_new_subscriber_text_to_admin', ' New Subscriber #%s %s has been registered!', '[[regtime]]', '[[regtime]]'),
(4634, 1, 0, 'common_im', 'im_sendpoint_name_customer_account_update', ' Account Update ', '[[regtime]]', '[[regtime]]'),
(4635, 1, 0, 'common_im', 'im_sendpoint_name_customer_account_update_note', ' Select to receive notifications about your account updates.', '[[regtime]]', '[[regtime]]'),
(4636, 1, 0, 'common_im', 'im_customer_account_update_text_to_customer', ' Your account has been updated! If you did not do any changes, please contact site owner ', '[[regtime]]', '[[regtime]]'),
(4637, 1, 0, 'common_im', 'im_customer_account_update_email_to_customer', ' Your account email address was changed to %s! If you did not do this change, please contact site owner ', '[[regtime]]', '[[regtime]]'),
(4638, 1, 0, 'common_im', 'im_customer_account_update_login_to_customer', ' Your account login name was changed to %s! If you did not do this change, please contact site owner ', '[[regtime]]', '[[regtime]]'),
(4639, 1, 0, 'common_im', 'im_customer_account_update_password_to_customer', ' Your account password has been changed! If you did not do this change, please contact site owner ', '[[regtime]]', '[[regtime]]'),
(4640, 1, 0, 'common_im', 'im_customer_contact_admin_text', ' You''ve got new enquiry from customer (%s, %s)! ', '[[regtime]]', '[[regtime]]'),
(4641, 1, 0, 'common_im', 'im_sendpoint_name_newsletter', ' Newsletters ', '[[regtime]]', '[[regtime]]'),
(4642, 1, 0, 'common_im', 'im_sendpoint_name_newsletter_note', ' Select to receive notifications about our products and service updates.', '[[regtime]]', '[[regtime]]'),
(4643, 1, 0, 'common_im', 'im_product_review_text_to_admin', ' New product review has been added. See details #admin#rt=catalog/review/update&review_id=%s ', '[[regtime]]', '[[regtime]]'),
(4644, 1, 0, 'common_im', 'im_product_out_of_stock_admin_text', ' Product with ID #%s is out of Stock. ', '[[regtime]]', '[[regtime]]'),
(4645, 1, 0, 'common_template_debug', 'text_block_id', 'Block ID:', '[[regtime]]', '[[regtime]]'),
(4646, 1, 0, 'common_template_debug', 'text_block_name', 'Name:', '[[regtime]]', '[[regtime]]'),
(4647, 1, 0, 'common_template_debug', 'text_block_controller', 'Controller:', '[[regtime]]', '[[regtime]]'),
(4648, 1, 0, 'common_template_debug', 'text_block_path', 'Path:', '[[regtime]]', '[[regtime]]'),
(4649, 1, 0, 'common_template_debug', 'text_block_template', 'Template:', '[[regtime]]', '[[regtime]]'),
(4650, 1, 0, 'common_template_debug', 'text_block_parent', 'Parent:', '[[regtime]]', '[[regtime]]'),
(4651, 1, 0, 'common_template_debug', 'text_parent_id', 'Parent ID:', '[[regtime]]', '[[regtime]]'),
(4652, 1, 0, 'common_template_debug', 'text_close', 'Close', '[[regtime]]', '[[regtime]]'),
(4653, 1, 0, 'common_template_debug', 'text_click', 'Click Me', '[[regtime]]', '[[regtime]]'),
(4654, 1, 0, 'content_contact', 'heading_title', 'Contact Us', '[[regtime]]', '[[regtime]]'),
(4655, 1, 0, 'content_contact', 'text_address', 'Address:', '[[regtime]]', '[[regtime]]'),
(4656, 1, 0, 'content_contact', 'text_email', 'E-Mail:', '[[regtime]]', '[[regtime]]'),
(4657, 1, 0, 'content_contact', 'text_telephone', 'Telephone:', '[[regtime]]', '[[regtime]]'),
(4658, 1, 0, 'content_contact', 'text_fax', 'Fax:', '[[regtime]]', '[[regtime]]'),
(4659, 1, 0, 'content_contact', 'text_message', '<p>Your enquiry has been successfully sent to the store owner!</p>', '[[regtime]]', '[[regtime]]'),
(4660, 1, 0, 'content_contact', 'entry_name', 'First Name:', '[[regtime]]', '[[regtime]]'),
(4661, 1, 0, 'content_contact', 'entry_email', 'E-Mail Address:', '[[regtime]]', '[[regtime]]'),
(4662, 1, 0, 'content_contact', 'entry_enquiry', 'Enquiry:', '[[regtime]]', '[[regtime]]'),
(4663, 1, 0, 'content_contact', 'entry_captcha', 'Enter the code in the box below:', '[[regtime]]', '[[regtime]]'),
(4664, 1, 0, 'content_contact', 'email_subject', 'Enquiry from %s', '[[regtime]]', '[[regtime]]'),
(4665, 1, 0, 'content_contact', 'error_name', 'Name must be between 3 and 32 characters!', '[[regtime]]', '[[regtime]]'),
(4666, 1, 0, 'content_contact', 'error_email', 'E-Mail Address does not appear to be valid!', '[[regtime]]', '[[regtime]]'),
(4667, 1, 0, 'content_contact', 'error_enquiry', 'Enquiry must be between 10 and 3000 characters!', '[[regtime]]', '[[regtime]]'),
(4668, 1, 0, 'content_contact', 'entry_duplicate_message_subject', 'New Enquiry From %s (%s)', '[[regtime]]', '[[regtime]]'),
(4669, 1, 0, 'content_content', 'heading_title', 'Content pages', '[[regtime]]', '[[regtime]]'),
(4670, 1, 0, 'content_content', 'text_author', 'Author:', '[[regtime]]', '[[regtime]]'),
(4671, 1, 0, 'content_content', 'text_published', 'Published:', '[[regtime]]', '[[regtime]]'),
(4672, 1, 0, 'content_content', 'text_sort', 'Sort By:', '[[regtime]]', '[[regtime]]'),
(4673, 1, 0, 'content_content', 'text_new', 'NEW', '[[regtime]]', '[[regtime]]'),
(4674, 1, 0, 'content_content', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(4675, 1, 0, 'content_content', 'content_not_found', 'No content found. Try again.', '[[regtime]]', '[[regtime]]'),
(4676, 1, 0, 'content_content', 'text_error', 'Information Page Not Found!', '[[regtime]]', '[[regtime]]'),
(4677, 1, 0, 'content_sitemap', 'heading_title', 'Site Map', '[[regtime]]', '[[regtime]]'),
(4678, 1, 0, 'content_sitemap', 'text_special', 'Special Offers', '[[regtime]]', '[[regtime]]'),
(4679, 1, 0, 'content_sitemap', 'text_account', 'My Account', '[[regtime]]', '[[regtime]]'),
(4680, 1, 0, 'content_sitemap', 'text_edit', 'Account Information', '[[regtime]]', '[[regtime]]'),
(4681, 1, 0, 'content_sitemap', 'text_password', 'Password', '[[regtime]]', '[[regtime]]'),
(4682, 1, 0, 'content_sitemap', 'text_address', 'Address Book', '[[regtime]]', '[[regtime]]'),
(4683, 1, 0, 'content_sitemap', 'text_history', 'Order History', '[[regtime]]', '[[regtime]]'),
(4684, 1, 0, 'content_sitemap', 'text_download', 'Downloads', '[[regtime]]', '[[regtime]]'),
(4685, 1, 0, 'content_sitemap', 'text_cart', 'Shopping Cart', '[[regtime]]', '[[regtime]]'),
(4686, 1, 0, 'content_sitemap', 'text_checkout', 'Checkout', '[[regtime]]', '[[regtime]]'),
(4687, 1, 0, 'content_sitemap', 'text_search', 'Search', '[[regtime]]', '[[regtime]]'),
(4688, 1, 0, 'content_sitemap', 'text_information', 'Information', '[[regtime]]', '[[regtime]]'),
(4689, 1, 0, 'content_sitemap', 'text_contact', 'Contact Us', '[[regtime]]', '[[regtime]]'),
(4690, 1, 0, 'english', 'code', 'en', '[[regtime]]', '[[regtime]]'),
(4691, 1, 0, 'english', 'direction', 'ltr', '[[regtime]]', '[[regtime]]'),
(4692, 1, 0, 'english', 'date_format_short', 'm/d/Y', '[[regtime]]', '[[regtime]]'),
(4693, 1, 0, 'english', 'date_format_long', 'l dS F Y', '[[regtime]]', '[[regtime]]'),
(4694, 1, 0, 'english', 'time_format', 'h:i:s A', '[[regtime]]', '[[regtime]]'),
(4695, 1, 0, 'english', 'time_format_short', 'H:i', '[[regtime]]', '[[regtime]]'),
(4696, 1, 0, 'english', 'decimal_point', '.', '[[regtime]]', '[[regtime]]'),
(4697, 1, 0, 'english', 'thousand_point', ',', '[[regtime]]', '[[regtime]]'),
(4698, 1, 0, 'english', 'text_home', 'Home', '[[regtime]]', '[[regtime]]'),
(4699, 1, 0, 'english', 'text_yes', 'Yes', '[[regtime]]', '[[regtime]]'),
(4700, 1, 0, 'english', 'text_no', 'No', '[[regtime]]', '[[regtime]]'),
(4701, 1, 0, 'english', 'text_none', ' --- None --- ', '[[regtime]]', '[[regtime]]'),
(4702, 1, 0, 'english', 'text_select', ' --- Please Select --- ', '[[regtime]]', '[[regtime]]'),
(4703, 1, 0, 'english', 'text_all_zones', 'All Zones', '[[regtime]]', '[[regtime]]'),
(4704, 1, 0, 'english', 'text_pagination', '{start} - {end} of {total}', '[[regtime]]', '[[regtime]]'),
(4705, 1, 0, 'english', 'text_per_page', 'Per Page', '[[regtime]]', '[[regtime]]'),
(4706, 1, 0, 'english', 'text_separator', ' &gt; ', '[[regtime]]', '[[regtime]]'),
(4707, 1, 0, 'english', 'button_continue', 'Continue', '[[regtime]]', '[[regtime]]'),
(4708, 1, 0, 'english', 'button_back', 'Back', '[[regtime]]', '[[regtime]]'),
(4709, 1, 0, 'english', 'button_add_to_cart', 'Add to Cart', '[[regtime]]', '[[regtime]]'),
(4710, 1, 0, 'english', 'button_add_wishlist', 'Add to wish list', '[[regtime]]', '[[regtime]]'),
(4711, 1, 0, 'english', 'button_remove_wishlist', 'Remove from wish list', '[[regtime]]', '[[regtime]]'),
(4712, 1, 0, 'english', 'text_wishlist_add_success', 'Added to wish list', '[[regtime]]', '[[regtime]]'),
(4713, 1, 0, 'english', 'text_wishlist_remove_success', 'Removed from wish list', '[[regtime]]', '[[regtime]]'),
(4714, 1, 0, 'english', 'button_add_address', 'Add Address', '[[regtime]]', '[[regtime]]'),
(4715, 1, 0, 'english', 'button_new_address', 'New Address', '[[regtime]]', '[[regtime]]'),
(4716, 1, 0, 'english', 'button_change_address', 'Change Address', '[[regtime]]', '[[regtime]]'),
(4717, 1, 0, 'english', 'button_edit', 'Edit', '[[regtime]]', '[[regtime]]'),
(4718, 1, 0, 'english', 'button_delete', 'Delete', '[[regtime]]', '[[regtime]]'),
(4719, 1, 0, 'english', 'button_reviews', 'Reviews', '[[regtime]]', '[[regtime]]'),
(4720, 1, 0, 'english', 'button_write', 'Write Review', '[[regtime]]', '[[regtime]]'),
(4721, 1, 0, 'english', 'button_login', 'Login', '[[regtime]]', '[[regtime]]'),
(4722, 1, 0, 'english', 'button_update', 'Update', '[[regtime]]', '[[regtime]]'),
(4723, 1, 0, 'english', 'button_wish', 'Wish', '[[regtime]]', '[[regtime]]'),
(4724, 1, 0, 'english', 'button_print', 'Print', '[[regtime]]', '[[regtime]]'),
(4725, 1, 0, 'english', 'button_shopping', 'Continue Shopping', '[[regtime]]', '[[regtime]]'),
(4726, 1, 0, 'english', 'button_checkout', 'Checkout', '[[regtime]]', '[[regtime]]'),
(4727, 1, 0, 'english', 'button_confirm', 'Confirm Order', '[[regtime]]', '[[regtime]]'),
(4728, 1, 0, 'english', 'button_view', 'View', '[[regtime]]', '[[regtime]]'),
(4729, 1, 0, 'english', 'button_search', 'Search', '[[regtime]]', '[[regtime]]'),
(4730, 1, 0, 'english', 'button_go', 'Go', '[[regtime]]', '[[regtime]]'),
(4731, 1, 0, 'english', 'button_coupon', 'Apply Coupon', '[[regtime]]', '[[regtime]]'),
(4732, 1, 0, 'english', 'button_guest', 'Guest Checkout', '[[regtime]]', '[[regtime]]'),
(4733, 1, 0, 'english', 'notice_out_of_stock_ttl', 'Out of stock notice for: %s', '[[regtime]]', '[[regtime]]'),
(4734, 1, 0, 'english', 'notice_out_of_stock_body', 'Product "%s" has reached zero or negative stock count for main product or all options. <br> As a result of autodisable setting, product (%s) was auto disabled!<br> For more details visit %s', '[[regtime]]', '[[regtime]]'),
(4735, 1, 0, 'english', 'no_payment_required', 'No Payment Required', '[[regtime]]', '[[regtime]]'),
(4736, 1, 0, 'english', 'gen_data_entry_error', 'Oops, there is an error with information provided!', '[[regtime]]', '[[regtime]]'),
(4737, 1, 0, 'english', 'text_sorting_name_asc', 'Name A - Z', '[[regtime]]', '[[regtime]]'),
(4738, 1, 0, 'english', 'text_sorting_name_desc', 'Name Z - A', '[[regtime]]', '[[regtime]]'),
(4739, 1, 0, 'english', 'text_sorting_price_asc', 'Price Low &gt; High', '[[regtime]]', '[[regtime]]'),
(4740, 1, 0, 'english', 'text_sorting_price_desc', 'Price High &gt; Low', '[[regtime]]', '[[regtime]]'),
(4741, 1, 0, 'english', 'text_sorting_rating_asc', 'Rating Lowest', '[[regtime]]', '[[regtime]]'),
(4742, 1, 0, 'english', 'text_sorting_rating_desc', 'Rating Highest', '[[regtime]]', '[[regtime]]'),
(4743, 1, 0, 'english', 'text_sorting_date_asc', 'Date Old &gt; New', '[[regtime]]', '[[regtime]]'),
(4744, 1, 0, 'english', 'text_sorting_date_desc', 'Date New &gt; Old', '[[regtime]]', '[[regtime]]'),
(4745, 1, 0, 'english', 'text_google_places_address_placeholder', 'Start typing your address', '[[regtime]]', '[[regtime]]'),
(4746, 1, 0, 'english', 'text_add_cart_confirm', 'Added to cart', '[[regtime]]', '[[regtime]]'),
(4747, 1, 0, 'english', 'text_close', 'Close', '[[regtime]]', '[[regtime]]'),
(4748, 1, 0, 'english', 'text_balance', 'Account Balance ', '[[regtime]]', '[[regtime]]'),
(4749, 1, 0, 'english', 'text_balance_checkout', 'Account Balance: ', '[[regtime]]', '[[regtime]]'),
(4750, 1, 0, 'english', 'button_pay_with_balance', 'Pay With Balance', '[[regtime]]', '[[regtime]]'),
(4751, 1, 0, 'english', 'button_apply_balance', 'Apply to Order', '[[regtime]]', '[[regtime]]'),
(4752, 1, 0, 'english', 'button_disapply_balance', 'Remove from Order', '[[regtime]]', '[[regtime]]'),
(4753, 1, 0, 'english', 'text_applied_balance', 'applied to order', '[[regtime]]', '[[regtime]]'),
(4754, 1, 0, 'english', 'text_applied_balance_to_order', '%s used for order #%s', '[[regtime]]', '[[regtime]]'),
(4755, 1, 0, 'english', 'text_maintenance_notice', 'Notice: Maintenance mode is on.', '[[regtime]]', '[[regtime]]'),
(4756, 1, 0, 'english', 'text_act_on_behalf', 'Notice: Impersonate mode for customer "%s" by "%s"', '[[regtime]]', '[[regtime]]'),
(4757, 1, 0, 'english', 'text_browse', 'Select File', '[[regtime]]', '[[regtime]]'),
(4758, 1, 0, 'english', 'button_cancel', 'Cancel', '[[regtime]]', '[[regtime]]'),
(4759, 1, 0, 'english', 'button_reset', 'Reset', '[[regtime]]', '[[regtime]]'),
(4760, 1, 0, 'english', 'button_submit', 'Submit', '[[regtime]]', '[[regtime]]'),
(4761, 1, 0, 'english', 'button_save', 'Save', '[[regtime]]', '[[regtime]]'),
(4762, 1, 0, 'english', 'text_field_required', 'is required field!', '[[regtime]]', '[[regtime]]'),
(4763, 1, 0, 'english', 'error_captcha', 'Human verification has failed! Please try again.', '[[regtime]]', '[[regtime]]'),
(4764, 1, 0, 'english', 'entry_attached', 'Attached', '[[regtime]]', '[[regtime]]'),
(4765, 1, 0, 'english', 'text_call_to_order', 'Call To Order', '[[regtime]]', '[[regtime]]'),
(4766, 1, 0, 'english', 'text_discount', 'Discount', '[[regtime]]', '[[regtime]]'),
(4767, 1, 0, 'english', 'text_download', 'Download', '[[regtime]]', '[[regtime]]'),
(4768, 1, 0, 'english', 'text_free', 'Free', '[[regtime]]', '[[regtime]]'),
(4769, 1, 0, 'english', 'text_free_shipping', 'Free Shipping', '[[regtime]]', '[[regtime]]'),
(4770, 1, 0, 'english', 'price_with_tax', 'Inc Tax', '[[regtime]]', '[[regtime]]'),
(4771, 1, 0, 'english', 'text_unavailable', 'Unavailable', '[[regtime]]', '[[regtime]]'),
(4772, 1, 0, 'english', 'error_unknown', 'Unknown error encountered. Please try again!', '[[regtime]]', '[[regtime]]'),
(4773, 1, 0, 'english', 'text_click_browse_file', 'Click to browse file', '[[regtime]]', '[[regtime]]'),
(4774, 1, 0, 'english', 'text_back_on_top', 'Back to top', '[[regtime]]', '[[regtime]]'),
(4775, 1, 0, 'english', 'text_out_of_stock', 'Out of Stock', '[[regtime]]', '[[regtime]]'),
(4776, 1, 0, 'english', 'text_badge_sale', 'SALE', '[[regtime]]', '[[regtime]]'),
(4777, 1, 0, 'english', 'text_pagination_pages_info', 'Showing {start} to {end} of {total} ({pages} Pages)', '[[regtime]]', '[[regtime]]'),
(4778, 1, 0, 'english', 'text_first', 'First', '[[regtime]]', '[[regtime]]'),
(4779, 1, 0, 'english', 'text_last', 'Last', '[[regtime]]', '[[regtime]]'),
(4780, 1, 0, 'english', 'text_next', 'Next', '[[regtime]]', '[[regtime]]'),
(4781, 1, 0, 'english', 'text_previous', 'Previous', '[[regtime]]', '[[regtime]]'),
(4782, 1, 0, 'english', 'warning_capslock', 'CapsLock is On!', '[[regtime]]', '[[regtime]]'),
(4783, 1, 0, 'error_error', 'heading_title', 'Application Error!', '[[regtime]]', '[[regtime]]'),
(4784, 1, 0, 'error_error', 'text_error', 'Please check error log for more information', '[[regtime]]', '[[regtime]]'),
(4785, 1, 0, 'error_login', 'heading_title', 'Login Error!', '[[regtime]]', '[[regtime]]'),
(4786, 1, 0, 'error_login', 'text_login', 'You are not logged in. You will be redirected to login page', '[[regtime]]', '[[regtime]]'),
(4787, 1, 0, 'error_not_found', 'heading_title', 'The page you requested cannot be found!', '[[regtime]]', '[[regtime]]'),
(4788, 1, 0, 'error_not_found', 'text_error', 'The page you requested cannot be found.', '[[regtime]]', '[[regtime]]'),
(4789, 1, 0, 'error_permission', 'heading_title', 'Permission Denied!', '[[regtime]]', '[[regtime]]'),
(4790, 1, 0, 'error_permission', 'text_permission', 'You do not have permission to access this page, please refer to your system administrator.', '[[regtime]]', '[[regtime]]'),
(4791, 1, 0, 'index_home', 'heading_title', 'Welcome to %s', '[[regtime]]', '[[regtime]]'),
(4792, 1, 0, 'index_home', 'text_latest', 'Latest Products', '[[regtime]]', '[[regtime]]'),
(4793, 1, 0, 'index_maintenance', 'heading_title', 'Maintenance', '[[regtime]]', '[[regtime]]'),
(4794, 1, 0, 'index_maintenance', 'text_maintenance', 'Maintenance', '[[regtime]]', '[[regtime]]'),
(4795, 1, 0, 'index_maintenance', 'text_message', '<h1 style="text-align:center;">We are currently performing some scheduled maintenance. <br/>We will be back as soon as possible. Please check back soon.</h1>', '[[regtime]]', '[[regtime]]'),
(4796, 1, 0, 'mail_account_create', 'text_subject', '%s - Thank you for registering', '[[regtime]]', '[[regtime]]'),
(4797, 1, 0, 'mail_account_create', 'text_welcome', 'Welcome and thank you for registering at %s!', '[[regtime]]', '[[regtime]]'),
(4798, 1, 0, 'mail_account_create', 'text_login', 'Your account has now been created and you can access it by visiting our website or at the following URL:', '[[regtime]]', '[[regtime]]'),
(4799, 1, 0, 'mail_account_create', 'text_approval', 'Your account must be approved before you can login. Once approved you can log in by using your email address and password by visiting our website or at the following URL:', '[[regtime]]', '[[regtime]]'),
(4800, 1, 0, 'mail_account_create', 'text_activate', 'Before we can activate your account one last step must be taken to complete your registration.<br>\n    You must complete this last step to become a registered member. Please click the following link to activate your account %s . ', '[[regtime]]', '[[regtime]]'),
(4801, 1, 0, 'mail_account_create', 'text_services', 'Upon logging in, you will be able to access other services including reviewing past orders, printing invoices and editing your account information.', '[[regtime]]', '[[regtime]]'),
(4802, 1, 0, 'mail_account_create', 'text_thanks', 'Thank you,', '[[regtime]]', '[[regtime]]'),
(4803, 1, 0, 'mail_account_forgotten', 'text_subject', '%s - Password reset', '[[regtime]]', '[[regtime]]'),
(4804, 1, 0, 'mail_account_forgotten', 'text_greeting', 'A password reset was requested from %s.', '[[regtime]]', '[[regtime]]'),
(4805, 1, 0, 'mail_account_forgotten', 'text_password', 'To reset your password click link below:', '[[regtime]]', '[[regtime]]'),
(4806, 1, 0, 'mail_account_forgotten', 'text_password_reset', 'Your password was successfully reset on %s.', '[[regtime]]', '[[regtime]]'),
(4807, 1, 0, 'mail_account_forgotten', 'text_new_password', 'Enter your new password below:', '[[regtime]]', '[[regtime]]'),
(4808, 1, 0, 'mail_account_forgotten', 'error_reset_token', 'Incorrect link for password request. Try to reset one more time and use link from most recent email.', '[[regtime]]', '[[regtime]]'),
(4809, 1, 0, 'mail_account_forgotten_login', 'text_subject', '%s - Login name reminder', '[[regtime]]', '[[regtime]]'),
(4810, 1, 0, 'mail_account_forgotten_login', 'text_greeting', 'Login name reminder was requested from %s.', '[[regtime]]', '[[regtime]]'),
(4811, 1, 0, 'mail_account_forgotten_login', 'text_your_loginname', 'Your login name is:', '[[regtime]]', '[[regtime]]'),
(4812, 1, 0, 'mail_order_confirm', 'text_subject', '%s - Order %s', '[[regtime]]', '[[regtime]]'),
(4813, 1, 0, 'mail_order_confirm', 'text_greeting', 'Thank you for your interest in %s products. Your order has been received and will be processed after payment is confirmed.', '[[regtime]]', '[[regtime]]'),
(4814, 1, 0, 'mail_order_confirm', 'text_received', 'You have received an order.', '[[regtime]]', '[[regtime]]'),
(4815, 1, 0, 'mail_order_confirm', 'text_order_detail', 'Order Details', '[[regtime]]', '[[regtime]]'),
(4816, 1, 0, 'mail_order_confirm', 'text_order_id', 'Order ID:', '[[regtime]]', '[[regtime]]'),
(4817, 1, 0, 'mail_order_confirm', 'text_date_added', 'Date Ordered:', '[[regtime]]', '[[regtime]]'),
(4818, 1, 0, 'mail_order_confirm', 'text_order_status', 'Order Status:', '[[regtime]]', '[[regtime]]'),
(4819, 1, 0, 'mail_order_confirm', 'text_invoice', 'To view your order click on the link below:', '[[regtime]]', '[[regtime]]'),
(4820, 1, 0, 'mail_order_confirm', 'text_shipping_method', 'Shipping Method:', '[[regtime]]', '[[regtime]]'),
(4821, 1, 0, 'mail_order_confirm', 'text_payment_method', 'Payment Method:', '[[regtime]]', '[[regtime]]'),
(4822, 1, 0, 'mail_order_confirm', 'text_shipping_address', 'Shipping Address', '[[regtime]]', '[[regtime]]'),
(4823, 1, 0, 'mail_order_confirm', 'text_payment_address', 'Payment Address', '[[regtime]]', '[[regtime]]'),
(4824, 1, 0, 'mail_order_confirm', 'text_email', 'Email:', '[[regtime]]', '[[regtime]]'),
(4825, 1, 0, 'mail_order_confirm', 'text_telephone', 'Telephone:', '[[regtime]]', '[[regtime]]'),
(4826, 1, 0, 'mail_order_confirm', 'text_mobile_phone', 'Mobile Phone:', '[[regtime]]', '[[regtime]]'),
(4827, 1, 0, 'mail_order_confirm', 'text_fax', 'Fax:', '[[regtime]]', '[[regtime]]'),
(4828, 1, 0, 'mail_order_confirm', 'text_ip', 'IP Address:', '[[regtime]]', '[[regtime]]'),
(4829, 1, 0, 'mail_order_confirm', 'text_product', 'Products:', '[[regtime]]', '[[regtime]]'),
(4830, 1, 0, 'mail_order_confirm', 'text_total', 'Totals:', '[[regtime]]', '[[regtime]]'),
(4831, 1, 0, 'mail_order_confirm', 'text_download', 'Once your payment has been confirmed you can click on the link below to access your downloadable products:', '[[regtime]]', '[[regtime]]'),
(4832, 1, 0, 'mail_order_confirm', 'text_comment', 'The comments for your order are:', '[[regtime]]', '[[regtime]]'),
(4833, 1, 0, 'mail_order_confirm', 'text_footer', 'Please reply to this email if you have any questions.', '[[regtime]]', '[[regtime]]'),
(4834, 1, 0, 'mail_order_confirm', 'text_powered_by', 'powered by', '[[regtime]]', '[[regtime]]'),
(4835, 1, 0, 'mail_order_confirm', 'text_new_order', 'New Order - #', '[[regtime]]', '[[regtime]]'),
(4836, 1, 0, 'mail_order_confirm', 'text_new_order_text', 'Customer %s added new order', '[[regtime]]', '[[regtime]]'),
(4837, 1, 0, 'mail_order_confirm', 'column_product', 'Product', '[[regtime]]', '[[regtime]]'),
(4838, 1, 0, 'mail_order_confirm', 'column_model', 'Model', '[[regtime]]', '[[regtime]]'),
(4839, 1, 0, 'mail_order_confirm', 'column_quantity', 'Quantity', '[[regtime]]', '[[regtime]]'),
(4840, 1, 0, 'mail_order_confirm', 'column_price', 'Price', '[[regtime]]', '[[regtime]]'),
(4841, 1, 0, 'mail_order_confirm', 'column_total', 'Total', '[[regtime]]', '[[regtime]]'),
(4842, 1, 0, 'mail_order_update', 'text_subject', '%s - Order Update %s', '[[regtime]]', '[[regtime]]'),
(4843, 1, 0, 'mail_order_update', 'text_order', 'Order ID:', '[[regtime]]', '[[regtime]]'),
(4844, 1, 0, 'mail_order_update', 'text_date_added', 'Date Ordered:', '[[regtime]]', '[[regtime]]'),
(4845, 1, 0, 'mail_order_update', 'text_order_status', 'Your order has been updated to the following status:', '[[regtime]]', '[[regtime]]'),
(4846, 1, 0, 'mail_order_update', 'text_comment', 'The comments for your order are:', '[[regtime]]', '[[regtime]]'),
(4847, 1, 0, 'mail_order_update', 'text_invoice', 'To view your order click on the link below:', '[[regtime]]', '[[regtime]]'),
(4848, 1, 0, 'mail_order_update', 'text_footer', 'Please reply to this email if you have any questions.', '[[regtime]]', '[[regtime]]'),
(4849, 1, 0, 'product_category', 'text_product', 'Products', '[[regtime]]', '[[regtime]]'),
(4850, 1, 0, 'product_category', 'text_error', 'Category not found!', '[[regtime]]', '[[regtime]]'),
(4851, 1, 0, 'product_category', 'text_empty', 'There are no products to list in this category.', '[[regtime]]', '[[regtime]]'),
(4852, 1, 0, 'product_category', 'text_stars', '%s out of 5 Stars!', '[[regtime]]', '[[regtime]]'),
(4853, 1, 0, 'product_category', 'text_sort', 'Sort By:', '[[regtime]]', '[[regtime]]'),
(4854, 1, 0, 'product_category', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(4855, 1, 0, 'product_category', 'text_name_asc', 'Name A - Z', '[[regtime]]', '[[regtime]]'),
(4856, 1, 0, 'product_category', 'text_name_desc', 'Name Z - A', '[[regtime]]', '[[regtime]]'),
(4857, 1, 0, 'product_category', 'text_price_asc', 'Price Low &gt; High', '[[regtime]]', '[[regtime]]'),
(4858, 1, 0, 'product_category', 'text_price_desc', 'Price High &gt; Low', '[[regtime]]', '[[regtime]]'),
(4859, 1, 0, 'product_category', 'text_rating_asc', 'Rating Lowest', '[[regtime]]', '[[regtime]]'),
(4860, 1, 0, 'product_category', 'text_rating_desc', 'Rating Highest', '[[regtime]]', '[[regtime]]'),
(4861, 1, 0, 'product_category', 'text_top_category', 'Top Category', '[[regtime]]', '[[regtime]]'),
(4862, 1, 0, 'product_collection', 'text_empty_collection', 'There are no products to list ', '[[regtime]]', '[[regtime]]'),
(4863, 1, 0, 'product_manufacturer', 'text_product', 'Products', '[[regtime]]', '[[regtime]]'),
(4864, 1, 0, 'product_manufacturer', 'text_error', 'Brand not found!', '[[regtime]]', '[[regtime]]'),
(4865, 1, 0, 'product_manufacturer', 'text_empty', 'There are no products to list from this brand.', '[[regtime]]', '[[regtime]]'),
(4866, 1, 0, 'product_manufacturer', 'text_stars', '%s out of 5 Stars!', '[[regtime]]', '[[regtime]]'),
(4867, 1, 0, 'product_manufacturer', 'text_sort', 'Sort By:', '[[regtime]]', '[[regtime]]'),
(4868, 1, 0, 'product_manufacturer', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(4869, 1, 0, 'product_manufacturer', 'text_name_asc', 'Name A - Z', '[[regtime]]', '[[regtime]]'),
(4870, 1, 0, 'product_manufacturer', 'text_name_desc', 'Name Z - A', '[[regtime]]', '[[regtime]]'),
(4871, 1, 0, 'product_manufacturer', 'text_price_asc', 'Price Low &gt; High', '[[regtime]]', '[[regtime]]'),
(4872, 1, 0, 'product_manufacturer', 'text_price_desc', 'Price High &gt; Low', '[[regtime]]', '[[regtime]]'),
(4873, 1, 0, 'product_manufacturer', 'text_rating_asc', 'Rating Lowest', '[[regtime]]', '[[regtime]]'),
(4874, 1, 0, 'product_manufacturer', 'text_rating_desc', 'Rating Highest', '[[regtime]]', '[[regtime]]'),
(4875, 1, 0, 'product_product', 'text_enlarge', 'Click image to enlarge', '[[regtime]]', '[[regtime]]'),
(4876, 1, 0, 'product_product', 'text_zoom', 'Move pointer over the image to zoom in', '[[regtime]]', '[[regtime]]'),
(4877, 1, 0, 'product_product', 'text_quantity_discount', 'Quantity Discount:', '[[regtime]]', '[[regtime]]'),
(4878, 1, 0, 'product_product', 'text_options', 'Available Options:', '[[regtime]]', '[[regtime]]'),
(4879, 1, 0, 'product_product', 'text_error', 'Product not found!', '[[regtime]]', '[[regtime]]'),
(4880, 1, 0, 'product_product', 'text_price', 'Price:', '[[regtime]]', '[[regtime]]'),
(4881, 1, 0, 'product_product', 'text_availability', 'Availability:', '[[regtime]]', '[[regtime]]'),
(4882, 1, 0, 'product_product', 'text_model', 'Model:', '[[regtime]]', '[[regtime]]'),
(4883, 1, 0, 'product_product', 'text_sku', 'SKU:', '[[regtime]]', '[[regtime]]'),
(4884, 1, 0, 'product_product', 'text_manufacturer', 'Brand:', '[[regtime]]', '[[regtime]]'),
(4885, 1, 0, 'product_product', 'text_instock', 'In Stock', '[[regtime]]', '[[regtime]]'),
(4886, 1, 0, 'product_product', 'text_out_of_stock', 'Out of Stock', '[[regtime]]', '[[regtime]]'),
(4887, 1, 0, 'product_product', 'text_order_quantity', 'Order Quantity', '[[regtime]]', '[[regtime]]'),
(4888, 1, 0, 'product_product', 'text_price_per_item', 'Price Per Item', '[[regtime]]', '[[regtime]]'),
(4889, 1, 0, 'product_product', 'text_write', 'Write Review', '[[regtime]]', '[[regtime]]'),
(4890, 1, 0, 'product_product', 'text_no_reviews', 'There are no reviews for this product.', '[[regtime]]', '[[regtime]]'),
(4891, 1, 0, 'product_product', 'text_average', 'Average Rating:', '[[regtime]]', '[[regtime]]'),
(4892, 1, 0, 'product_product', 'text_stars', '%s out of 5 Stars!', '[[regtime]]', '[[regtime]]'),
(4893, 1, 0, 'product_product', 'text_no_rating', 'Not Rated', '[[regtime]]', '[[regtime]]'),
(4894, 1, 0, 'product_product', 'text_no_images', 'There are no additional images for this product.', '[[regtime]]', '[[regtime]]'),
(4895, 1, 0, 'product_product', 'text_no_related', 'There are no related products for this product.', '[[regtime]]', '[[regtime]]'),
(4896, 1, 0, 'product_product', 'text_qty', 'Qty:', '[[regtime]]', '[[regtime]]'),
(4897, 1, 0, 'product_product', 'text_note', '<span style="color: #FF0000;">Note:</span> Do not use HTML in the text.', '[[regtime]]', '[[regtime]]'),
(4898, 1, 0, 'product_product', 'text_success', 'Thank you for your review. It has been submitted to the webmaster for approval.', '[[regtime]]', '[[regtime]]'),
(4899, 1, 0, 'product_product', 'text_wait', 'Please Wait!', '[[regtime]]', '[[regtime]]'),
(4900, 1, 0, 'product_product', 'text_search', 'Search', '[[regtime]]', '[[regtime]]'),
(4901, 1, 0, 'product_product', 'text_tags', 'Tags:', '[[regtime]]', '[[regtime]]'),
(4902, 1, 0, 'product_product', 'text_minimum', '(This product has a minimum quantity of %s)', '[[regtime]]', '[[regtime]]'),
(4903, 1, 0, 'product_product', 'text_maximum', '(This product has a limit set to %s item(s) per order)', '[[regtime]]', '[[regtime]]'),
(4904, 1, 0, 'product_product', 'entry_name', 'Your Name:', '[[regtime]]', '[[regtime]]'),
(4905, 1, 0, 'product_product', 'entry_review', 'Your Review:', '[[regtime]]', '[[regtime]]'),
(4906, 1, 0, 'product_product', 'entry_rating', 'Rating:', '[[regtime]]', '[[regtime]]'),
(4907, 1, 0, 'product_product', 'entry_good', 'Good', '[[regtime]]', '[[regtime]]');
INSERT INTO `[[dbprefix]]language_definitions` VALUES
(4908, 1, 0, 'product_product', 'entry_bad', 'Bad', '[[regtime]]', '[[regtime]]'),
(4909, 1, 0, 'product_product', 'entry_captcha', 'Enter the code in the box below:', '[[regtime]]', '[[regtime]]'),
(4910, 1, 0, 'product_product', 'tab_description', 'Description', '[[regtime]]', '[[regtime]]'),
(4911, 1, 0, 'product_product', 'tab_image', 'Additional Images', '[[regtime]]', '[[regtime]]'),
(4912, 1, 0, 'product_product', 'tab_review', 'Reviews (%s)', '[[regtime]]', '[[regtime]]'),
(4913, 1, 0, 'product_product', 'tab_review_empty', 'Reviews', '[[regtime]]', '[[regtime]]'),
(4914, 1, 0, 'product_product', 'tab_related', 'Related Products', '[[regtime]]', '[[regtime]]'),
(4915, 1, 0, 'product_product', 'error_name', 'Error: Review Name must be between 3 and 25 characters!', '[[regtime]]', '[[regtime]]'),
(4916, 1, 0, 'product_product', 'error_text', 'Error: Review Text must be between 25 and 1000 characters!', '[[regtime]]', '[[regtime]]'),
(4917, 1, 0, 'product_product', 'error_rating', 'Error: Please select a review rating!', '[[regtime]]', '[[regtime]]'),
(4918, 1, 0, 'product_product', 'text_total_price', 'Total Price:', '[[regtime]]', '[[regtime]]'),
(4919, 1, 0, 'product_product', 'text_login_view_price', 'Please login or register to see price or to order.', '[[regtime]]', '[[regtime]]'),
(4920, 1, 0, 'product_product', 'tab_downloads', 'Downloads', '[[regtime]]', '[[regtime]]'),
(4921, 1, 0, 'product_product', 'text_start_download', 'Start Download', '[[regtime]]', '[[regtime]]'),
(4922, 1, 0, 'product_product', 'text_new_review', 'Product review approval is pending', '[[regtime]]', '[[regtime]]'),
(4923, 1, 0, 'product_product', 'text_pending_review_approval', 'Review for product id %s is posted. Action of approval is required! Click to view #admin#rt=catalog/review/update&review_id=%s', '[[regtime]]', '[[regtime]]'),
(4924, 1, 0, 'product_product', 'text_verified_review', 'Verified purchase', '[[regtime]]', '[[regtime]]'),
(4925, 1, 0, 'product_product', 'percentage_review', 'of buyers have recommended this.', '[[regtime]]', '[[regtime]]'),
(4926, 1, 0, 'product_product', 'feedback_customer_title', 'Customers Feedback', '[[regtime]]', '[[regtime]]'),
(4927, 1, 0, 'product_product', 'review_title', 'Reviews', '[[regtime]]', '[[regtime]]'),
(4928, 1, 0, 'product_product', 'write_review_title', 'Write a Review', '[[regtime]]', '[[regtime]]'),
(4929, 1, 0, 'product_product', 'product_rate_title', 'Product Rating', '[[regtime]]', '[[regtime]]'),
(4930, 1, 0, 'product_search', 'heading_title', 'Search', '[[regtime]]', '[[regtime]]'),
(4931, 1, 0, 'product_search', 'text_search', 'Products meeting the search criteria', '[[regtime]]', '[[regtime]]'),
(4932, 1, 0, 'product_search', 'text_keyword', 'Keywords', '[[regtime]]', '[[regtime]]'),
(4933, 1, 0, 'product_search', 'text_category', 'All Categories', '[[regtime]]', '[[regtime]]'),
(4934, 1, 0, 'product_search', 'text_critea', 'Search Criteria', '[[regtime]]', '[[regtime]]'),
(4935, 1, 0, 'product_search', 'text_empty', 'There is no product that matches the search criteria.', '[[regtime]]', '[[regtime]]'),
(4936, 1, 0, 'product_search', 'text_stars', '%s out of 5 Stars!', '[[regtime]]', '[[regtime]]'),
(4937, 1, 0, 'product_search', 'text_sort', 'Sort By:', '[[regtime]]', '[[regtime]]'),
(4938, 1, 0, 'product_search', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(4939, 1, 0, 'product_search', 'text_name_asc', 'Name A - Z', '[[regtime]]', '[[regtime]]'),
(4940, 1, 0, 'product_search', 'text_name_desc', 'Name Z - A', '[[regtime]]', '[[regtime]]'),
(4941, 1, 0, 'product_search', 'text_price_asc', 'Price Low &gt; High', '[[regtime]]', '[[regtime]]'),
(4942, 1, 0, 'product_search', 'text_price_desc', 'Price High &gt; Low', '[[regtime]]', '[[regtime]]'),
(4943, 1, 0, 'product_search', 'text_rating_asc', 'Rating Lowest', '[[regtime]]', '[[regtime]]'),
(4944, 1, 0, 'product_search', 'text_rating_desc', 'Rating Highest', '[[regtime]]', '[[regtime]]'),
(4945, 1, 0, 'product_search', 'entry_search', 'Search:', '[[regtime]]', '[[regtime]]'),
(4946, 1, 0, 'product_search', 'entry_description', 'Search in product descriptions', '[[regtime]]', '[[regtime]]'),
(4947, 1, 0, 'product_search', 'entry_model', 'Search in product model', '[[regtime]]', '[[regtime]]'),
(4948, 1, 0, 'product_special', 'heading_title', 'Special Offers', '[[regtime]]', '[[regtime]]'),
(4949, 1, 0, 'product_special', 'text_empty', 'There are no special offer products to list.', '[[regtime]]', '[[regtime]]'),
(4950, 1, 0, 'product_special', 'text_stars', '%s out of 5 Stars!', '[[regtime]]', '[[regtime]]'),
(4951, 1, 0, 'product_special', 'text_sort', 'Sort By:', '[[regtime]]', '[[regtime]]'),
(4952, 1, 0, 'product_special', 'text_default', 'Default', '[[regtime]]', '[[regtime]]'),
(4953, 1, 0, 'product_special', 'text_name_asc', 'Name A - Z', '[[regtime]]', '[[regtime]]'),
(4954, 1, 0, 'product_special', 'text_name_desc', 'Name Z - A', '[[regtime]]', '[[regtime]]'),
(4955, 1, 0, 'product_special', 'text_price_asc', 'Price Low &gt; High', '[[regtime]]', '[[regtime]]'),
(4956, 1, 0, 'product_special', 'text_price_desc', 'Price High &gt; Low', '[[regtime]]', '[[regtime]]'),
(4957, 1, 0, 'product_special', 'text_rating_asc', 'Rating Lowest', '[[regtime]]', '[[regtime]]'),
(4958, 1, 0, 'product_special', 'text_rating_desc', 'Rating Highest', '[[regtime]]', '[[regtime]]'),
(4959, 1, 0, 'total_handling', 'text_handling', 'Handling Fee:', '[[regtime]]', '[[regtime]]'),
(4960, 1, 0, 'total_low_order_fee', 'text_low_order_fee', 'Low Order Fee:', '[[regtime]]', '[[regtime]]'),
(4961, 1, 0, 'total_sub_total', 'text_sub_total', 'Sub-Total:', '[[regtime]]', '[[regtime]]'),
(4962, 1, 0, 'total_total', 'text_total', 'Total:', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]layouts`
--

CREATE TABLE `[[dbprefix]]layouts` (
  `layout_id` int NOT NULL AUTO_INCREMENT,
  `template_id` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  `layout_name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `layout_type` smallint NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`layout_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=41 ;

--
-- Dumping data for table `[[dbprefix]]layouts`
--

INSERT INTO `[[dbprefix]]layouts` VALUES
(1, 'default', 'Default Page Layout', 0, '[[regtime]]', '[[regtime]]'),
(2, 'default', 'Home Page', 1, '[[regtime]]', '[[regtime]]'),
(3, 'default', 'Login Page', 1, '[[regtime]]', '[[regtime]]'),
(4, 'default', 'Contact Us Page', 1, '[[regtime]]', '[[regtime]]'),
(5, 'default', 'Default Product Page', 1, '[[regtime]]', '[[regtime]]'),
(6, 'default', 'Product Listing Page', 1, '[[regtime]]', '[[regtime]]'),
(7, 'default', 'Maintenance Page', 1, '[[regtime]]', '[[regtime]]'),
(8, 'default', 'Customer Dashboard', 1, '[[regtime]]', '[[regtime]]'),
(9, 'default', 'Account Details', 1, '[[regtime]]', '[[regtime]]'),
(10, 'default', 'Change Password', 1, '[[regtime]]', '[[regtime]]'),
(11, 'default', 'Addresses', 1, '[[regtime]]', '[[regtime]]'),
(12, 'default', 'Wish List', 1, '[[regtime]]', '[[regtime]]'),
(13, 'default', 'Order History', 1, '[[regtime]]', '[[regtime]]'),
(14, 'default', 'Transaction History', 1, '[[regtime]]', '[[regtime]]'),
(15, 'default', 'Downloads', 1, '[[regtime]]', '[[regtime]]'),
(16, 'default', 'Notifications', 1, '[[regtime]]', '[[regtime]]'),
(17, 'default', 'Cart Page', 1, '[[regtime]]', '[[regtime]]'),
(18, 'default', 'Fast Checkout Page', 1, '[[regtime]]', '[[regtime]]'),
(19, 'default', 'Fast Checkout Success Page', 1, '[[regtime]]', '[[regtime]]'),
(20, 'default', 'Default Content Layout', 1, '[[regtime]]', '[[regtime]]'),
(21, 'novator', 'Default Page Layout', 0, '[[regtime]]', '[[regtime]]'),
(22, 'novator', 'Home Page', 1, '[[regtime]]', '[[regtime]]'),
(23, 'novator', 'Login Page', 1, '[[regtime]]', '[[regtime]]'),
(24, 'novator', 'Contact Us Page', 1, '[[regtime]]', '[[regtime]]'),
(25, 'novator', 'Default Product Page', 1, '[[regtime]]', '[[regtime]]'),
(26, 'novator', 'Product Listing Page', 1, '[[regtime]]', '[[regtime]]'),
(27, 'novator', 'Maintenance Page', 1, '[[regtime]]', '[[regtime]]'),
(28, 'novator', 'Customer Dashboard', 1, '[[regtime]]', '[[regtime]]'),
(29, 'novator', 'Account Details', 1, '[[regtime]]', '[[regtime]]'),
(30, 'novator', 'Change Password', 1, '[[regtime]]', '[[regtime]]'),
(31, 'novator', 'Addresses', 1, '[[regtime]]', '[[regtime]]'),
(32, 'novator', 'Wish List', 1, '[[regtime]]', '[[regtime]]'),
(33, 'novator', 'Order History', 1, '[[regtime]]', '[[regtime]]'),
(34, 'novator', 'Transaction History', 1, '[[regtime]]', '[[regtime]]'),
(35, 'novator', 'Downloads', 1, '[[regtime]]', '[[regtime]]'),
(36, 'novator', 'Notifications', 1, '[[regtime]]', '[[regtime]]'),
(37, 'novator', 'Cart Page', 1, '[[regtime]]', '[[regtime]]'),
(38, 'novator', 'Fast Checkout Page', 1, '[[regtime]]', '[[regtime]]'),
(39, 'novator', 'Fast Checkout Success Page', 1, '[[regtime]]', '[[regtime]]'),
(40, 'novator', 'Default Content Layout', 1, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]length_classes`
--

CREATE TABLE `[[dbprefix]]length_classes` (
  `length_class_id` int NOT NULL AUTO_INCREMENT,
  `value` decimal(15,8) NOT NULL,
  `iso_code` varchar(5) COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`length_class_id`,`iso_code`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]length_classes`
--

INSERT INTO `[[dbprefix]]length_classes` VALUES
(1, '1.00000000', 'CMET', '[[regtime]]', '[[regtime]]'),
(2, '10.00000000', 'MMET', '[[regtime]]', '[[regtime]]'),
(3, '0.39370000', 'INCH', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]length_class_descriptions`
--

CREATE TABLE `[[dbprefix]]length_class_descriptions` (
  `length_class_id` int NOT NULL,
  `language_id` int NOT NULL,
  `title` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `unit` varchar(4) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`length_class_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]length_class_descriptions`
--

INSERT INTO `[[dbprefix]]length_class_descriptions` VALUES
(1, 1, 'Centimeter', 'cm'),
(2, 1, 'Millimeter', 'mm'),
(3, 1, 'Inch', 'in');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]locations`
--

CREATE TABLE `[[dbprefix]]locations` (
  `location_id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`location_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=3 ;

--
-- Dumping data for table `[[dbprefix]]locations`
--

INSERT INTO `[[dbprefix]]locations` VALUES
(1, 'USA', 'All States', '[[regtime]]', '[[regtime]]'),
(2, 'Canada', 'All provinces', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]manufacturers`
--

CREATE TABLE `[[dbprefix]]manufacturers` (
  `manufacturer_id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `sort_order` int NOT NULL,
  PRIMARY KEY (`manufacturer_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=21 ;

--
-- Dumping data for table `[[dbprefix]]manufacturers`
--

INSERT INTO `[[dbprefix]]manufacturers` VALUES
(11, 'M·A·C', 0),
(12, 'Benefit', 0),
(13, 'Calvin Klein', 0),
(14, 'Bvlgari', 0),
(15, 'Lancôme', 0),
(16, 'Sephora', 0),
(17, 'Pantene', 0),
(18, 'Dove', 0),
(19, 'Giorgio Armani', 0),
(20, 'Gucci', 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]manufacturers_to_stores`
--

CREATE TABLE `[[dbprefix]]manufacturers_to_stores` (
  `manufacturer_id` int NOT NULL,
  `store_id` int NOT NULL,
  PRIMARY KEY (`manufacturer_id`,`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]manufacturers_to_stores`
--

INSERT INTO `[[dbprefix]]manufacturers_to_stores` VALUES
(11, 0),
(12, 0),
(13, 0),
(14, 0),
(15, 0),
(16, 0),
(17, 0),
(18, 0),
(19, 0),
(20, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]messages`
--

CREATE TABLE `[[dbprefix]]messages` (
  `msg_id` int NOT NULL AUTO_INCREMENT,
  `title` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `message` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `status` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `viewed` int NOT NULL DEFAULT '0',
  `repeated` int NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`msg_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]object_types`
--

CREATE TABLE `[[dbprefix]]object_types` (
  `id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  `related_to` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  PRIMARY KEY (`id`,`name`,`related_to`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='list of types for mapping data';

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]online_customers`
--

CREATE TABLE `[[dbprefix]]online_customers` (
  `customer_id` int NOT NULL,
  `ip` varchar(50) COLLATE utf8mb4_unicode_ci NOT NULL,
  `url` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `referer` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`ip`),
  KEY `[[dbprefix]]online_customers_idx` (`date_added`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]orders`
--

CREATE TABLE `[[dbprefix]]orders` (
  `order_id` int NOT NULL AUTO_INCREMENT,
  `invoice_id` int NOT NULL DEFAULT '0',
  `invoice_prefix` varchar(10) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `store_id` int NOT NULL DEFAULT '0',
  `store_name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  `store_url` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `customer_id` int NOT NULL DEFAULT '0',
  `customer_group_id` int NOT NULL DEFAULT '0',
  `firstname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `lastname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL,
  `telephone` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `fax` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `email` varchar(96) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `shipping_firstname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL,
  `shipping_lastname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `shipping_company` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `shipping_address_1` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `shipping_address_2` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `shipping_city` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `shipping_postcode` varchar(10) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `shipping_zone` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `shipping_zone_id` int NOT NULL,
  `shipping_country` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `shipping_country_id` int NOT NULL,
  `shipping_address_format` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `shipping_method` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `shipping_method_key` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `payment_firstname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `payment_lastname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `payment_company` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `payment_address_1` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `payment_address_2` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `payment_city` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `payment_postcode` varchar(10) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `payment_zone` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `payment_zone_id` int NOT NULL,
  `payment_country` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `payment_country_id` int NOT NULL,
  `payment_address_format` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `payment_method` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `payment_method_key` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `payment_method_data` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `comment` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `total` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `order_status_id` int NOT NULL DEFAULT '0',
  `language_id` int NOT NULL,
  `currency_id` int NOT NULL,
  `currency` varchar(3) COLLATE utf8mb4_unicode_ci NOT NULL,
  `value` decimal(15,8) NOT NULL,
  `coupon_id` int NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `ip` varchar(50) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `ext_fields` json DEFAULT NULL,
  PRIMARY KEY (`order_id`,`customer_id`,`order_status_id`),
  KEY `[[dbprefix]]orders_idx` (`invoice_id`,`store_id`,`customer_group_id`,`shipping_zone_id`,`shipping_country_id`,`payment_zone_id`,`payment_country_id`,`language_id`,`currency_id`,`coupon_id`),
  KEY `[[dbprefix]]orders_date_idx` (`date_added` DESC,`date_modified` DESC)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=25 ;

--
-- Dumping data for table `[[dbprefix]]orders`
--

INSERT INTO `[[dbprefix]]orders` VALUES
(2, 0, '', 0, 'Web Store Name', 'demo', 11, 1, 'Anthony', 'Blair', '+1 907-842-2240', '', 'anthonyblair@abantecart.com', '', '', '', '', '', '', '', '', 0, '', 0, '', '', '', 'Anthony', 'Blair', '', '104 Main Street', '', 'Dillingham', '', 'North Dakota', 3657, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', '', '', '', '418.8100', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(3, 0, '', 0, 'Web Store Name', 'demo', 5, 1, 'Gloria', 'Macias', '+1 418-461-2440', '', 'gloriamacias@abantecart.com', 'Gloria', 'Macias', '', 'Camille Marcoux 15', '', 'Blanc-Sablon', '1569', 'Nunavut', 609, 'Canada', 38, '', 'Flat Shipping Rate', '', 'Gloria', 'Macias', '', 'Camille Marcoux 15', '', 'Blanc-Sablon', '1569', 'Nunavut', 609, 'Canada', 38, '', 'Cash On Delivery', '', '', 'Please ASAP', '246.0000', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(4, 0, '', 0, 'Web Store Name', 'demo', 5, 1, 'Gloria', 'Macias', '+1 418-461-2440', '', 'gloriamacias@abantecart.com', '', '', '', '', '', '', '', '', 0, '', 0, '', '', '', 'Gloria', 'Macias', '', 'Camille Marcoux 15', '', 'Blanc-Sablon', '1569', 'Nunavut', 609, 'Canada', 38, '', 'Cash On Delivery', '', '', '', '310.5270', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(5, 0, '', 0, 'Web Store Name', 'demo', 3, 1, 'Keely', 'Mccoy', '+44 1324 483784 ', '', 'keelymccoy@abantecart.com', 'Keely', 'Mccoy', '', '4842 Amet', '', 'Grangemouth', '', 'Gloucestershire', 3552, 'United Kingdom', 222, '', 'Flat Shipping Rate', '', 'Keely', 'Mccoy', '', '4842 Amet', '', 'Grangemouth', '', 'Gloucestershire', 3552, 'United Kingdom', 222, '', 'Cash On Delivery', '', '', '', '686.0925', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(6, 0, '', 0, 'Web Store Name', 'demo', 2, 1, 'Juliana', 'Davis', '+44 1688 308321', '', 'julidavis@abantecart.com', '', '', '', '', '', '', '', '', 0, '', 0, '', '', '', 'Juliana', 'Davis', '', 'Highlands and Islands PA75 6QE', '', 'Isle of Mull', '', 'Highlands', 3559, 'United Kingdom', 222, '', 'Cash On Delivery', '', '', 'Bulgari', '218.0850', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(7, 0, '', 0, 'Web Store Name', 'demo', 9, 1, 'Carlos', 'Compton', '+1 867-874-22391', '', 'carloscmpton@abantecart.com', '', '', '', '', '', '', '', '', 0, '', 0, '', '', '', 'Carlos', 'Compton', '', '31 Capital Drive', '', 'Hay River', '', 'Nova Scotia', 608, 'Canada', 38, '', 'Cash On Delivery', '', '', '', '175.7700', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(8, 0, '', 0, 'Web Store Name', 'demo', 8, 1, 'Bruce', 'Rosarini', '+1 807-346-10763', '', 'brucerosarini@abantecart.com', 'Bruce', 'Rosarini', '', '61 Cumberland ST', '', 'Thunder Bay', '', 'Minnesota', 3646, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', '', 'Bruce', 'Rosarini', '', '61 Cumberland ST', '', 'Thunder Bay', '', 'Minnesota', 3646, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', '', '', '', '62.0000', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(9, 0, '', 0, 'Web Store Name', 'demo', 8, 1, 'Bruce', 'Rosarini', '+1 807-346-10763', '', 'brucerosarini@abantecart.com', 'Bruce', 'Rosarini', '', '61 Cumberland ST', '', 'Thunder Bay', '', 'Minnesota', 3646, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', '', 'Bruce', 'Rosarini', '', '61 Cumberland ST', '', 'Thunder Bay', '', 'Minnesota', 3646, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', '', '', '', '352.0000', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(10, 0, '', 0, 'Web Store Name', 'demo', 12, 1, 'Allen', 'Waters', '+1 540-985-59700', '', 'allenwaters@abantecart.com', '', '', '', '', '', '', '', '', 0, '', 0, '', '', '', 'Allen', 'Waters', '', '110 Shenandoah Avenue', '', 'Roanoke', '', 'Virginia', 3673, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', '', '', '', '155.1550', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(11, 0, '', 0, 'Web Store Name', 'demo', 12, 1, 'Allen', 'Waters', '+1 540-985-59700', '', 'allenwaters@abantecart.com', 'Allen', 'Waters', '', '110 Shenandoah Avenue', '', 'Roanoke', '', 'Virginia', 3673, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', '', 'Allen', 'Waters', '', '110 Shenandoah Avenue', '', 'Roanoke', '', 'Virginia', 3673, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', '', '', '', '21.0000', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '109.104.166.98', NULL),
(12, 0, '', 0, 'Web Store Name', 'demo', 11, 1, 'Anthony', 'Blair', '+1 907-842-2240', '', 'anthonyblair@abantecart.com', 'Anthony', 'Blair', '', '104 Main Street', '', 'Dillingham', '', 'North Dakota', 3657, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', '', 'Anthony', 'Blair', '', '104 Main Street', '', 'Dillingham', '', 'North Dakota', 3657, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', '', '', '', '487.3750', 2, 1, 3, 'GBP', '0.63820000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '171.98.12.12', NULL),
(13, 0, '', 0, 'Web Store Name', 'demo', 11, 1, 'Anthony', 'Blair', '+1 907-842-2240', '', 'anthonyblair@abantecart.com', 'Anthony', 'Blair', '', '104 Main Street', '', 'Dillingham', '', 'North Dakota', 3657, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', '', 'Anthony', 'Blair', '', '104 Main Street', '', 'Dillingham', '', 'North Dakota', 3657, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', '', '', '', '626.9600', 1, 1, 3, 'GBP', '0.63820000', 0, '2019-03-18 06:07:51', '2019-03-18 06:07:51', '171.98.12.12', NULL),
(14, 0, '', 0, 'Web Store Name', 'demo', 13, 1, 'Michael', 'Neal', '55 555 5555 5555', '', 'michaelj@abantecart.com', 'Tom', 'Kipling', '', '100 Main Str', '', 'Shell Pile', '64034-2948', 'Missouri', 3648, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Tom', 'Kipling', '', '100 Main Str', '', 'Shell Pile', '64034-2948', 'Missouri', 3648, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', 'default_cod', '', '', '94.2300', 5, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:43:24', '2019-03-18 06:44:29', '77.111.246.167', NULL),
(15, 0, '', 0, 'Web Store Name', 'demo', 12, 1, 'Allen', 'Waters', '(417) 280-7406', '', 'allenwaters@abantecart.com', 'Allen', 'Waters', '', '110 Shenandoah Avenue', '', 'Honohina', '86565-1710', 'Arizona', 3616, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Allen', 'Waters', '', '110 Shenandoah Avenue', '', 'Honohina', '86565-1710', 'Arizona', 3616, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', 'default_cod', '', '', '30.2100', 3, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 06:50:54', '2019-03-18 06:56:40', '77.111.246.167', NULL),
(16, 0, '', 0, 'Web Store Name', 'demo', 14, 1, 'Yuri', 'Howard', '+1 (694) 373-3146', '', 'howardinc@abantecart.com', 'Yuri', 'Howard', 'Eaton Stevenson Inc', '22555 Jensen Ave', '', 'Reedley', '93654', 'California', 3624, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Yuri', 'Howard', 'Eaton Stevenson Inc', '22555 Jensen Ave', '', 'Reedley', '93654', 'California', 3624, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', 'default_cod', '', '', '15.1900', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-18 08:09:08', '2019-03-18 08:09:24', '85.235.65.198', NULL),
(17, 0, '', 0, 'Web Store Name', 'demo', 15, 1, 'Regan', 'Shields', '+1 (267) 125-5153', '', 'ricuvif@abantecart.com', 'Regan', 'Shields', 'Day and Rivera Traders', '2355 Boulevard Bastien', '', 'Québec', 'G2B 1B3', 'Qu&eacute;bec', 612, 'Canada', 38, '', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Regan', 'Shields', 'Day and Rivera Traders', '2355 Boulevard Bastien', '', 'Québec', 'G2B 1B3', 'Qu&eacute;bec', 612, 'Canada', 38, '', 'Cash On Delivery', 'default_cod', '', '', '36.9000', 5, 1, 1, 'USD', '1.00000000', 0, '2019-03-19 03:02:53', '2019-03-19 03:06:46', '23.129.64.106', NULL),
(18, 0, '', 0, 'Web Store Name', 'demo', 16, 1, 'Randall', 'Richards', ' 1 (788) 773-7896', ' 1 (706) 122-6856', 'randallri@abantecart.com', 'Randall', 'Richards', '', '500 N Nebraska Ave', '', 'Tampa', '33603', 'Florida', 3630, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Mallory', 'Ballard', 'Guzman and Morin Inc', '2430 S French Ave', '', 'Sanford', '32771', 'Florida', 3630, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', 'default_cod', '', '', '50.8300', 1, 1, 1, 'USD', '1.00000000', 0, '2019-03-21 06:40:03', '2022-06-28 02:38:05', '205.185.126.56', NULL),
(19, 0, '', 0, 'Web Store Name', 'demo', 12, 1, 'Allen', 'Waters', '(417) 280-7406', '', 'allenwaters@abantecart.com', 'Allen', 'Waters', '', '110 Shenandoah Avenue', '', 'Honohina', '86565-1710', 'Arizona', 3616, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Allen', 'Waters', '', '110 Shenandoah Avenue', '', 'Honohina', '86565-1710', 'Arizona', 3616, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', 'default_cod', '', '', '112.6700', 3, 1, 1, 'USD', '1.00000000', 0, '2019-05-06 00:35:01', '2022-06-28 02:37:42', '77.111.246.147', NULL),
(20, 0, '', 0, 'Web Store Name', 'demo', 12, 1, 'Allen', 'Waters', '(417) 280-7406', '', 'allenwaters@abantecart.com', 'Allen', 'Waters', '', '110 Shenandoah Avenue', '', 'Honohina', '86565-1710', 'Arizona', 3616, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Allen', 'Waters', '', '110 Shenandoah Avenue', '', 'Honohina', '86565-1710', 'Arizona', 3616, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', 'default_cod', '', '', '47.5700', 1, 1, 1, 'USD', '1.00000000', 0, '2019-05-06 00:49:57', '2022-06-28 02:37:29', '77.111.246.147', NULL),
(21, 0, '', 0, 'Web Store Name', 'https://demo.abantecart.com/', 17, 1, 'Michelle', 'Barnett', '1 469 537-8505', '', 'mbarnett@abantecart.com', 'Michelle', 'Barnett', '', '3180 S Redwood Rd', '', 'West Valley City', '84119', 'Utah', 3670, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Michelle', 'Barnett', '', '3180 S Redwood Rd', '', 'West Valley City', '84119', 'Utah', 3670, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', 'default_cod', '', 'Please don''t deliver the shipment on Friday as I won''t be available', '202.1737', 1, 1, 2, 'EUR', '0.93850000', 0, '2022-06-28 02:35:30', '2022-06-28 05:45:55', '77.111.246.40', NULL),
(22, 0, '', 0, 'Web Store Name', 'https://demo.abantecart.com/', 18, 1, 'Elmer', 'West', '(914) 328-0251', '', 'elmer@abantecart.com', 'Elmer', 'West', '', '1433 Armand-Frappier', '', 'Sainte-Julie', 'J3E 3R6', 'Qu&eacute;bec', 612, 'Canada', 38, '', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Elmer', 'West', '', '291 Central Ave', '', 'White Plains', '10606', 'North Dakota', 3657, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', 'default_cod', '', 'Please drop the parcel on the doorstep if the house is locked', '8.0000', 1, 1, 2, 'EUR', '0.93850000', 0, '2022-06-28 02:41:43', '2022-06-28 05:45:55', '77.111.247.7', NULL),
(23, 0, '', 0, 'Web Store Name', 'https://demo.abantecart.com/', 14, 1, 'Yuri', 'Howard', '16943733146', '', 'howardinc@abantecart.com', 'Yuri', 'Howard', 'Eaton Stevenson Inc', '22555 Jensen Ave', '', 'Reedley', '93654', 'California', 3624, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Yuri', 'Howard', 'Eaton Stevenson Inc', '22555 Jensen Ave', '', 'Reedley', '93654', 'California', 3624, 'United States', 223, '{firstname} {lastname}\r\n{company}\r\n{address_1}\r\n{address_2}\r\n{city}, {zone} {postcode}\r\n{country}', 'Cash On Delivery', 'default_cod', '', 'Please provide the order with gift wrap', '33.4700', 1, 1, 1, 'USD', '1.00000000', 0, '2022-06-28 03:14:08', '2022-06-28 05:45:55', '77.111.247.7', NULL),
(24, 0, '', 0, 'Web Store Name', 'https://demo.abantecart.com/', 18, 1, 'Elmer', 'West', ' 1 (128) 392-8036', '', 'elmer@abantecart.com', 'Elmer', 'West', '', '1433 Armand-Frappier', '', 'Sainte-Julie', 'J3E 3R6', 'Qu&eacute;bec', 612, 'Canada', 38, '', 'Flat Shipping Rate', 'default_flat_rate_shipping.default_flat_rate_shipping', 'Elmer', 'West', '', '1433 Armand-Frappier', '', 'Sainte-Julie', 'J3E 3R6', 'Qu&eacute;bec', 612, 'Canada', 38, '', 'Cash On Delivery', 'default_cod', '', '', '166.0000', 0, 1, 1, 'USD', '1.00000000', 0, '2022-07-13 01:21:51', '2022-07-13 01:31:24', '77.111.246.40', NULL);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_data`
--

CREATE TABLE `[[dbprefix]]order_data` (
  `order_id` int NOT NULL,
  `type_id` int NOT NULL,
  `data` text COLLATE utf8mb4_unicode_ci,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`order_id`,`type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]order_data`
--

INSERT INTO `[[dbprefix]]order_data` VALUES
(14, 1, 'a:2:{s:3:"uri";s:23:"michaelj@abantecart.com";s:6:"status";s:1:"1";}', '2019-03-18 06:43:24', '2019-03-18 06:43:24'),
(15, 1, 'a:2:{s:3:"uri";s:26:"allenwaters@abantecart.com";s:6:"status";s:1:"1";}', '2019-03-18 06:50:54', '2019-03-18 06:50:54'),
(16, 1, 'a:2:{s:3:"uri";s:24:"howardinc@abantecart.com";s:6:"status";s:1:"1";}', '2019-03-18 08:09:08', '2019-03-18 08:09:08'),
(17, 1, 'a:2:{s:3:"uri";s:22:"ricuvif@abantecart.com";s:6:"status";s:1:"1";}', '2019-03-19 03:02:53', '2019-03-19 03:02:53'),
(19, 1, 'a:2:{s:3:"uri";s:26:"allenwaters@abantecart.com";s:6:"status";s:1:"1";}', '2019-05-06 00:35:01', '2019-05-06 00:35:01'),
(20, 1, 'a:2:{s:3:"uri";s:26:"allenwaters@abantecart.com";s:6:"status";s:1:"1";}', '2019-05-06 00:49:57', '2019-05-06 00:49:57'),
(21, 1, 'a:2:{s:3:"uri";s:23:"mbarnett@abantecart.com";s:6:"status";s:1:"1";}', '2022-06-28 02:35:30', '2022-06-28 02:35:30'),
(21, 3, 'Zg4n0EGvzxHOwqPgZvxKPxv69saEan1t', '2022-06-28 02:35:34', '2022-06-28 02:35:34'),
(22, 1, 'a:2:{s:3:"uri";s:20:"elmer@abantecart.com";s:6:"status";s:1:"1";}', '2022-06-28 02:41:43', '2022-06-28 02:41:43'),
(22, 3, 'Tb5bV8sMYxBMXGCLw6YkBS1gKBvhcdMf', '2022-06-28 02:41:49', '2022-06-28 02:41:49');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_data_types`
--

CREATE TABLE `[[dbprefix]]order_data_types` (
  `type_id` int NOT NULL AUTO_INCREMENT,
  `language_id` int NOT NULL,
  `name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`type_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]order_data_types`
--

INSERT INTO `[[dbprefix]]order_data_types` VALUES
(1, 1, 'email', '[[regtime]]', '[[regtime]]'),
(2, 1, 'sms', '[[regtime]]', '[[regtime]]'),
(3, 1, 'guest_token', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_downloads`
--

CREATE TABLE `[[dbprefix]]order_downloads` (
  `order_download_id` int NOT NULL AUTO_INCREMENT,
  `order_id` int NOT NULL,
  `order_product_id` int NOT NULL,
  `name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `filename` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `mask` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `download_id` int NOT NULL,
  `status` int NOT NULL DEFAULT '0',
  `remaining_count` int DEFAULT NULL,
  `percentage` int DEFAULT '0',
  `expire_date` datetime DEFAULT NULL,
  `sort_order` int NOT NULL,
  `activate` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  `activate_order_status_id` varchar(256) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `attributes_data` longtext COLLATE utf8mb4_unicode_ci,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`order_download_id`),
  KEY `[[dbprefix]]order_downloads_idx` (`order_id`,`order_product_id`,`download_id`,`status`,`activate_order_status_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=3 ;

--
-- Dumping data for table `[[dbprefix]]order_downloads`
--

INSERT INTO `[[dbprefix]]order_downloads` VALUES
(1, 14, 50, 'Audio CD1', 'download/18/76/4.mp3', 'audio-cd.mp3', 1, 1, 49, 0, NULL, 0, '', '5', 'a:0:{}', '2019-03-18 06:43:24', '2019-03-18 06:44:47'),
(2, 16, 52, 'Find your fit', 'download/18/79/f.pdf', 'size-fit-guide-print.pdf', 5, 1, NULL, 0, NULL, 0, '', '0', 'a:0:{}', '2019-03-18 08:17:47', '2019-03-18 08:17:47');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_downloads_history`
--

CREATE TABLE `[[dbprefix]]order_downloads_history` (
  `order_download_history_id` int NOT NULL AUTO_INCREMENT,
  `order_download_id` int NOT NULL,
  `order_id` int NOT NULL,
  `order_product_id` int NOT NULL,
  `filename` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `mask` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `download_id` int NOT NULL,
  `download_percent` int DEFAULT '0',
  `time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`order_download_history_id`,`order_download_id`,`order_id`,`order_product_id`),
  KEY `[[dbprefix]]order_downloads_history_idx` (`download_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=8 ;

--
-- Dumping data for table `[[dbprefix]]order_downloads_history`
--

INSERT INTO `[[dbprefix]]order_downloads_history` VALUES
(1, 0, 0, 0, 'download/18/76/5.mp3', 'sample.mp3', 2, 100, '2015-07-08 05:06:06'),
(2, 1, 14, 50, 'download/18/76/4.mp3', 'audio-cd.mp3', 1, 100, '2019-03-18 06:44:47'),
(3, 0, 0, 0, 'download/18/76/5.mp3', 'sample.mp3', 2, 100, '2019-03-18 06:49:34'),
(4, 0, 0, 0, 'download/18/79/f.pdf', 'size-fit-guide-print.pdf', 5, 100, '2019-03-18 07:51:10'),
(5, 0, 0, 0, 'download/18/79/f.pdf', 'size-fit-guide-print.pdf', 5, 100, '2019-03-18 08:15:25'),
(6, 0, 0, 0, 'download/18/76/5.mp3', 'sample.mp3', 2, 100, '2019-03-18 08:17:11'),
(7, 0, 0, 0, 'download/18/79/f.pdf', 'size-fit-guide-print.pdf', 5, 100, '2019-03-19 04:47:30');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_history`
--

CREATE TABLE `[[dbprefix]]order_history` (
  `order_history_id` int NOT NULL AUTO_INCREMENT,
  `order_id` int NOT NULL,
  `order_status_id` int NOT NULL,
  `notify` int NOT NULL DEFAULT '0',
  `comment` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`order_history_id`),
  KEY `[[dbprefix]]order_history_idx` (`order_id`,`order_status_id`,`notify`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=26 ;

--
-- Dumping data for table `[[dbprefix]]order_history`
--

INSERT INTO `[[dbprefix]]order_history` VALUES
(2, 2, 1, 1, '', '2013-09-07 02:32:31', '2015-06-12 04:26:25'),
(3, 3, 1, 1, '', '2013-09-07 03:11:25', '2015-06-12 04:26:25'),
(4, 4, 1, 1, '', '2013-09-07 03:21:07', '2015-06-12 04:26:25'),
(5, 5, 1, 1, '', '2013-09-07 03:50:22', '2015-06-12 04:26:25'),
(6, 6, 1, 1, '', '2013-09-07 03:51:56', '2015-06-12 04:26:25'),
(7, 7, 1, 1, '', '2013-09-07 03:54:11', '2015-06-12 04:26:25'),
(8, 8, 1, 1, '', '2013-09-07 04:06:21', '2015-06-12 04:26:25'),
(9, 9, 1, 1, '', '2013-09-07 04:07:20', '2015-06-12 04:26:25'),
(10, 10, 1, 1, '', '2013-09-07 04:09:30', '2015-06-12 04:26:25'),
(11, 11, 1, 1, '', '2013-09-07 04:10:03', '2015-06-12 04:26:25'),
(12, 12, 1, 1, '', '2012-03-15 08:34:06', '2015-06-12 04:26:25'),
(13, 13, 1, 1, '', '2012-03-15 08:35:40', '2015-06-12 04:26:25'),
(14, 14, 1, 1, '', '2019-03-18 06:43:45', '2019-03-18 06:43:45'),
(15, 14, 5, 1, 'Thank you for your order!', '2019-03-18 06:44:29', '2019-03-18 06:44:29'),
(16, 15, 1, 1, '', '2019-03-18 06:51:03', '2019-03-18 06:51:03'),
(17, 15, 3, 1, 'Your order has been shipped. Tracking number is 4221736293', '2019-03-18 06:56:40', '2019-03-18 06:56:40'),
(18, 16, 1, 1, '', '2019-03-18 08:09:24', '2019-03-18 08:09:24'),
(19, 17, 1, 1, '', '2019-03-19 03:03:15', '2019-03-19 03:03:15'),
(20, 18, 1, 1, '', '2019-03-21 06:40:11', '2019-03-21 06:40:11'),
(21, 19, 1, 1, '', '2019-05-06 00:35:14', '2019-05-06 00:35:14'),
(22, 20, 1, 1, '', '2019-05-06 00:50:00', '2019-05-06 00:50:00'),
(23, 21, 1, 1, '', '2022-06-28 02:35:32', '2022-06-28 02:35:32'),
(24, 22, 1, 1, '', '2022-06-28 02:41:47', '2022-06-28 02:41:47'),
(25, 23, 1, 1, '', '2022-06-28 03:14:14', '2022-06-28 03:14:14');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_options`
--

CREATE TABLE `[[dbprefix]]order_options` (
  `order_option_id` int NOT NULL AUTO_INCREMENT,
  `order_id` int NOT NULL,
  `order_product_id` int NOT NULL,
  `product_option_value_id` int NOT NULL DEFAULT '0',
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `sku` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `value` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `price` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `cost` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `prefix` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `settings` longtext COLLATE utf8mb4_unicode_ci,
  PRIMARY KEY (`order_option_id`),
  KEY `[[dbprefix]]order_options_idx` (`order_id`,`order_product_id`,`product_option_value_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=52 ;

--
-- Dumping data for table `[[dbprefix]]order_options`
--

INSERT INTO `[[dbprefix]]order_options` VALUES
(2, 2, 7, 684, 'Color', '', 'brown', '10.0000', '0.0000', '+', NULL),
(3, 3, 9, 651, 'Size', '', '33.8 oz', '49.0000', '0.0000', '+', NULL),
(4, 3, 10, 650, 'Size', '', '8 oz', '19.0000', '0.0000', '+', NULL),
(5, 3, 15, 646, 'Color', '', 'Brown', '20.0000', '0.0000', '-', NULL),
(6, 4, 16, 613, 'Color', '', 'Mandarin Sky', '29.5000', '0.0000', '+', NULL),
(7, 4, 18, 664, 'Fragrance Size', '', '3.4 oz', '84.0000', '0.0000', '+', NULL),
(8, 4, 19, 673, 'Fragrance Size', '', '6.7 oz', '92.0000', '0.0000', '+', NULL),
(9, 4, 21, 661, 'Fragrance Size', '', '150ml', '45.0000', '0.0000', '+', NULL),
(10, 5, 23, 627, 'Color', '', 'Jade Fever', '48.0000', '0.0000', '+', NULL),
(11, 5, 24, 626, 'Color', '', 'Gris Fatale', '48.0000', '0.0000', '+', NULL),
(12, 5, 25, 622, 'Color', '', 'Shirelle', '15.0000', '0.0000', '+', NULL),
(13, 5, 26, 619, 'Color', '', 'Lacewood', '27.0000', '0.0000', '+', NULL),
(14, 5, 27, 657, 'Color', '', 'Light Bisque', '30.5000', '0.0000', '+', NULL),
(15, 5, 30, 651, 'Size', '', '33.8 oz', '49.0000', '0.0000', '+', NULL),
(16, 6, 31, 666, 'Size', '', '30 ml', '30.0000', '0.0000', '+', NULL),
(17, 7, 33, 649, 'Fragrance Size', '', '1.7 oz', '88.0000', '0.0000', '+', NULL),
(18, 7, 34, 660, 'Fragrance Size', '', '100ml', '37.0000', '0.0000', '+', NULL),
(19, 8, 35, 646, 'Color', '', 'Brown', '20.0000', '0.0000', '-', NULL),
(20, 8, 36, 681, 'Color', '', 'beige', '10.0000', '0.0000', '+', NULL),
(21, 12, 45, 721, 'Size', '', 'Eau de Toilette', '78.5000', '0.0000', '$', NULL),
(22, 12, 45, 1, 'Gift Wrapping', '', '1', '78.5000', '0.0000', '$', NULL),
(23, 12, 47, 738, 'Size', '', '30ml', '90.0000', '0.0000', '$', NULL),
(24, 13, 49, 713, 'Size', '', '1.7 oz', '72.0000', '0.0000', '$', NULL),
(25, 13, 49, 1, 'Gift Wrapping', '', '1', '72.0000', '0.0000', '$', NULL),
(26, 15, 51, 747, 'UK size', '', '3 UK ', '26.0000', '0.0000', '$', ''),
(27, 15, 51, 754, 'Colour', '', 'black', '26.0000', '0.0000', '$', ''),
(28, 16, 52, 783, 'Color&amp;Size', '', 'S / Red', '14.0000', '0.0000', '$', 'a:4:{s:10:"extensions";s:0:"";s:8:"min_size";s:0:"";s:8:"max_size";s:0:"";s:9:"directory";s:0:"";}'),
(29, 17, 53, 778, 'Size EU', '', 'EU XS (Asia M)', '21.0000', '0.0000', '$', ''),
(32, 18, 59, 749, 'UK size', '', '5 UK ', '26.0000', '0.0000', '$', ''),
(33, 18, 59, 752, 'Colour', '', 'white', '26.0000', '0.0000', '$', ''),
(34, 20, 61, 778, 'Size EU', '', 'EU XS (Asia M)', '21.0000', '0.0000', '$', ''),
(45, 21, 71, 657, 'Color', '', 'Light Bisque', '30.5000', '0.0000', '$', ''),
(46, 21, 72, 653, 'Color', '', 'Natural Ambre', '38.5000', '0.0000', '$', ''),
(47, 20, 62, 778, 'Size EU', '', 'EU XS (Asia M)', '0.0000', '0.0000', '$', NULL),
(51, 23, 80, 662, 'Fragrance Size', '', '50ml', '29.0000', '0.0000', '$', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_products`
--

CREATE TABLE `[[dbprefix]]order_products` (
  `order_product_id` int NOT NULL AUTO_INCREMENT,
  `order_id` int NOT NULL,
  `product_id` int NOT NULL,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `model` varchar(24) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `sku` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `price` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `cost` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `weight` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `weight_iso_code` varchar(5) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `width` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `length` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `height` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `length_iso_code` varchar(5) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `total` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `tax` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `quantity` int NOT NULL DEFAULT '0',
  `subtract` int NOT NULL DEFAULT '0',
  PRIMARY KEY (`order_product_id`),
  KEY `[[dbprefix]]order_products_idx` (`order_id`,`product_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=84 ;

--
-- Dumping data for table `[[dbprefix]]order_products`
--

INSERT INTO `[[dbprefix]]order_products` VALUES
(6, 2, 97, 'Eye Rejuvenating Serum', 'GRMBC004', '', '126.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '126.0000', '8.5000', 1, 0),
(7, 2, 100, 'Smooth silk lip pencils', 'GRMBC007', '', '10.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '40.0000', '8.5000', 4, 0),
(8, 2, 93, 'Creme Precieuse Nuit 50ml', 'BVLG003', '', '220.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '220.0000', '8.5000', 1, 0),
(9, 3, 69, 'Seaweed Conditioner', 'SCND001', '', '49.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '49.0000', '0.0000', 1, 0),
(10, 3, 69, 'Seaweed Conditioner', 'SCND001', '', '19.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '19.0000', '0.0000', 1, 0),
(11, 3, 77, 'Men+Care Active Clean Shower Tool', 'DMBW0014', '', '6.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '6.0000', '0.0000', 1, 0),
(12, 3, 98, 'Shaving cream', 'GRMBC005', '', '98.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '98.0000', '0.0000', 1, 0),
(13, 3, 62, 'ck one shock for him Deodorant', '601232', '', '14.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '14.0000', '0.0000', 1, 0),
(14, 3, 66, 'Total Moisture Facial Cream', '556240', '', '38.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '38.0000', '0.0000', 1, 0),
(15, 3, 54, 'L''EXTRÊME Instant Extensions Lengthening Mascara', '74144', '', '20.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '20.0000', '0.0000', 1, 0),
(16, 4, 57, 'Delicate Oil-Free Powder Blush', '117148', '', '29.5000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '29.5000', '8.5000', 1, 0),
(17, 4, 67, 'Flash Bronzer Body Gel', '463686', '', '29.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '29.0000', '8.5000', 1, 0),
(18, 4, 80, 'Acqua Di Gio Pour Homme', 'GRM001', '', '84.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '84.0000', '8.5000', 1, 0),
(19, 4, 89, 'Secret Obsession Perfume', 'CK0012', '', '92.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '92.0000', '8.5000', 1, 0),
(20, 4, 75, 'Dove Men +Care Body Wash', 'DMBW0012', '', '6.7000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '6.7000', '8.5000', 1, 0),
(21, 4, 78, 'ck IN2U Eau De Toilette Spray for Him', 'Cl0001', '', '45.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '45.0000', '8.5000', 1, 0),
(22, 5, 97, 'Eye Rejuvenating Serum', 'GRMBC004', '', '126.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '126.0000', '8.5000', 1, 0),
(23, 5, 61, 'Color Design Eye Brightening All in One 5 Shadow &amp; Liner Palette', '529071', '', '48.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '48.0000', '8.5000', 1, 0),
(24, 5, 61, 'Color Design Eye Brightening All in One 5 Shadow &amp; Liner Palette', '529071', '', '48.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '96.0000', '8.5000', 2, 0),
(25, 5, 60, 'Nail Lacquer', '112423', '', '15.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '15.0000', '8.5000', 1, 0),
(26, 5, 55, 'LE ROUGE ABSOLU Reshaping &amp; Replenishing LipColour SPF 15', 'tw152236', '', '27.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '27.0000', '8.5000', 1, 0),
(27, 5, 56, 'Waterproof Protective Undereye Concealer', '35190', '', '30.5000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '30.5000', '8.5000', 1, 0),
(28, 5, 51, 'BeneFit Girl Meets Pearl', '483857', '', '19.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '19.0000', '8.5000', 1, 0),
(29, 5, 93, 'Creme Precieuse Nuit 50ml', 'BVLG003', '', '220.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '220.0000', '8.5000', 1, 0),
(30, 5, 69, 'Seaweed Conditioner', 'SCND001', '', '49.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '49.0000', '8.5000', 1, 0),
(31, 6, 84, 'Armani Code Pour Femme', 'GRM005', '', '30.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '30.0000', '8.5000', 1, 0),
(32, 6, 92, 'Body Cream by Bulgari', 'BVLG002', '', '57.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '171.0000', '8.5000', 3, 0),
(33, 7, 63, 'Pour Homme Eau de Toilette', '374622', '', '88.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '88.0000', '8.5000', 1, 0),
(34, 7, 78, 'ck IN2U Eau De Toilette Spray for Him', 'Cl0001', '', '37.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '74.0000', '8.5000', 2, 0),
(35, 8, 54, 'L''EXTRÊME Instant Extensions Lengthening Mascara', '74144', '', '20.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '20.0000', '0.0000', 1, 0),
(36, 8, 100, 'Smooth silk lip pencils', 'GRMBC007', '', '10.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '40.0000', '0.0000', 4, 0),
(37, 9, 94, 'Night Care Crema Nera Obsidian Mineral Complex', 'GRMBC001', '', '263.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '263.0000', '0.0000', 1, 0),
(38, 9, 67, 'Flash Bronzer Body Gel', '463686', '', '29.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '29.0000', '0.0000', 1, 0),
(39, 9, 91, 'Jasmin Noir Body Lotion 6.8 fl oz', 'BVLG001', '', '29.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '58.0000', '0.0000', 2, 0),
(40, 10, 72, 'Brunette expressions Conditioner', 'PCND002', '', '24.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '24.0000', '8.5000', 1, 0),
(41, 10, 81, 'Armani Eau de Toilette Spray ', 'GRM002', '', '61.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '61.0000', '8.5000', 1, 0),
(42, 10, 88, 'ck one Summer 3.4 oz', 'CK0011', '', '27.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '27.0000', '8.5000', 1, 0),
(43, 10, 70, 'Eau Parfumee au The Vert Shampoo', '522823', '', '31.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '31.0000', '8.5000', 1, 0),
(44, 11, 51, 'BeneFit Girl Meets Pearl', '483857', '', '19.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '19.0000', '0.0000', 1, 0),
(45, 12, 105, 'Bvlgari Aqua', 'PRF00273', '', '78.5000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '78.5000', '0.0000', 1, 0),
(46, 12, 65, 'Absolue Eye Precious Cells', '427847', '', '105.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '105.0000', '8.5000', 1, 0),
(47, 12, 110, 'Flora By Gucci Eau Fraiche', 'PRF00278', '', '90.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '270.0000', '8.5000', 3, 0),
(48, 12, 95, 'Skin Minerals For Men Cleansing Cream', 'GRMBC002', '', '104.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '0.0000', '8.5000', 0, 0),
(49, 13, 104, 'Calvin Klein Obsession For Women EDP Spray', 'PRF00271', '', '72.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '576.0000', '8.5000', 8, 0),
(50, 14, 111, 'New French With Ease (1 book + 1 mp3 CD)', '', '', '85.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '85.0000', '7.2250', 1, 1),
(51, 15, 116, 'New Ladies High Wedge Heel Toe Thong Diamante Flip Flop Sandals', '', '', '26.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '26.0000', '2.2100', 1, 1),
(52, 16, 123, 'Casual 3/4 Sleeve Baseball T-Shirt', 'LTQFX', '#2738', '14.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '14.0000', '1.1900', 1, 1),
(53, 17, 122, 'Mens Fine Cotton Giraffe Polo Shirts', 'JDSK36', '', '21.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '21.0000', '0.0000', 1, 1),
(54, 17, 75, 'Dove Men +Care Body Wash', 'DMBW0012', '', '6.7000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '6.7000', '0.0000', 1, 1),
(55, 17, 76, 'Men+Care Clean Comfort Deodorant', 'DMBW0013', '1235B', '7.2000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '7.2000', '0.0000', 1, 1),
(58, 18, 51, 'BeneFit Girl Meets Pearl', '483857', '', '19.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '19.0000', '1.6150', 1, 1),
(59, 18, 116, 'New Ladies High Wedge Heel Toe Thong Diamante Flip Flop Sandals', '', '', '26.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '26.0000', '2.2100', 1, 1),
(62, 20, 122, 'Product with options and stock locations', 'JDSK36', '', '21.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '42.0000', '0.0000', 2, 0),
(63, 19, 58, 'Product with stock locations', '374002', '', '34.0000', '0.0000', '0.0000', '', '0.0000', '0.0000', '0.0000', '', '102.0000', '0.0000', 3, 0),
(71, 21, 56, 'Waterproof Protective Undereye Concealer', '35190', '', '30.5000', '0.0000', '85.0000', 'g', '0.0000', '0.0000', '0.0000', 'cm', '30.5000', '2.5925', 1, 1),
(72, 21, 53, 'Tropiques Minerale Loose Bronzer', '380440', '', '38.5000', '22.0000', '100.0000', 'g', '0.0000', '0.0000', '0.0000', 'in', '154.0000', '13.0900', 4, 1),
(76, 22, 77, 'Men Care Active Clean Shower Tool', 'DMBW0014', '1234B', '6.0000', '2.0000', '0.3000', 'kg', '0.0000', '0.0000', '0.0000', 'in', '6.0000', '0.0000', 1, 1),
(80, 23, 78, 'ck IN2U Eau De Toilette Spray for Him', 'Cl0001', '', '29.0000', '0.0000', '125.0000', 'g', '0.0000', '0.0000', '0.0000', 'cm', '29.0000', '2.4650', 1, 1),
(83, 24, 96, 'Eye master', 'GRMBC003', '', '82.0000', '67.0000', '80.0000', 'g', '0.0000', '0.0000', '0.0000', 'cm', '164.0000', '0.0000', 2, 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_product_stock_locations`
--

CREATE TABLE `[[dbprefix]]order_product_stock_locations` (
  `order_product_id` int NOT NULL,
  `product_id` int NOT NULL,
  `product_option_value_id` int DEFAULT NULL,
  `location_id` int NOT NULL,
  `location_name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `quantity` int NOT NULL DEFAULT '0',
  `sort_order` int DEFAULT '0',
  KEY `[[dbprefix]]product_options_value_idx` (`product_option_value_id`),
  KEY `[[dbprefix]]product_options_value_idx2` (`order_product_id`,`product_id`,`product_option_value_id`,`location_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]order_product_stock_locations`
--

INSERT INTO `[[dbprefix]]order_product_stock_locations` VALUES
(62, 122, 778, 2, 'Canada', 2, 0),
(62, 122, 778, 1, 'USA All States', 0, 0),
(63, 58, NULL, 2, 'Canada', 3, 0),
(63, 58, NULL, 1, 'USA All States', 0, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_statuses`
--

CREATE TABLE `[[dbprefix]]order_statuses` (
  `order_status_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`order_status_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]order_statuses`
--

INSERT INTO `[[dbprefix]]order_statuses` VALUES
(0, 1, 'Incomplete'),
(1, 1, 'Pending'),
(2, 1, 'Processing'),
(3, 1, 'Shipped'),
(5, 1, 'Completed'),
(7, 1, 'Canceled'),
(8, 1, 'Denied'),
(9, 1, 'Canceled Reversal'),
(10, 1, 'Failed'),
(11, 1, 'Refunded'),
(12, 1, 'Reversed'),
(13, 1, 'Chargeback'),
(14, 1, 'Canceled by Customer');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_status_ids`
--

CREATE TABLE `[[dbprefix]]order_status_ids` (
  `order_status_id` int NOT NULL,
  `status_text_id` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  PRIMARY KEY (`order_status_id`,`status_text_id`),
  UNIQUE KEY `[[dbprefix]]order_status_ids_idx` (`status_text_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]order_status_ids`
--

INSERT INTO `[[dbprefix]]order_status_ids` VALUES
(7, 'canceled'),
(14, 'canceled_by_customer'),
(9, 'canceled_reversal'),
(13, 'chargeback'),
(5, 'completed'),
(8, 'denied'),
(10, 'failed'),
(0, 'incomplete'),
(1, 'pending'),
(2, 'processing'),
(11, 'refunded'),
(12, 'reversed'),
(3, 'shipped');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_totals`
--

CREATE TABLE `[[dbprefix]]order_totals` (
  `order_total_id` int NOT NULL AUTO_INCREMENT,
  `order_id` int NOT NULL,
  `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `text` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `value` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `sort_order` int NOT NULL,
  `type` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `key` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (`order_total_id`),
  KEY `idx_orders_total_orders_id` (`order_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=123 ;

--
-- Dumping data for table `[[dbprefix]]order_totals`
--

INSERT INTO `[[dbprefix]]order_totals` VALUES
(4, 2, 'Sub-Total:', '$386.00', '386.0000', 1, 'subtotal', 'sub_total'),
(5, 2, 'Retail 8.5%:', '$32.81', '32.8100', 5, 'tax', 'tax'),
(6, 2, 'Total:', '$418.81', '418.8100', 6, 'total', 'total'),
(7, 3, 'Sub-Total:', '$244.00', '244.0000', 1, 'subtotal', 'sub_total'),
(8, 3, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(9, 3, 'Total:', '$246.00', '246.0000', 6, 'total', 'total'),
(10, 4, 'Sub-Total:', '$286.20', '286.2000', 1, 'subtotal', 'sub_total'),
(11, 4, 'Retail 8.5%:', '$24.33', '24.3270', 5, 'tax', 'tax'),
(12, 4, 'Total:', '$310.53', '310.5270', 6, 'total', 'total'),
(13, 5, 'Sub-Total:', '$630.50', '630.5000', 1, 'subtotal', 'sub_total'),
(14, 5, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(15, 5, 'Retail 8.5%:', '$53.59', '53.5925', 5, 'tax', 'tax'),
(16, 5, 'Total:', '$686.09', '686.0925', 6, 'total', 'total'),
(17, 6, 'Sub-Total:', '$201.00', '201.0000', 1, 'subtotal', 'sub_total'),
(18, 6, 'Retail 8.5%:', '$17.09', '17.0850', 5, 'tax', 'tax'),
(19, 6, 'Total:', '$218.09', '218.0850', 6, 'total', 'total'),
(20, 7, 'Sub-Total:', '$162.00', '162.0000', 1, 'subtotal', 'sub_total'),
(21, 7, 'Retail 8.5%:', '$13.77', '13.7700', 5, 'tax', 'tax'),
(22, 7, 'Total:', '$175.77', '175.7700', 6, 'total', 'total'),
(23, 8, 'Sub-Total:', '$60.00', '60.0000', 1, 'subtotal', 'sub_total'),
(24, 8, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(25, 8, 'Total:', '$62.00', '62.0000', 6, 'total', 'total'),
(26, 9, 'Sub-Total:', '$350.00', '350.0000', 1, 'subtotal', 'sub_total'),
(27, 9, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(28, 9, 'Total:', '$352.00', '352.0000', 6, 'total', 'total'),
(29, 10, 'Sub-Total:', '$143.00', '143.0000', 1, 'subtotal', 'sub_total'),
(30, 10, 'Retail 8.5%:', '$12.16', '12.1550', 5, 'tax', 'tax'),
(31, 10, 'Total:', '$155.16', '155.1550', 6, 'total', 'total'),
(32, 11, 'Sub-Total:', '$19.00', '19.0000', 1, 'subtotal', 'sub_total'),
(33, 11, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(34, 11, 'Total:', '$21.00', '21.0000', 6, 'total', 'total'),
(35, 12, 'Sub-Total:', '£289.42', '453.5000', 1, 'subtotal', 'sub_total'),
(36, 12, 'Flat Shipping Rate:', '£1.28', '2.0000', 3, 'shipping', 'shipping'),
(37, 12, 'Retail 8.5%:', '£20.34', '31.8750', 5, 'tax', 'tax'),
(38, 12, 'Total:', '£311.04', '487.3750', 6, 'total', 'total'),
(39, 13, 'Sub-Total:', '£367.60', '576.0000', 1, 'subtotal', 'sub_total'),
(40, 13, 'Flat Shipping Rate:', '£1.28', '2.0000', 3, 'shipping', 'shipping'),
(41, 13, 'Retail 8.5%:', '£31.25', '48.9600', 5, 'tax', 'tax'),
(42, 13, 'Total:', '£400.13', '626.9600', 6, 'total', 'total'),
(43, 14, 'Sub-Total:', '$85.00', '85.0000', 1, 'subtotal', 'subtotal'),
(44, 14, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(45, 14, 'Retail 8.5%:', '$7.23', '7.2300', 5, 'tax', 'tax'),
(46, 14, 'Total:', '$94.23', '94.2300', 1000, 'total', 'total'),
(47, 15, 'Sub-Total:', '$26.00', '26.0000', 1, 'subtotal', 'subtotal'),
(48, 15, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(49, 15, 'Retail 8.5%:', '$2.21', '2.2100', 5, 'tax', 'tax'),
(50, 15, 'Total:', '$30.21', '30.2100', 1000, 'total', 'total'),
(51, 16, 'Sub-Total:', '$14.00', '14.0000', 1, 'subtotal', 'subtotal'),
(52, 16, 'Flat Shipping Rate:', '$0.00', '0.0000', 3, 'shipping', 'shipping'),
(53, 16, 'Retail 8.5%:', '$1.19', '1.1900', 5, 'tax', 'tax'),
(54, 16, 'Total:', '$15.19', '15.1900', 1000, 'total', 'total'),
(55, 17, 'Sub-Total:', '$34.90', '34.9000', 1, 'subtotal', 'subtotal'),
(56, 17, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(57, 17, 'Total:', '$36.90', '36.9000', 1000, 'total', 'total'),
(62, 18, 'Sub-Total:', '$45.00', '45.0000', 1, 'subtotal', 'subtotal'),
(63, 18, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(64, 18, 'Retail 8.5%:', '$3.83', '3.8300', 5, 'tax', 'tax'),
(65, 18, 'Total:', '$50.83', '50.8300', 1000, 'total', 'total'),
(66, 19, 'Sub-Total:', '$102.00', '102.0000', 1, 'subtotal', 'subtotal'),
(67, 19, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(68, 19, 'Retail 8.5%:', '$8.67', '8.6700', 5, 'tax', 'tax'),
(69, 19, 'Total:', '$112.67', '112.6700', 1000, 'total', 'total'),
(70, 20, 'Sub-Total:', '$42.00', '42.0000', 1, 'subtotal', 'subtotal'),
(71, 20, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(72, 20, 'Retail 8.5%:', '$3.57', '3.5700', 5, 'tax', 'tax'),
(73, 20, 'Total:', '$47.57', '47.5700', 1000, 'total', 'total'),
(85, 21, 'Sub-Total:', '173.14€', '184.4859', 1, 'subtotal', 'subtotal'),
(86, 21, 'Flat Shipping Rate:', '1.88€', '2.0000', 3, 'shipping', 'shipping'),
(87, 21, 'Retail 8.5%:', '14.72€', '15.6800', 5, 'tax', 'tax'),
(88, 21, 'Total:', '189.74€', '202.1737', 1000, 'total', 'total'),
(97, 22, 'Sub-Total:', '5.63€', '6.0000', 1, 'subtotal', 'subtotal'),
(98, 22, 'Flat Shipping Rate:', '1.88€', '2.0000', 3, 'shipping', 'shipping'),
(99, 22, 'Total:', '7.51€', '8.0000', 1000, 'total', 'total'),
(111, 23, 'Sub-Total:', '$29.00', '29.0000', 1, 'subtotal', 'subtotal'),
(112, 23, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(113, 23, 'Retail 8.5%:', '$2.47', '2.4700', 5, 'tax', 'tax'),
(114, 23, 'Total:', '$33.47', '33.4700', 1000, 'total', 'total'),
(120, 24, 'Sub-Total:', '$164.00', '164.0000', 1, 'subtotal', 'subtotal'),
(121, 24, 'Flat Shipping Rate:', '$2.00', '2.0000', 3, 'shipping', 'shipping'),
(122, 24, 'Total:', '$166.00', '166.0000', 1000, 'total', 'total');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]pages`
--

CREATE TABLE `[[dbprefix]]pages` (
  `page_id` int NOT NULL AUTO_INCREMENT,
  `parent_page_id` int NOT NULL DEFAULT '0',
  `controller` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  `key_param` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `key_value` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`page_id`),
  UNIQUE KEY `[[dbprefix]]pages_idx` (`page_id`,`controller`,`key_param`,`key_value`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=21 ;

--
-- Dumping data for table `[[dbprefix]]pages`
--

INSERT INTO `[[dbprefix]]pages` VALUES
(1, 0, 'generic', '', '', '[[regtime]]', '[[regtime]]'),
(2, 0, 'pages/index/home', '', '', '[[regtime]]', '[[regtime]]'),
(3, 0, 'pages/account/login', '', '', '[[regtime]]', '[[regtime]]'),
(4, 0, 'pages/content/contact', '', '', '[[regtime]]', '[[regtime]]'),
(5, 0, 'pages/product/product', '', '', '[[regtime]]', '[[regtime]]'),
(6, 0, 'pages/product/category', '', '', '[[regtime]]', '[[regtime]]'),
(7, 0, 'pages/index/maintenance', '', '', '[[regtime]]', '[[regtime]]'),
(8, 0, 'pages/account/account', '', '', '[[regtime]]', '[[regtime]]'),
(9, 0, 'pages/account/edit', '', '', '[[regtime]]', '[[regtime]]'),
(10, 0, 'pages/account/password', '', '', '[[regtime]]', '[[regtime]]'),
(11, 0, 'pages/account/address', '', '', '[[regtime]]', '[[regtime]]'),
(12, 0, 'pages/account/wishlist', '', '', '[[regtime]]', '[[regtime]]'),
(13, 0, 'pages/account/history', '', '', '[[regtime]]', '[[regtime]]'),
(14, 0, 'pages/account/transactions', '', '', '[[regtime]]', '[[regtime]]'),
(15, 0, 'pages/account/download', '', '', '[[regtime]]', '[[regtime]]'),
(16, 0, 'pages/account/notification', '', '', '[[regtime]]', '[[regtime]]'),
(17, 0, 'pages/checkout/cart', '', '', '[[regtime]]', '[[regtime]]'),
(18, 0, 'pages/checkout/fast_checkout', '', '', '[[regtime]]', '[[regtime]]'),
(19, 0, 'pages/checkout/fast_checkout_success', '', '', '[[regtime]]', '[[regtime]]'),
(20, 0, 'pages/content/content', '', '', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]pages_forms`
--

CREATE TABLE `[[dbprefix]]pages_forms` (
  `page_id` int NOT NULL,
  `form_id` int NOT NULL,
  PRIMARY KEY (`form_id`,`page_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]pages_layouts`
--

CREATE TABLE `[[dbprefix]]pages_layouts` (
  `layout_id` int NOT NULL,
  `page_id` int NOT NULL,
  PRIMARY KEY (`layout_id`,`page_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]pages_layouts`
--

INSERT INTO `[[dbprefix]]pages_layouts` VALUES
(1, 1),
(2, 2),
(3, 3),
(4, 4),
(5, 5),
(6, 6),
(7, 7),
(8, 8),
(9, 9),
(10, 10),
(11, 11),
(12, 12),
(13, 13),
(14, 14),
(15, 15),
(16, 16),
(17, 17),
(18, 18),
(19, 19),
(20, 20),
(21, 1),
(22, 2),
(23, 3),
(24, 4),
(25, 5),
(26, 6),
(27, 7),
(28, 8),
(29, 9),
(30, 10),
(31, 11),
(32, 12),
(33, 13),
(34, 14),
(35, 15),
(36, 16),
(37, 17),
(38, 18),
(39, 19),
(40, 20);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]page_descriptions`
--

CREATE TABLE `[[dbprefix]]page_descriptions` (
  `page_id` int NOT NULL DEFAULT '0',
  `language_id` int NOT NULL,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `title` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `seo_url` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `keywords` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  `description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  `content` text COLLATE utf8mb4_unicode_ci COMMENT 'translatable',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`page_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]page_descriptions`
--

INSERT INTO `[[dbprefix]]page_descriptions` VALUES
(1, 1, 'All Other Pages', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(2, 1, 'Home Page', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(3, 1, 'Login Page', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(4, 1, 'Contact Us Page', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(5, 1, 'Default Product Page', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(6, 1, 'Product Listing Page (Category)', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(7, 1, 'Maintenance Page', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(8, 1, 'Customer Dashboard', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(9, 1, 'Account Details', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(10, 1, 'Change Password', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(11, 1, 'Addresses', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(12, 1, 'Wish List', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(13, 1, 'Order History', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(14, 1, 'Transaction History', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(15, 1, 'Downloads', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(16, 1, 'Notifications', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(17, 1, 'Cart Page', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(18, 1, 'Fast Checkout Page', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(19, 1, 'Fast Checkout Success Page', '', '', '', '', '', '[[regtime]]', '[[regtime]]'),
(20, 1, 'Default Content Page', '', '', '', '', '', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]products`
--

CREATE TABLE `[[dbprefix]]products` (
  `product_id` int NOT NULL AUTO_INCREMENT,
  `model` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  `sku` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  `location` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL,
  `quantity` int NOT NULL DEFAULT '0',
  `stock_checkout` char(1) COLLATE utf8mb4_unicode_ci DEFAULT '',
  `stock_status_id` int NOT NULL,
  `manufacturer_id` int NOT NULL,
  `shipping` int NOT NULL DEFAULT '1',
  `ship_individually` int NOT NULL DEFAULT '0',
  `free_shipping` int NOT NULL DEFAULT '0',
  `shipping_price` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `price` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `tax_class_id` int NOT NULL,
  `date_available` date NOT NULL,
  `weight` decimal(5,2) NOT NULL DEFAULT '0.00',
  `weight_class_id` int NOT NULL DEFAULT '0',
  `length` decimal(5,2) NOT NULL DEFAULT '0.00',
  `width` decimal(5,2) NOT NULL DEFAULT '0.00',
  `height` decimal(5,2) NOT NULL DEFAULT '0.00',
  `length_class_id` int NOT NULL DEFAULT '0',
  `status` int NOT NULL DEFAULT '0',
  `viewed` int NOT NULL DEFAULT '0',
  `sort_order` int NOT NULL DEFAULT '0',
  `subtract` int NOT NULL DEFAULT '1',
  `minimum` int NOT NULL DEFAULT '1',
  `maximum` int NOT NULL DEFAULT '0',
  `cost` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `call_to_order` smallint NOT NULL DEFAULT '0',
  `supplier_code` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `supplier_id` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `settings` longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`product_id`),
  UNIQUE KEY `[[dbprefix]]products_supplier_idx` (`supplier_code`,`supplier_id`),
  KEY `[[dbprefix]]products_idx` (`stock_status_id`,`manufacturer_id`,`weight_class_id`,`length_class_id`),
  KEY `[[dbprefix]]products_status_idx` (`product_id`,`status`,`date_available`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=125 ;

--
-- Dumping data for table `[[dbprefix]]products`
--

INSERT INTO `[[dbprefix]]products` VALUES
(50, '558003', '', '', 99, '', 1, 11, 1, 0, 0, '0.0000', '29.5000', 1, '2022-07-01', '75.00', 2, '0.00', '0.00', '0.00', 1, 1, 9, 1, 0, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:16:40'),
(51, '483857', '', '', 97, '', 1, 12, 1, 0, 0, '0.0000', '30.0000', 1, '2013-08-29', '0.05', 1, '0.00', '0.00', '0.00', 1, 1, 9, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 04:43:49'),
(52, '523755', '', '', 99, '', 1, 12, 1, 0, 0, '0.0000', '28.0000', 0, '2013-08-29', '0.80', 1, '0.00', '0.00', '0.00', 2, 1, 5, 1, 1, 2, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 04:43:56'),
(53, '380440', '', '', 1000, '', 0, 15, 1, 0, 0, '0.0000', '38.5000', 1, '2021-08-31', '100.00', 2, '0.00', '0.00', '0.00', 3, 1, 11, 1, 1, 1, 0, '22.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 04:44:11'),
(54, '74144', '', '', 999, '', 1, 15, 1, 0, 0, '0.0000', '25.0000', 1, '2022-01-06', '0.15', 1, '0.00', '0.00', '0.00', 2, 1, 15, 1, 1, 1, 0, '0.0000', 1, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 04:44:35'),
(55, 'tw152236', '', '', 1000, '', 1, 15, 1, 0, 0, '0.0000', '29.0000', 1, '2019-08-29', '0.08', 1, '0.00', '0.00', '0.00', 2, 1, 8, 1, 1, 1, 0, '22.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 04:44:47'),
(56, '35190', '', '', 1000, '', 1, 15, 1, 0, 0, '0.0000', '29.5000', 1, '2021-08-29', '85.00', 2, '0.00', '0.00', '0.00', 1, 1, 12, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 04:45:03'),
(57, '117148', 'SKGLM004', '', 1000, '', 1, 15, 1, 0, 0, '0.0000', '29.5000', 1, '2013-08-29', '0.20', 1, '0.00', '0.00', '0.00', 1, 1, 13, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 04:50:36'),
(58, '374002', '', '', 36, '', 0, 12, 1, 0, 0, '0.0000', '34.0000', 1, '2013-08-29', '25.00', 2, '0.00', '0.00', '0.00', 3, 1, 6, 1, 1, 1, 0, '10.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:16:14'),
(59, '14.50', 'SKGLM002', '', 1000, '', 1, 11, 1, 0, 0, '0.0000', '5.0000', 1, '2021-08-15', '75.00', 2, '0.00', '0.00', '0.00', 1, 1, 3, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 04:50:15'),
(60, '112423', 'SKC001', '', 1000, '', 1, 11, 1, 0, 0, '0.0000', '15.0000', 1, '2021-08-30', '0.30', 2, '0.00', '0.00', '0.00', 2, 1, 3, 1, 0, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 04:49:51'),
(61, '529071', '', '', 1000, '', 1, 15, 1, 0, 0, '0.0000', '48.0000', 1, '2021-08-30', '0.13', 2, '0.00', '0.00', '0.00', 1, 1, 5, 1, 0, 1, 0, '29.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:06:59'),
(62, '601232', '', '', 1000, '', 1, 13, 1, 0, 0, '0.0000', '14.0000', 1, '2013-08-30', '0.50', 1, '0.00', '0.00', '0.00', 3, 1, 5, 1, 0, 1, 0, '8.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:06:50'),
(63, '374622', 'PH001', '', 1000, '', 1, 14, 1, 0, 0, '0.0000', '88.0000', 1, '2021-08-30', '0.75', 1, '55.00', '90.00', '120.00', 2, 1, 5, 1, 0, 1, 0, '55.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:08:17'),
(64, '497303', '', '', 1000, '', 1, 13, 1, 0, 0, '0.0000', '50.0000', 1, '2013-08-30', '150.00', 2, '0.00', '0.00', '0.00', 1, 1, 9, 1, 1, 1, 0, '33.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:08:27'),
(65, '427847', '', '', 1000, '', 1, 15, 1, 0, 0, '0.0000', '105.0000', 1, '2013-08-30', '70.00', 2, '0.00', '0.00', '0.00', 1, 1, 23, 1, 0, 1, 0, '99.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:16:24'),
(66, '556240', '', '', 145, '', 1, 12, 1, 0, 0, '0.0000', '38.0000', 1, '2021-08-30', '0.40', 1, '0.00', '0.00', '0.00', 3, 1, 5, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:16:34'),
(67, '463686', '', '', 0, '', 0, 15, 1, 0, 0, '0.0000', '34.5000', 1, '2021-08-30', '0.30', 1, '6.00', '3.00', '5.00', 1, 1, 7, 1, 1, 1, 0, '22.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:07:15'),
(68, '108681', '', '', 1000, '', 1, 15, 1, 0, 0, '0.0000', '42.0000', 1, '2013-08-30', '0.11', 1, '0.00', '0.00', '0.00', 2, 1, 1, 1, 1, 1, 0, '24.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:16:19'),
(69, 'SCND001', '', '', 1000, '', 1, 16, 1, 0, 0, '0.0000', '19.0000', 1, '2021-08-30', '0.25', 1, '0.00', '0.00', '0.00', 1, 1, 7, 1, 0, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:08:35'),
(70, '522823', '', '', 1000, '', 1, 14, 1, 0, 0, '0.0000', '31.0000', 1, '2022-06-05', '0.25', 2, '0.00', '0.00', '0.00', 3, 1, 5, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:08:49'),
(71, 'PCND001', '', '', 1000, '', 1, 17, 1, 0, 0, '0.0000', '11.4500', 1, '2013-08-30', '0.30', 1, '0.00', '0.00', '0.00', 1, 1, 4, 1, 1, 1, 0, '5.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:08:57'),
(72, 'PCND002', '', '', 1000, '', 1, 17, 1, 0, 0, '0.0000', '27.0000', 1, '2013-08-30', '0.40', 1, '0.00', '0.00', '0.00', 1, 1, 7, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:09:04'),
(73, 'PCND003', '', '', 1000, '', 1, 17, 1, 0, 0, '0.0000', '33.0000', 1, '2021-08-30', '0.40', 1, '0.00', '0.00', '0.00', 1, 1, 3, 1, 1, 1, 0, '21.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:09:14'),
(74, 'PCND004', '', '', 10000, '', 1, 17, 1, 0, 0, '0.0000', '4.0000', 1, '2021-08-30', '0.35', 1, '0.00', '0.00', '0.00', 1, 1, 5, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:09:26'),
(75, 'DMBW0012', '', '', 999, '', 1, 18, 1, 0, 0, '0.0000', '6.7000', 1, '2013-08-30', '0.20', 1, '0.00', '0.00', '0.00', 1, 1, 3, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:09:45'),
(76, 'DMBW0013', '1235B', '', 98, '', 1, 18, 1, 0, 0, '0.0000', '7.2000', 1, '2021-08-30', '0.20', 1, '0.00', '0.00', '0.00', 1, 1, 6, 1, 1, 1, 0, '4.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:09:52'),
(77, 'DMBW0014', '1234B', '', 999, '', 1, 18, 1, 0, 0, '0.0000', '6.0000', 1, '2021-08-30', '0.30', 1, '0.00', '0.00', '0.00', 3, 1, 11, 1, 1, 1, 0, '2.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:41:47'),
(78, 'Cl0001', '', '', 1000, '', 1, 13, 1, 0, 0, '0.0000', '29.0000', 1, '2021-08-30', '125.00', 2, '0.00', '0.00', '0.00', 1, 1, 15, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:10:11'),
(79, 'CKGS01', 'CK14A', '', 1000, '', 1, 13, 1, 0, 0, '0.0000', '36.0000', 1, '2013-08-30', '250.00', 2, '0.00', '0.00', '0.00', 3, 1, 3, 1, 1, 1, 0, '28.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-27 06:17:50'),
(80, 'GRM001', '', '', 850, '', 1, 19, 1, 0, 0, '0.0000', '59.0000', 1, '2021-09-01', '80.00', 2, '0.00', '0.00', '0.00', 1, 1, 6, 1, 1, 1, 0, '33.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:15:31'),
(81, 'GRM002', '', '', 1000, '', 1, 19, 1, 0, 0, '0.0000', '61.0000', 1, '2013-09-01', '150.00', 2, '0.00', '0.00', '0.00', 2, 1, 6, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:15:07'),
(82, 'GRM003', '', '', 1000, '', 1, 19, 1, 0, 0, '0.0000', '42.0000', 1, '2021-09-01', '100.00', 2, '0.00', '0.00', '0.00', 2, 1, 3, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:15:00'),
(83, 'GRM004', 'ACSP23423', '', 1000, '', 1, 19, 1, 0, 0, '0.0000', '37.5000', 1, '2021-09-01', '15.00', 2, '0.00', '0.00', '0.00', 1, 1, 3, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:14:51'),
(84, 'GRM005', 'ACP23453', '', 1000, '', 1, 19, 1, 0, 0, '0.0000', '30.0000', 1, '2021-09-01', '175.00', 2, '2.90', '1.00', '2.00', 3, 1, 8, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:14:31'),
(85, 'Ck0010', '', '', 1000, '', 1, 13, 1, 0, 0, '0.0000', '45.0000', 1, '2021-09-01', '0.08', 5, '0.00', '0.00', '0.00', 3, 1, 4, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:09:07'),
(86, 'CK0009', '', '', 1, '', 1, 13, 1, 0, 0, '0.0000', '44.1000', 1, '2021-09-04', '0.17', 2, '0.00', '0.00', '0.00', 2, 1, 3, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:08:58'),
(87, 'CK0010', 'MED923432', '', 10000, '', 1, 13, 1, 0, 0, '0.0000', '37.5000', 1, '2013-09-04', '0.20', 1, '0.00', '0.00', '0.00', 2, 1, 2, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:08:41'),
(88, 'CK0011', '', '', 2, '', 1, 13, 1, 0, 0, '0.0000', '31.0000', 1, '2021-09-04', '340.00', 2, '0.00', '0.00', '0.00', 2, 1, 3, 1, 1, 1, 0, '19.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:08:24'),
(89, 'CK0012', '', '', 1000, '', 0, 13, 1, 0, 0, '0.0000', '62.0000', 1, '2021-09-04', '0.12', 1, '0.00', '0.00', '0.00', 2, 1, 6, 1, 1, 1, 0, '40.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:07:53'),
(90, 'CK0013', '', '', 1000, '', 1, 13, 1, 0, 0, '0.0000', '39.0000', 1, '1970-01-01', '0.33', 2, '0.00', '0.00', '0.00', 3, 1, 3, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:07:37'),
(91, 'BVLG001', '', '', 1000, '', 1, 14, 1, 0, 0, '0.0000', '29.0000', 1, '2021-09-04', '0.16', 2, '0.00', '0.00', '0.00', 2, 1, 3, 1, 1, 1, 0, '20.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:07:05'),
(92, 'BVLG002', '', '', 1000, '', 1, 14, 1, 0, 0, '0.0000', '57.0000', 1, '2013-09-04', '0.40', 5, '0.00', '0.00', '0.00', 3, 1, 8, 1, 1, 1, 0, '44.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:07:13'),
(93, 'BVLG003', '', '', 1000, '', 1, 14, 1, 0, 0, '0.0000', '280.0000', 1, '2013-09-04', '0.30', 5, '0.00', '0.00', '0.00', 2, 1, 9, 1, 1, 1, 0, '100.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:14:57'),
(94, 'GRMBC001', '', '', 589, '', 1, 19, 1, 0, 0, '0.0000', '263.0000', 1, '2013-09-04', '0.15', 1, '0.00', '0.00', '0.00', 2, 1, 4, 1, 1, 1, 0, '125.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:14:50'),
(95, 'GRMBC002', 'SKMCN876', '', 100, '', 0, 19, 1, 0, 0, '0.0000', '104.0000', 1, '2021-09-04', '0.15', 1, '0.00', '0.00', '0.00', 1, 1, 6, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:14:13'),
(96, 'GRMBC003', '', '', 100, '', 1, 19, 1, 0, 0, '0.0000', '82.0000', 1, '2021-09-04', '80.00', 2, '0.00', '0.00', '0.00', 1, 1, 11, 1, 0, 2, 0, '67.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:13:55'),
(97, 'GRMBC004', '', '', 1, '', 1, 19, 1, 0, 0, '0.0000', '126.0000', 1, '2021-09-04', '20.00', 2, '0.00', '0.00', '0.00', 3, 1, 10, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:13:13'),
(98, 'GRMBC005', '', '', 1000, '', 1, 19, 1, 0, 0, '0.0000', '98.0000', 1, '2021-09-04', '40.00', 2, '0.00', '0.00', '0.00', 1, 1, 3, 1, 1, 1, 0, '87.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:12:51'),
(99, 'GRMBC006', '', '', 1000, '', 1, 19, 1, 0, 0, '0.0000', '137.0000', 1, '2021-09-04', '0.09', 6, '0.00', '0.00', '0.00', 1, 1, 13, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:13:47'),
(100, 'GRMBC007', '', '', 1000, '', 1, 19, 1, 0, 0, '0.0000', '10.0000', 1, '2013-09-04', '15.00', 2, '0.00', '0.00', '0.00', 1, 0, 13, 1, 1, 4, 0, '8.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:13:29'),
(101, 'Pro-V', 'PRV43545', '', 1000, '', 1, 17, 1, 0, 0, '0.0000', '8.2300', 1, '2021-03-13', '8.45', 6, '2.00', '3.00', '15.00', 1, 1, 37, 1, 0, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:12:38'),
(102, 'PRF00269', '', '', 1000, '', 1, 20, 1, 0, 0, '0.0000', '105.0000', 1, '2021-03-14', '2.50', 6, '0.00', '0.00', '0.00', 3, 1, 7, 1, 0, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:12:18'),
(103, 'PRF00270', '', '', 100, '', 1, 14, 1, 0, 0, '0.0000', '78.0000', 1, '2021-03-14', '80.00', 2, '0.00', '0.00', '0.00', 3, 1, 5, 1, 0, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:13:22'),
(104, 'PRF00271', '', '', 1000, '', 1, 13, 1, 0, 0, '0.0000', '49.0000', 1, '2021-03-14', '2.10', 5, '0.00', '0.00', '0.00', 3, 1, 21, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:11:57'),
(105, 'PRF00273', 'PRF00273', '', 100, '', 0, 14, 1, 0, 0, '0.0000', '55.0000', 1, '2021-03-14', '1.00', 5, '0.00', '0.00', '0.00', 3, 1, 19, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:11:43'),
(106, 'PRF00274', '', '', 185, '', 1, 14, 1, 0, 0, '0.0000', '70.0000', 1, '2012-03-14', '80.00', 5, '0.00', '0.00', '0.00', 3, 1, 9, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:11:00'),
(107, 'PRF00274', '', '', 0, '', 0, 15, 1, 0, 0, '0.0000', '66.0000', 1, '2012-03-14', '7.00', 6, '0.00', '0.00', '0.00', 3, 1, 6, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:10:54'),
(108, 'PRF00268', '', '', 420, '', 1, 15, 1, 0, 0, '0.0000', '125.0000', 1, '2012-03-14', '2.00', 6, '0.00', '0.00', '0.00', 3, 1, 8, 1, 1, 2, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:11:19'),
(109, 'PRF00279', 'LNKVGH5', '', 4, '', 1, 15, 1, 0, 0, '0.0000', '84.0000', 1, '2012-03-14', '50.00', 6, '3.00', '2.00', '10.00', 1, 1, 11, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:10:25'),
(110, 'PRF00278', '', '', 1000, '', 1, 20, 1, 0, 0, '0.0000', '90.0000', 1, '2012-03-14', '5.00', 6, '0.00', '0.00', '0.00', 3, 1, 22, 1, 0, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:10:05'),
(111, '', '', '', 4, '', 1, 0, 1, 0, 0, '0.0000', '85.0000', 1, '2015-06-11', '0.20', 1, '23.60', '17.80', '5.10', 1, 1, 16, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:09:33'),
(112, '', '', '', 10, '', 1, 0, 1, 0, 1, '0.0000', '16.2000', 1, '2015-06-11', '0.12', 1, '0.00', '0.00', '0.00', 3, 1, 6, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:09:14'),
(113, '', '', '', 1, '', 1, 0, 1, 0, 0, '0.0000', '9.9900', 1, '2015-06-11', '0.10', 1, '12.00', '10.00', '3.00', 1, 1, 7, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:09:07'),
(114, '', 'ABV003SM', '', 1, '', 1, 0, 1, 0, 0, '0.0000', '7.9900', 0, '2021-06-01', '0.20', 1, '15.00', '12.00', '1.00', 1, 1, 3, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:08:56'),
(115, '', '', '', 1, '', 1, 0, 1, 0, 0, '0.0000', '110.0000', 0, '2015-06-15', '300.00', 2, '26.00', '10.00', '8.00', 1, 1, 20, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:08:31'),
(116, '', '', '', 100, '', 1, 0, 1, 0, 0, '0.0000', '26.0000', 1, '2022-06-15', '1.00', 5, '8.00', '5.00', '7.00', 3, 1, 29, 1, 0, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:08:27'),
(117, 'B00OGL2XKO', '', '', 100, '', 1, 0, 1, 0, 1, '0.0000', '78.0000', 1, '2021-06-17', '0.50', 5, '7.00', '4.00', '3.00', 3, 1, 27, 1, 1, 1, 0, '50.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:07:49'),
(118, '', '', '', 10, '', 1, 0, 1, 0, 0, '0.0000', '26.0000', 1, '2015-06-21', '222.00', 2, '5.00', '5.00', '4.00', 3, 1, 14, 1, 0, 1, 0, '20.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:07:41'),
(119, '', '', '', 455, '', 1, 0, 1, 0, 0, '0.0000', '9.9900', 1, '2015-06-21', '400.00', 2, '0.00', '0.00', '0.00', 3, 1, 13, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 03:42:03'),
(120, 'B00UG4NFNY', '', '', 1, '', 1, 0, 1, 0, 0, '0.0000', '6.7500', 0, '2015-06-21', '100.00', 2, '0.00', '0.00', '0.00', 3, 1, 7, 1, 1, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:11:05'),
(121, '', '', '', 17, '', 1, 19, 1, 0, 0, '0.0000', '32.0000', 1, '2021-06-21', '120.00', 2, '0.00', '0.00', '0.00', 3, 1, 13, 1, 0, 1, 10, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 01:09:22'),
(122, 'JDSK36', '', '', 155, '', 1, 0, 1, 0, 0, '0.0000', '21.0000', 1, '2015-06-21', '140.00', 2, '23.00', '20.00', '2.00', 1, 1, 11, 1, 0, 1, 0, '0.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:16:02'),
(123, 'LTQFX', '2738', '', 100, '', 1, 19, 1, 0, 1, '0.0000', '14.0000', 1, '2020-03-17', '150.00', 2, '0.00', '0.00', '0.00', 3, 1, 9, 1, 1, 1, 0, '11.0000', 0, NULL, NULL, NULL, '2019-07-12 01:51:52', '2022-06-28 02:15:47'),
(124, 'model1', 'SKUTEST', 'location1', 100, '0', 1, 14, 1, 1, 1, '0.0000', '100.0000', 1, '2022-06-15', '1.40', 5, '8.00', '5.00', '7.00', 3, 0, 36, 1, 0, 2, 5, '10.0000', 0, NULL, NULL, NULL, '2023-12-05 07:52:18', '2023-12-07 02:38:43');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]products_featured`
--

CREATE TABLE `[[dbprefix]]products_featured` (
  `product_id` int NOT NULL DEFAULT '0',
  PRIMARY KEY (`product_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]products_featured`
--

INSERT INTO `[[dbprefix]]products_featured` VALUES
(50),
(51),
(52),
(53),
(54),
(55),
(56),
(57),
(123),
(124);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]products_related`
--

CREATE TABLE `[[dbprefix]]products_related` (
  `product_id` int NOT NULL,
  `related_id` int NOT NULL,
  PRIMARY KEY (`product_id`,`related_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]products_related`
--

INSERT INTO `[[dbprefix]]products_related` VALUES
(62, 124),
(71, 101),
(77, 124),
(89, 124),
(90, 124),
(100, 108),
(101, 71),
(108, 100),
(115, 116),
(115, 118),
(115, 124),
(116, 115),
(116, 118),
(117, 124),
(118, 115),
(118, 116),
(118, 124),
(119, 123),
(121, 123),
(122, 123),
(123, 119),
(123, 121),
(123, 122),
(124, 62),
(124, 77),
(124, 89),
(124, 90),
(124, 115),
(124, 117),
(124, 118);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]products_to_categories`
--

CREATE TABLE `[[dbprefix]]products_to_categories` (
  `product_id` int NOT NULL,
  `category_id` int NOT NULL,
  PRIMARY KEY (`product_id`,`category_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]products_to_categories`
--

INSERT INTO `[[dbprefix]]products_to_categories` VALUES
(50, 40),
(51, 40),
(52, 40),
(53, 40),
(54, 39),
(55, 41),
(56, 39),
(57, 38),
(58, 38),
(59, 41),
(60, 42),
(61, 37),
(62, 51),
(63, 51),
(64, 50),
(65, 47),
(66, 46),
(67, 44),
(68, 48),
(69, 54),
(69, 64),
(70, 53),
(71, 54),
(72, 54),
(73, 54),
(74, 53),
(75, 63),
(76, 60),
(77, 60),
(77, 63),
(78, 59),
(78, 62),
(79, 50),
(79, 62),
(80, 51),
(81, 51),
(82, 51),
(82, 59),
(83, 51),
(84, 50),
(85, 50),
(86, 51),
(86, 59),
(87, 51),
(87, 59),
(88, 50),
(89, 50),
(90, 50),
(90, 59),
(91, 46),
(92, 46),
(93, 46),
(94, 45),
(95, 45),
(95, 60),
(96, 47),
(96, 60),
(97, 47),
(98, 61),
(99, 42),
(100, 41),
(101, 54),
(102, 50),
(104, 50),
(105, 50),
(106, 50),
(107, 45),
(107, 63),
(108, 37),
(108, 39),
(108, 41),
(108, 45),
(109, 46),
(110, 50),
(111, 66),
(112, 67),
(113, 67),
(114, 67),
(115, 69),
(116, 69),
(117, 69),
(118, 69),
(119, 70),
(120, 70),
(121, 70),
(122, 70),
(123, 70),
(124, 69);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]products_to_downloads`
--

CREATE TABLE `[[dbprefix]]products_to_downloads` (
  `product_id` int NOT NULL,
  `download_id` int NOT NULL,
  PRIMARY KEY (`product_id`,`download_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]products_to_downloads`
--

INSERT INTO `[[dbprefix]]products_to_downloads` VALUES
(111, 1),
(111, 2),
(123, 5),
(124, 5),
(124, 6);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]products_to_stores`
--

CREATE TABLE `[[dbprefix]]products_to_stores` (
  `product_id` int NOT NULL,
  `store_id` int NOT NULL DEFAULT '0',
  PRIMARY KEY (`product_id`,`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]products_to_stores`
--

INSERT INTO `[[dbprefix]]products_to_stores` VALUES
(50, 0),
(51, 0),
(52, 0),
(53, 0),
(54, 0),
(55, 0),
(56, 0),
(57, 0),
(58, 0),
(59, 0),
(60, 0),
(61, 0),
(62, 0),
(63, 0),
(64, 0),
(65, 0),
(66, 0),
(67, 0),
(68, 0),
(69, 0),
(70, 0),
(71, 0),
(72, 0),
(73, 0),
(74, 0),
(75, 0),
(76, 0),
(77, 0),
(78, 0),
(79, 0),
(80, 0),
(81, 0),
(82, 0),
(83, 0),
(84, 0),
(85, 0),
(86, 0),
(87, 0),
(88, 0),
(89, 0),
(90, 0),
(91, 0),
(92, 0),
(93, 0),
(94, 0),
(95, 0),
(96, 0),
(97, 0),
(98, 0),
(99, 0),
(100, 0),
(101, 0),
(102, 0),
(103, 0),
(104, 0),
(105, 0),
(106, 0),
(107, 0),
(108, 0),
(109, 0),
(110, 0),
(111, 0),
(112, 0),
(113, 0),
(114, 0),
(115, 0),
(116, 0),
(117, 0),
(118, 0),
(119, 0),
(120, 0),
(121, 0),
(122, 0),
(123, 0),
(124, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_descriptions`
--

CREATE TABLE `[[dbprefix]]product_descriptions` (
  `product_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `meta_keywords` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `meta_description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `description` longtext COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `blurb` text COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`product_id`,`language_id`),
  KEY `name` (`name`),
  KEY `[[dbprefix]]product_descriptions_name_idx` (`product_id`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]product_descriptions`
--

INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(50, 1, 'Skinsheen Bronzer Stick', '', '', '&lt;p&gt;\r\n	Bronzes, shapes and sculpts the face. Sheer-to-medium buildable coverage that looks naturally radiant and sunny. Stashable - and with its M·A·C Surf, Baby look – way cool. Limited edition.&lt;/p&gt;\r\n', ''),
(51, 1, 'BeneFit Girl Meets Pearl', '', '', '&lt;p&gt;\r\n	Luxurious liquid pearl…the perfect accessory! This soft golden pink liquid pearl glides on for a breathtakingly luminous complexion. Customise your pearlessence with the easy to use twist up package … a few clicks for a subtle sheen, more clicks for a whoa! glow. Pat the luminous liquid over make up or wear alone for dewy lit from within radiance. It''s pure pearly pleasure. Raspberry and chamomile for soothing. Light reflecting pigments for exquisite radiance. Sweet almond seed for firming and smoothing. Sesame seed oil for moisturising.Fresh red raspberry scent.&lt;/p&gt;\r\n', ''),
(52, 1, 'Benefit Bella Bamba', '', '', '&lt;p&gt;\r\n	Amplify cheekbones and create the illusion of sculpted features with this 3D watermelon blush. Laced with shimmering gold undertones, bellabamba is taking eye popping pretty to the third dimension…you’ll never use traditional blush again! Tip: For a poreless complexion that pops, sweep bellabamba on cheeks after applying professional&lt;/p&gt;\r\n', ''),
(53, 1, 'Tropiques Minerale Loose Bronzer', '', '', '&lt;p&gt;\r\n	Precious earths, exclusively selected for their luxurious silky texture and gentle quality, are layered with mineral pigments in this lightweight powder to mimic the true color of tanned skin. Unique technology with inalterable earths ensures exquisite wear all day. Mineral blend smoothes complexion, while Aloe Vera helps protect skin from dryness.&lt;/p&gt;\r\n', ''),
(54, 1, 'L''EXTRÊME Instant Extensions Lengthening Mascara', '', '', '&lt;p&gt;\r\n	Extend your lashes up to 60% instantly! This exclusive Fibrestretch formula takes even the smallest natural lashes to dramatic lengths. The patented Extreme Lash brush attaches supple fibers to every eyelash for an instant lash extension effect.&lt;/p&gt;\r\n', ''),
(55, 1, 'LE ROUGE ABSOLU Reshaping &amp; Replenishing LipColour SPF 15', '', '', '&lt;p&gt;\r\n	Smoother. Fuller. Absolutely replenished lips. This advanced lip color provides 6-hour care with continuous moisture and protective Vitamin E. Features plumping polymer and non-feathering color to define and reshape lips. Choose from an array of absolutely luxurious shades with a lustrous pearl or satin cream finish.&lt;/p&gt;\r\n', ''),
(56, 1, 'Waterproof Protective Undereye Concealer', '', '', '&lt;p&gt;\r\n	This natural coverage concealer lets you instantly eliminate tell-tale signs of stress and fatigue. Provides complete, natural-looking coverage, evens skin tone, covers dark circles and minimizes fine lines around the eyes. The Result: A soft, matte finish&lt;/p&gt;\r\n', ''),
(57, 1, 'Delicate Oil-Free Powder Blush', '', '', '&lt;p&gt;\r\n	A sparkling shimmer of colour for a radiant glow. Silky soft, micro-bubble formula glides on easily and evenly. Lasts for hours. Oil-free and oil-absorbing, yet moisture-balancing. Perfect for all skin types.&lt;/p&gt;\r\n', ''),
(58, 1, 'Product with stock locations', '', '', '&lt;p&gt;\r\n	There are degrees of cover-up…some like less, some like more! Our blendable powder formula with SPF 15 goes on beautifully sheer &amp;amp; builds easily for customized coverage. Sweep on with the accompanying brush for a sheer, natural finish or apply with the sponge for full coverage or spot cover-up. Our 6 flattering shades (2 light, 2 medium, 2 deep) make it incredibly easy to find your perfect shade. Once gals apply &quot;hello flawless!&quot; they''ll finally have met their match q!&lt;/p&gt;\r\n', ''),
(59, 1, 'Viva Glam Lipstick', '', '', '&lt;p&gt;\r\n	Time to wham up the GLAM in VIVA GLAM! It''s a gaga-glamorous look at our abiding passion: The M·A·C AIDS Fund and the VIVA GLAM program are the heart and soul of M·A·C Cosmetics. Ladies and gentlemen, we give you the sensational Cyndi Lauper and the electric Lady Gaga&lt;/p&gt;\r\n', ''),
(60, 1, 'Nail Lacquer', '', '', '&lt;p&gt;\r\n	Revolutionary new high gloss formula. Three long-wearing finishes - Cream, Sheer, and Frosted. Visibly different. Provides no-streak/no-chip finish. Contains conditioners and UV protection. Go hi-lacquer!&lt;/p&gt;\r\n', ''),
(61, 1, 'Color Design Eye Brightening All in One 5 Shadow &amp; Liner Palette', '', '', '&lt;p&gt;\r\n	Infinitely luminous. Sensationally smooth. All-in-one 5 shadow palette to brighten eyes. Lancome’s new versatile, all-in-one palette conveniently creates a full eye look for day or night. Experience the newest generation of luminosity as silky lustrous powders transparently wrap the skin, allowing a seamless layering of pure color for a silky sheen and radiant finish. Build with absolute precision and apply the shades in 5 simple steps (all over, lid, crease, highlighter and liner) to design your customized eye look. Contour, sculpt and lift in soft day colors or intensify with dramatic evening hues for smoldering smoky effects. Long wear, 8-hour formula. Color does not fade, continues to stay true&lt;/p&gt;\r\n', ''),
(62, 1, 'ck one shock for him Deodorant', '', '', '&lt;p&gt;\r\n	Shock Off! cK one shock for him opens with pure freshness, the heart pulses with spice and finishes with a masculine tobacco musk. Experience ck one shock, the newest fragrance from Calvin Klein with this 2.6 oz Deodorant.&lt;/p&gt;\r\n', ''),
(63, 1, 'Pour Homme Eau de Toilette', '', '', '&lt;p&gt;\r\n	An intriguing masculine fragrance that fuses the bracing freshness of Darjeeling tea with the intensity of spice and musk. For those seeking a discreet accent to their personality.&lt;/p&gt;\r\n', ''),
(64, 1, 'Beauty Eau de Parfum', '', '', '&lt;p&gt;\r\n	Beauty by Calvin Klein is a sophisticated and feminine fragrance presenting a new scructure to modern florals. Radiating rich and intense luminosity; Beauty leaves a complex and memorable impression. Experience the glamour and strength with the Beauty Eau de Parfum&lt;/p&gt;\r\n', ''),
(65, 1, 'Absolue Eye Precious Cells', '', '', '&lt;p&gt;\r\n	Smoothes – Tightens – Regenerates Radiance Exclusive innovation from Lancôme A powerful combination of unique ingredients – Reconstruction Complex and Pro-Xylane™ – has been shown to improve the condition around the stem cells, and stimulate cell regeneration to reconstruct skin to a denser quality*. Results Immediately, the eye contour appears smoother and more radiant. Day 7, signs of fatigue are minimized and the appearance of puffiness is reduced. Day 28, density is improved. Skin is soft and looks healthier. The youthful look of the eye contour is restored. Ophthalmologist – tested. Dermatologist – tested for safety.&lt;/p&gt;\r\n', ''),
(66, 1, 'Total Moisture Facial Cream', '', '', '&lt;p&gt;\r\n	Say good-bye to dry skin and hello to “total moisture”. This facial cream provides concentrated immediate &amp;amp; long-term hydration for an ultra radiant complexion. Contains exclusive tri-radiance complex to help develop the skin’s reserves of water &amp;amp; reinforce skin’s moisture barrier for a radiantly refreshed complexion. For normal to dry skin.&lt;/p&gt;\r\n', ''),
(67, 1, 'Flash Bronzer Body Gel', '', '', '&lt;p&gt;\r\n	Look irresistible! Discover the self-tanning results you dream of: Instant bronzed glowing body Enriched with natural caramel extract for an immediate, gorgeous, bronzed glow. Exquisitely beautiful tan The perfect balance of self-tanning ingredients helps to achieve an ideal color, providing an even, natural-looking, golden tan. Color development within 30 minutes, lasting up to 5 days. Transfer-resistant formula With an exclusive Color-Set™ complex that smoothes on without streaks, dries in 4 minutes and protects clothes against rub-off. Hydrating &amp;amp; smoothing action Leaves skin soft, smooth, and hydrated. Pure Vitamin E delivers antioxidant protection, helping to reduce signs of premature aging. Indulgent experience Delightfully scented with hints of jasmine and honey in a silky, non-greasy formula&lt;/p&gt;\r\n', ''),
(68, 1, 'Absolute Anti-Age Spot Replenishing Unifying TreatmentSPF 15', '', '', '&lt;p&gt;\r\n	A luxurious and comprehensive hand treatment that addresses the special needs of mature hands. Diminishes and discourages the appearance of age spots, while replenishing and protecting the skin. RESULT: Immediately, skin on hands is hydrated, soft and luminous. With continued use, skin becomes more uniform, looks firmer and youthful.Massage into hands and cuticles as needed.&lt;/p&gt;\r\n', ''),
(69, 1, 'Seaweed Conditioner', '', '', '&lt;p&gt;\r\n	What it is:&lt;br /&gt;\r\n	A lightweight detangler made with marine seaweed and spirulina.&lt;/p&gt;\r\n&lt;p&gt;\r\n	What it does:&lt;br /&gt;\r\n	This conditioner gently detangles, nourishes, softens, and helps to manage freshly washed hair.&lt;/p&gt;\r\n&lt;p&gt;\r\n	What it is formulated WITHOUT:&lt;br /&gt;\r\n	- Parabens&lt;/p&gt;\r\n&lt;p&gt;\r\n	What else you need to know:&lt;br /&gt;\r\n	Made with marine greens for practically anyone (and ideal for frequent bathers), this conditioner is best paired with Seaweed Shampoo. It''s also safe for use on color-treated hair.&lt;/p&gt;\r\n&lt;p&gt;\r\n	-Sea Silk Extract: Nourishes scalp; promotes healthy looking hair.&lt;br /&gt;\r\n	-Ascophyllum Nudosum (Seaweed) Extract: Moisturizes; adds elasticity, luster, softness, body; reduces flyaways.&lt;br /&gt;\r\n	-Macrocystis Pyrifera (Sea Kelp) Extract: Adds shine and manageability.&lt;br /&gt;\r\n	-Spirulina Maxima Extract: Hydrates.&lt;/p&gt;\r\n', ''),
(70, 1, 'Eau Parfumee au The Vert Shampoo', '', '', '&lt;p&gt;\r\n	Structured around the refreshing vitality and purtiy of green tea, Bvlgari Eau the Vert Shampoo is an expression of elegance and personal indulgence. Delicately perfumed Eau Parfumée au thé vert shampoo gentle cleansing action makes it perfect for daily use.&lt;/p&gt;\r\n', ''),
(71, 1, 'Pantene Pro-V Conditioner, Classic Care', '', '', '&lt;p&gt;\r\n	Conditions hair for healthy shine. How Can You See Healthy Hair? Pantene Complete Therapy Conditioner has a unique pro-vitamin complex that deeply infuses every strand - So you see 6 signs of health hair: Shine; Softness; Strength; Body; Less Frizz; Silkiness. Pantene Complete Therapy Conditioner: The ultimate pro-vitamin therapy provides gentle daily nourishing moisture for enhanced shine; Helps hair detangle easily; Helps prevent frizz and flyaways. Simply use and in just 10 days - and very day after - see shiny hair that''s soft with less frizz. Best of all, healthy Pantene hair that is strong and more resistant to damage. Made in USA.&lt;/p&gt;\r\n', ''),
(72, 1, 'Brunette expressions Conditioner', '', '', '&lt;p&gt;\r\n	YOUR HAIR’S STARTING POINT&lt;br /&gt;\r\n	Colour-Treated or Highlighted&lt;/p&gt;\r\n&lt;p&gt;\r\n	WHAT&lt;br /&gt;\r\n	Pantene Pro-V COLOUR HAIR SOLUTIONS Brunette Expressions™ Conditioner hydrates hair for rich colour that is protected from daily stress and damage. This non-colour depositing formula works for all shades of brunette hair.&lt;/p&gt;\r\n&lt;p&gt;\r\n	WHY&lt;br /&gt;\r\n	Pantene uncovered that oxidative colouring changes hair’s surface. Internally, the chemistry in hair colour attacks strength-giving proteins in hair and makes the fibre more porous, leading to weaker hair and that fades more quickly. The surface of the hair fibres then becomes uneven and the protective layer of the hair fibre disintegrates. Without the protective layer, the hair fibre is prone to micro-scarring and damage, which changes the way it interacts with light and leads to a dull appearance.&lt;/p&gt;\r\n&lt;p&gt;\r\n	HOW&lt;br /&gt;\r\n	Pantene’s advanced Pro-Vitamin formula enhances brunette colour for great intensity and radiant shine. Non-colour depositing conditioning ingredients enhance and protect colour treated hair, while helping to restore shine to coloured strands. Hair is moisturized and infused with radiant shine.&lt;/p&gt;\r\n&lt;p&gt;\r\n	USE&lt;br /&gt;\r\n	For rich, vibrant colour that’s shiny and healthy-looking, use with Pantene Pro-V Pantene COLOUR HAIR SOLUTIONS Brunette Expressions™ Shampoo and Colour Nourishing Treatment.&lt;/p&gt;\r\n', ''),
(73, 1, 'Highlighting Expressions', '', '', '&lt;p&gt;\r\n	WHAT&lt;br /&gt;\r\n	Pantene Pro-V COLOUR HAIR SOLUTIONS Highlighting Expressions™ Conditioner protects and enhances colour treated hair and infuses blonde highlights with shine. The advanced Pro-Vitamin formula restores shine to dull highlights and protects hair from daily damage. This non-colour depositing formula works for all blonde highlights.&lt;/p&gt;\r\n&lt;p&gt;\r\n	WHY&lt;br /&gt;\r\n	Pantene uncovered that oxidative colouring changes hair’s structure. Internally, the chemistry in hair colour attacks strength-giving proteins in hair and makes the fibre more porous, leading to weaker hair that fades more quickly. The surface of the hair fibres becomes uneven and the protective layer of the hair fibre disintegrates. Without the protective layer, the hair fibre is prone to micro-scarring and damage, which changes the way it interacts with light and leads to a dull appearance.&lt;/p&gt;\r\n&lt;p&gt;\r\n	HOW&lt;br /&gt;\r\n	Pantene’s non-colour depositing conditioner is designed to reinforce the structure of blonde highlighted hair and give it what it needs to reveal vibrant, glossy colour. Conditioning ingredients help revitalize and replenish highlighted hair while delivering brilliant shine and protecting from future damage. The result is healthy-looking hair rejuvenated with shimmering blonde highlights.&lt;/p&gt;\r\n&lt;p&gt;\r\n	USE&lt;br /&gt;\r\n	For rich, vibrant colour that’s shiny and healthy-looking, use with Pantene Pro-V Pantene COLOUR HAIR SOLUTIONS Highlighting Expressions™ Shampoo and Colour Nourishing Treatment.&lt;/p&gt;\r\n', ''),
(74, 1, 'Curls to straight Shampoo', '', '', '&lt;p&gt;\r\n	YOUR HAIR’S STARTING POINT&lt;br /&gt;\r\n	Curly&lt;/p&gt;\r\n&lt;p&gt;\r\n	WHAT&lt;br /&gt;\r\n	Pantene Curly Hair Series Curls to Straight Shampoo gently removes build-up, adding softness and control to your curls. The cleansing formula helps align and smooth the hair fibers. The result is healthy-looking hair that’s protected from frizz and ready for straight styling.&lt;/p&gt;\r\n&lt;p&gt;\r\n	WHY&lt;br /&gt;\r\n	Research shows that each curly hair fibre grows in a unique pattern, twisting and turning in all directions. This unpredictable pattern makes it difficult to create and control straight styles. The curved fibres of curly hair intersect with each other more often than any other hair type, causing friction which can result in breakage. The curvature of the hair fibre also provides a large amount of volume in curly hair, which can be hard to tame.&lt;/p&gt;\r\n&lt;p&gt;\r\n	HOW&lt;br /&gt;\r\n	Pantene’s straight shampoo contains micro-smoothers that aid you in loosening and unwinding curls from their natural pattern. Curly hair is left ready for frizz controlled straight styling, and protected from styling damage.&lt;/p&gt;\r\n&lt;p&gt;\r\n	USE&lt;br /&gt;\r\n	For healthy-looking, curly hair that’s styled straight, use with Curls to Straight Conditioner and Anti-Frizz Straightening Crème.&lt;/p&gt;\r\n', ''),
(75, 1, 'Dove Men  Care Body Wash', '', '', '&lt;p&gt;\r\n	A body and face wash developed for men''s skin with Micromoisture technology.&lt;br /&gt;\r\n	Micromoisture activates on skin when lathering up, clinically proven to fight skin dryness.&lt;br /&gt;\r\n	Deep cleansing gel that rinses off easily. With purifying grains.&lt;br /&gt;\r\n	Dermatologist recommended.&lt;/p&gt;\r\n', ''),
(76, 1, 'Men Care Clean Comfort Deodorant', '', '', '&lt;p&gt;\r\n        The first scented deodorant from Dove® specifically designed with a non-irritating formula to give men the power of 48-hour protection against underarm odor with advanced ¼ moisturizer technology. The bottom line? It’s tough on odor, not on skin&lt;/p&gt;\r\n', ''),
(77, 1, 'Men Care Active Clean Shower Tool', 'tool, man', '', '&lt;p&gt;\r\n	Dove® Men CareTM Active Clean Dual-Sided Shower Tool works with body wash for extra scrubbing power you can’t get from just using your hands. The mesh side delivers the perfect amount of thick cleansing lather, and the scrub side helps exfoliate for a deeper clean. Easy to grip and easy to hang. For best results, replace every 4-6 weeks.&lt;/p&gt;\r\n', ''),
(78, 1, 'ck IN2U Eau De Toilette Spray for Him', '', '', '&lt;p&gt;\r\n	Fresh but warm; a tension that creates sexiness.Spontaneous - sexy - connectedCK IN2U him is a fresh woody oriental that penetrates with lime gin fizz and rushes into a combination of cool musks that radiate from top to bottom and leaves you wanting more.&lt;/p&gt;\r\n', ''),
(79, 1, 'ck One Gift Set', '', '', '&lt;p&gt;\r\n	2 PC Gift Set includes 3.4 oz EDT Spray   Magnets. Ck One Cologne by Calvin Klein, Two bodies, two minds, and two souls are merged into the heat and passion of one. This erotic cologne combines man and woman with one provocative scent. This clean, refreshing fragrance has notes of bergamot, cardamom, pineapple, papaya, amber, and green tea.&lt;/p&gt;\r\n', ''),
(80, 1, 'Acqua Di Gio Pour Homme', '', '', '&lt;p&gt;\r\n	A resolutely masculine fragrance born from the sea, the sun, the earth, and the breeze of a Mediterranean island. Transparent, aromatic, and woody in nature Aqua Di Gio Pour Homme is a contemporary expression of masculinity, in an aura of marine notes, fruits, herbs, and woods.&lt;/p&gt;\r\n&lt;p&gt;\r\n	Notes:&lt;br /&gt;\r\n	Marine Notes, Mandarin, Bergamot, Neroli, Persimmon, Rosemary, Nasturtium, Jasmine, Amber, Patchouli, Cistus.&lt;br /&gt;\r\n	Style:&lt;br /&gt;\r\n	Transparent, modern, and masculine.&lt;/p&gt;\r\n', ''),
(81, 1, 'Armani Eau de Toilette Spray ', '', '', '&lt;p&gt;\r\n	This confidently masculine embodiment of the sophisticated ease and understated elegance of Giorgio Armani fashions - is a simply tailored, yet intensely sensual combination of sparkling fresh fruits, robust spices, and rich wood notes.&lt;br /&gt;\r\n	Notes:&lt;br /&gt;\r\n	Lime, Bergamot, Mandarin, Sweet Orange, Petitgrain, Cinnamon, Clove, Nutmeg, Jasmine, Neroli, Coriander, Lavender, Oakmoss, Sandalwood, Patchouli, Vetiver, Cedar.&lt;br /&gt;\r\n	Style:&lt;br /&gt;\r\n	Fresh, masculine, and discreet.&lt;/p&gt;\r\n', ''),
(82, 1, 'Armani Code after shave balm', '', '', '&lt;p&gt;\r\n	Splash on this refreshing balm post-shave to soothe and calm the skin. Scents skin with a hint of seductive Code.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	Ingredients&lt;br /&gt;\r\n	Alcohol, Aqua/Water/Eau, Parfum/Fragrance, PEG 8, PEG 60 Hydrogenated Castor Oil, BHT, Allantoin (Comfrey Root), Linalool, Geraniol, Alpha Isomethyl Ionone, Coumarin, Limonene, Hydroxyisohexl 3 Cyclohexene Carboxaldehyde, Hydroxycitronellal, Citronellol, Citral, Butylphenyl Methlyproprional, Hexylcinnamal&lt;/p&gt;\r\n', ''),
(83, 1, 'Armani Code Sport', '', '', '&lt;p&gt;\r\n	Sport. It''s a rite of seduction. A vision of Giorgio Armani, translated into a fragrance.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	This scent opens with an explosive freshness that features spearmint, peppermint, and wild mint—surprising and unusual top notes with a stunning effect. The citrusy heart of the fragrance reveals Code Sport''s seductive power. Notes of vetiver from Haiti reveal a woody and distinguished character, at once wet and dry. Like a crisp coating of ice, a note of hivernal prolongs the dialogue between the scent''s cool crispness and sensual breath, giving the fragrance an almost unlimited life.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	Notes:&lt;br /&gt;\r\n	Spearmint, Peppermint, Wild Mint, Citrus, Hivernal, Hatian Vetiver, Nigerian Ginger.&lt;br /&gt;\r\n	Style:&lt;br /&gt;\r\n	Stunning. Cool. Seductive.&lt;/p&gt;\r\n', ''),
(84, 1, 'Armani Code Pour Femme', '', '', '&lt;p&gt;\r\n	A seductive new fragrance for women, Armani Code Pour Femme is a fresh, sexy, feminine blend of zesty blood orange, ginger, and pear sorbet softened with hints of sambac jasmine, orange blossom, and lavender honey, warmed with precious woods and vanilla.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	Notes:&lt;br /&gt;\r\n	Blood Orange, Ginger, Pear Sorbet, Sambac Jasmine, Orange Blossom, Seringa Flower, Lavender Honey, Precious Woods Complex, Vanilla.&lt;br /&gt;\r\n	Style:&lt;br /&gt;\r\n	Fresh. Sexy. Feminine.&lt;/p&gt;\r\n', ''),
(85, 1, 'Forbidden euphoria Eau de Parfum Spray ', '', '', '&lt;p&gt;\r\n	Possessing an innate confidence and sophistication, she is just starting to explore her sexuality. What she doesn''t yet know is that she already is every man''s fantasy.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	A younger interpretation of Euphoria, this fruity floriental scent capitalizes on a modern, fresh sexiness with a mysterious twist. Its sparkling top notes seduce the senses with a blend of forbidden fruit such as mandarin, passion fruit, and iced raspberry. The heart blooms with a hypnotic bouquet of tiger orchid and jasmine. Underneath its exotic floralcy lies a layer of addictive patchouli and a sophisticated blend of musks and cashmere woods for an everlasting impression.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	Notes:&lt;br /&gt;\r\n	Sparkling Mandarin, Peach Blossom, Iced Raspberry, Pink Peony, Tiger Orchid, Jasmine, Cashmere Woods, Patchouli Absolute, Skin Musk.&lt;br /&gt;\r\n	Style:&lt;br /&gt;\r\n	Sophisticated. Confident. Forbidden.&lt;/p&gt;\r\n', ''),
(86, 1, 'Euphoria Men Intense Eau De Toilette Spray', '', '', '&lt;p&gt;\r\n	Launched by the design house of Calvin Klein in 2008, EUPHORIA MEN INTENSE is a men''s fragrance that possesses a blend of Rain Water, Pepper, Ginger, Sage, Frosted Sudachi, Cedar leaf, Patchouli, Myrrh, Labdanum, Amber Solid, Vetiver&lt;/p&gt;\r\n', ''),
(87, 1, 'MAN Eau de Toilette Spray', '', '', '&lt;p&gt;\r\n	Man by Calvin Klein was launched in October of 2007 and proposed as a new classic for the modern Calvin Klein man, aged from 25 to 40. The name itself is programmatic and unambiguous, like an English translation of L''Homme by Yves Saint Laurent. Simple, brief, to the point. You are going to smell the essence of masculinity if you are to take your cue from the name of the fragrance. The packaging is sleek, modernist, with an architectural sense of proportions and looks good. The fragrance was created by perfumers Jacques Cavallier and Harry Fremont from Firmenich in collaboration with consultant Ann Gottlieb. All these people are old hands at marketing successful mainstream fragrances. Man offers therefore a mainstream palatability but without coming across as depersonalized. It plays the distinctiveness card, but in a well reined in manner. The fragrance bears a typical masculine fresh aromatic, woody and spicy signature around the linear heart of the scent which itself is dark, fruity, and sweet enough to feel feminine. This rich amber-fruity accord is made even more seductive thanks to just the right amount of citrus-y counterpoint, which never clarifies the scent but on the contrary helps to deepen the dark fruity sensation.&lt;br /&gt;\r\n	 &lt;/p&gt;\r\n', ''),
(88, 1, 'ck one Summer 3.4 oz', '', '', '&lt;p&gt;\r\n	It''s a concert on a hot summer night. The stage is set and the show''s about to start. Feel the breeze, catch the vibe, and move to the beat with the pulsating energy of this limited-edition fragrance. A unisex scent, it is fresh, clean, and easy to wear. The fragrance opens with a burst of crisp melon. In the heart notes, an invigorating blend of green citrus and the zesty herbaceous effect of verbena creates a cool, edgy freshness. A base of exotic incense and earthy oakmoss is wrapped in the light, sensuous warmth of cedarwood, musk, and peach skin. Notes:Tangerine, Water Fern, Melon, Lemon, Sea Breeze Accord, Blue Freesia, Verbena, Rhubarb, Cedarwood, Skin Musk, Incense, Peach Skin. Style:Invigorating. Crisp. Cool.&lt;/p&gt;\r\n', ''),
(89, 1, 'Secret Obsession Perfume', '', '', '&lt;p&gt;\r\n	Calvin Klein Secret Obsession eau de parfum spray for women blends notes of forbidden fruits, exotic flowers and a sultry wood signature to create an intoxicating aroma that is provocative and addictive.Calvin Klein is one of World of Shops most popular brands, and this Calvin Klein Secret Obsession eau de parfum spray for women is a firm favourite amongst our customers for its deep, feminine aroma that is perfect for those special evenings out.&lt;/p&gt;\r\n', ''),
(90, 1, 'Obsession Night Perfume', '', '', '&lt;p&gt;\r\n	Launched by the design house of Calvin Klein in 2005, OBSESSION NIGHT is a women''s fragrance that possesses a blend of gardenia, tonka bean, bergamot, vanilla, sandalwood, jasmine, rose, amber, muguet and mandarin. It is recommended for evening wear.&lt;/p&gt;\r\n&lt;p&gt;\r\n	Ingredients&lt;br /&gt;\r\n	Notes: Bergamot, Bitter Orange, Mandarin, White Floral, Angelica Root, Gardenia, Rose, Muguet, Night-Blooming Jasmine, Vanilla, Tonka Bean, Amber, Labdanum, Sandalwood, Cashmere Wood&lt;/p&gt;\r\n', ''),
(91, 1, 'Jasmin Noir Body Lotion 6.8 fl oz', '', '', '&lt;p&gt;\r\n	A bath collection for the body, scented with the Jasmin Noir fragrance. A tribute to ultimate femininity. Seduction and personal indulgence.&lt;br /&gt;\r\n	Body Lotion Fragrance: The new emblematic creation within the Bvlgari Pour Femme Collection Jasmin Noir, perfectly embodies the luxury and prestige of Bvlgari fine jewelry.&lt;br /&gt;\r\n	Jasmin Noir is a flower of the imagination. Precious jasmine, white and immaculate, in its noire interpretation. A flower of pure mystery. A rich and delicate flower that at nightfall, reveals its intriguing sensuality. A precious floral woody fragrance with ambery accents centered around one of the true jewels of perfumery: the jasmin flower. A scent that conjures forth the bewildering seductiveness of feminity as elegant as it is profoundly sensual.&lt;br /&gt;\r\n	Jasmin Noir tells a voluptuous floral story that begins with the pure radiance of luminous light given by green and scintillating notes: Vegetal Sap and fresh Gardenia Petals. Then, tender and seductive, the Sambac Jasmine Absolute, delivers its generous and bewitching notes. Unexpectedly allied with a transparent silky almond accord, it reveals a heart that is light yet thoroughly exhilarating and marvelously addictive. The scent''s sumptuously rich notes repose on a bed of Precious Wood and ambery undertones, bringing together the depth and mystery of Patchouli, the warmth of Tonka Bean and the comfort of silky Musks for an elegant and intimate sensuality.&lt;br /&gt;\r\n	An exquisite fragrance of incomparable prestige, Jasmin Noir captures the very essence of the jeweler.&lt;br /&gt;\r\n	Made in Italy&lt;br /&gt;\r\n	 &lt;/p&gt;\r\n', ''),
(92, 1, 'Body Cream by Bulgari', '', '', '&lt;p&gt;\r\n	BVLGARI (Bulgari) by Bvlgari Body Cream 6.7 oz for Women Launched by the design house of Bvlgari in 1994, BVLGARI is classified as a refined, floral fragrance. This feminine scent possesses a blend of violet, orange blossom, and jasmine. Common spellings: Bulgari, Bvlgary, Bulgary.&lt;/p&gt;\r\n', ''),
(93, 1, 'Creme Precieuse Nuit 50ml', '', '', '&lt;p&gt;\r\n	A luxurious, melting night cream to repair skin during sleep Features Polypeptides that boost production of collagen &amp;amp; elastin Improves skin elasticity &amp;amp; firmness Visibly reduces appearance of wrinkles, fine lines &amp;amp; brown spots Enriched with Bvlgari Gem Essence to restore radiance Skin appears smooth, energized &amp;amp; luminous in morning Perfect for all skin types&lt;/p&gt;\r\n', ''),
(94, 1, 'Night Care Crema Nera Obsidian Mineral Complex', '', '', '&lt;p&gt;\r\n	When it comes to body, skin or eye care, you want to look to our products and you will find the best there is. These are the most exceptional personal care products available. They meet the strictest standards for quality sourcing, environmental impact, results and safety. Our body care products truly allows you to be good to your whole body.&lt;/p&gt;\r\n&lt;p&gt;\r\n	Giorgio Armani - Cream Nera - Night Care Crema Nera Obsidian Mineral Complex3 Restoring Cream SPF 15 50ml/1.69oz A lavish, fresh &amp;amp; weightless anti-aging creamProvides shielding &amp;amp; moisturizing benefitsDeveloped with Obsidian Mineral Complex technology Formulated with iron, silicon &amp;amp; perlite to create a potent dermal restructuring system Contains Pro-XylaneTM &amp;amp; Hyaluronique Acid Targets loss of substance, sagging of features &amp;amp; deepening of wrinkles Reveals firmer, sleeker &amp;amp; plumper skin in a youthful look. With a fabulous Skincare product like this one, you''ll be sure to enjoy the ultimate in a Skincare experience with promising results.&lt;/p&gt;\r\n', ''),
(95, 1, 'Skin Minerals For Men Cleansing Cream', '', '', '&lt;p&gt;\r\n	Ultra-purifying skincare enriched with essential moisturizing minerals, designed to instantly moisturize / purify the skin.&lt;br /&gt;\r\n	Active Ingredients&lt;br /&gt;\r\n	- Sodium and Potassium System: to preserve cutaneous hydration.&lt;br /&gt;\r\n	- Salicylic Acid and Hamamelis Extract: to tighten the pores and tone skin.&lt;br /&gt;\r\n	High Performances: the figures.&lt;br /&gt;\r\n	Self-assessment*:&lt;br /&gt;\r\n	- leaves the skin clean 100%&lt;br /&gt;\r\n	- leaves the skin comfortable 93%&lt;br /&gt;\r\n	- leaves the skin smooth 95%&lt;br /&gt;\r\n	- skin complexion is uniform 89%&lt;br /&gt;\r\n	- skin texture is refined 80%&lt;br /&gt;\r\n	* use test: 60 men 20 -65 years old 4 weeks of self-assessment&lt;/p&gt;\r\n', ''),
(96, 1, 'Eye master', '', '', '&lt;p&gt;\r\n	The volcanic force of minerals concentrated in multi action skincare specifically designed to target wrinkles, bags and dark circles of the delicate eye area. To combat signs of aging and fatigue and visibly improve skin quality.&lt;br /&gt;\r\n	Active Ingredients&lt;br /&gt;\r\n	- Volcanic Complex: an innovative combination of energy charged minerals, inspired by volcanic rocks&lt;br /&gt;\r\n	- Caffeine extract: to fight puffiness&lt;br /&gt;\r\n	- Conker and butcher’s broom extracts to stimulate cutaneous blood micro-circulation&lt;br /&gt;\r\n	High Performances: the figures.&lt;br /&gt;\r\n	Proven immediate anti-puffiness action*:&lt;br /&gt;\r\n	- 15 minutes after application –19%&lt;br /&gt;\r\n	*instrumental test, 40 men, 42-65 years old&lt;br /&gt;\r\n	Self-assessment&lt;br /&gt;\r\n	- instantly revitalizes skin 77%**&lt;br /&gt;\r\n	- wrinkles appear reduced 78%***&lt;br /&gt;\r\n	- diminishes the appearance of dark circles 68%***&lt;br /&gt;\r\n	** use test, 40 men 42-65 years old, single application, self-assessment&lt;br /&gt;\r\n	*** use test, 40 men 42-65 years old, 4 weeks, self-assessment&lt;/p&gt;\r\n', ''),
(97, 1, 'Eye Rejuvenating Serum', '', '', '&lt;p&gt;\r\n	The first advanced rejuvenating ‘weapon’ thanks to a corrective and smoothing texture and a power amplifying applicator.&lt;br /&gt;\r\n	The alliance of the [3.R] technology combined with an intensive re-smoothing system.&lt;br /&gt;\r\n	The eye rejuvenation serum also comes in an easily portable tube that boasts a silver bevelled applicator to ensure a good delivery of the product to the eye area as well as offering a means to improve circulation and reduce puffiness and eye bags.&lt;/p&gt;\r\n&lt;p&gt;\r\n	Rarely women have been so convinced of its efficiency on skin rejuvenation:&lt;/p&gt;\r\n&lt;p&gt;\r\n	EYE CONTOUR LOOKS SMOOTHER 85%*&lt;br /&gt;\r\n	EYES LOOK YOUNGER 91%*&lt;br /&gt;\r\n	EYE PUFFINESS LOOKS SOFTENED 83%*&lt;/p&gt;\r\n&lt;p&gt;\r\n	*% of women – self assessment on 60 women after 4 weeks&lt;/p&gt;\r\n', ''),
(98, 1, 'Shaving cream', '', '', '&lt;p&gt;\r\n	Moisturizing, charged with minerals and enriched with ultra softening agents. Its specific formula ensures an optimal, extremely gentle shave. Even four hours after shaving, the skin remains hydrated, soft and supple.&lt;br /&gt;\r\n	Active Ingredients&lt;br /&gt;\r\n	- Sodium and Potassium System: to preserve cutaneous hydration&lt;br /&gt;\r\n	- Bisabolol: to soothe skin&lt;br /&gt;\r\n	High Performances: the figures.&lt;br /&gt;\r\n	Measurements 4 hours after shaving:&lt;br /&gt;\r\n	- skin hydration  29%*&lt;br /&gt;\r\n	- skin softness  61%**&lt;br /&gt;\r\n	- skin suppleness  18%**&lt;br /&gt;\r\n	- skin dryness -39%**&lt;/p&gt;\r\n&lt;p&gt;\r\n	&lt;br /&gt;\r\n	* instrumental test, 20 men, 20-70 years old&lt;br /&gt;\r\n	** clinical scorage, 20 men, 20-70 years old&lt;/p&gt;\r\n', ''),
(99, 1, 'Fluid shine nail polish', '', '', '&lt;p&gt;\r\n	Luxurious color at your fingertips. Fluid shine coats nails with intense shine and long-lasting, sophisticated color. The essential accessory to any makeup wardrobe.&lt;/p&gt;\r\n&lt;p&gt;\r\n	Discover the Bronze collection 2010&lt;br /&gt;\r\n	Finish this season’s high summer look with a cranberry n°43 or blackberry n°44 nail, to echo the wet lips with intense color.&lt;/p&gt;\r\n', ''),
(100, 1, 'Smooth silk lip pencils', '', '', '&lt;p&gt;\r\n	An incredibly soft lip pencil for subtle, precise definition. The silky texture allows for easy application and flawless results. To extend the hold of your lip color, fill lips in completely with Smooth silk lip pencil before applying your lipstick. Choose from a wide range of shades to complement every color in your lipstick wardrobe.&lt;/p&gt;\r\n', ''),
(101, 1, 'Pro-V Color Hair Solutions Color Preserve Shine Conditioner', 'pantene, shampoo', '', '&lt;p&gt;\r\n	PANTENE''s color preserve shine shampoo and conditioner system with micro-polishers smoothes and refinishes the hair’s outer layer. So your hair reflects light and shines brilliantly. Help preserve your multi-dimensional color.&lt;/p&gt;\r\n&lt;p&gt;\r\n	&lt;strong&gt;Product Features&lt;/strong&gt;&lt;br /&gt;\r\n	Micro-polishers smooth the outer layer of hair to help Protect color and leave hair shiny&lt;br /&gt;\r\n	Lightweight moisturizers provide protection against damage&lt;br /&gt;\r\n	Designed for color-treated hair; Gentle enough for permed hair&lt;/p&gt;\r\n&lt;p&gt;\r\n	&lt;strong&gt;Ingredients&lt;/strong&gt;&lt;br /&gt;\r\n	Water, Stearyl Alcohol, Behentrimonium Methosulfate, Cetyl Alcohol, Fragrance, Bis-Aminopropyl Dimethicone, Isopropyl Alcohol, Benzyl Alcohol, Disodium EDTA, Panthenol, Panthenyl Ethyl Ether, Methylchloroisothiazolinone, Methylisothiazolinone&lt;/p&gt;\r\n&lt;p&gt;\r\n	 &lt;/p&gt;\r\n', ''),
(102, 1, 'Gucci Guilty', 'gicci, spray', '', '&lt;ul&gt;\r\n	&lt;li&gt;\r\n		Notes Consist Of Mandarin, Pink Pepper, Peach, Lilac, Geranium, Amber And Patchouli&lt;/li&gt;\r\n	&lt;li&gt;\r\n		For Casual Use&lt;/li&gt;\r\n&lt;/ul&gt;\r\n&lt;p&gt;\r\n	&lt;em&gt;Gucci Guilty&lt;/em&gt; is a warm yet striking oriental floral with hedonism at its heart.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	The scent seizes the attention with a flamboyant opening born of the natural rush that is mandarin shimmering alongside an audacious fist of pink pepper.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	The middle notes are an alluring concoction of heady lilac and geranium, laced with the succulent tactility of peach - all velvet femininity with a beguiling hint of provocation.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	The patchouli that is the hallmark of Gucci fragrances here conveys a message of strength, while the voluptuousness of amber suggests deep femininity.&lt;/p&gt;\r\n', ''),
(103, 1, 'Jasmin Noir L''Essence Eau de Parfum Spray 75ml', '', '', '&lt;p&gt;\r\n	A carnal impression of the immaculate jasmine flower, Bvlgari Jasmin Noir L''Essence dresses the purity of the bloom in jet black mystery.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	The fragrance is a more concentrated Eau de Parfum than the original Jasmin Noir, a blend of rare and precious ingredients that are more seductive, and more addictive than ever before. The profoundly sensual elixir captivates the senses, and enchants its wearer with its generous and bewitching touches.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	A luminous bottle that honours the heritage of Bvlgari.&lt;/p&gt;\r\n', ''),
(104, 1, 'Calvin Klein Obsession For Women EDP Spray', '', '', '&lt;p&gt;\r\n	Citrus, vanilla and greens lowering to notes of sandalwood, spices and musk. Recommended Use daytime&lt;/p&gt;\r\n&lt;p&gt;\r\n	&lt;em&gt;''Obsession''&lt;/em&gt; perfume was launched by the design house of Calvin Klein in 1985&lt;/p&gt;\r\n&lt;p&gt;\r\n	When you think about Calvin Klein, initially you think of his clothing line – specifically his jeans and underwear lines (not to mention the famous ad with a young Brooke Shields). But Calvin Klein’s penchant for perfume was equally as cutting edge as his foray into fashion.&lt;/p&gt;\r\n', ''),
(105, 1, 'Bvlgari Aqua', '', '', '&lt;p&gt;\r\n	Bvlgari Aqua (Pour Homme) Eau De Toilette Spray is an enticing and fresh cologne that exudes masculinity from its unique blend of amber santolina, posidonia and mandarin.&lt;/p&gt;\r\n&lt;p&gt;\r\n	Bvlgari Aqua (Pour Homme) Eau De Toilette Spray scent lasts throughout the day without having an overpowering smell. It is subtle enough for daytime use and masculine enough for night wear.&lt;/p&gt;\r\n', ''),
(106, 1, 'Omnia Eau de Toilette 65ml', 'bvlgary, omnia, EDT', '', '&lt;p&gt;\r\n	Choose Your scent&lt;/p&gt;\r\n&lt;p&gt;\r\n	 &lt;/p&gt;\r\n&lt;p&gt;\r\n	&lt;strong&gt;Omnia Coral:&lt;/strong&gt; Inspired by the shimmering hues of precious red coral, Omnia Coral is a radiant floral-fruity Eau de Toilette of tropical Hibiscus and juicy Pomegranate, reminiscent of Summer, the sun, resplendent nature and far-off oceans.&lt;/p&gt;\r\n&lt;p&gt;\r\n	&lt;strong&gt;Omnia Amethyst:&lt;/strong&gt; Inspired by the shimmering hues of the amethyst gemstone, this floral Eau de Toilette captures the myriad scents of Iris and Rose gardens caressed with morning dew.&lt;/p&gt;\r\n&lt;p&gt;\r\n	&lt;strong&gt;Omnia Crystalline:&lt;/strong&gt; Created from the glowing clarity and purity of crystal, Omnia Crystalline is a sparkling jewel of light, illuminating and reflecting the gentle sensuality and luminous femininity. Sparkling like a precious jewel, like the rarest of crystals, in an exquisite jewel flacon.&lt;/p&gt;\r\n', ''),
(107, 1, 'Lancome Slimissime 360 Slimming Activating Concentrate Unisex Treatment', '', '', '&lt;ul&gt;\r\n	&lt;li&gt;\r\n		An anti-cellulite body treatment&lt;/li&gt;\r\n	&lt;li&gt;\r\n		Features a special gel-cream texture &amp;amp; a quick-dissolving formula&lt;/li&gt;\r\n	&lt;li&gt;\r\n		Formulated with an exclusive 360 Complex&lt;/li&gt;\r\n&lt;/ul&gt;\r\n&lt;p&gt;\r\n	An anti-cellulite body treatment. Features a special gel-cream texture &amp;amp; a quick-dissolving formula. Formulated with an exclusive 360 Complex. Helps combat presence of cellulite &amp;amp; reduce existing cellulite. Provides immediate invigorating &amp;amp; firming results. Concentrated with micro-pearl particles to illuminate skin. Creates svelte &amp;amp; re-sculpted body contours....&lt;/p&gt;\r\n', ''),
(108, 1, 'Lancome Hypnose Doll Lashes Mascara 4-Piece Gift Set', '', '', '&lt;p&gt;\r\n	 Lancome Hypnose Doll Lashes Mascara 4-Piece Gift Set! Limited Edition!&lt;/p&gt;\r\n&lt;ol&gt;\r\n	&lt;li&gt;\r\n		0.22 oz full-size Hypnôse Doll Lashes Mascara in Black&lt;/li&gt;\r\n	&lt;li&gt;\r\n		0.07 oz full-size Le Crayon Khol Eyeliner in Black Ebony&lt;/li&gt;\r\n	&lt;li&gt;\r\n		0.07 oz travel-size Cils Booster XL Super Enhancing Mascara Base&lt;/li&gt;\r\n	&lt;li&gt;\r\n		1.7 fl oz travel-size Bi-Facil Double-Action Eye Makeup Remover&lt;/li&gt;\r\n&lt;/ol&gt;\r\n', ''),
(109, 1, 'Lancome Visionnaire Advanced Skin Corrector', '', '', '&lt;p&gt;\r\n	Lancôme innovates with VISIONNAIRE [LR 2412  4%], its first skincare product formulated to fundamentally recreate truly beautiful skin.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	A Lancôme technological breakthrough has identified a miraculous new molecule.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	The name of this molecule: LR 2412.&lt;br /&gt;\r\n	&lt;br /&gt;\r\n	A molecule that is able to “self-propel” through the layers of the epidermis, to set off a series of tissular micro-transformations. The result is that skin is visibly transformed: the texture is inner, wrinkles are erased, pigmentary and vascular irregularities are reduced and pores are tightened.&lt;/p&gt;\r\n&lt;p&gt;\r\n	 &lt;/p&gt;\r\n&lt;p&gt;\r\n	&lt;em&gt;&lt;/em&gt;&lt;/p&gt;\r\n', ''),
(110, 1, 'Flora By Gucci Eau Fraiche', '', '', '&lt;ul&gt;\r\n	&lt;li&gt;\r\n		Perfect for all occasions&lt;/li&gt;\r\n	&lt;li&gt;\r\n		This item is not a tester; New and sealed&lt;/li&gt;\r\n	&lt;li&gt;\r\n		Contains natural ingredients&lt;/li&gt;\r\n&lt;/ul&gt;\r\n&lt;p&gt;\r\n	Gucci presents the new spring version of this perfume called flora by Gucci eau fraiche in 2011. Even younger, more airy, vivid, sparkling and fresher than the original, the new fragrance is enriched with additional aromas of citruses in the top notes and aquatic and green nuances in the heart, while the base remains unchanged. The composition begins with mandarin, bergamot, kumquat, lemon and peony. The heart is made of rose petals and Osman thus with green and aquatic additions, laid on the base of sandalwood, patchouli and pink pepper.&lt;/p&gt;\r\n', ''),
(111, 1, 'New French With Ease (1 book   1 mp3 CD)', '', '', 'This title is available in book and CD. All Assimil courses are based on intuitive assimilations[registered], an original principle that is simple yet highly effective. Assimil has taken this natural process, through which you learned to speak your own language, and adapted it to their book and audio courses. Working progressively, with natural, lively dialogues, simple text notes and exercises, you will progress steadily to a level where you are able to converse in everyday situations. The first part of the course is the passive phase: you immerse yourself in the language by reading and repeating each lesson. During the second, the active phase, you use the structures and reflexes you have already absorbed while continuing to advance and learn. In just a few months, you will be able to speak French easily, fluently and naturally.&lt;br /&gt;\r\n&amp;nbsp;\r\n&lt;ul style=&quot;color: rgb(51, 51, 51); padding: 0px; list-style-type: none; font-size: 13px; font-family: verdana, arial, helvetica, sans-serif; line-height: 19px; orphans: auto; text-align: start; text-indent: 0px;&quot;&gt;\r\n	&lt;li&gt;Audio CD: 610 pages&lt;/li&gt;\r\n	&lt;li&gt;Publisher: ASSiMiL (3 April 2008)&lt;/li&gt;\r\n	&lt;li&gt;Language: English&lt;/li&gt;\r\n	&lt;li&gt;ISBN-10: 2700570057&lt;/li&gt;\r\n	&lt;li&gt;ISBN-13: 978-2700570052&lt;/li&gt;\r\n	&lt;li&gt;Product Dimensions: 23.6 x 17.8 x 5.1 cm&lt;/li&gt;\r\n&lt;/ul&gt;\r\n', ''),
(112, 1, 'The Miracle Morning: The Not-So-Obvious Secret Guaranteed to Transform Your Life', '', '', 'What if you could miraculously wake up tomorrow and any&amp;mdash;or every area of your life was transformed? What would be different? Would you be happier? Healthier? More successful? In better shape? Would you have more energy? Less Stress? More Money? Better relationships? Which of your problems would be solved?&lt;br /&gt;\r\n&amp;nbsp;\r\n&lt;ul style=&quot;color: rgb(51, 51, 51); font-family: Arial, sans-serif; font-size: 13px; font-style: normal; font-variant: normal; font-weight: normal;&quot;&gt;\r\n	&lt;li&gt;&lt;b style=&quot;font-weight: 700; font-family: verdana, arial, helvetica, sans-serif;&quot;&gt;Print Length:&lt;/b&gt; 172 pages&lt;/li&gt;\r\n	&lt;li&gt;&lt;b style=&quot;font-weight: 700; font-family: verdana, arial, helvetica, sans-serif;&quot;&gt;Page Numbers Source ISBN:&lt;/b&gt; 0979019710&lt;/li&gt;\r\n	&lt;li&gt;&lt;b style=&quot;font-weight: 700; font-family: verdana, arial, helvetica, sans-serif;&quot;&gt;Publication Date:&lt;/b&gt; December 7, 2012&lt;/li&gt;\r\n	&lt;li&gt;&lt;b style=&quot;font-weight: 700; font-family: verdana, arial, helvetica, sans-serif;&quot;&gt;Language:&lt;/b&gt; English&lt;/li&gt;\r\n	&lt;li&gt;&lt;b style=&quot;font-weight: 700; font-family: verdana, arial, helvetica, sans-serif;&quot;&gt;ASIN:&lt;/b&gt; B00AKKS278&lt;/li&gt;\r\n&lt;/ul&gt;\r\n\r\n&lt;hr /&gt;\r\nAbout the Author\r\n&lt;p&gt;At age 20, Hal Elrod was hit head on by a drunk driver at 70 mph, was dead for 6 minutes, and doctors told his parents that if Hal ever came out of his coma, he had permanent brain damage and may never walk again. After 6 days of fighting for his life, Hal proved that we all have the ability to overcome any obstacle and create the life of our dreams. Not only did he walk, he became an ultra-marathon runner, hall of fame business achiever, international Keynote Speaker, Success Coach, husband, father, hip-hop recording artist, and multiple time #1 bestselling author of &amp;quot;The Miracle Morning: The Not-So-Obvious Secret Guaranteed To Transform Your Life... (Before 8AM)&amp;quot; and &amp;quot;Taking Life Head On: How To Love the Life You Have While You Create the Life of Your Dreams&amp;quot;&amp;mdash;two of the highest rated and most acclaimed books on Amazon.com. (Just read a few of the 200  five-star reviews, and you&amp;rsquo;ll see why.) Hal has appeared on dozens of radio and TV shows, and he&amp;rsquo;s been featured in numerous books, including The Education of Millionaires, Cutting Edge Sales, Living College Life in the Front Row, The Author&amp;rsquo;s Guide To Building An Online Platform, The 800-Pound Gorilla of Sales and the bestselling Chicken Soup for the Soul series. To contact Hal about media appearances, speaking at your event, or if you just want to receive free training videos and resources, visit www.YoPalHal.com. To connect with Hal on Twitter, follow @HalElrod, and on Facebook at www.Facebook.com/YoPalHal.&lt;/p&gt;\r\n', ''),
(113, 1, 'Paper Towns by John Green', '', '', '&lt;strong&gt;Winner of the Edgar Award&lt;br /&gt;\r\nThe #1 New York Times Bestseller&lt;br /&gt;\r\nPublishers Weekly and USA Today Bestseller&lt;/strong&gt;&lt;br /&gt;\r\n&lt;br /&gt;\r\n&lt;em&gt;Millions of Copies Sold&lt;/em&gt;&lt;br /&gt;\r\n&lt;br /&gt;\r\nQuentin Jacobsen has spent a lifetime loving the magnificent Margo Roth Spiegelman from afar. So when she cracks open a window and climbs back into his life&amp;mdash;summoning him for an ingenious campaign of revenge&amp;mdash;he follows. When their all-nighter ends and a new day breaks, Margo has disappeared. But Q soon learns that there are clues&amp;mdash;and they&amp;rsquo;re for him. Embarking on an exhilarating adventure to find her, the closer Q gets, the less he sees the girl he thought he knew.&lt;br /&gt;\r\n&lt;br /&gt;\r\nOctober 2008&lt;br /&gt;\r\n352 pages&lt;br /&gt;\r\nISBN 9781101010938&lt;br /&gt;\r\nTitle: Paper Towns&lt;br /&gt;\r\nAuthor: John Green', ''),
(114, 1, 'Allegiant by Veronica Roth', '', '', 'Now includes an excerpt from the upcoming Four: A Divergent Collection.&lt;br /&gt;\r\n&lt;br /&gt;\r\nWhat if your whole world was a lie? What if a single revelation&amp;mdash;like a single choice&amp;mdash;changed everything? What if love and loyalty made you do things you never expected?&lt;br /&gt;\r\nThe explosive conclusion to Veronica Roth&amp;#39;s #1 New York Times bestselling Divergent trilogy reveals the secrets of the dystopian world that has captivated millions of readers in &lt;em&gt;Divergent&lt;/em&gt; and &lt;em&gt;Insurgent&lt;/em&gt;.&lt;br /&gt;\r\n&lt;br /&gt;\r\nOctober 2013&lt;br /&gt;\r\n544 pages&lt;br /&gt;\r\nISBN 9780062209276&lt;br /&gt;\r\nTitle: Allegiant&lt;br /&gt;\r\nAuthor: Veronica Roth', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(115, 1, 'Fiorella Purple Peep Toes', '', '', 'Add more charm to your casual footwear collection with these purple peep toes from the house of Fiorella. Featuring a non-leather upper and lining, these slip-ons ate high on durability and style. While the wedge heels add extra inches to your silhouette, the resin sole ensures optimal traction for your feet. Team these peep toes with your casual outfits to complete your look for the day.&lt;br /&gt;\r\n&lt;br /&gt;\r\nSole Material&amp;nbsp; &lt;strong&gt;Resin Sheet&lt;/strong&gt;&lt;br /&gt;\r\nInner Lining&amp;nbsp;&amp;nbsp; &amp;nbsp;&lt;strong&gt;SYNTHETIC&lt;/strong&gt;&lt;br /&gt;\r\nClosing&amp;nbsp;&amp;nbsp; &amp;nbsp;&lt;strong&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; &amp;nbsp; &amp;nbsp; Slip On&lt;/strong&gt;&lt;br /&gt;\r\nHeel shape&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp; &lt;strong&gt;Wedge&lt;/strong&gt;&lt;br /&gt;\r\nHeel height&amp;nbsp;&amp;nbsp; &amp;nbsp;&lt;strong&gt; Medium: 2.5-3.5 Inch&lt;/strong&gt;\r\n&lt;hr /&gt;&amp;nbsp;\r\n&lt;table style=&quot;margin: 0px; padding: 0px; width: 385px; color: rgb(34, 34, 34); font-family: Arial; font-size: 13px; font-style: normal; font-variant: normal; font-weight: normal; letter-spacing: normal; line-height: 18px; orphans: auto; text-align: start; text-indent: 0px; text-transform: none; white-space: normal; widows: 1; word-spacing: 0px; -webkit-text-stroke-width: 0px; background-color: rgb(255, 255, 255);&quot;&gt;\r\n	&lt;tbody style=&quot;margin: 0px; padding: 0px;&quot;&gt;\r\n		&lt;tr style=&quot;margin: 0px; padding: 0px;&quot;&gt;\r\n			&lt;th style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap;&quot;&gt;Euro Size&lt;/th&gt;\r\n			&lt;th style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap;&quot;&gt;UK Size&lt;/th&gt;\r\n			&lt;th style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap;&quot;&gt;Foot Size (In Cm)&lt;/th&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr class=&quot;even&quot; style=&quot;margin: 0px; padding: 0px;&quot;&gt;\r\n			&lt;td class=&quot;f-bold&quot; style=&quot;margin: 0px; padding: 7px; font-weight: bold; text-align: center; white-space: nowrap; background: rgb(238, 238, 238);&quot;&gt;36&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap; background: rgb(238, 238, 238);&quot;&gt;3&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap; background: rgb(238, 238, 238);&quot;&gt;22.8-23.2&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr style=&quot;margin: 0px; padding: 0px;&quot;&gt;\r\n			&lt;td class=&quot;f-bold&quot; style=&quot;margin: 0px; padding: 7px; font-weight: bold; text-align: center; white-space: nowrap;&quot;&gt;37&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap;&quot;&gt;4&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap;&quot;&gt;23.4-23.7&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr class=&quot;even&quot; style=&quot;margin: 0px; padding: 0px;&quot;&gt;\r\n			&lt;td class=&quot;f-bold&quot; style=&quot;margin: 0px; padding: 7px; font-weight: bold; text-align: center; white-space: nowrap; background: rgb(238, 238, 238);&quot;&gt;38&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap; background: rgb(238, 238, 238);&quot;&gt;5&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap; background: rgb(238, 238, 238);&quot;&gt;24.0-24.6&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr style=&quot;margin: 0px; padding: 0px;&quot;&gt;\r\n			&lt;td class=&quot;f-bold&quot; style=&quot;margin: 0px; padding: 7px; font-weight: bold; text-align: center; white-space: nowrap;&quot;&gt;39&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap;&quot;&gt;6&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap;&quot;&gt;24.8-25.2&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr class=&quot;even&quot; style=&quot;margin: 0px; padding: 0px;&quot;&gt;\r\n			&lt;td class=&quot;f-bold&quot; style=&quot;margin: 0px; padding: 7px; font-weight: bold; text-align: center; white-space: nowrap; background: rgb(238, 238, 238);&quot;&gt;40&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap; background: rgb(238, 238, 238);&quot;&gt;6.5&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap; background: rgb(238, 238, 238);&quot;&gt;25.4-25.7&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n		&lt;tr style=&quot;margin: 0px; padding: 0px;&quot;&gt;\r\n			&lt;td class=&quot;f-bold&quot; style=&quot;margin: 0px; padding: 7px; font-weight: bold; text-align: center; white-space: nowrap;&quot;&gt;41&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap;&quot;&gt;7&lt;/td&gt;\r\n			&lt;td style=&quot;margin: 0px; padding: 7px; text-align: center; white-space: nowrap;&quot;&gt;26.0-26.4&lt;/td&gt;\r\n		&lt;/tr&gt;\r\n	&lt;/tbody&gt;\r\n&lt;/table&gt;\r\n', ''),
(116, 1, 'New Ladies High Wedge Heel Toe Thong Diamante Flip Flop Sandals', '', '', '&lt;p&gt;The annual Summer trend for wedges is back with these classic flip flop wedge heels. The sandals have a toe thong design, diamante detailing to the front and look fab worn with a maxi dress for a classic Summer look. Available in a choice of five different colours.&lt;/p&gt;\r\n\r\n&lt;ul&gt;\r\n	&lt;li&gt;Available in 5 different colours&lt;/li&gt;\r\n	&lt;li&gt;Diamante detailing to the front&lt;/li&gt;\r\n	&lt;li&gt;Outer Material: &lt;em&gt;Synthetic&lt;/em&gt;&lt;/li&gt;\r\n	&lt;li&gt;Inner Material: &lt;em&gt;Manmade&lt;/em&gt;&lt;/li&gt;\r\n	&lt;li&gt;Heel Height: &lt;em&gt;9.5 centimetres&lt;/em&gt;&lt;/li&gt;\r\n	&lt;li&gt;Heel Type: Wedge&lt;/li&gt;\r\n	&lt;li&gt;Sandals have a toe thong design&lt;/li&gt;\r\n	&lt;li&gt;Classic flip flop wedge heels&lt;/li&gt;\r\n	&lt;li&gt;&lt;strong&gt;Perfect for the Summer!&lt;/strong&gt;&lt;/li&gt;\r\n&lt;/ul&gt;\r\n\r\n&lt;p&gt;&amp;nbsp;&lt;/p&gt;\r\n', ''),
(117, 1, 'Ruby Shoo Womens Jada T-Bar', '', '', '&lt;p&gt;Ruby Shoo is made up of a small team based in north London, England, with a passion for creating unique shoes and accessories that generate smiles whenever they are worn. We simply love it when we are asked the question: &amp;quot;Where did you get your shoes?&amp;quot;&lt;/p&gt;\r\n\r\n&lt;ul&gt;\r\n	&lt;li style=&quot;list-style-type: square; margin-left: 20px;&quot;&gt;Occasion footwear&lt;/li&gt;\r\n	&lt;li style=&quot;list-style-type: square; margin-left: 20px;&quot;&gt;Flower detail&lt;/li&gt;\r\n	&lt;li style=&quot;list-style-type: square; margin-left: 20px;&quot;&gt;Outer Material: Synthetic&lt;/li&gt;\r\n	&lt;li style=&quot;list-style-type: square; margin-left: 20px;&quot;&gt;Inner Material: Manmade&lt;/li&gt;\r\n	&lt;li style=&quot;list-style-type: square; margin-left: 20px;&quot;&gt;Sole: Manmade&lt;/li&gt;\r\n	&lt;li style=&quot;list-style-type: square; margin-left: 20px;&quot;&gt;Closure: Buckle&lt;/li&gt;\r\n	&lt;li style=&quot;list-style-type: square; margin-left: 20px;&quot;&gt;Heel Height: 9 centimetres&lt;/li&gt;\r\n	&lt;li style=&quot;list-style-type: square; margin-left: 20px;&quot;&gt;Heel Type: Stiletto&lt;/li&gt;\r\n&lt;/ul&gt;\r\n', ''),
(118, 1, 'Womens high heel point toe stiletto sandals ankle strap court shoes', '', '', '&lt;p&gt;Fashion Thirsty&amp;reg; branded products are only available exclusively through Fashion Thirsty&lt;/p&gt;\r\n&lt;ul&gt;\r\n	&lt;li&gt;Brand New In Box&lt;/li&gt;\r\n	&lt;li&gt;Available In A Range Of Colours And Fabrics&lt;/li&gt;\r\n	&lt;li&gt;Outer Material: Synthetic&lt;/li&gt;\r\n	&lt;li&gt;Inner Material: Manmade&lt;/li&gt;\r\n	&lt;li&gt;Sole: manmade&lt;/li&gt;\r\n	&lt;li&gt;Closure: Buckle&lt;/li&gt;\r\n	&lt;li&gt;Heel Height: 4.3&lt;/li&gt;\r\n	&lt;li&gt;Heel Type: Stiletto&lt;/li&gt;\r\n	&lt;li&gt;Approx Heel Height: 4.3 Inches / 10.8 cm&lt;/li&gt;\r\n	&lt;li&gt;Approx Platform Height: 0.1 inches / 0.3 cm&lt;/li&gt;\r\n	&lt;li&gt;Ankle Strap With Buckle Fastening&lt;/li&gt;\r\n&lt;/ul&gt;\r\n\r\n', ''),
(119, 1, 'Fruit of the Loom T-Shirts 5 Pack - Super Premium', '', '', '5x Fruit of the Loom T-Shirt Super Premium T&lt;br /&gt;\r\n10 Colors - Sizes: S, M, L, XL, XXL oder XXXL\r\n&lt;hr /&gt;The purchase of this 5-packs, you have the following choice:&lt;br /&gt;\r\n&amp;bull; 5 of the same color t-shirts (available in 18 colors)&lt;br /&gt;\r\n&amp;bull; 5 different colored T-shirts (given in 8 color sets available)&lt;br /&gt;\r\nYou have the freedom to choose from the adult sizes S, M, L, XL, XXL or XXXL.', ''),
(120, 1, 'Jersey Cotton Striped Polo Shirt', '', 't-shirs, men', '&lt;p&gt;Classically designed Charles Wilson polo shirts now available.&lt;br /&gt;\r\nThis premium polo collection is a result of many years experience in designing and manufacturing polo shirts.&lt;br /&gt;\r\nPart of our Jersey Stripe polo range this colourful jersey cotton polo shirt is a must have piece for any casual wardrobe.&lt;br /&gt;\r\nDesigned in the UK&lt;br /&gt;\r\n100% Cotton&lt;br /&gt;\r\nJersey Stripe Polo&lt;br /&gt;\r\nMulti-Stripe Design&lt;br /&gt;\r\nThree Button Design&lt;br /&gt;\r\nMachine Washable at 40 Degrees&lt;/p&gt;\r\n', ''),
(121, 1, 'Designer Men Casual Formal Double Cuffs Grandad Band Collar Shirt Elegant Tie', '', '', 'Superb style double cuffs shirt. Made using highest quality cotton. Grandad collar. Slim Fit. Highest quality - made in Turkey. Great as casual or formal shirt.', ''),
(122, 1, 'Product with options and stock locations', '', '', 'Designed by slim fit style FOR men and women in highest qualities and workmanship to bring buyers A different outlook on life of fashion Casual Basic Slim Fit Polo Shirts\r\n&lt;ul&gt;\r\n	&lt;li&gt;100% COTTON&lt;/li&gt;\r\n	&lt;li&gt;If you buy these Polo shits, You&amp;#39;ll never regret about purchase. Because it is so nice designed shirts for your daily look.&lt;/li&gt;\r\n	&lt;li&gt;Soft Elastic Decent slim fit &amp;amp; Button placket &amp;amp; sleeve ribbing with contrast trim.&lt;/li&gt;\r\n	&lt;li&gt;Machine Wash / Hand Wash Recommended&lt;/li&gt;\r\n&lt;/ul&gt;\r\n', ''),
(123, 1, 'Casual 3/4 Sleeve Baseball T-Shirt', 't-shirt', 'Rich Cotton Raglan T-Shirts', 'This classic raglan t-shirt is perfect for all occasions. Whether you are working out or hanging out, this shirt is a win for the versatility. Perfect to join your friends to watch and cheer for your favorite team in all sports: basketball, football, football, hockey or baseball.&lt;br /&gt;&lt;br /&gt;&lt;!--n--&gt;&lt;!--n--&gt;The raglan t-shirts are great options for men and women looking for a stylish look in their casual looks. For mild days bet on the 3/4 sleeve model in contrasting color. &lt;br /&gt;Made in 100% cotton fabric, features slim fit and round neckline.', ''),
(124, 1, 'Test name: Infinite Comfort Performance Jackson''s  Running Shoes with Shock Absorption Technology - AirFlex Pro Elite Series', 'Running shoes, Performance footwear, Shock absorption technology, Comfortable running sneakers, Athletic footwear, Jogging shoes, Elite series shoes, Sports shoes, Cushioned running shoes, Breathable mesh upper, Impact reduction shoes, Fitness footwear, M', 'Step into ultimate comfort and performance with the AirFlex Pro Elite Series running shoes. Engineered with advanced shock absorption technology, these athletic sneakers offer a smooth and cushioned ride', '&lt;p&gt;The annual Summer trend for wedges is back with these classic flip flop wedge heels. The sandals have a toe thong design, diamante detailing to the front and look fab worn with a maxi dress for a classic Summer look. Available in a choice of five different colours.&lt;/p&gt;\r\n\r\n&lt;ul&gt;\r\n	&lt;li&gt;Available in 5 different colours&lt;/li&gt;\r\n	&lt;li&gt;Diamante detailing to the front&lt;/li&gt;\r\n	&lt;li&gt;Outer Material: &lt;em&gt;Synthetic&lt;/em&gt;&lt;/li&gt;\r\n	&lt;li&gt;Inner Material: &lt;em&gt;Manmade&lt;/em&gt;&lt;/li&gt;\r\n	&lt;li&gt;Heel Height: &lt;em&gt;9.5 centimetres&lt;/em&gt;&lt;/li&gt;\r\n	&lt;li&gt;Heel Type: Wedge&lt;/li&gt;\r\n	&lt;li&gt;Sandals have a toe thong design&lt;/li&gt;\r\n	&lt;li&gt;Classic flip flop wedge heels&lt;/li&gt;\r\n	&lt;li&gt;&lt;strong&gt;Perfect for the Summer!&lt;/strong&gt;&lt;/li&gt;\r\n&lt;/ul&gt;\r\n\r\n&lt;p&gt;&amp;nbsp;&lt;/p&gt;\r\n', 'Step into a world of unparalleled comfort and performance with our AirFlex Pro Elite Series, the ultimate running shoes for athletes and fitness enthusiasts.');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_discounts`
--

CREATE TABLE `[[dbprefix]]product_discounts` (
  `product_discount_id` int NOT NULL AUTO_INCREMENT,
  `product_id` int NOT NULL,
  `customer_group_id` int NOT NULL,
  `quantity` int NOT NULL DEFAULT '0',
  `priority` int NOT NULL DEFAULT '1',
  `price_prefix` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `price` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `date_start` date DEFAULT NULL,
  `date_end` date DEFAULT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`product_discount_id`),
  KEY `[[dbprefix]]product_discounts_idx` (`product_id`,`customer_group_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=10 ;

--
-- Dumping data for table `[[dbprefix]]product_discounts`
--

INSERT INTO `[[dbprefix]]product_discounts` VALUES
(1, 81, 1, 2, 0, '', '59.0000', NULL, NULL, '0000-00-00 00:00:00', '2015-06-22 07:10:54'),
(2, 81, 1, 3, 0, '', '56.0000', NULL, NULL, '0000-00-00 00:00:00', '2015-06-22 07:11:09'),
(3, 81, 1, 4, 0, '', '50.0000', NULL, NULL, '0000-00-00 00:00:00', '2015-06-22 07:11:25'),
(4, 119, 1, 2, 0, '%', '10.0000', NULL, NULL, '0000-00-00 00:00:00', '2022-06-28 03:40:30'),
(5, 119, 1, 3, 0, '%', '20.0000', NULL, NULL, '0000-00-00 00:00:00', '2022-06-28 03:42:03'),
(6, 124, 1, 4, 2, '$', '80.0000', NULL, NULL, '0000-00-00 00:00:00', '2023-12-05 08:17:44'),
(7, 124, 2, 4, 1, '%', '20.0000', NULL, NULL, '0000-00-00 00:00:00', '2023-12-05 08:18:06'),
(8, 124, 1, 5, 0, '$', '75.0000', '2023-10-01', NULL, '0000-00-00 00:00:00', '2023-12-05 08:18:26'),
(9, 124, 2, 5, 0, '%', '35.0000', NULL, '2033-12-23', '0000-00-00 00:00:00', '2023-12-05 08:18:51');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_filters`
--

CREATE TABLE `[[dbprefix]]product_filters` (
  `filter_id` int NOT NULL AUTO_INCREMENT,
  `filter_type` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `categories_hash` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `feature_id` int DEFAULT NULL,
  `sort_order` int NOT NULL DEFAULT '0',
  `status` smallint NOT NULL DEFAULT '0',
  PRIMARY KEY (`filter_id`),
  KEY `feature_id` (`feature_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_filter_descriptions`
--

CREATE TABLE `[[dbprefix]]product_filter_descriptions` (
  `filter_id` int NOT NULL,
  `value` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  `language_id` int NOT NULL,
  PRIMARY KEY (`filter_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_filter_ranges`
--

CREATE TABLE `[[dbprefix]]product_filter_ranges` (
  `range_id` int NOT NULL AUTO_INCREMENT,
  `feature_id` int DEFAULT NULL,
  `filter_id` int NOT NULL,
  `from` decimal(12,2) NOT NULL DEFAULT '0.00',
  `to` decimal(12,2) NOT NULL DEFAULT '0.00',
  `sort_order` int NOT NULL DEFAULT '0',
  PRIMARY KEY (`range_id`),
  KEY `from` (`from`,`to`),
  KEY `filter_id` (`filter_id`),
  KEY `feature_id` (`feature_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_filter_ranges_descriptions`
--

CREATE TABLE `[[dbprefix]]product_filter_ranges_descriptions` (
  `range_id` int NOT NULL,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  `language_id` int NOT NULL,
  PRIMARY KEY (`range_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_options`
--

CREATE TABLE `[[dbprefix]]product_options` (
  `product_option_id` int NOT NULL AUTO_INCREMENT,
  `attribute_id` int NOT NULL,
  `product_id` int NOT NULL,
  `group_id` int NOT NULL DEFAULT '0',
  `sort_order` int NOT NULL DEFAULT '0',
  `status` int NOT NULL DEFAULT '1',
  `element_type` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 'I',
  `required` smallint NOT NULL DEFAULT '0',
  `regexp_pattern` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `settings` text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  PRIMARY KEY (`product_option_id`),
  KEY `[[dbprefix]]product_options_idx` (`attribute_id`,`product_id`,`group_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=365 ;

--
-- Dumping data for table `[[dbprefix]]product_options`
--

INSERT INTO `[[dbprefix]]product_options` VALUES
(304, 0, 57, 0, 0, 1, 'S', 0, '', NULL),
(305, 0, 59, 0, 0, 1, 'S', 0, '', NULL),
(306, 0, 55, 0, 0, 1, 'S', 0, '', NULL),
(307, 0, 60, 0, 0, 1, 'S', 0, '', NULL),
(308, 0, 61, 0, 0, 1, 'S', 0, '', NULL),
(314, 0, 64, 0, 0, 1, 'S', 0, '', NULL),
(315, 0, 54, 0, 0, 1, 'S', 0, '', NULL),
(316, 0, 63, 0, 0, 1, 'S', 0, '', NULL),
(317, 0, 69, 0, 0, 1, 'S', 0, '', NULL),
(318, 0, 53, 0, 2, 1, 'S', 0, '', NULL),
(319, 0, 56, 0, 0, 1, 'S', 0, '', NULL),
(320, 0, 78, 0, 0, 1, 'S', 0, '', NULL),
(321, 0, 80, 0, 0, 1, 'S', 0, '', NULL),
(322, 0, 84, 0, 0, 1, 'S', 0, '', NULL),
(323, 0, 85, 0, 0, 1, 'S', 0, '', NULL),
(324, 0, 89, 0, 0, 1, 'S', 0, '', NULL),
(326, 0, 90, 0, 0, 1, 'S', 0, '', NULL),
(327, 0, 99, 0, 0, 1, 'S', 0, '', NULL),
(328, 0, 100, 0, 0, 1, 'S', 0, '', NULL),
(329, 1, 101, 0, 0, 1, 'S', 1, '', NULL),
(330, 1, 102, 0, 0, 1, 'S', 0, '', NULL),
(331, 1, 104, 0, 0, 1, 'S', 1, '', NULL),
(332, 2, 104, 0, 0, 1, 'C', 0, '', NULL),
(335, 5, 105, 0, 0, 1, 'G', 1, '', NULL),
(336, 2, 105, 0, 5, 1, 'C', 0, '', NULL),
(337, 1, 105, 0, 2, 1, 'S', 1, '', NULL),
(338, 0, 106, 0, 1, 1, 'S', 1, '', NULL),
(339, 2, 106, 0, 2, 1, 'C', 0, '', NULL),
(340, 2, 109, 0, 0, 1, 'C', 0, '', NULL),
(341, 1, 110, 0, 0, 1, 'S', 1, '', NULL),
(342, 0, 115, 0, 0, 1, 'S', 1, '', ''),
(344, 0, 116, 0, 0, 1, 'R', 1, '', ''),
(345, 0, 116, 0, 0, 1, 'S', 1, '', ''),
(346, 6, 117, 0, 0, 1, 'S', 1, '', 'a:4:{s:10:"extensions";s:0:"";s:8:"min_size";s:0:"";s:8:"max_size";s:0:"";s:9:"directory";s:0:"";}'),
(347, 0, 118, 0, 0, 1, 'R', 1, '', ''),
(348, 0, 119, 0, 0, 1, 'S', 1, '', ''),
(349, 0, 120, 0, 0, 1, 'S', 1, '', ''),
(350, 0, 121, 0, 0, 1, 'S', 1, '', ''),
(351, 0, 121, 0, 0, 1, 'S', 1, '', ''),
(352, 0, 122, 0, 0, 1, 'S', 1, '', ''),
(353, 6, 123, 0, 0, 1, 'S', 0, '', 'a:4:{s:10:"extensions";s:0:"";s:8:"min_size";s:0:"";s:8:"max_size";s:0:"";s:9:"directory";s:0:"";}'),
(354, 0, 124, 0, 2, 1, 'R', 1, '', NULL),
(355, 0, 124, 0, 1, 1, 'S', 1, '', NULL),
(356, 0, 124, 0, 3, 1, 'U', 0, '', 'a:4:{s:10:"extensions";s:15:"txt,png,jpg,zip";s:8:"min_size";s:0:"";s:8:"max_size";s:4:"6000";s:9:"directory";s:13:"productfiles/";}'),
(357, 0, 124, 0, 4, 1, 'H', 1, '', ''),
(358, 0, 124, 0, 5, 1, 'I', 0, '/^.{0,10}$/', ''),
(359, 0, 124, 0, 7, 1, 'T', 0, '', ''),
(360, 0, 124, 0, 8, 1, 'M', 0, '', ''),
(361, 0, 124, 0, 9, 1, 'C', 0, '', ''),
(362, 0, 124, 0, 10, 1, 'G', 0, '', ''),
(363, 0, 124, 0, 11, 1, 'D', 0, '', ''),
(364, 0, 124, 0, 12, 1, 'B', 1, '', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_option_descriptions`
--

CREATE TABLE `[[dbprefix]]product_option_descriptions` (
  `product_option_id` int NOT NULL,
  `language_id` int NOT NULL,
  `product_id` int NOT NULL,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `option_placeholder` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT '' COMMENT 'translatable',
  `error_text` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`product_option_id`,`language_id`),
  KEY `[[dbprefix]]product_option_descriptions_idx` (`product_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]product_option_descriptions`
--

INSERT INTO `[[dbprefix]]product_option_descriptions` VALUES
(304, 1, 57, 'Color', '', ''),
(305, 1, 59, 'Color', '', ''),
(306, 1, 55, 'Color', '', ''),
(307, 1, 60, 'Color', '', ''),
(308, 1, 61, 'Color', '', ''),
(314, 1, 64, 'Fragrance Size', '', ''),
(315, 1, 54, 'Shade', '', ''),
(316, 1, 63, 'Fragrance Size', '', ''),
(317, 1, 69, 'Size', '', ''),
(318, 1, 53, 'Color', '', ''),
(319, 1, 56, 'Color', '', ''),
(320, 1, 78, 'Fragrance Size', '', ''),
(321, 1, 80, 'Fragrance Size', '', ''),
(322, 1, 84, 'Size', '', ''),
(323, 1, 85, 'Fragrance Size', '', ''),
(324, 1, 89, 'Fragrance Size', '', ''),
(326, 1, 90, 'Fragrance Size', '', ''),
(327, 1, 99, 'Color', '', ''),
(328, 1, 100, 'Color', '', ''),
(329, 1, 101, 'Size', '', ''),
(330, 1, 102, 'Size', '', ''),
(331, 1, 104, 'Size', '', ''),
(332, 1, 104, 'Gift Wrapping', '', ''),
(335, 1, 105, 'Fragrance Type', '', ''),
(336, 1, 105, 'Gift Wrapping', '', ''),
(337, 1, 105, 'Size', '', ''),
(338, 1, 106, 'Choose Scent', '', ''),
(339, 1, 106, 'Gift Wrapping', '', ''),
(340, 1, 109, 'Gift Wrapping', '', ''),
(341, 1, 110, 'Size', '', ''),
(342, 1, 115, 'Select Size (EURO)', '', ''),
(344, 1, 116, 'UK size', '', ''),
(345, 1, 116, 'Colour', '', ''),
(346, 1, 117, 'Color&amp;Size', '', ''),
(347, 1, 118, 'Colour', '', ''),
(348, 1, 119, 'Size', '', ''),
(349, 1, 120, 'Size', '', ''),
(350, 1, 121, 'Colour', '', ''),
(351, 1, 121, 'Size', '', ''),
(352, 1, 122, 'Size EU', '', ''),
(353, 1, 123, 'Color&amp;Size', '', ''),
(354, 1, 124, 'UK size', '', ''),
(355, 1, 124, 'Colour', '', ''),
(356, 1, 124, 'File', 'Please attach file', ''),
(357, 1, 124, 'Hidden', '', ''),
(358, 1, 124, 'Text', 'Enter engraving text max 10 chars', 'maximum 10 chars allowed'),
(359, 1, 124, 'Textarea', '', ''),
(360, 1, 124, 'Multi-select', 'Choose preffered type', ''),
(361, 1, 124, 'Checkbox', '', ''),
(362, 1, 124, 'Checkbox Group', '', ''),
(363, 1, 124, 'Date', 'Select pickup date', ''),
(364, 1, 124, 'Label title', '', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_option_values`
--

CREATE TABLE `[[dbprefix]]product_option_values` (
  `product_option_value_id` int NOT NULL AUTO_INCREMENT,
  `product_option_id` int NOT NULL,
  `product_id` int NOT NULL,
  `group_id` int NOT NULL DEFAULT '0',
  `txt_id` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `sku` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `quantity` int NOT NULL DEFAULT '0',
  `subtract` int NOT NULL DEFAULT '0',
  `price` decimal(15,4) NOT NULL,
  `cost` decimal(15,4) NOT NULL,
  `prefix` char(1) COLLATE utf8mb4_unicode_ci NOT NULL,
  `require_shipping` smallint NOT NULL DEFAULT '0' COMMENT 'depends on "shipping" column of table "products" ',
  `weight` decimal(15,8) NOT NULL,
  `weight_type` varchar(3) COLLATE utf8mb4_unicode_ci NOT NULL,
  `attribute_value_id` int DEFAULT NULL,
  `grouped_attribute_data` text COLLATE utf8mb4_unicode_ci,
  `sort_order` int NOT NULL,
  `default` smallint DEFAULT '0',
  `supplier_code` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `supplier_id` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`product_option_value_id`),
  UNIQUE KEY `[[dbprefix]]product_option_values_supplier_idx` (`supplier_id`,`supplier_code`),
  KEY `[[dbprefix]]product_option_values_idx` (`product_option_id`,`product_id`,`group_id`,`attribute_value_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=809 ;

--
-- Dumping data for table `[[dbprefix]]product_option_values`
--

INSERT INTO `[[dbprefix]]product_option_values` VALUES
(612, 304, 57, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(613, 304, 57, 0, NULL, '', 999, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(614, 304, 57, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(615, 305, 59, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(616, 305, 59, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(617, 305, 59, 0, NULL, '', 1000, 1, '2.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(618, 306, 55, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(619, 306, 55, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(620, 306, 55, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(621, 306, 55, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(622, 307, 60, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(623, 307, 60, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(624, 307, 60, 0, NULL, '', 0, 0, '1.4200', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(625, 308, 61, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(626, 308, 61, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(627, 308, 61, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(642, 314, 64, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(643, 314, 64, 0, NULL, '', 1000, 1, '10.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(644, 314, 64, 0, NULL, '', 66, 1, '22.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(645, 315, 54, 0, NULL, '', 1000, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(646, 315, 54, 0, NULL, '', 983, 1, '5.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(647, 316, 63, 0, NULL, '', 0, 0, '25.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(648, 316, 63, 0, NULL, '', 0, 0, '20.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(649, 316, 63, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(650, 317, 69, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(651, 317, 69, 0, NULL, '', 553, 1, '30.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(652, 318, 53, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(653, 318, 53, 0, NULL, '', 1996, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(654, 319, 56, 0, NULL, '', 555, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(655, 319, 56, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(656, 319, 56, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(657, 319, 56, 0, NULL, '', 997, 1, '1.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(658, 319, 56, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(659, 319, 56, 0, NULL, '', 999, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(660, 320, 78, 0, NULL, '', 998, 1, '8.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(661, 320, 78, 0, NULL, '', 887, 1, '16.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(662, 320, 78, 0, NULL, '', 58, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(663, 321, 80, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(664, 321, 80, 0, NULL, '', 0, 0, '25.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(665, 321, 80, 0, NULL, '', 0, 0, '45.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(666, 322, 84, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(667, 322, 84, 0, NULL, '', 1000, 1, '20.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(668, 322, 84, 0, NULL, '', 0, 0, '32.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(669, 323, 85, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(670, 323, 85, 0, NULL, '', 100, 0, '18.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(671, 323, 85, 0, NULL, '', 0, 0, '23.5000', '0.0000', '$', 0, '0.00000000', 'lb', 0, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(672, 324, 89, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(673, 324, 89, 0, NULL, '', 0, 0, '30.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(674, 324, 89, 0, NULL, '', 1000, 1, '10.0000', '0.0000', '$', 0, '0.00000000', 'kg', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(676, 326, 90, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(677, 326, 90, 0, NULL, '', 556, 1, '15.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(678, 327, 99, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(679, 327, 99, 0, NULL, '', 50, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(680, 327, 99, 0, NULL, '', 48, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(681, 328, 100, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(682, 328, 100, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(683, 328, 100, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(684, 328, 100, 0, NULL, '', 46, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(685, 328, 100, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(686, 328, 100, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(687, 329, 101, 0, NULL, '', 256, 0, '-2.0000', '0.0000', '$', 0, '0.80000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(688, 329, 101, 0, NULL, '', 155, 0, '4.0000', '0.0000', '$', 0, '0.15000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(689, 329, 101, 0, NULL, '', 100, 1, '10.0000', '0.0000', '$', 0, '0.33000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(690, 330, 102, 0, NULL, '', 55, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(691, 330, 102, 0, NULL, '', 55, 0, '20.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(692, 330, 102, 0, NULL, '', 55, 0, '30.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(700, 332, 104, 0, NULL, '', 0, 0, '3.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(713, 331, 104, 0, NULL, '', 50, 0, '20.0000', '0.0000', '$', 0, '0.00000000', 'lb', 54, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(714, 331, 104, 0, NULL, '', 50, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 53, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(719, 336, 105, 0, NULL, '', 0, 0, '2.5000', '0.0000', '$', 0, '0.00000000', 'lb', 0, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(720, 335, 105, 0, NULL, '', 25, 1, '60.0000', '0.0000', '$', 0, '0.00000000', 'lb', 75, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(721, 335, 105, 0, NULL, '', 44, 1, '21.0000', '0.0000', '$', 0, '0.00000000', 'lb', 76, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(722, 335, 105, 0, NULL, '', 100, 1, '24.0000', '0.0000', '$', 0, '0.00000000', 'lb', 77, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(723, 337, 105, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 53, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(724, 337, 105, 0, NULL, '', 0, 0, '25.0000', '0.0000', '%', 0, '0.00000000', 'lb', 54, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(731, 338, 106, 0, NULL, '', 120, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(732, 338, 106, 0, NULL, '', 59, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(733, 338, 106, 0, NULL, '', 80, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(735, 339, 106, 0, NULL, '', 0, 0, '1.5000', '0.0000', '$', 0, '0.00000000', 'lb', 0, NULL, 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(737, 340, 109, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(738, 341, 110, 0, NULL, '', 97, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(739, 341, 110, 0, NULL, '', 120, 1, '15.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(740, 341, 110, 0, NULL, '', 56, 1, '30.0000', '0.0000', '$', 0, '0.00000000', 'oz', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(741, 342, 115, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(742, 342, 115, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(743, 342, 115, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 2, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(744, 342, 115, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 3, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(745, 342, 115, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 4, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(746, 342, 115, 0, NULL, '', 9, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 5, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(747, 344, 116, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(748, 344, 116, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(749, 344, 116, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(750, 344, 116, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 3, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(751, 344, 116, 0, NULL, '', 0, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 4, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(752, 345, 116, 0, NULL, '', 2, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(753, 345, 116, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 1, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(754, 345, 116, 0, NULL, '', 3, 1, '0.0000', '0.0000', '$', 0, '0.10000000', 'lb', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(755, 346, 117, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"79";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"89";}}', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(756, 346, 117, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"80";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"89";}}', 1, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(757, 346, 117, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"81";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"89";}}', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(758, 346, 117, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"85";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"89";}}', 3, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(759, 346, 117, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"79";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"88";}}', 4, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(760, 346, 117, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"83";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"88";}}', 5, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(761, 346, 117, 0, NULL, '', 0, 0, '2.5000', '0.0000', '$', 0, '0.00000000', 'lb', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"86";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"88";}}', 6, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(762, 346, 117, 0, NULL, '', 14, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"84";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"91";}}', 7, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(763, 347, 118, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(764, 347, 118, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(765, 347, 118, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(766, 347, 118, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 3, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(767, 347, 118, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 4, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(768, 348, 119, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(769, 348, 119, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 1, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(770, 348, 119, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(771, 348, 119, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 3, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(772, 349, 120, 0, NULL, '', 6, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(773, 349, 120, 0, NULL, '', 8, 1, '1.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 1, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(774, 350, 121, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(775, 350, 121, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(776, 351, 121, 0, NULL, '', 3, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(777, 351, 121, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 1, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(778, 352, 122, 0, NULL, '', 14, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 0, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(779, 352, 122, 0, NULL, '', 3, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(780, 352, 122, 0, NULL, '', 24, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(781, 353, 123, 0, NULL, '', 20, 1, '2.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"93";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"88";}}', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(782, 353, 123, 0, NULL, '', 20, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"94";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"88";}}', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(783, 353, 123, 0, NULL, '', 9, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"95";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"88";}}', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(784, 353, 123, 0, NULL, '', 5, 1, '2.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"93";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"91";}}', 3, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(785, 353, 123, 0, NULL, '', 0, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 0, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"96";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"91";}}', 4, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(786, 353, 123, 0, NULL, '', 20, 1, '2.0000', '0.0000', '$', 0, '0.00000000', 'g', 98, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"93";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"98";}}', 5, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(787, 353, 123, 0, NULL, '', 10, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'g', 98, 'a:2:{i:0;a:2:{s:7:"attr_id";i:7;s:9:"attr_v_id";s:2:"96";}i:1;a:2:{s:7:"attr_id";i:8;s:9:"attr_v_id";s:2:"98";}}', 6, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(788, 354, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(789, 354, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(790, 354, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(791, 354, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 3, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(792, 354, 124, 0, NULL, '', 0, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 4, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(793, 355, 124, 0, NULL, '', 2, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(794, 355, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 1, 1, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(795, 355, 124, 0, NULL, '', 3, 1, '0.0000', '0.0000', '$', 0, '0.10000000', 'lb', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(796, 356, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '', 0, '0.00000000', '', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(797, 357, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(798, 358, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '', 0, '0.00000000', '', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(799, 359, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(800, 360, 124, 0, NULL, '', -1, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(801, 360, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(802, 360, 124, 0, NULL, '', 40, 1, '2.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(803, 361, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(804, 362, 124, 0, NULL, '', 0, 1, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(805, 362, 124, 0, NULL, '', 40, 1, '10.0000', '0.0000', '%', 0, '0.00000000', 'lb', 0, '', 1, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(806, 362, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', 'lb', 0, '', 2, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(807, 363, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '', 0, '0.00000000', '', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]'),
(808, 364, 124, 0, NULL, '', 0, 0, '0.0000', '0.0000', '$', 0, '0.00000000', '', 0, '', 0, 0, NULL, NULL, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_option_value_descriptions`
--

CREATE TABLE `[[dbprefix]]product_option_value_descriptions` (
  `product_option_value_id` int NOT NULL,
  `language_id` int NOT NULL,
  `product_id` int NOT NULL,
  `name` text COLLATE utf8mb4_unicode_ci COMMENT 'translatable',
  `grouped_attribute_names` text COLLATE utf8mb4_unicode_ci,
  PRIMARY KEY (`product_option_value_id`,`language_id`),
  KEY `[[dbprefix]]product_option_value_descriptions_idx` (`product_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]product_option_value_descriptions`
--

INSERT INTO `[[dbprefix]]product_option_value_descriptions` VALUES
(612, 1, 57, 'Pink Pool', NULL),
(613, 1, 57, 'Mandarin Sky', NULL),
(614, 1, 57, 'Brilliant Berry', NULL),
(615, 1, 59, 'Viva Glam IV', NULL),
(616, 1, 59, 'Viva Glam II', NULL),
(617, 1, 59, 'Viva Glam VI', NULL),
(618, 1, 55, 'La Base', NULL),
(619, 1, 55, 'Lacewood', NULL),
(620, 1, 55, 'Smoky Rouge', NULL),
(621, 1, 55, 'Tulipwood', NULL),
(622, 1, 60, 'Shirelle', NULL),
(623, 1, 60, 'Vintage Vamp', NULL),
(624, 1, 60, 'Nocturnelle', NULL),
(625, 1, 61, 'Golden Frenzy', NULL),
(626, 1, 61, 'Gris Fatale', NULL),
(627, 1, 61, 'Jade Fever', NULL),
(642, 1, 64, '1.0 oz', NULL),
(643, 1, 64, '1.7 oz', NULL),
(644, 1, 64, '3.4 oz', NULL),
(645, 1, 54, 'Black', ''),
(646, 1, 54, 'Brown', ''),
(647, 1, 63, '3.4 oz', NULL),
(648, 1, 63, '2.5 oz', NULL),
(649, 1, 63, '1.7 oz', NULL),
(650, 1, 69, '8 oz', NULL),
(651, 1, 69, '33.8 oz', NULL),
(652, 1, 53, 'Natural Golden', NULL),
(653, 1, 53, 'Natural Ambre', NULL),
(654, 1, 56, 'Bronze', NULL),
(655, 1, 56, 'Dore', NULL),
(656, 1, 56, 'Ivore', NULL),
(657, 1, 56, 'Light Bisque', NULL),
(658, 1, 56, 'Suede', NULL),
(659, 1, 56, 'Light Buff', NULL),
(660, 1, 78, '100ml', NULL),
(661, 1, 78, '150ml', NULL),
(662, 1, 78, '50ml', NULL),
(663, 1, 80, '1.7 oz', NULL),
(664, 1, 80, '3.4 oz', NULL),
(665, 1, 80, '6.7 oz', NULL),
(666, 1, 84, '30 ml', NULL),
(667, 1, 84, '50 ml', NULL),
(668, 1, 84, '75 ml', NULL),
(669, 1, 85, '1 oz', NULL),
(670, 1, 85, '1.7 oz', NULL),
(671, 1, 85, '3.4 oz', NULL),
(672, 1, 89, '0.04 oz', NULL),
(673, 1, 89, '6.7 oz', NULL),
(674, 1, 89, '1.7 oz', NULL),
(676, 1, 90, '1.7 oz EDP Spray', NULL),
(677, 1, 90, '3.4 oz EDP Spray', NULL),
(678, 1, 99, 'rose beige', NULL),
(679, 1, 99, 'cranberry', NULL),
(680, 1, 99, 'cassis', NULL),
(681, 1, 100, 'beige', NULL),
(682, 1, 100, 'red beige', NULL),
(683, 1, 100, 'brique', NULL),
(684, 1, 100, 'brown', NULL),
(685, 1, 100, 'mauve', NULL),
(686, 1, 100, 'red', NULL),
(687, 1, 101, '8.45 oz', NULL),
(688, 1, 101, '15.2 oz', NULL),
(689, 1, 101, '33.8 oz', NULL),
(690, 1, 102, '30ml', NULL),
(691, 1, 102, '50ml', NULL),
(692, 1, 102, '75ml', NULL),
(713, 1, 104, '1.7 oz', NULL),
(714, 1, 104, '1 oz', NULL),
(719, 1, 105, 'yes', NULL),
(720, 1, 105, 'Eau de Parfum', NULL),
(721, 1, 105, 'Eau de Toilette', NULL),
(722, 1, 105, 'Eau de Cologne', NULL),
(723, 1, 105, '1 oz', NULL),
(724, 1, 105, '1.7 oz', NULL),
(731, 1, 106, 'Coral', NULL),
(732, 1, 106, 'Amethyst', NULL),
(733, 1, 106, 'Crystalline', NULL),
(735, 1, 106, 'yes', NULL),
(737, 1, 109, 'yes', NULL),
(738, 1, 110, '30ml', NULL),
(739, 1, 110, '50ml', NULL),
(740, 1, 110, '75ml', NULL),
(741, 1, 115, '36', ''),
(742, 1, 115, '37', ''),
(743, 1, 115, '38', ''),
(744, 1, 115, '39', ''),
(745, 1, 115, '40', ''),
(746, 1, 115, '41 -', ''),
(747, 1, 116, '3 UK ', ''),
(748, 1, 116, '4 UK ', ''),
(749, 1, 116, '5 UK ', ''),
(750, 1, 116, '6 UK ', ''),
(751, 1, 116, '7 UK ', ''),
(752, 1, 116, 'white', ''),
(753, 1, 116, 'red', ''),
(754, 1, 116, 'black', ''),
(755, 1, 117, 'UK 3 / White', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"79";s:4:"name";s:4:"UK 3";}i:1;a:2:{s:9:"attr_v_id";s:2:"89";s:4:"name";s:5:"White";}i:2;a:2:{i:0;s:4:"UK 3";i:1;s:5:"White";}}'),
(756, 1, 117, 'UK 3.5 / White', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"80";s:4:"name";s:6:"UK 3.5";}i:1;a:2:{s:9:"attr_v_id";s:2:"89";s:4:"name";s:5:"White";}i:2;a:2:{i:0;s:6:"UK 3.5";i:1;s:5:"White";}}'),
(757, 1, 117, 'UK 4 / White', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"81";s:4:"name";s:4:"UK 4";}i:1;a:2:{s:9:"attr_v_id";s:2:"89";s:4:"name";s:5:"White";}i:2;a:2:{i:0;s:4:"UK 4";i:1;s:5:"White";}}'),
(758, 1, 117, 'UK 6 / White', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"85";s:4:"name";s:4:"UK 6";}i:1;a:2:{s:9:"attr_v_id";s:2:"89";s:4:"name";s:5:"White";}i:2;a:2:{i:0;s:4:"UK 6";i:1;s:5:"White";}}'),
(759, 1, 117, 'UK 3 / Red', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"79";s:4:"name";s:4:"UK 3";}i:1;a:2:{s:9:"attr_v_id";s:2:"88";s:4:"name";s:3:"Red";}i:2;a:2:{i:0;s:4:"UK 3";i:1;s:3:"Red";}}'),
(760, 1, 117, 'UK 5 / Red', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"83";s:4:"name";s:4:"UK 5";}i:1;a:2:{s:9:"attr_v_id";s:2:"88";s:4:"name";s:3:"Red";}i:2;a:2:{i:0;s:4:"UK 5";i:1;s:3:"Red";}}'),
(761, 1, 117, 'UK 7 / Red', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"86";s:4:"name";s:4:"UK 7";}i:1;a:2:{s:9:"attr_v_id";s:2:"88";s:4:"name";s:3:"Red";}i:2;a:2:{i:0;s:4:"UK 7";i:1;s:3:"Red";}}'),
(762, 1, 117, 'UK 5.5 / Blue', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"84";s:4:"name";s:6:"UK 5.5";}i:1;a:2:{s:9:"attr_v_id";s:2:"91";s:4:"name";s:4:"Blue";}i:2;a:2:{i:0;s:6:"UK 5.5";i:1;s:4:"Blue";}}'),
(763, 1, 118, 'black', ''),
(764, 1, 118, 'red', ''),
(765, 1, 118, 'green', ''),
(766, 1, 118, 'blue', ''),
(767, 1, 118, 'white', ''),
(768, 1, 119, 'Small', ''),
(769, 1, 119, 'Medium', ''),
(770, 1, 119, 'Large', ''),
(771, 1, 119, 'X-Large', ''),
(772, 1, 120, 'Small', ''),
(773, 1, 120, 'Large', ''),
(774, 1, 121, 'Light Blue', ''),
(775, 1, 121, 'White', ''),
(776, 1, 121, 'Small', ''),
(777, 1, 121, 'Medium', ''),
(778, 1, 122, 'EU XS (Asia M)', ''),
(779, 1, 122, 'EU S (Asia L)', ''),
(780, 1, 122, 'EU 2XL (Asia 5XL)', ''),
(781, 1, 123, 'XXL / Red', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"93";s:4:"name";s:3:"XXL";}i:1;a:2:{s:9:"attr_v_id";s:2:"88";s:4:"name";s:3:"Red";}i:2;a:2:{i:0;s:3:"XXL";i:1;s:3:"Red";}}'),
(782, 1, 123, 'XL / Red', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"94";s:4:"name";s:2:"XL";}i:1;a:2:{s:9:"attr_v_id";s:2:"88";s:4:"name";s:3:"Red";}i:2;a:2:{i:0;s:2:"XL";i:1;s:3:"Red";}}'),
(783, 1, 123, 'S / Red', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"95";s:4:"name";s:1:"S";}i:1;a:2:{s:9:"attr_v_id";s:2:"88";s:4:"name";s:3:"Red";}i:2;a:2:{i:0;s:1:"S";i:1;s:3:"Red";}}'),
(784, 1, 123, 'XXL / Blue', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"93";s:4:"name";s:3:"XXL";}i:1;a:2:{s:9:"attr_v_id";s:2:"91";s:4:"name";s:4:"Blue";}i:2;a:2:{i:0;s:3:"XXL";i:1;s:4:"Blue";}}'),
(785, 1, 123, 'L / Blue', 'a:3:{i:0;a:2:{s:9:"attr_v_id";s:2:"96";s:4:"name";s:1:"L";}i:1;a:2:{s:9:"attr_v_id";s:2:"91";s:4:"name";s:4:"Blue";}i:2;a:2:{i:0;s:1:"L";i:1;s:4:"Blue";}}'),
(786, 1, 123, 'XXL / Yellow', 'a:2:{i:0;a:2:{s:9:"attr_v_id";s:2:"93";s:4:"name";s:3:"XXL";}i:1;a:2:{s:9:"attr_v_id";s:2:"98";s:4:"name";s:6:"Yellow";}}'),
(787, 1, 123, 'L / Yellow', 'a:2:{i:0;a:2:{s:9:"attr_v_id";s:2:"96";s:4:"name";s:1:"L";}i:1;a:2:{s:9:"attr_v_id";s:2:"98";s:4:"name";s:6:"Yellow";}}'),
(788, 1, 124, '3 UK ', 'N;'),
(789, 1, 124, '4 UK ', 'N;'),
(790, 1, 124, '5 UK ', 'N;'),
(791, 1, 124, '6 UK ', 'N;'),
(792, 1, 124, '7 UK ', 'N;'),
(793, 1, 124, 'white', 'N;'),
(794, 1, 124, 'red', 'N;'),
(795, 1, 124, 'black', 'N;'),
(797, 1, 124, '555555', ''),
(799, 1, 124, 'Please enter long text.', ''),
(800, 1, 124, 'Type1', ''),
(801, 1, 124, 'Type2', ''),
(802, 1, 124, 'Type3', ''),
(803, 1, 124, 'yes', ''),
(804, 1, 124, 'green', ''),
(805, 1, 124, 'black', ''),
(806, 1, 124, 'white', ''),
(808, 1, 124, 'the label text', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_specials`
--

CREATE TABLE `[[dbprefix]]product_specials` (
  `product_special_id` int NOT NULL AUTO_INCREMENT,
  `product_id` int NOT NULL,
  `customer_group_id` int NOT NULL,
  `priority` int NOT NULL DEFAULT '1',
  `price_prefix` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `price` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `date_start` date DEFAULT NULL,
  `date_end` date DEFAULT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`product_special_id`),
  KEY `[[dbprefix]]product_specials_idx` (`product_id`,`customer_group_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=262 ;

--
-- Dumping data for table `[[dbprefix]]product_specials`
--

INSERT INTO `[[dbprefix]]product_specials` VALUES
(252, 51, 1, 0, '', '19.0000', NULL, NULL, '[[regtime]]', '[[regtime]]'),
(253, 55, 1, 0, '', '27.0000', NULL, NULL, '[[regtime]]', '[[regtime]]'),
(254, 67, 1, 0, '', '29.0000', NULL, NULL, '[[regtime]]', '[[regtime]]'),
(255, 72, 1, 0, '$', '24.0000', NULL, NULL, '[[regtime]]', '[[regtime]]'),
(256, 88, 1, 0, '%', '2.0000', NULL, NULL, '[[regtime]]', '[[regtime]]'),
(257, 93, 1, 0, '$', '220.0000', '2022-06-04', NULL, '[[regtime]]', '[[regtime]]'),
(258, 65, 1, 1, '$', '89.0000', '2022-06-01', NULL, '[[regtime]]', '[[regtime]]'),
(260, 80, 1, 1, '$', '45.0000', '2022-06-01', NULL, '[[regtime]]', '[[regtime]]'),
(261, 124, 1, 1, '$', '90.0000', '2023-12-04', NULL, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_stock_locations`
--

CREATE TABLE `[[dbprefix]]product_stock_locations` (
  `product_id` int NOT NULL,
  `product_option_value_id` int DEFAULT NULL,
  `location_id` int NOT NULL,
  `quantity` int NOT NULL DEFAULT '0',
  `sort_order` int NOT NULL DEFAULT '0',
  `supplier_code` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `supplier_id` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  UNIQUE KEY `[[dbprefix]]product_stock_locations_idx` (`product_id`,`product_option_value_id`,`location_id`),
  UNIQUE KEY `[[dbprefix]]product_stock_locations_supplier_idx` (`supplier_code`,`supplier_id`),
  KEY `[[dbprefix]]product_stock_locations_idx2` (`product_option_value_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]product_stock_locations`
--

INSERT INTO `[[dbprefix]]product_stock_locations` VALUES
(122, 778, 1, 10, 0, NULL, NULL),
(122, 778, 2, 4, 0, NULL, NULL),
(122, 779, 2, 3, 0, NULL, NULL),
(122, 779, 1, 0, 0, NULL, NULL),
(122, 780, 1, 4, 0, NULL, NULL),
(122, 780, 2, 20, 0, NULL, NULL),
(58, NULL, 2, 25, 0, NULL, NULL),
(58, NULL, 1, 11, 0, NULL, NULL);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_tags`
--

CREATE TABLE `[[dbprefix]]product_tags` (
  `product_id` int NOT NULL,
  `tag` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `language_id` int NOT NULL,
  PRIMARY KEY (`product_id`,`tag`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]product_tags`
--

INSERT INTO `[[dbprefix]]product_tags` VALUES
(50, 'cheeks', 1),
(50, 'makeup', 1),
(51, 'cheeks', 1),
(51, 'makeup', 1),
(54, 'eye', 1),
(54, 'makeup', 1),
(77, 'body', 1),
(77, 'men', 1),
(77, 'shower', 1),
(78, 'fragrance', 1),
(78, 'men', 1),
(79, 'fragrance', 1),
(79, 'men', 1),
(79, 'unisex', 1),
(79, 'women', 1),
(81, 'Eau de Toilette', 1),
(85, 'fragrance', 1),
(85, 'women', 1),
(87, 'fragrance', 1),
(89, 'fragrance', 1),
(89, 'woman', 1),
(95, 'gift', 1),
(95, 'man', 1),
(96, 'man', 1),
(96, 'skincare', 1),
(98, 'man', 1),
(99, 'nail', 1),
(99, 'women', 1),
(101, 'conditioner', 1),
(103, 'spray', 1),
(108, 'gift', 1),
(108, 'pen', 1),
(108, 'set', 1),
(115, 'fashion', 1),
(115, 'purple', 1),
(115, 'shoe', 1),
(116, 'fashion', 1),
(116, 'shoe', 1),
(117, 'fashion', 1),
(117, 'shoe', 1),
(119, 'fashion', 1),
(119, 't-shirt', 1),
(119, 'yellow', 1),
(120, 'fashion', 1),
(120, 't-shirt', 1),
(121, 'fashion', 1),
(122, 'fashion', 1),
(122, 'grey', 1),
(123, 'red', 1),
(123, 'shirt', 1),
(123, 'white', 1),
(123, 'yellow', 1),
(124, 'fashion', 1),
(124, 'shoe', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]resource_descriptions`
--

CREATE TABLE `[[dbprefix]]resource_descriptions` (
  `resource_id` int NOT NULL DEFAULT '0',
  `language_id` int NOT NULL,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT '' COMMENT 'translatable',
  `title` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT '' COMMENT 'translatable',
  `description` text COLLATE utf8mb4_unicode_ci COMMENT 'translatable',
  `resource_path` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `resource_code` text COLLATE utf8mb4_unicode_ci,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`resource_id`,`language_id`),
  KEY `[[dbprefix]]resource_descriptions_name_idx` (`resource_id`,`name`),
  KEY `[[dbprefix]]resource_descriptions_title_idx` (`resource_id`,`title`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]resource_descriptions`
--

INSERT INTO `[[dbprefix]]resource_descriptions` VALUES
(1, 1, 'Star Icon', '', '', '', '<i class="fa fa-star"></i>&nbsp;&nbsp;', '[[regtime]]', '[[regtime]]'),
(2, 1, 'Icon Home', '', '', '', '<i class="fa fa-home"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(3, 1, 'Login Icon', '', '', '', '<i class="fa fa-lock"></i>&nbsp;&nbsp;', '[[regtime]]', '[[regtime]]'),
(4, 1, 'Account Icon', '', '', '', '<i class="fa fa-user"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(5, 1, 'Cart Icon', '', '', '', '<i class="fa fa-shopping-cart"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(6, 1, 'Checkout Icon', '', '', '', '<i class="fa fa-barcode"></i>&nbsp;&nbsp;', '[[regtime]]', '[[regtime]]'),
(7, 1, 'store_logo.png', '', '', '18/73/3.png', '', '[[regtime]]', '[[regtime]]'),
(8, 1, 'favicon.png', '', '', '18/73/4.png', '', '[[regtime]]', '[[regtime]]'),
(10, 1, 'Field Icon Country', '', '', '', '<i class="fa fa-globe"></i>', '[[regtime]]', '[[regtime]]'),
(11, 1, 'Field Icon Zone', '', '', '', '<i class="fa fa-map"></i>', '[[regtime]]', '[[regtime]]'),
(12, 1, 'Field Icon Postcode', '', '', '', '<i class="fa fa-signs-post"></i>', '[[regtime]]', '[[regtime]]'),
(13, 1, 'Field Icon Company', '', '', '', '<i class="fa-solid fa-handshake"></i>', '[[regtime]]', '[[regtime]]'),
(14, 1, 'Field Icon Address Line 1', '', '', '', '<i class="fa-solid fa-location-pin"></i>', '[[regtime]]', '[[regtime]]'),
(15, 1, 'Field Icon Address Line 2', '', '', '', '<i class="fa-solid fa-location-dot"></i>', '[[regtime]]', '[[regtime]]'),
(16, 1, 'Field Icon City', '', '', '', '<i class="fa-solid fa-city"></i>', '[[regtime]]', '[[regtime]]'),
(17, 1, 'Field Icon First Name', '', '', '', '<i class="fa fa-solid fa-user"></i>', '[[regtime]]', '[[regtime]]'),
(18, 1, 'Field Icon Last Name', '', '', '', '<i class="fa fa-solid fa-user-tag"></i>', '[[regtime]]', '[[regtime]]'),
(19, 1, 'Field Icon Email', '', '', '', '<i class="fa-solid fa-at"></i>', '[[regtime]]', '[[regtime]]'),
(20, 1, 'Field Icon Phone', '', '', '', '<i class="fa-solid fa-phone"></i>', '[[regtime]]', '[[regtime]]'),
(21, 1, 'Field Icon Login Name', '', '', '', '<i class="fa-solid fa-fingerprint"></i>', '[[regtime]]', '[[regtime]]'),
(200, 1, 'Icon Catalog', '', '', '', '<i class="fa fa-folder-open"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(201, 1, 'Icon Sale', '', '', '', '<i class="fa fa-flag-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(202, 1, 'Icon Design', '', '', '', '<i class="fa fa-file-text"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(203, 1, 'Icon Extension', '', '', '', '<i class="fa fa-puzzle-piece"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(204, 1, 'Icon System', '', '', '', '<i class="fa fa-wrench"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(205, 1, 'Icon Reports', '', '', '', '<i class="fa fa-bar-chart-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(206, 1, 'Icon Help', '', '', '', '<i class="fa fa-life-ring"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(207, 1, 'Icon Category', '', '', '', '<i class="fa fa-folder-open"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(208, 1, 'Icon Product', '', '', '', '<i class="fa fa-cubes"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(209, 1, 'Icon Manufacturer', '', '', '', '<i class="fa fa-bookmark-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(210, 1, 'Icon Download', '', '', '', '<i class="fa fa-download"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(211, 1, 'Icon Review', '', '', '', '<i class="fa fa-comment-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(212, 1, 'Icon Attributes', '', '', '', '<i class="fa fa-ticket"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(213, 1, 'Icon Extensions', '', '', '', '<i class="fa fa-th"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(214, 1, 'Icon Shipping', '', '', '', '<i class="fa fa-truck"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(215, 1, 'Icon Building', '', '', '', '<i class="fa fa-university"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(216, 1, 'Icon Templates', '', '', '', '<i class="fa fa-outdent"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(217, 1, 'Icon Languages', '', '', '', '<i class="fa fa-language"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(218, 1, 'Icon Total', '', '', '', '<i class="fa fa-sign-in"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(219, 1, 'Icon Add extension', '', '', '', '<i class="fa fa-magic"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(220, 1, 'Icon Get Extensions', '', '', '', '<i class="fa fa-cloud-download"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(221, 1, 'Icon Order', '', '', '', '<i class="fa fa-flag-checkered"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(222, 1, 'Icon Customer', '', '', '', '<i class="fa fa-users"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(223, 1, 'Icon Customer group', '', '', '', '<i class="fa fa-book"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(224, 1, 'Icon Coupon', '', '', '', '<i class="fa fa-tags"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(225, 1, 'Icon Contact', '', '', '', '<i class="fa fa-envelope-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(226, 1, 'Icon Setting', '', '', '', '<i class="fa fa-cogs"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(227, 1, 'Icon Users', '', '', '', '<i class="fa fa-users"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(228, 1, 'Icon Localisation', '', '', '', '<i class="fa fa-random"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(229, 1, 'Icon Data', '', '', '', '<i class="fa fa-cubes"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(230, 1, 'Icon Updater', '', '', '', '<i class="fa fa-refresh"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(231, 1, 'Icon Cache', '', '', '', '<i class="fa fa-recycle"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(232, 1, 'Icon Messages', '', '', '', '<i class="fa fa-weixin"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(233, 1, 'Icon Logs', '', '', '', '<i class="fa fa-floppy-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(234, 1, 'Icon Report sale', '', '', '', '<i class="fa fa-signal"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(235, 1, 'Icon Viewed', '', '', '', '<i class="fa fa-sort-amount-desc"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(236, 1, 'Icon Purchased', '', '', '', '<i class="fa fa-file-text-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(237, 1, 'Icon Banner manager stat', '', '', '', '<i class="fa fa-reply-all"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(238, 1, 'Icon Abantecart', '', '', '', '<i class="fa fa-external-link"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(239, 1, 'Icon Documentation', '', '', '', '<i class="fa fa-graduation-cap"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(240, 1, 'Icon Support', '', '', '', '<i class="fa fa-info"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(241, 1, 'Icon Template', '', '', '', '<i class="fa fa-files-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(242, 1, 'Icon Layout', '', '', '', '<i class="fa fa-bars"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(243, 1, 'Icon Blocks', '', '', '', '<i class="fa fa-qrcode"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(244, 1, 'Icon Menu', '', '', '', '<i class="fa fa-tag"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(245, 1, 'Icon Content', '', '', '', '<i class="fa fa-clipboard"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(246, 1, 'Icon Banner manager', '', '', '', '<i class="fa fa-picture-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(247, 1, 'Icon All settings', '', '', '', '<i class="fa fa-sliders"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(248, 1, 'Icon Settings details', '', '', '', '<i class="fa fa-list"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(249, 1, 'Icon Settings general', '', '', '', '<i class="fa fa-folder-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(250, 1, 'Icon Settings checkout', '', '', '', '<i class="fa fa-shopping-cart"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(251, 1, 'Icon Settings appearance', '', '', '', '<i class="fa fa-pencil-square-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(252, 1, 'Icon Settings mail', '', '', '', '<i class="fa fa-envelope-square"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(253, 1, 'Icon Settings api', '', '', '', '<i class="fa fa-slack"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(254, 1, 'Icon Settings system', '', '', '', '<i class="fa fa-tasks"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(255, 1, 'Icon Settings newstore', '', '', '', '<i class="fa fa-sitemap"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(256, 1, 'Icon User', '', '', '', '<i class="fa fa-male"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(257, 1, 'Icon Permission', '', '', '', '<i class="fa fa-code-fork"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(258, 1, 'Icon Language', '', '', '', '<i class="fa fa-language"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(259, 1, 'Icon Language definitions', '', '', '', '<i class="fa fa-sort-alpha-asc"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(260, 1, 'Icon Currency', '', '', '', '<i class="fa fa-money"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(261, 1, 'Icon Stock Status', '', '', '', '<i class="fa fa-list-alt"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(262, 1, 'Icon Order Status', '', '', '', '<i class="fa fa-sort-amount-asc"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(263, 1, 'Icon Country', '', '', '', '<i class="fa fa-globe"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(264, 1, 'Icon Zone', '', '', '', '<i class="fa fa-thumb-tack"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(265, 1, 'Icon Location', '', '', '', '<i class="fa fa-flag-checkered"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(266, 1, 'Icon Tax class', '', '', '', '<i class="fa fa-briefcase"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(267, 1, 'Icon Length class', '', '', '', '<i class="fa fa-arrows-h"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(268, 1, 'Icon Weight class', '', '', '', '<i class="fa fa-angle-double-down"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(269, 1, 'Icon Backup', '', '', '', '<i class="fa fa-jsfiddle"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(270, 1, 'Icon Migrate', '', '', '', '<i class="fa fa-share-alt-square"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(271, 1, 'Icon Datasets', '', '', '', '<i class="fa fa-database"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(272, 1, 'Icon Import export', '', '', '', '<i class="fa fa-exchange"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(273, 1, 'Icon File uploads', '', '', '', '<i class="fa fa-download"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(274, 1, 'Icon Install Log', '', '', '', '<i class="fa fa-history"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(275, 1, 'Icon Error log', '', '', '', '<i class="fa fa-exclamation-triangle"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(276, 1, 'Icon Settings IM', '', '', '', '<i class="fa fa-bullhorn"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(277, 1, 'Icon Resource Library', '', '', '', '<i class="fa fa-image"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(278, 1, 'Icon Analytics & Insights', '', '', '', '<i class="fa fa-signal"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(279, 1, 'Icon Collections', '', '', '', '<i class="fa fa-paste"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(280, 1, 'Icon Email Templates', '', '', '', '<i class="fa fa-envelope-open-o"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(281, 1, 'abc-logo-white', 'abc-logo-white', 'abc-logo-white.png', '18/7a/logo.png', '', '[[regtime]]', '[[regtime]]'),
(282, 1, 'Icon Menu Checkout', '', '', '', '<i class="fa fa-money-bill"></i>&nbsp;', '[[regtime]]', '[[regtime]]'),
(100007, 1, 'demo_product14_2.jpg', '', '', '18/6a/7.webp', '', '[[regtime]]', '[[regtime]]'),
(100008, 1, 'demo_product14.jpg', '', '', '18/6a/8.jpg', '', '[[regtime]]', '[[regtime]]'),
(100009, 1, 'demo_product14_1.jpg', '', '', '18/6a/9.jpg', '', '[[regtime]]', '[[regtime]]'),
(100010, 1, 'demo_product15_1.jpg', '', '', '18/6a/a.png', '', '[[regtime]]', '[[regtime]]'),
(100011, 1, 'demo_product15.jpg', '', '', '18/6a/b.webp', '', '[[regtime]]', '[[regtime]]'),
(100012, 1, 'demo_product07.jpg', '', '', '18/6a/c.webp', '', '[[regtime]]', '[[regtime]]'),
(100013, 1, 'demo_product18.jpg', '', '', '18/6a/d.webp', '', '[[regtime]]', '[[regtime]]'),
(100014, 1, 'demo_product30.jpg', '', '', '18/6a/e.webp', '', '[[regtime]]', '[[regtime]]'),
(100015, 1, 'demo_product30_2.jpg', '', '', '18/6a/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100016, 1, 'demo_product30_1.jpg', '', '', '18/6b/0.jpg', '', '[[regtime]]', '[[regtime]]'),
(100017, 1, 'demo_product30_3.jpg', '', '', '18/6b/1.jpg', '', '[[regtime]]', '[[regtime]]'),
(100018, 1, 'demo_product34.jpg', '', '', '18/6b/2.webp', '', '[[regtime]]', '[[regtime]]'),
(100019, 1, 'demo_product34_2.jpg', '', '', '18/6b/3.jpg', '', '[[regtime]]', '[[regtime]]'),
(100020, 1, 'demo_product34_1.jpg', '', '', '18/6b/4.jpg', '', '[[regtime]]', '[[regtime]]'),
(100021, 1, 'demo_product32.jpg', '', '', '18/6b/5.png', '', '[[regtime]]', '[[regtime]]'),
(100022, 1, 'demo_product32.png', '', '', '18/6b/6.png', '', '[[regtime]]', '[[regtime]]'),
(100023, 1, 'demo_product33.jpg', '', '', '18/6b/7.jpg', '', '[[regtime]]', '[[regtime]]'),
(100024, 1, 'demo_product32_1.jpg', '', '', '18/6b/8.jpg', '', '[[regtime]]', '[[regtime]]'),
(100026, 1, 'demo_product02.jpg', '', '', '18/6b/a.webp', '', '[[regtime]]', '[[regtime]]'),
(100027, 1, 'demo_product02_2.jpg', '', '', '18/6b/b.webp', '', '[[regtime]]', '[[regtime]]'),
(100028, 1, 'demo_product02_1.jpg', '', '', '18/6b/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100029, 1, 'demo_product02_3.jpg', '', '', '18/6b/d.webp', '', '[[regtime]]', '[[regtime]]'),
(100030, 1, 'demo_product42.jpg', '', '', '18/6b/e.webp', '', '[[regtime]]', '[[regtime]]'),
(100031, 1, 'demo_product22.jpg', '', '', '18/6b/f.webp', '', '[[regtime]]', '[[regtime]]'),
(100032, 1, 'demo_product11_1.jpg', '', '', '18/6c/0.webp', '', '[[regtime]]', '[[regtime]]'),
(100033, 1, 'demo_product11_2.jpg', '', '', '18/6c/1.jpg', '', '[[regtime]]', '[[regtime]]'),
(100034, 1, 'demo_product11.jpg', '', '', '18/6c/2.jpg', '', '[[regtime]]', '[[regtime]]'),
(100035, 1, 'demo_product43.jpg', '', '', '18/6c/3.png', '', '[[regtime]]', '[[regtime]]'),
(100036, 1, 'demo_product24.jpg', '', '', '18/6c/4.png', '', '[[regtime]]', '[[regtime]]'),
(100037, 1, 'demo_product06_6.jpg', '', '', '18/6c/5.webp', '', '[[regtime]]', '[[regtime]]'),
(100038, 1, 'demo_product06_2.jpg', '', '', '18/6c/6.jpg', '', '[[regtime]]', '[[regtime]]'),
(100039, 1, 'demo_product06_1.jpg', '', '', '18/6c/7.jpg', '', '[[regtime]]', '[[regtime]]'),
(100040, 1, 'demo_product06.jpg', '', '', '18/6c/8.jpg', '', '[[regtime]]', '[[regtime]]'),
(100041, 1, 'demo_product06_4.jpg', '', '', '18/6c/9.jpg', '', '[[regtime]]', '[[regtime]]'),
(100042, 1, 'demo_product06_3.jpg', '', '', '18/6c/a.jpg', '', '[[regtime]]', '[[regtime]]'),
(100043, 1, 'demo_product06_5.jpg', '', '', '18/6c/b.jpg', '', '[[regtime]]', '[[regtime]]'),
(100044, 1, 'demo_product25_1.jpg', '', '', '18/6c/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100045, 1, 'demo_product25_2.jpg', '', '', '18/6c/d.webp', '', '[[regtime]]', '[[regtime]]'),
(100046, 1, 'demo_product25.jpg', '', '', '18/6c/e.jpg', '', '[[regtime]]', '[[regtime]]'),
(100047, 1, 'demo_product20.jpg', '', '', '18/6c/f.webp', '', '[[regtime]]', '[[regtime]]'),
(100048, 1, 'demo_product36.jpg', '', '', '18/6d/0.webp', '', '[[regtime]]', '[[regtime]]'),
(100049, 1, 'demo_product47.png', '', '', '18/6d/1.png', '', '[[regtime]]', '[[regtime]]'),
(100050, 1, 'demo_product46.jpg', '', '', '18/6d/2.webp', '', '[[regtime]]', '[[regtime]]'),
(100051, 1, 'demo_product46.png', '', '', '18/6d/3.png', '', '[[regtime]]', '[[regtime]]'),
(100052, 1, 'demo_product17.jpg', '', '', '18/6d/4.webp', '', '[[regtime]]', '[[regtime]]'),
(100053, 1, 'demo_product49_1.png', '', '', '18/6d/5.png', '', '[[regtime]]', '[[regtime]]'),
(100054, 1, 'demo_product35_1.jpg', '', '', '18/6d/6.webp', '', '[[regtime]]', '[[regtime]]'),
(100055, 1, 'demo_product35_2.jpg', '', '', '18/6d/7.jpg', '', '[[regtime]]', '[[regtime]]'),
(100056, 1, 'demo_product35.jpg', '', '', '18/6d/8.jpg', '', '[[regtime]]', '[[regtime]]'),
(100057, 1, 'demo_product23.jpg', '', '', '18/6d/9.png', '', '[[regtime]]', '[[regtime]]'),
(100058, 1, 'demo_product41.jpg', '', '', '18/6d/a.png', '', '[[regtime]]', '[[regtime]]'),
(100059, 1, 'demo_product09_4.jpg', '', '', '18/6d/b.webp', '', '[[regtime]]', '[[regtime]]'),
(100060, 1, 'demo_product09_1.jpg', '', '', '18/6d/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100061, 1, 'demo_product09.jpg', '', '', '18/6d/d.jpg', '', '[[regtime]]', '[[regtime]]'),
(100062, 1, 'demo_product09_3.jpg', '', '', '18/6d/e.jpg', '', '[[regtime]]', '[[regtime]]'),
(100063, 1, 'demo_product09_2.jpg', '', '', '18/6d/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100064, 1, 'demo_product37.jpg', '', '', '18/6e/0.webp', '', '[[regtime]]', '[[regtime]]'),
(100065, 1, 'demo_product26_2.jpg', '', '', '18/6e/1.webp', '', '[[regtime]]', '[[regtime]]'),
(100066, 1, 'demo_product26_3.jpg', '', '', '18/6e/2.jpg', '', '[[regtime]]', '[[regtime]]'),
(100067, 1, 'demo_product26.jpg', '', '', '18/6e/3.jpg', '', '[[regtime]]', '[[regtime]]'),
(100068, 1, 'demo_product26_1.jpg', '', '', '18/6e/4.jpg', '', '[[regtime]]', '[[regtime]]'),
(100069, 1, 'demo_product27_1.jpg', '', '', '18/6e/5.jpg', '', '[[regtime]]', '[[regtime]]'),
(100070, 1, 'demo_product27.jpg', '', '', '18/6e/6.webp', '', '[[regtime]]', '[[regtime]]'),
(100071, 1, 'demo_product10.jpg', '', '', '18/6e/7.webp', '', '[[regtime]]', '[[regtime]]'),
(100072, 1, 'demo_product10_1.jpg', '', '', '18/6e/8.jpg', '', '[[regtime]]', '[[regtime]]'),
(100073, 1, 'demo_product10_2.jpg', '', '', '18/6e/9.jpg', '', '[[regtime]]', '[[regtime]]'),
(100074, 1, 'demo_product10_3.jpg', '', '', '18/6e/a.jpg', '', '[[regtime]]', '[[regtime]]'),
(100075, 1, 'demo_product44.jpg', '', '', '18/6e/b.png', '', '[[regtime]]', '[[regtime]]'),
(100076, 1, 'demo_product40_1.jpg', '', '', '18/6e/c.webp', '', '[[regtime]]', '[[regtime]]'),
(100077, 1, 'demo_product40.jpg', '', '', '18/6e/d.jpg', '', '[[regtime]]', '[[regtime]]'),
(100078, 1, 'demo_product40_2.jpg', '', '', '18/6e/e.jpg', '', '[[regtime]]', '[[regtime]]'),
(100079, 1, 'demo_product21.jpg', '', '', '18/6e/f.webp', '', '[[regtime]]', '[[regtime]]'),
(100080, 1, 'demo_product13_2.jpg', '', '', '18/6f/0.webp', '', '[[regtime]]', '[[regtime]]'),
(100081, 1, 'demo_product13_1.jpg', '', '', '18/6f/1.jpg', '', '[[regtime]]', '[[regtime]]'),
(100082, 1, 'demo_product19.jpg', '', '', '18/6f/2.webp', '', '[[regtime]]', '[[regtime]]'),
(100083, 1, 'demo_product39.jpg', '', '', '18/6f/3.webp', '', '[[regtime]]', '[[regtime]]'),
(100084, 1, 'demo_product39_3.jpg', '', '', '18/6f/4.jpg', '', '[[regtime]]', '[[regtime]]'),
(100085, 1, 'demo_product39_2.jpg', '', '', '18/6f/5.jpg', '', '[[regtime]]', '[[regtime]]'),
(100086, 1, 'demo_product39_1.jpg', '', '', '18/6f/6.jpg', '', '[[regtime]]', '[[regtime]]'),
(100087, 1, 'demo_product45.png', '', '', '18/6f/7.png', '', '[[regtime]]', '[[regtime]]'),
(100088, 1, 'demo_product48.png', '', '', '18/6f/8.png', '', '[[regtime]]', '[[regtime]]'),
(100089, 1, 'demo_product01.jpg', '', '', '18/6f/9.webp', '', '[[regtime]]', '[[regtime]]'),
(100091, 1, 'demo_product16_1.jpg', '', '', '18/6f/b.webp', '', '[[regtime]]', '[[regtime]]'),
(100092, 1, 'demo_product16.jpg', '', '', '18/6f/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100093, 1, 'demo_product16_2.jpg', '', '', '18/6f/d.jpg', '', '[[regtime]]', '[[regtime]]'),
(100094, 1, 'demo_product03.jpg', '', '', '18/6f/e.webp', '', '[[regtime]]', '[[regtime]]'),
(100095, 1, 'demo_product03_1.jpg', '', '', '18/6f/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100096, 1, 'demo_product03_2.jpg', '', '', '18/70/0.jpg', '', '[[regtime]]', '[[regtime]]'),
(100097, 1, 'demo_product08.jpg', '', '', '18/70/1.webp', '', '[[regtime]]', '[[regtime]]'),
(100098, 1, 'demo_product08_2.jpg', '', '', '18/70/2.jpg', '', '[[regtime]]', '[[regtime]]'),
(100099, 1, 'demo_product08_3.jpg', '', '', '18/70/3.jpg', '', '[[regtime]]', '[[regtime]]'),
(100100, 1, 'demo_product08_1.jpg', '', '', '18/70/4.jpg', '', '[[regtime]]', '[[regtime]]'),
(100101, 1, 'demo_product05.jpg', '', '', '18/70/5.webp', '', '[[regtime]]', '[[regtime]]'),
(100102, 1, 'demo_product29_2.jpg', '', '', '18/70/6.jpg', '', '[[regtime]]', '[[regtime]]'),
(100103, 1, 'demo_product29.jpg', '', '', '18/70/7.jpg', '', '[[regtime]]', '[[regtime]]'),
(100104, 1, 'demo_product29_1.jpg', '', '', '18/70/8.jpg', '', '[[regtime]]', '[[regtime]]'),
(100105, 1, 'demo_product29.jpg', '', '', '18/70/9.webp', '', '[[regtime]]', '[[regtime]]'),
(100106, 1, 'demo_product29_2.jpg', '', '', '18/70/a.jpg', '', '[[regtime]]', '[[regtime]]'),
(100107, 1, 'demo_product29_1.jpg', '', '', '18/70/b.jpg', '', '[[regtime]]', '[[regtime]]'),
(100108, 1, 'demo_product28_1.jpg', '', '', '18/70/c.webp', '', '[[regtime]]', '[[regtime]]'),
(100109, 1, 'demo_product28.jpg', '', '', '18/70/d.webp', '', '[[regtime]]', '[[regtime]]'),
(100110, 1, 'demo_product28_2.jpg', '', '', '18/70/e.jpg', '', '[[regtime]]', '[[regtime]]'),
(100111, 1, 'demo_product38.jpg', '', '', '18/70/f.webp', '', '[[regtime]]', '[[regtime]]'),
(100112, 1, 'demo_product12.jpg', '', '', '18/71/0.png', '', '[[regtime]]', '[[regtime]]'),
(100114, 1, 'mf_sephora_ba_logo_black.jpg', '', '', '18/71/2.webp', '', '[[regtime]]', '[[regtime]]'),
(100115, 1, 'mf_Bvlgari.jpg', '', '', '18/71/3.jpg', '', '[[regtime]]', '[[regtime]]'),
(100116, 1, 'mf_calvin_klein.jpg', '', '', '18/71/4.jpg', '', '[[regtime]]', '[[regtime]]'),
(100117, 1, 'mf_benefit_logo_black.jpg', '', '', '18/71/5.jpg', '', '[[regtime]]', '[[regtime]]'),
(100118, 1, 'mf_mac_logo.jpg', '', '', '18/71/6.jpg', '', '[[regtime]]', '[[regtime]]'),
(100119, 1, 'mf_lancome_logo.gif', '', '', '18/71/7.gif', '', '[[regtime]]', '[[regtime]]'),
(100120, 1, 'mf_pantene_logo.jpg', '', '', '18/71/8.jpg', '', '[[regtime]]', '[[regtime]]'),
(100121, 1, 'mf_dove_logo.jpg', '', '', '18/71/9.jpg', '', '[[regtime]]', '[[regtime]]'),
(100122, 1, 'mf_armani_logo.gif', '', '', '18/71/a.gif', '', '[[regtime]]', '[[regtime]]'),
(100123, 1, 'demo_product_23.jpg', '', '', '18/71/b.jpg', '', '[[regtime]]', '[[regtime]]'),
(100124, 1, 'demo_product_04.jpg', '', '', '18/71/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100125, 1, 'demo_product_15.jpg', '', '', '18/71/d.jpg', '', '[[regtime]]', '[[regtime]]'),
(100126, 1, 'demo_product_14_2.jpg', '', '', '18/71/e.jpg', '', '[[regtime]]', '[[regtime]]'),
(100127, 1, 'demo_product_31.jpg', '', '', '18/71/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100128, 1, 'demo_product_34.jpg', '', '', '18/72/0.jpg', '', '[[regtime]]', '[[regtime]]'),
(100129, 1, 'demo_product_30_2.jpg', '', '', '18/72/1.jpg', '', '[[regtime]]', '[[regtime]]'),
(100130, 1, 'demo_product_24.jpg', '', '', '18/72/2.jpg', '', '[[regtime]]', '[[regtime]]'),
(100131, 1, 'demo_product_23.jpg', '', '', '18/72/3.jpg', '', '[[regtime]]', '[[regtime]]'),
(100132, 1, 'demo_product_05.jpg', '', '', '18/72/4.jpg', '', '[[regtime]]', '[[regtime]]'),
(100133, 1, 'demo_product_07.jpg', '', '', '18/72/5.jpg', '', '[[regtime]]', '[[regtime]]'),
(100134, 1, 'demo_product_08_3.jpg', '', '', '18/72/6.jpg', '', '[[regtime]]', '[[regtime]]'),
(100135, 1, 'demo_product_10_2.jpg', '', '', '18/72/7.jpg', '', '[[regtime]]', '[[regtime]]'),
(100136, 1, 'demo_product_47.png', '', '', '18/72/8.png', '', '[[regtime]]', '[[regtime]]'),
(100137, 1, 'demo_product_11_2.jpg', '', '', '18/72/9.jpg', '', '[[regtime]]', '[[regtime]]'),
(100138, 1, 'demo_product_40_2.jpg', '', '', '18/72/a.jpg', '', '[[regtime]]', '[[regtime]]'),
(100139, 1, 'demo_product_44.jpg', '', '', '18/72/b.jpg', '', '[[regtime]]', '[[regtime]]'),
(100140, 1, 'demo_product_29.jpg', '', '', '18/72/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100141, 1, 'demo_product_27.jpg', '', '', '18/72/d.jpg', '', '[[regtime]]', '[[regtime]]'),
(100142, 1, 'demo_product_42.jpg', '', '', '18/72/e.jpg', '', '[[regtime]]', '[[regtime]]'),
(100143, 1, 'demo_product_46.jpg', '', '', '18/72/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100144, 1, 'demo_product_18.jpg', '', '', '18/73/0.jpg', '', '[[regtime]]', '[[regtime]]'),
(100145, 1, 'demo_product_37.jpg', '', '', '18/73/1.jpg', '', '[[regtime]]', '[[regtime]]'),
(100146, 1, 'demo_product_49_1.png', '', '', '18/73/2.png', '', '[[regtime]]', '[[regtime]]'),
(100147, 1, 'store_logo.png', '', '', '18/73/3.png', '', '[[regtime]]', '[[regtime]]'),
(100148, 1, 'favicon.png', '', '', '18/73/4.png', '', '[[regtime]]', '[[regtime]]'),
(100150, 1, 'demo_product51.png', '', '', '18/73/6.png', '', '[[regtime]]', '[[regtime]]'),
(100153, 1, 'demo_mf_gucci.jpg', '', '', '18/73/9.jpg', '', '[[regtime]]', '[[regtime]]'),
(100154, 1, 'demo_product52_1.jpg', '', '', '18/73/a.webp', '', '[[regtime]]', '[[regtime]]'),
(100155, 1, 'demo_product52_2.png', '', '', '18/73/b.png', '', '[[regtime]]', '[[regtime]]'),
(100156, 1, 'demo_product52_3.png', '', '', '18/73/c.png', '', '[[regtime]]', '[[regtime]]'),
(100157, 1, 'demo_product53_3.jpg', '', '', '18/73/d.webp', '', '[[regtime]]', '[[regtime]]'),
(100159, 1, 'demo_product53_2.png', '', '', '18/73/f.png', '', '[[regtime]]', '[[regtime]]'),
(100160, 1, 'demo_product54_1.jpg', '', '', '18/74/0.webp', '', '[[regtime]]', '[[regtime]]'),
(100162, 1, 'demo_product55_1.jpg', '', '', '18/74/2.webp', '', '[[regtime]]', '[[regtime]]'),
(100163, 1, 'demo_product56_3.jpg', '', '', '18/74/3.jpg', '', '[[regtime]]', '[[regtime]]'),
(100164, 1, 'demo_product56_2.jpg', '', '', '18/74/4.jpg', '', '[[regtime]]', '[[regtime]]'),
(100165, 1, 'demo_product56_1.jpg', '', '', '18/74/5.webp', '', '[[regtime]]', '[[regtime]]'),
(100166, 1, 'demo_product57_1.jpg', '', '', '18/74/6.png', '', '[[regtime]]', '[[regtime]]'),
(100167, 1, 'demo_product57_2.jpg', '', '', '18/74/7.jpg', '', '[[regtime]]', '[[regtime]]'),
(100168, 1, 'demo_product58_1.jpg', '', '', '18/74/8.png', '', '[[regtime]]', '[[regtime]]'),
(100169, 1, 'demo_product58_3.jpg', '', '', '18/74/9.jpg', '', '[[regtime]]', '[[regtime]]'),
(100170, 1, 'demo_product58_4.jpg', '', '', '18/74/a.jpg', '', '[[regtime]]', '[[regtime]]'),
(100171, 1, 'demo_product58_2.jpg', '', '', '18/74/b.jpg', '', '[[regtime]]', '[[regtime]]'),
(100172, 1, 'Visionnaire.zip', '', '', '18/74/c.zip', '', '[[regtime]]', '[[regtime]]'),
(100173, 1, 'demo_product59_1.jpg', '', '', '18/74/d.png', '', '[[regtime]]', '[[regtime]]'),
(100174, 1, 'demo_product60_1.jpg', '', '', '18/74/e.webp', '', '[[regtime]]', '[[regtime]]'),
(100175, 1, 'demo_product60_2.jpg', '', '', '18/74/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100176, 1, 'demo_product60_5.jpg', '', '', '18/75/0.jpg', '', '[[regtime]]', '[[regtime]]'),
(100178, 1, 'abantecart video', '', '', '', '<object width="640" height="360"><param name="movie" value="https://www.youtube.com/v/IQ5SLJUWbdA"></param><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="https://www.youtube.com/v/IQ5SLJUWbdA" type="application/x-shockwave-flash" width="640" height="360" allowscriptaccess="always" allowfullscreen="true"></embed></object>', '[[regtime]]', '[[regtime]]'),
(100188, 1, 'smbanner.jpg', '', '', '18/75/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100190, 1, 'AM_mc_vs_dc_ae_319x110.jpg', 'PayPal Credit Cards', 'PayPal logo with supported Credit Cards', '18/75/e.jpg', '', '[[regtime]]', '[[regtime]]'),
(100191, 1, 'AM_SbyPP_mc_vs_dc_ae_319x110.jpg', 'PayPal Secure Payments', 'Secure Payments by PayPal logo', '18/75/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100192, 1, 'bdg_payments_by_pp_2line_165x56.png', 'Payments by PayPal', 'Payments by PayPal Logo', '18/76/0.png', '', '[[regtime]]', '[[regtime]]'),
(100193, 1, 'pp_cc_mark_76x48.jpg', 'PayPal Icon', 'PayPal Small Icon', '18/76/1.jpg', '', '[[regtime]]', '[[regtime]]'),
(100194, 1, 'banner_fallback.jpg', 'Fall back banner for small screen resolutions', 'Fall back banner for small screen resolutions', '18/76/2.jpg', '', '[[regtime]]', '[[regtime]]'),
(100195, 1, 'audiocd1.jpg', '', '', '18/76/3.webp', '', '[[regtime]]', '[[regtime]]'),
(100196, 1, 'Marketplace-and_Extension-Installation-in-AbanteCart.mp3', 'Audio CD 1', '', '18/76/4.mp3', '', '[[regtime]]', '[[regtime]]'),
(100197, 1, 'sample.mp3', '', '', '18/76/5.mp3', '', '[[regtime]]', '[[regtime]]'),
(100198, 1, 'paperback1.jpg', '', '', '18/76/6.webp', '', '[[regtime]]', '[[regtime]]'),
(100199, 1, 'cdaudio.png', 'category image', '', '18/76/7.png', '', '[[regtime]]', '[[regtime]]'),
(100200, 1, 'book2.png', '', '', '18/76/8.png', '', '[[regtime]]', '[[regtime]]'),
(100201, 1, 'papertowns2.jpg', '', '', '18/76/9.webp', '', '[[regtime]]', '[[regtime]]'),
(100202, 1, 'paper2.jpg', '', '', '18/76/a.jpg', '', '[[regtime]]', '[[regtime]]'),
(100203, 1, 'paper-cover_allegiant.jpg', '', '', '18/76/b.webp', '', '[[regtime]]', '[[regtime]]'),
(100204, 1, 'Fiorella-Purple-Peep-Toes-1.jpg', '', '', '18/76/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100206, 1, 'Fiorella-Purple-Peep-Toes-2.jpg', '', '', '18/76/e.webp', '', '[[regtime]]', '[[regtime]]'),
(100207, 1, 'new-ladies-black1.jpg', '', '', '18/76/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100208, 1, 'new-ladies-black2.jpg', '', '', '18/77/0.jpg', '', '[[regtime]]', '[[regtime]]'),
(100209, 1, 'new-ladies-black3.jpg', '', '', '18/77/1.jpg', '', '[[regtime]]', '[[regtime]]'),
(100210, 1, 'new-ladies-black4.jpg', '', '', '18/77/2.jpg', '', '[[regtime]]', '[[regtime]]'),
(100211, 1, 'new-ladies-red6.jpg', '', '', '18/77/3.jpg', '', '[[regtime]]', '[[regtime]]'),
(100212, 1, 'new-ladies-red5.jpg', '', '', '18/77/4.jpg', '', '[[regtime]]', '[[regtime]]'),
(100213, 1, 'new-ladies-red4.jpg', '', '', '18/77/5.jpg', '', '[[regtime]]', '[[regtime]]'),
(100214, 1, 'new-ladies-red3.jpg', '', '', '18/77/6.jpg', '', '[[regtime]]', '[[regtime]]'),
(100215, 1, 'new-ladies-red2.jpg', '', '', '18/77/7.jpg', '', '[[regtime]]', '[[regtime]]'),
(100216, 1, 'new-ladies-red1.jpg', '', '', '18/77/8.webp', '', '[[regtime]]', '[[regtime]]'),
(100217, 1, 'new-ladies-white5.jpg', '', '', '18/77/9.jpg', '', '[[regtime]]', '[[regtime]]'),
(100218, 1, 'new-ladies-white4.jpg', '', '', '18/77/a.jpg', '', '[[regtime]]', '[[regtime]]'),
(100219, 1, 'new-ladies-white3.jpg', '', '', '18/77/b.jpg', '', '[[regtime]]', '[[regtime]]'),
(100220, 1, 'new-ladies-white2.jpg', '', '', '18/77/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100221, 1, 'new-ladies-white1.jpg', '', '', '18/77/d.jpg', '', '[[regtime]]', '[[regtime]]'),
(100222, 1, 'new-ladies-red6.jpg', '', '', '18/77/e.jpg', '', '[[regtime]]', '[[regtime]]'),
(100223, 1, 'new-ladies-red5.jpg', '', '', '18/77/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100224, 1, 'new-ladies-red4.jpg', '', '', '18/78/0.jpg', '', '[[regtime]]', '[[regtime]]'),
(100225, 1, 'new-ladies-red3.jpg', '', '', '18/78/1.webp', '', '[[regtime]]', '[[regtime]]'),
(100226, 1, 'new-ladies-red2.jpg', '', '', '18/78/2.jpg', '', '[[regtime]]', '[[regtime]]'),
(100227, 1, 'new-ladies-red1.jpg', '', '', '18/78/3.jpg', '', '[[regtime]]', '[[regtime]]'),
(100228, 1, 'shoe_1.jpg', '', '', '18/78/4.webp', '', '[[regtime]]', '[[regtime]]'),
(100229, 1, 'shoe_1a.jpg', '', '', '18/78/5.jpg', '', '[[regtime]]', '[[regtime]]'),
(100230, 1, 'shoe_1b.jpg', '', '', '18/78/6.jpg', '', '[[regtime]]', '[[regtime]]'),
(100231, 1, 'shoe_1c.jpg', '', '', '18/78/7.jpg', '', '[[regtime]]', '[[regtime]]'),
(100232, 1, 'shoe_1d.jpg', '', '', '18/78/8.jpg', '', '[[regtime]]', '[[regtime]]'),
(100233, 1, 'shoe_1e.jpg', '', '', '18/78/9.jpg', '', '[[regtime]]', '[[regtime]]'),
(100235, 1, 'shoeblack_1.jpg', '', '', '18/78/b.webp', '', '[[regtime]]', '[[regtime]]'),
(100236, 1, 'shoeblack_2.jpg', '', '', '18/78/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100237, 1, 'shoeblack_3.jpg', '', '', '18/78/d.jpg', '', '[[regtime]]', '[[regtime]]'),
(100238, 1, 'shoeblack_5.jpg', '', '', '18/78/e.jpg', '', '[[regtime]]', '[[regtime]]'),
(100239, 1, 'shoeblack_6.jpg', '', '', '18/78/f.jpg', '', '[[regtime]]', '[[regtime]]'),
(100240, 1, 'shoeblack_7.jpg', '', '', '18/79/0.jpg', '', '[[regtime]]', '[[regtime]]'),
(100241, 1, 't-shirt.jpg', '', '', '18/79/1.webp', '', '[[regtime]]', '[[regtime]]'),
(100242, 1, 't-shirt-2.jpg', '', '', '18/79/2.webp', '', '[[regtime]]', '[[regtime]]'),
(100243, 1, 't-shirt-3.jpg', '', '', '18/79/3.png', '', '[[regtime]]', '[[regtime]]'),
(100244, 1, 't-shirt-3a.jpg', '', '', '18/79/4.jpg', '', '[[regtime]]', '[[regtime]]'),
(100245, 1, 't-shirt-4c.jpg', '', '', '18/79/5.jpg', '', '[[regtime]]', '[[regtime]]'),
(100246, 1, 't-shirt-4b.jpg', '', '', '18/79/6.jpg', '', '[[regtime]]', '[[regtime]]'),
(100247, 1, 't-shirt-4a.jpg', '', '', '18/79/7.jpg', '', '[[regtime]]', '[[regtime]]'),
(100248, 1, 't-shirt-4.jpg', '', '', '18/79/8.webp', '', '[[regtime]]', '[[regtime]]'),
(100249, 1, 'demo_product31.png', 'Armani Eau de Toilette', '', '18/79/9.png', '', '[[regtime]]', '[[regtime]]'),
(100250, 1, 'lancome-mascara.jpg', '', '', '18/79/a.webp', '', '[[regtime]]', '[[regtime]]'),
(100251, 1, 'blue.jpg', 'blue cotton t-shirt', '', '18/79/b.webp', '', '[[regtime]]', '[[regtime]]'),
(100252, 1, 'red.jpg', '', '', '18/79/c.jpg', '', '[[regtime]]', '[[regtime]]'),
(100253, 1, 'yellow.jpg', '', '', '18/79/d.jpg', '', '[[regtime]]', '[[regtime]]'),
(100255, 1, 'size-fit-guide-print.pdf', 'Fit guide', '', '18/79/f.pdf', '', '[[regtime]]', '[[regtime]]'),
(100257, 1, 'local_delivery_icon.png', '', '', '18/7a/1.png', '', '[[regtime]]', '[[regtime]]'),
(100261, 1, 'file-sample_150kB.pdf', '', '', '18/7a/5.pdf', '', '[[regtime]]', '[[regtime]]'),
(100262, 1, 'abc-logo', 'abc-logo', 'abc-logo.png', '18/7a/6.png', '', '[[regtime_yest]]', '[[regtime]]'),
(100263, 1, 'Menu Icon Page Builder', '', '', '', '<i class="fa fa-object-group"></i>&nbsp;', '[[regtime_yest]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]resource_library`
--

CREATE TABLE `[[dbprefix]]resource_library` (
  `resource_id` int NOT NULL AUTO_INCREMENT,
  `type_id` int NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`resource_id`),
  KEY `[[dbprefix]]resource_library_idx` (`resource_id`,`type_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=100264 ;

--
-- Dumping data for table `[[dbprefix]]resource_library`
--

INSERT INTO `[[dbprefix]]resource_library` VALUES
(1, 1, '[[regtime]]', '[[regtime]]'),
(2, 1, '[[regtime]]', '[[regtime]]'),
(3, 1, '[[regtime]]', '[[regtime]]'),
(4, 1, '[[regtime]]', '[[regtime]]'),
(5, 1, '[[regtime]]', '[[regtime]]'),
(6, 1, '[[regtime]]', '[[regtime]]'),
(7, 1, '[[regtime]]', '[[regtime]]'),
(8, 1, '[[regtime]]', '[[regtime]]'),
(10, 1, '[[regtime]]', '[[regtime]]'),
(11, 1, '[[regtime]]', '[[regtime]]'),
(12, 1, '[[regtime]]', '[[regtime]]'),
(13, 1, '[[regtime]]', '[[regtime]]'),
(14, 1, '[[regtime]]', '[[regtime]]'),
(15, 1, '[[regtime]]', '[[regtime]]'),
(16, 1, '[[regtime]]', '[[regtime]]'),
(17, 1, '[[regtime]]', '[[regtime]]'),
(18, 1, '[[regtime]]', '[[regtime]]'),
(19, 1, '[[regtime]]', '[[regtime]]'),
(20, 1, '[[regtime]]', '[[regtime]]'),
(21, 1, '[[regtime]]', '[[regtime]]'),
(200, 1, '[[regtime]]', '[[regtime]]'),
(201, 1, '[[regtime]]', '[[regtime]]'),
(202, 1, '[[regtime]]', '[[regtime]]'),
(203, 1, '[[regtime]]', '[[regtime]]'),
(204, 1, '[[regtime]]', '[[regtime]]'),
(205, 1, '[[regtime]]', '[[regtime]]'),
(206, 1, '[[regtime]]', '[[regtime]]'),
(207, 1, '[[regtime]]', '[[regtime]]'),
(208, 1, '[[regtime]]', '[[regtime]]'),
(209, 1, '[[regtime]]', '[[regtime]]'),
(210, 1, '[[regtime]]', '[[regtime]]'),
(211, 1, '[[regtime]]', '[[regtime]]'),
(212, 1, '[[regtime]]', '[[regtime]]'),
(213, 1, '[[regtime]]', '[[regtime]]'),
(214, 1, '[[regtime]]', '[[regtime]]'),
(215, 1, '[[regtime]]', '[[regtime]]'),
(216, 1, '[[regtime]]', '[[regtime]]'),
(217, 1, '[[regtime]]', '[[regtime]]'),
(218, 1, '[[regtime]]', '[[regtime]]'),
(219, 1, '[[regtime]]', '[[regtime]]'),
(220, 1, '[[regtime]]', '[[regtime]]'),
(221, 1, '[[regtime]]', '[[regtime]]'),
(222, 1, '[[regtime]]', '[[regtime]]'),
(223, 1, '[[regtime]]', '[[regtime]]'),
(224, 1, '[[regtime]]', '[[regtime]]'),
(225, 1, '[[regtime]]', '[[regtime]]'),
(226, 1, '[[regtime]]', '[[regtime]]'),
(227, 1, '[[regtime]]', '[[regtime]]'),
(228, 1, '[[regtime]]', '[[regtime]]'),
(229, 1, '[[regtime]]', '[[regtime]]'),
(230, 1, '[[regtime]]', '[[regtime]]'),
(231, 1, '[[regtime]]', '[[regtime]]'),
(232, 1, '[[regtime]]', '[[regtime]]'),
(233, 1, '[[regtime]]', '[[regtime]]'),
(234, 1, '[[regtime]]', '[[regtime]]'),
(235, 1, '[[regtime]]', '[[regtime]]'),
(236, 1, '[[regtime]]', '[[regtime]]'),
(237, 1, '[[regtime]]', '[[regtime]]'),
(238, 1, '[[regtime]]', '[[regtime]]'),
(239, 1, '[[regtime]]', '[[regtime]]'),
(240, 1, '[[regtime]]', '[[regtime]]'),
(241, 1, '[[regtime]]', '[[regtime]]'),
(242, 1, '[[regtime]]', '[[regtime]]'),
(243, 1, '[[regtime]]', '[[regtime]]'),
(244, 1, '[[regtime]]', '[[regtime]]'),
(245, 1, '[[regtime]]', '[[regtime]]'),
(246, 1, '[[regtime]]', '[[regtime]]'),
(247, 1, '[[regtime]]', '[[regtime]]'),
(248, 1, '[[regtime]]', '[[regtime]]'),
(249, 1, '[[regtime]]', '[[regtime]]'),
(250, 1, '[[regtime]]', '[[regtime]]'),
(251, 1, '[[regtime]]', '[[regtime]]'),
(252, 1, '[[regtime]]', '[[regtime]]'),
(253, 1, '[[regtime]]', '[[regtime]]'),
(254, 1, '[[regtime]]', '[[regtime]]'),
(255, 1, '[[regtime]]', '[[regtime]]'),
(256, 1, '[[regtime]]', '[[regtime]]'),
(257, 1, '[[regtime]]', '[[regtime]]'),
(258, 1, '[[regtime]]', '[[regtime]]'),
(259, 1, '[[regtime]]', '[[regtime]]'),
(260, 1, '[[regtime]]', '[[regtime]]'),
(261, 1, '[[regtime]]', '[[regtime]]'),
(262, 1, '[[regtime]]', '[[regtime]]'),
(263, 1, '[[regtime]]', '[[regtime]]'),
(264, 1, '[[regtime]]', '[[regtime]]'),
(265, 1, '[[regtime]]', '[[regtime]]'),
(266, 1, '[[regtime]]', '[[regtime]]'),
(267, 1, '[[regtime]]', '[[regtime]]'),
(268, 1, '[[regtime]]', '[[regtime]]'),
(269, 1, '[[regtime]]', '[[regtime]]'),
(270, 1, '[[regtime]]', '[[regtime]]'),
(271, 1, '[[regtime]]', '[[regtime]]'),
(272, 1, '[[regtime]]', '[[regtime]]'),
(273, 1, '[[regtime]]', '[[regtime]]'),
(274, 1, '[[regtime]]', '[[regtime]]'),
(275, 1, '[[regtime]]', '[[regtime]]'),
(276, 1, '[[regtime]]', '[[regtime]]'),
(277, 1, '[[regtime]]', '[[regtime]]'),
(278, 1, '[[regtime]]', '[[regtime]]'),
(279, 1, '[[regtime]]', '[[regtime]]'),
(280, 1, '[[regtime]]', '[[regtime]]'),
(281, 1, '[[regtime]]', '[[regtime]]'),
(100007, 1, '[[regtime]]', '[[regtime]]'),
(100008, 1, '[[regtime]]', '[[regtime]]'),
(100009, 1, '[[regtime]]', '[[regtime]]'),
(100010, 1, '[[regtime]]', '[[regtime]]'),
(100011, 1, '[[regtime]]', '[[regtime]]'),
(100012, 1, '[[regtime]]', '[[regtime]]'),
(100013, 1, '[[regtime]]', '[[regtime]]'),
(100014, 1, '[[regtime]]', '[[regtime]]'),
(100015, 1, '[[regtime]]', '[[regtime]]'),
(100016, 1, '[[regtime]]', '[[regtime]]'),
(100017, 1, '[[regtime]]', '[[regtime]]'),
(100018, 1, '[[regtime]]', '[[regtime]]'),
(100019, 1, '[[regtime]]', '[[regtime]]'),
(100020, 1, '[[regtime]]', '[[regtime]]'),
(100021, 1, '[[regtime]]', '[[regtime]]'),
(100022, 1, '[[regtime]]', '[[regtime]]'),
(100023, 1, '[[regtime]]', '[[regtime]]'),
(100024, 1, '[[regtime]]', '[[regtime]]'),
(100026, 1, '[[regtime]]', '[[regtime]]'),
(100027, 1, '[[regtime]]', '[[regtime]]'),
(100028, 1, '[[regtime]]', '[[regtime]]'),
(100029, 1, '[[regtime]]', '[[regtime]]'),
(100030, 1, '[[regtime]]', '[[regtime]]'),
(100031, 1, '[[regtime]]', '[[regtime]]'),
(100032, 1, '[[regtime]]', '[[regtime]]'),
(100033, 1, '[[regtime]]', '[[regtime]]'),
(100034, 1, '[[regtime]]', '[[regtime]]'),
(100035, 1, '[[regtime]]', '[[regtime]]'),
(100036, 1, '[[regtime]]', '[[regtime]]'),
(100037, 1, '[[regtime]]', '[[regtime]]'),
(100038, 1, '[[regtime]]', '[[regtime]]'),
(100039, 1, '[[regtime]]', '[[regtime]]'),
(100040, 1, '[[regtime]]', '[[regtime]]'),
(100041, 1, '[[regtime]]', '[[regtime]]'),
(100042, 1, '[[regtime]]', '[[regtime]]'),
(100043, 1, '[[regtime]]', '[[regtime]]'),
(100044, 1, '[[regtime]]', '[[regtime]]'),
(100045, 1, '[[regtime]]', '[[regtime]]'),
(100046, 1, '[[regtime]]', '[[regtime]]'),
(100047, 1, '[[regtime]]', '[[regtime]]'),
(100048, 1, '[[regtime]]', '[[regtime]]'),
(100049, 1, '[[regtime]]', '[[regtime]]'),
(100050, 1, '[[regtime]]', '[[regtime]]'),
(100051, 1, '[[regtime]]', '[[regtime]]'),
(100052, 1, '[[regtime]]', '[[regtime]]'),
(100053, 1, '[[regtime]]', '[[regtime]]'),
(100054, 1, '[[regtime]]', '[[regtime]]'),
(100055, 1, '[[regtime]]', '[[regtime]]'),
(100056, 1, '[[regtime]]', '[[regtime]]'),
(100057, 1, '[[regtime]]', '[[regtime]]'),
(100058, 1, '[[regtime]]', '[[regtime]]'),
(100059, 1, '[[regtime]]', '[[regtime]]'),
(100060, 1, '[[regtime]]', '[[regtime]]'),
(100061, 1, '[[regtime]]', '[[regtime]]'),
(100062, 1, '[[regtime]]', '[[regtime]]'),
(100063, 1, '[[regtime]]', '[[regtime]]'),
(100064, 1, '[[regtime]]', '[[regtime]]'),
(100065, 1, '[[regtime]]', '[[regtime]]'),
(100066, 1, '[[regtime]]', '[[regtime]]'),
(100067, 1, '[[regtime]]', '[[regtime]]'),
(100068, 1, '[[regtime]]', '[[regtime]]'),
(100069, 1, '[[regtime]]', '[[regtime]]'),
(100070, 1, '[[regtime]]', '[[regtime]]'),
(100071, 1, '[[regtime]]', '[[regtime]]'),
(100072, 1, '[[regtime]]', '[[regtime]]'),
(100073, 1, '[[regtime]]', '[[regtime]]'),
(100074, 1, '[[regtime]]', '[[regtime]]'),
(100075, 1, '[[regtime]]', '[[regtime]]'),
(100076, 1, '[[regtime]]', '[[regtime]]'),
(100077, 1, '[[regtime]]', '[[regtime]]'),
(100078, 1, '[[regtime]]', '[[regtime]]'),
(100079, 1, '[[regtime]]', '[[regtime]]'),
(100080, 1, '[[regtime]]', '[[regtime]]'),
(100081, 1, '[[regtime]]', '[[regtime]]'),
(100082, 1, '[[regtime]]', '[[regtime]]'),
(100083, 1, '[[regtime]]', '[[regtime]]'),
(100084, 1, '[[regtime]]', '[[regtime]]'),
(100085, 1, '[[regtime]]', '[[regtime]]'),
(100086, 1, '[[regtime]]', '[[regtime]]'),
(100087, 1, '[[regtime]]', '[[regtime]]'),
(100088, 1, '[[regtime]]', '[[regtime]]'),
(100089, 1, '[[regtime]]', '[[regtime]]'),
(100091, 1, '[[regtime]]', '[[regtime]]'),
(100092, 1, '[[regtime]]', '[[regtime]]'),
(100093, 1, '[[regtime]]', '[[regtime]]'),
(100094, 1, '[[regtime]]', '[[regtime]]'),
(100095, 1, '[[regtime]]', '[[regtime]]'),
(100096, 1, '[[regtime]]', '[[regtime]]'),
(100097, 1, '[[regtime]]', '[[regtime]]'),
(100098, 1, '[[regtime]]', '[[regtime]]'),
(100099, 1, '[[regtime]]', '[[regtime]]'),
(100100, 1, '[[regtime]]', '[[regtime]]'),
(100101, 1, '[[regtime]]', '[[regtime]]'),
(100102, 1, '[[regtime]]', '[[regtime]]'),
(100103, 1, '[[regtime]]', '[[regtime]]'),
(100104, 1, '[[regtime]]', '[[regtime]]'),
(100105, 1, '[[regtime]]', '[[regtime]]'),
(100106, 1, '[[regtime]]', '[[regtime]]'),
(100107, 1, '[[regtime]]', '[[regtime]]'),
(100108, 1, '[[regtime]]', '[[regtime]]'),
(100109, 1, '[[regtime]]', '[[regtime]]'),
(100110, 1, '[[regtime]]', '[[regtime]]'),
(100111, 1, '[[regtime]]', '[[regtime]]'),
(100112, 1, '[[regtime]]', '[[regtime]]'),
(100114, 1, '[[regtime]]', '[[regtime]]'),
(100115, 1, '[[regtime]]', '[[regtime]]'),
(100116, 1, '[[regtime]]', '[[regtime]]'),
(100117, 1, '[[regtime]]', '[[regtime]]'),
(100118, 1, '[[regtime]]', '[[regtime]]'),
(100119, 1, '[[regtime]]', '[[regtime]]'),
(100120, 1, '[[regtime]]', '[[regtime]]'),
(100121, 1, '[[regtime]]', '[[regtime]]'),
(100122, 1, '[[regtime]]', '[[regtime]]'),
(100123, 1, '[[regtime]]', '[[regtime]]'),
(100124, 1, '[[regtime]]', '[[regtime]]'),
(100125, 1, '[[regtime]]', '[[regtime]]'),
(100126, 1, '[[regtime]]', '[[regtime]]'),
(100127, 1, '[[regtime]]', '[[regtime]]'),
(100128, 1, '[[regtime]]', '[[regtime]]'),
(100129, 1, '[[regtime]]', '[[regtime]]'),
(100130, 1, '[[regtime]]', '[[regtime]]'),
(100131, 1, '[[regtime]]', '[[regtime]]'),
(100132, 1, '[[regtime]]', '[[regtime]]'),
(100133, 1, '[[regtime]]', '[[regtime]]'),
(100134, 1, '[[regtime]]', '[[regtime]]'),
(100135, 1, '[[regtime]]', '[[regtime]]'),
(100136, 1, '[[regtime]]', '[[regtime]]'),
(100137, 1, '[[regtime]]', '[[regtime]]'),
(100138, 1, '[[regtime]]', '[[regtime]]'),
(100139, 1, '[[regtime]]', '[[regtime]]'),
(100140, 1, '[[regtime]]', '[[regtime]]'),
(100141, 1, '[[regtime]]', '[[regtime]]'),
(100142, 1, '[[regtime]]', '[[regtime]]'),
(100143, 1, '[[regtime]]', '[[regtime]]'),
(100144, 1, '[[regtime]]', '[[regtime]]'),
(100145, 1, '[[regtime]]', '[[regtime]]'),
(100146, 1, '[[regtime]]', '[[regtime]]'),
(100147, 1, '[[regtime]]', '[[regtime]]'),
(100148, 1, '[[regtime]]', '[[regtime]]'),
(100150, 1, '[[regtime]]', '[[regtime]]'),
(100153, 1, '[[regtime]]', '[[regtime]]'),
(100154, 1, '[[regtime]]', '[[regtime]]'),
(100155, 1, '[[regtime]]', '[[regtime]]'),
(100156, 1, '[[regtime]]', '[[regtime]]'),
(100157, 1, '[[regtime]]', '[[regtime]]'),
(100159, 1, '[[regtime]]', '[[regtime]]'),
(100160, 1, '[[regtime]]', '[[regtime]]'),
(100162, 1, '[[regtime]]', '[[regtime]]'),
(100163, 1, '[[regtime]]', '[[regtime]]'),
(100164, 1, '[[regtime]]', '[[regtime]]'),
(100165, 1, '[[regtime]]', '[[regtime]]'),
(100166, 1, '[[regtime]]', '[[regtime]]'),
(100167, 1, '[[regtime]]', '[[regtime]]'),
(100168, 1, '[[regtime]]', '[[regtime]]'),
(100169, 1, '[[regtime]]', '[[regtime]]'),
(100170, 1, '[[regtime]]', '[[regtime]]'),
(100171, 1, '[[regtime]]', '[[regtime]]'),
(100172, 5, '[[regtime]]', '[[regtime]]'),
(100173, 1, '[[regtime]]', '[[regtime]]'),
(100174, 1, '[[regtime]]', '[[regtime]]'),
(100175, 1, '[[regtime]]', '[[regtime]]'),
(100176, 1, '[[regtime]]', '[[regtime]]'),
(100178, 3, '[[regtime]]', '[[regtime]]'),
(100188, 1, '[[regtime]]', '[[regtime]]'),
(100190, 1, '[[regtime]]', '[[regtime]]'),
(100191, 1, '[[regtime]]', '[[regtime]]'),
(100192, 1, '[[regtime]]', '[[regtime]]'),
(100193, 1, '[[regtime]]', '[[regtime]]'),
(100194, 1, '[[regtime]]', '[[regtime]]'),
(100195, 1, '[[regtime]]', '[[regtime]]'),
(100196, 6, '[[regtime]]', '[[regtime]]'),
(100197, 6, '[[regtime]]', '[[regtime]]'),
(100198, 1, '[[regtime]]', '[[regtime]]'),
(100199, 1, '[[regtime]]', '[[regtime]]'),
(100200, 1, '[[regtime]]', '[[regtime]]'),
(100201, 1, '[[regtime]]', '[[regtime]]'),
(100202, 1, '[[regtime]]', '[[regtime]]'),
(100203, 1, '[[regtime]]', '[[regtime]]'),
(100204, 1, '[[regtime]]', '[[regtime]]'),
(100206, 1, '[[regtime]]', '[[regtime]]'),
(100207, 1, '[[regtime]]', '[[regtime]]'),
(100208, 1, '[[regtime]]', '[[regtime]]'),
(100209, 1, '[[regtime]]', '[[regtime]]'),
(100210, 1, '[[regtime]]', '[[regtime]]'),
(100211, 1, '[[regtime]]', '[[regtime]]'),
(100212, 1, '[[regtime]]', '[[regtime]]'),
(100213, 1, '[[regtime]]', '[[regtime]]'),
(100214, 1, '[[regtime]]', '[[regtime]]'),
(100215, 1, '[[regtime]]', '[[regtime]]'),
(100216, 1, '[[regtime]]', '[[regtime]]'),
(100217, 1, '[[regtime]]', '[[regtime]]'),
(100218, 1, '[[regtime]]', '[[regtime]]'),
(100219, 1, '[[regtime]]', '[[regtime]]'),
(100220, 1, '[[regtime]]', '[[regtime]]'),
(100221, 1, '[[regtime]]', '[[regtime]]'),
(100222, 1, '[[regtime]]', '[[regtime]]'),
(100223, 1, '[[regtime]]', '[[regtime]]'),
(100224, 1, '[[regtime]]', '[[regtime]]'),
(100225, 1, '[[regtime]]', '[[regtime]]'),
(100226, 1, '[[regtime]]', '[[regtime]]'),
(100227, 1, '[[regtime]]', '[[regtime]]'),
(100228, 1, '[[regtime]]', '[[regtime]]'),
(100229, 1, '[[regtime]]', '[[regtime]]'),
(100230, 1, '[[regtime]]', '[[regtime]]'),
(100231, 1, '[[regtime]]', '[[regtime]]'),
(100232, 1, '[[regtime]]', '[[regtime]]'),
(100233, 1, '[[regtime]]', '[[regtime]]'),
(100235, 1, '[[regtime]]', '[[regtime]]'),
(100236, 1, '[[regtime]]', '[[regtime]]'),
(100237, 1, '[[regtime]]', '[[regtime]]'),
(100238, 1, '[[regtime]]', '[[regtime]]'),
(100239, 1, '[[regtime]]', '[[regtime]]'),
(100240, 1, '[[regtime]]', '[[regtime]]'),
(100241, 1, '[[regtime]]', '[[regtime]]'),
(100242, 1, '[[regtime]]', '[[regtime]]'),
(100243, 1, '[[regtime]]', '[[regtime]]'),
(100244, 1, '[[regtime]]', '[[regtime]]'),
(100245, 1, '[[regtime]]', '[[regtime]]'),
(100246, 1, '[[regtime]]', '[[regtime]]'),
(100247, 1, '[[regtime]]', '[[regtime]]'),
(100248, 1, '[[regtime]]', '[[regtime]]'),
(100249, 1, '[[regtime]]', '[[regtime]]'),
(100250, 1, '[[regtime]]', '[[regtime]]'),
(100251, 1, '[[regtime]]', '[[regtime]]'),
(100252, 1, '[[regtime]]', '[[regtime]]'),
(100253, 1, '[[regtime]]', '[[regtime]]'),
(100255, 6, '[[regtime]]', '[[regtime]]'),
(100257, 1, '[[regtime]]', '[[regtime]]'),
(100260, 6, '[[regtime]]', '[[regtime]]'),
(100261, 6, '[[regtime]]', '[[regtime]]'),
(100262, 1, '[[regtime]]', '[[regtime]]'),
(100263, 1, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]resource_map`
--

CREATE TABLE `[[dbprefix]]resource_map` (
  `resource_id` int NOT NULL,
  `object_name` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL,
  `object_id` int NOT NULL,
  `default` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0-no, 1-Yes',
  `sort_order` int NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`resource_id`,`object_name`,`object_id`),
  KEY `[[dbprefix]]resource_map_sorting_idx` (`resource_id`,`sort_order`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]resource_map`
--

INSERT INTO `[[dbprefix]]resource_map` VALUES
(1, 'storefront_menu_item', 0, 0, 0, '[[regtime]]', '[[regtime]]'),
(2, 'storefront_menu_item', 0, 0, 0, '[[regtime]]', '[[regtime]]'),
(3, 'storefront_menu_item', 0, 0, 0, '[[regtime]]', '[[regtime]]'),
(4, 'storefront_menu_item', 0, 0, 0, '[[regtime]]', '[[regtime]]'),
(5, 'storefront_menu_item', 0, 0, 0, '[[regtime]]', '[[regtime]]'),
(6, 'storefront_menu_item', 0, 0, 0, '[[regtime]]', '[[regtime]]'),
(10, 'field', 4, 0, 1, '[[regtime]]', '[[regtime]]'),
(11, 'field', 4, 0, 2, '[[regtime]]', '[[regtime]]'),
(12, 'field', 4, 0, 3, '[[regtime]]', '[[regtime]]'),
(13, 'field', 4, 0, 4, '[[regtime]]', '[[regtime]]'),
(14, 'field', 4, 0, 5, '[[regtime]]', '[[regtime]]'),
(15, 'field', 4, 0, 6, '[[regtime]]', '[[regtime]]'),
(16, 'field', 4, 0, 7, '[[regtime]]', '[[regtime]]'),
(17, 'field', 4, 0, 8, '[[regtime]]', '[[regtime]]'),
(18, 'field', 4, 0, 9, '[[regtime]]', '[[regtime]]'),
(19, 'field', 5, 0, 1, '[[regtime]]', '[[regtime]]'),
(20, 'field', 5, 0, 2, '[[regtime]]', '[[regtime]]'),
(21, 'field', 6, 0, 1, '[[regtime]]', '[[regtime]]'),
(100007, 'products', 64, 0, 0, '[[regtime]]', '[[regtime]]'),
(100008, 'products', 64, 0, 0, '[[regtime]]', '[[regtime]]'),
(100009, 'products', 64, 0, 0, '[[regtime]]', '[[regtime]]'),
(100010, 'products', 65, 0, 0, '[[regtime]]', '[[regtime]]'),
(100011, 'products', 65, 0, 0, '[[regtime]]', '[[regtime]]'),
(100012, 'products', 58, 0, 0, '[[regtime]]', '[[regtime]]'),
(100013, 'products', 68, 0, 0, '[[regtime]]', '[[regtime]]'),
(100014, 'products', 80, 0, 0, '[[regtime]]', '[[regtime]]'),
(100015, 'products', 80, 0, 0, '[[regtime]]', '[[regtime]]'),
(100016, 'products', 80, 0, 0, '[[regtime]]', '[[regtime]]'),
(100017, 'products', 80, 0, 0, '[[regtime]]', '[[regtime]]'),
(100018, 'products', 84, 0, 0, '[[regtime]]', '[[regtime]]'),
(100019, 'products', 84, 0, 0, '[[regtime]]', '[[regtime]]'),
(100020, 'products', 84, 0, 0, '[[regtime]]', '[[regtime]]'),
(100021, 'products', 83, 0, 0, '[[regtime]]', '[[regtime]]'),
(100022, 'products', 82, 0, 0, '[[regtime]]', '[[regtime]]'),
(100023, 'products', 83, 0, 0, '[[regtime]]', '[[regtime]]'),
(100024, 'products', 83, 0, 0, '[[regtime]]', '[[regtime]]'),
(100026, 'products', 51, 0, 0, '[[regtime]]', '[[regtime]]'),
(100027, 'products', 51, 0, 0, '[[regtime]]', '[[regtime]]'),
(100028, 'products', 51, 0, 0, '[[regtime]]', '[[regtime]]'),
(100029, 'products', 52, 0, 0, '[[regtime]]', '[[regtime]]'),
(100030, 'products', 92, 0, 0, '[[regtime]]', '[[regtime]]'),
(100031, 'products', 72, 0, 0, '[[regtime]]', '[[regtime]]'),
(100032, 'products', 61, 0, 0, '[[regtime]]', '[[regtime]]'),
(100033, 'products', 61, 0, 0, '[[regtime]]', '[[regtime]]'),
(100034, 'products', 61, 0, 0, '[[regtime]]', '[[regtime]]'),
(100035, 'products', 93, 0, 0, '[[regtime]]', '[[regtime]]'),
(100036, 'products', 74, 0, 0, '[[regtime]]', '[[regtime]]'),
(100037, 'products', 57, 0, 0, '[[regtime]]', '[[regtime]]'),
(100038, 'products', 57, 0, 0, '[[regtime]]', '[[regtime]]'),
(100039, 'products', 57, 0, 0, '[[regtime]]', '[[regtime]]'),
(100040, 'products', 57, 0, 0, '[[regtime]]', '[[regtime]]'),
(100041, 'products', 57, 0, 0, '[[regtime]]', '[[regtime]]'),
(100042, 'products', 57, 0, 0, '[[regtime]]', '[[regtime]]'),
(100043, 'products', 57, 0, 0, '[[regtime]]', '[[regtime]]'),
(100044, 'products', 75, 0, 2, '[[regtime]]', '[[regtime]]'),
(100045, 'products', 75, 0, 1, '[[regtime]]', '[[regtime]]'),
(100046, 'products', 75, 0, 3, '[[regtime]]', '[[regtime]]'),
(100047, 'products', 70, 0, 0, '[[regtime]]', '[[regtime]]'),
(100048, 'products', 86, 0, 0, '[[regtime]]', '[[regtime]]'),
(100049, 'products', 97, 0, 0, '[[regtime]]', '[[regtime]]'),
(100050, 'products', 96, 0, 0, '[[regtime]]', '[[regtime]]'),
(100051, 'products', 96, 0, 0, '[[regtime]]', '[[regtime]]'),
(100052, 'products', 67, 0, 0, '[[regtime]]', '[[regtime]]'),
(100053, 'products', 99, 0, 0, '[[regtime]]', '[[regtime]]'),
(100054, 'products', 85, 0, 0, '[[regtime]]', '[[regtime]]'),
(100055, 'products', 85, 0, 0, '[[regtime]]', '[[regtime]]'),
(100056, 'products', 85, 0, 0, '[[regtime]]', '[[regtime]]'),
(100057, 'products', 73, 0, 0, '[[regtime]]', '[[regtime]]'),
(100058, 'products', 91, 0, 0, '[[regtime]]', '[[regtime]]'),
(100059, 'products', 55, 0, 0, '[[regtime]]', '[[regtime]]'),
(100060, 'products', 55, 0, 0, '[[regtime]]', '[[regtime]]'),
(100061, 'products', 55, 0, 0, '[[regtime]]', '[[regtime]]'),
(100062, 'products', 55, 0, 0, '[[regtime]]', '[[regtime]]'),
(100063, 'products', 55, 0, 0, '[[regtime]]', '[[regtime]]'),
(100064, 'products', 87, 0, 0, '[[regtime]]', '[[regtime]]'),
(100065, 'products', 77, 0, 0, '[[regtime]]', '[[regtime]]'),
(100066, 'products', 77, 0, 0, '[[regtime]]', '[[regtime]]'),
(100067, 'products', 77, 0, 0, '[[regtime]]', '[[regtime]]'),
(100068, 'products', 77, 0, 0, '[[regtime]]', '[[regtime]]'),
(100069, 'products', 76, 0, 2, '[[regtime]]', '[[regtime]]'),
(100070, 'products', 76, 0, 1, '[[regtime]]', '[[regtime]]'),
(100071, 'products', 60, 0, 0, '[[regtime]]', '[[regtime]]'),
(100072, 'products', 60, 0, 0, '[[regtime]]', '[[regtime]]'),
(100073, 'products', 60, 0, 0, '[[regtime]]', '[[regtime]]'),
(100074, 'products', 60, 0, 0, '[[regtime]]', '[[regtime]]'),
(100075, 'products', 94, 0, 0, '[[regtime]]', '[[regtime]]'),
(100076, 'products', 90, 0, 0, '[[regtime]]', '[[regtime]]'),
(100077, 'products', 90, 0, 0, '[[regtime]]', '[[regtime]]'),
(100078, 'products', 90, 0, 0, '[[regtime]]', '[[regtime]]'),
(100079, 'products', 71, 0, 0, '[[regtime]]', '[[regtime]]'),
(100080, 'products', 63, 0, 0, '[[regtime]]', '[[regtime]]'),
(100081, 'products', 63, 0, 0, '[[regtime]]', '[[regtime]]'),
(100082, 'products', 69, 0, 0, '[[regtime]]', '[[regtime]]'),
(100083, 'products', 89, 0, 0, '[[regtime]]', '[[regtime]]'),
(100084, 'products', 89, 0, 0, '[[regtime]]', '[[regtime]]'),
(100085, 'products', 89, 0, 0, '[[regtime]]', '[[regtime]]'),
(100086, 'products', 89, 0, 0, '[[regtime]]', '[[regtime]]'),
(100087, 'products', 98, 0, 0, '[[regtime]]', '[[regtime]]'),
(100088, 'products', 95, 0, 0, '[[regtime]]', '[[regtime]]'),
(100089, 'products', 50, 0, 0, '[[regtime]]', '[[regtime]]'),
(100091, 'products', 66, 0, 0, '[[regtime]]', '[[regtime]]'),
(100092, 'products', 66, 0, 0, '[[regtime]]', '[[regtime]]'),
(100093, 'products', 66, 0, 0, '[[regtime]]', '[[regtime]]'),
(100094, 'products', 53, 0, 0, '[[regtime]]', '[[regtime]]'),
(100095, 'products', 53, 0, 0, '[[regtime]]', '[[regtime]]'),
(100096, 'products', 53, 0, 0, '[[regtime]]', '[[regtime]]'),
(100097, 'products', 59, 0, 0, '[[regtime]]', '[[regtime]]'),
(100098, 'products', 59, 0, 0, '[[regtime]]', '[[regtime]]'),
(100099, 'products', 59, 0, 0, '[[regtime]]', '[[regtime]]'),
(100100, 'products', 59, 0, 0, '[[regtime]]', '[[regtime]]'),
(100101, 'products', 56, 0, 0, '[[regtime]]', '[[regtime]]'),
(100105, 'products', 79, 0, 0, '[[regtime]]', '[[regtime]]'),
(100106, 'products', 79, 0, 0, '[[regtime]]', '[[regtime]]'),
(100107, 'products', 79, 0, 0, '[[regtime]]', '[[regtime]]'),
(100108, 'products', 78, 0, 0, '[[regtime]]', '[[regtime]]'),
(100109, 'products', 78, 0, 0, '[[regtime]]', '[[regtime]]'),
(100110, 'products', 78, 0, 0, '[[regtime]]', '[[regtime]]'),
(100111, 'products', 88, 0, 0, '[[regtime]]', '[[regtime]]'),
(100112, 'products', 62, 0, 0, '[[regtime]]', '[[regtime]]'),
(100114, 'manufacturers', 16, 0, 0, '[[regtime]]', '[[regtime]]'),
(100115, 'manufacturers', 14, 0, 0, '[[regtime]]', '[[regtime]]'),
(100116, 'manufacturers', 13, 0, 0, '[[regtime]]', '[[regtime]]'),
(100117, 'manufacturers', 12, 0, 0, '[[regtime]]', '[[regtime]]'),
(100118, 'manufacturers', 11, 0, 0, '[[regtime]]', '[[regtime]]'),
(100119, 'manufacturers', 15, 0, 0, '[[regtime]]', '[[regtime]]'),
(100120, 'manufacturers', 17, 0, 0, '[[regtime]]', '[[regtime]]'),
(100121, 'manufacturers', 18, 0, 0, '[[regtime]]', '[[regtime]]'),
(100122, 'manufacturers', 19, 0, 0, '[[regtime]]', '[[regtime]]'),
(100123, 'categories', 52, 0, 0, '[[regtime]]', '[[regtime]]'),
(100124, 'categories', 36, 0, 0, '[[regtime]]', '[[regtime]]'),
(100125, 'categories', 43, 0, 0, '[[regtime]]', '[[regtime]]'),
(100126, 'categories', 49, 0, 0, '[[regtime]]', '[[regtime]]'),
(100128, 'categories', 50, 0, 0, '[[regtime]]', '[[regtime]]'),
(100129, 'categories', 51, 0, 0, '[[regtime]]', '[[regtime]]'),
(100130, 'categories', 53, 0, 0, '[[regtime]]', '[[regtime]]'),
(100131, 'categories', 54, 0, 0, '[[regtime]]', '[[regtime]]'),
(100132, 'categories', 38, 0, 0, '[[regtime]]', '[[regtime]]'),
(100133, 'categories', 40, 0, 0, '[[regtime]]', '[[regtime]]'),
(100134, 'categories', 41, 0, 0, '[[regtime]]', '[[regtime]]'),
(100135, 'categories', 42, 0, 0, '[[regtime]]', '[[regtime]]'),
(100136, 'categories', 39, 0, 0, '[[regtime]]', '[[regtime]]'),
(100137, 'categories', 37, 0, 0, '[[regtime]]', '[[regtime]]'),
(100138, 'categories', 59, 0, 0, '[[regtime]]', '[[regtime]]'),
(100139, 'categories', 60, 0, 0, '[[regtime]]', '[[regtime]]'),
(100140, 'categories', 61, 0, 0, '[[regtime]]', '[[regtime]]'),
(100141, 'categories', 63, 0, 0, '[[regtime]]', '[[regtime]]'),
(100142, 'categories', 46, 0, 0, '[[regtime]]', '[[regtime]]'),
(100143, 'categories', 47, 0, 0, '[[regtime]]', '[[regtime]]'),
(100144, 'categories', 44, 0, 0, '[[regtime]]', '[[regtime]]'),
(100145, 'categories', 45, 0, 0, '[[regtime]]', '[[regtime]]'),
(100146, 'categories', 48, 0, 0, '[[regtime]]', '[[regtime]]'),
(100150, 'products', 101, 0, 0, '[[regtime]]', '[[regtime]]'),
(100153, 'manufacturers', 20, 0, 0, '[[regtime]]', '[[regtime]]'),
(100154, 'products', 102, 0, 0, '[[regtime]]', '[[regtime]]'),
(100155, 'products', 102, 0, 0, '[[regtime]]', '[[regtime]]'),
(100156, 'products', 102, 0, 0, '[[regtime]]', '[[regtime]]'),
(100157, 'products', 103, 0, 2, '[[regtime]]', '[[regtime]]'),
(100159, 'products', 103, 0, 3, '[[regtime]]', '[[regtime]]'),
(100160, 'products', 104, 0, 0, '[[regtime]]', '[[regtime]]'),
(100162, 'products', 105, 0, 0, '[[regtime]]', '[[regtime]]'),
(100163, 'products', 106, 0, 2, '[[regtime]]', '[[regtime]]'),
(100164, 'products', 106, 0, 2, '[[regtime]]', '[[regtime]]'),
(100165, 'products', 106, 0, 1, '[[regtime]]', '[[regtime]]'),
(100166, 'products', 107, 0, 0, '[[regtime]]', '[[regtime]]'),
(100167, 'products', 107, 0, 0, '[[regtime]]', '[[regtime]]'),
(100168, 'products', 108, 0, 0, '[[regtime]]', '[[regtime]]'),
(100169, 'products', 108, 0, 0, '[[regtime]]', '[[regtime]]'),
(100170, 'products', 108, 0, 0, '[[regtime]]', '[[regtime]]'),
(100171, 'products', 108, 0, 0, '[[regtime]]', '[[regtime]]'),
(100173, 'products', 109, 0, 0, '[[regtime]]', '[[regtime]]'),
(100174, 'products', 110, 0, 0, '[[regtime]]', '[[regtime]]'),
(100175, 'products', 110, 0, 0, '[[regtime]]', '[[regtime]]'),
(100176, 'products', 110, 0, 0, '[[regtime]]', '[[regtime]]'),
(100178, 'products', 101, 0, 0, '[[regtime]]', '[[regtime]]'),
(100178, 'products', 124, 0, 7, '[[regtime]]', '[[regtime]]'),
(100188, 'banners', 13, 0, 0, '[[regtime]]', '[[regtime]]'),
(100188, 'banners', 14, 0, 0, '[[regtime]]', '[[regtime]]'),
(100188, 'banners', 15, 0, 0, '[[regtime]]', '[[regtime]]'),
(100188, 'banners', 16, 0, 0, '[[regtime]]', '[[regtime]]'),
(100194, 'banners', 18, 0, 1, '[[regtime]]', '[[regtime]]'),
(100195, 'products', 111, 0, 1, '[[regtime]]', '[[regtime]]'),
(100198, 'products', 112, 0, 1, '[[regtime]]', '[[regtime]]'),
(100199, 'categories', 66, 0, 1, '[[regtime]]', '[[regtime]]'),
(100200, 'categories', 65, 0, 1, '[[regtime]]', '[[regtime]]'),
(100201, 'products', 113, 0, 1, '[[regtime]]', '[[regtime]]'),
(100202, 'categories', 67, 0, 1, '[[regtime]]', '[[regtime]]'),
(100202, 'products', 113, 0, 2, '[[regtime]]', '[[regtime]]'),
(100203, 'products', 114, 0, 1, '[[regtime]]', '[[regtime]]'),
(100204, 'products', 115, 0, 2, '[[regtime]]', '[[regtime]]'),
(100206, 'products', 115, 0, 1, '[[regtime]]', '[[regtime]]'),
(100207, 'product_option_value', 754, 0, 1, '[[regtime]]', '[[regtime]]'),
(100208, 'product_option_value', 754, 0, 2, '[[regtime]]', '[[regtime]]'),
(100209, 'product_option_value', 754, 0, 3, '[[regtime]]', '[[regtime]]'),
(100210, 'product_option_value', 754, 0, 4, '[[regtime]]', '[[regtime]]'),
(100211, 'product_option_value', 753, 0, 6, '[[regtime]]', '[[regtime]]'),
(100212, 'product_option_value', 753, 0, 2, '[[regtime]]', '[[regtime]]'),
(100213, 'product_option_value', 753, 0, 3, '[[regtime]]', '[[regtime]]'),
(100214, 'product_option_value', 753, 0, 4, '[[regtime]]', '[[regtime]]'),
(100215, 'product_option_value', 753, 0, 5, '[[regtime]]', '[[regtime]]'),
(100216, 'categories', 69, 0, 1, '[[regtime]]', '[[regtime]]'),
(100216, 'product_option_value', 753, 0, 1, '[[regtime]]', '[[regtime]]'),
(100217, 'product_option_value', 752, 0, 4, '[[regtime]]', '[[regtime]]'),
(100218, 'product_option_value', 752, 0, 2, '[[regtime]]', '[[regtime]]'),
(100219, 'product_option_value', 752, 0, 3, '[[regtime]]', '[[regtime]]'),
(100220, 'product_option_value', 752, 0, 1, '[[regtime]]', '[[regtime]]'),
(100221, 'product_option_value', 752, 0, 5, '[[regtime]]', '[[regtime]]'),
(100222, 'products', 116, 0, 5, '[[regtime]]', '[[regtime]]'),
(100222, 'products', 124, 0, 5, '[[regtime]]', '[[regtime]]'),
(100223, 'products', 116, 0, 4, '[[regtime]]', '[[regtime]]'),
(100223, 'products', 124, 0, 4, '[[regtime]]', '[[regtime]]'),
(100224, 'products', 116, 0, 3, '[[regtime]]', '[[regtime]]'),
(100224, 'products', 124, 0, 3, '[[regtime]]', '[[regtime]]'),
(100225, 'products', 116, 0, 1, '[[regtime]]', '[[regtime]]'),
(100225, 'products', 124, 0, 1, '[[regtime]]', '[[regtime]]'),
(100226, 'products', 116, 0, 2, '[[regtime]]', '[[regtime]]'),
(100226, 'products', 124, 0, 2, '[[regtime]]', '[[regtime]]'),
(100227, 'products', 116, 0, 6, '[[regtime]]', '[[regtime]]'),
(100227, 'products', 124, 0, 6, '[[regtime]]', '[[regtime]]'),
(100228, 'products', 117, 0, 1, '[[regtime]]', '[[regtime]]'),
(100229, 'products', 117, 0, 2, '[[regtime]]', '[[regtime]]'),
(100230, 'products', 117, 0, 3, '[[regtime]]', '[[regtime]]'),
(100231, 'products', 117, 0, 4, '[[regtime]]', '[[regtime]]'),
(100232, 'products', 117, 0, 5, '[[regtime]]', '[[regtime]]'),
(100233, 'products', 117, 0, 6, '[[regtime]]', '[[regtime]]'),
(100235, 'products', 118, 0, 1, '[[regtime]]', '[[regtime]]'),
(100236, 'products', 118, 0, 2, '[[regtime]]', '[[regtime]]'),
(100237, 'products', 118, 0, 3, '[[regtime]]', '[[regtime]]'),
(100238, 'products', 118, 0, 4, '[[regtime]]', '[[regtime]]'),
(100239, 'products', 118, 0, 5, '[[regtime]]', '[[regtime]]'),
(100240, 'products', 118, 0, 6, '[[regtime]]', '[[regtime]]'),
(100241, 'products', 119, 0, 1, '[[regtime]]', '[[regtime]]'),
(100242, 'products', 120, 0, 1, '[[regtime]]', '[[regtime]]'),
(100243, 'categories', 70, 0, 1, '[[regtime]]', '[[regtime]]'),
(100243, 'products', 121, 0, 1, '[[regtime]]', '[[regtime]]'),
(100244, 'categories', 68, 0, 1, '[[regtime]]', '[[regtime]]'),
(100244, 'products', 121, 0, 2, '[[regtime]]', '[[regtime]]'),
(100245, 'products', 122, 0, 5, '[[regtime]]', '[[regtime]]'),
(100246, 'products', 122, 0, 2, '[[regtime]]', '[[regtime]]'),
(100247, 'products', 122, 0, 3, '[[regtime]]', '[[regtime]]'),
(100248, 'products', 122, 0, 1, '[[regtime]]', '[[regtime]]'),
(100249, 'categories', 58, 0, 1, '[[regtime]]', '[[regtime]]'),
(100249, 'products', 81, 0, 1, '[[regtime]]', '[[regtime]]'),
(100250, 'products', 54, 0, 1, '[[regtime]]', '[[regtime]]'),
(100251, 'products', 123, 0, 1, '[[regtime]]', '[[regtime]]'),
(100252, 'products', 123, 0, 2, '[[regtime]]', '[[regtime]]'),
(100253, 'products', 123, 0, 3, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]resource_types`
--

CREATE TABLE `[[dbprefix]]resource_types` (
  `type_id` int NOT NULL AUTO_INCREMENT,
  `type_name` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `default_directory` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL,
  `default_icon` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `file_types` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `access_type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0-Public, 1-Secured',
  PRIMARY KEY (`type_id`),
  KEY `group_id` (`type_id`,`type_name`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=7 ;

--
-- Dumping data for table `[[dbprefix]]resource_types`
--

INSERT INTO `[[dbprefix]]resource_types` VALUES
(1, 'image', 'image/', 'icon_resource_image.png', '/.+(jpe?g|gif|png|ico|svg|svgz|webp|avif)$/i', 0),
(2, 'audio', 'audio/', 'icon_resource_audio.png', '/.+(mp3|wav|ogg)$/i', 0),
(3, 'video', 'video/', 'icon_resource_video.png', '/.+(avi|mpg|mpeg|mov|flv|mp4|webm|ogg)$/i', 0),
(4, 'pdf', 'pdf_document/', 'icon_resource_pdf.png', '/.+(pdf)$/i', 0),
(5, 'archive', 'archive/', 'icon_resource_archive.png', '/.+(zip|rar|gz|7z)$/i', 1),
(6, 'download', 'download/', 'icon_resource_download.png', '/.+$/i', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]reviews`
--

CREATE TABLE `[[dbprefix]]reviews` (
  `review_id` int NOT NULL AUTO_INCREMENT,
  `product_id` int NOT NULL,
  `customer_id` int NOT NULL,
  `author` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `text` longtext COLLATE utf8mb4_unicode_ci NOT NULL,
  `rating` int NOT NULL,
  `verified_purchase` tinyint NOT NULL DEFAULT '0',
  `status` int NOT NULL DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`review_id`),
  KEY `[[dbprefix]]reviews_idx` (`product_id`,`customer_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=87 ;

--
-- Dumping data for table `[[dbprefix]]reviews`
--

INSERT INTO `[[dbprefix]]reviews` VALUES
(61, 56, 0, 'Cassandra', 'Fortunately, I got this as a gift. BUT, I am willing to purchase this when I run out. This may be expensive but it is sooooo worth it! I love this concealer and I wouldn''t even dare to use other brands. One more thing, the little tube lasts for a long time. I''ve been using it everyday for 8 months now and I still have about 1/4 left.', 5, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(62, 54, 2, 'Juliana Davis', 'I''ve been wearing all Lancome mascara''s and I''m just get really upset when I''m out. I''ve tried other Brands, but it''s always right back to the Lancome productss. The extend L''EXTREME is by far the best!!! Really Long and Great! ', 5, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(63, 77, 6, 'Bernard Horne', 'I thought since it was made for men that it was the perfect thing to go with the body wash. Its too small and doesnt lather up very well.', 3, 1, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(64, 76, 7, 'James', 'Finally a deodorant for men that doesn''t smell like cheap cologne. I''ve been using this for a couple of weeks now and I can''t say anything bad about it. To me it just smells fresh', 4, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(65, 100, 0, 'Juli', 'Smooth Silk is an accurate name for this creamy lip liner. It is by far the best lip pencil I have ever encountered.', 5, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(66, 100, 0, 'Marianne', 'Nice pencil! This is a smooth, long lasting pencil, wonderful shades!', 4, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(67, 97, 0, 'Ann', 'Really reduces shades and swellings)', 4, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(68, 99, 0, 'Alice', 'This is much darker than the picture', 2, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(69, 57, 0, 'Jane', 'When it arrived, the blush had cracked and was crumbling all over, so I''m only able to use half of it.', 2, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(70, 55, 0, 'Kristin K.', 'These lipsticks are moisturizing and have good pigmentation; however, their lasting power is not as advertised! ', 4, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(71, 55, 0, 'lara', 'This is quite simply good stuff. \nThe color payout is rich, the texture creamy and moist, and best of all no scent. No taste.', 5, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(72, 93, 0, 'L. D.', 'I totally love it.it smells heavenly . It smells so natural and my skin just loves it. ', 5, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(73, 93, 0, 'Walton', 'This creme is a bit heavy for my skin; however, as the day goes on it does not create an oily build-up. A little goes a long way, and I could see improvements in my skin tone within a week. Good product, will be purchasing again.', 4, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(74, 74, 0, 'Stefania V', 'it works very well moisturing and cleaning and unlike many other healthy shampoos it doesn''t open the hair platelets too far and therefore doesn''t feel so dry and sticky so I can get away without using a conditioner. Great value.', 4, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(75, 102, 0, 'Mary', 'This is more of a evening fragrance. I love it', 4, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(76, 110, 0, 'Lara', 'Product was very reasonably priced. It will make a nice gift.', 5, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(77, 111, 0, 'Mr. G. Thomas', 'I would totally recommend product for anyone keen to learn a foreign language quickly. \nHowever, you must be fully committed and be ready to dedicate your time for study every day!', 5, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(78, 119, 0, 'F Buckley ', 'Good quality. Also good enough to wear out.\n\nWould order more in the future. ', 5, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(79, 111, 13, 'Eric', ' I''ve tried every other course out there and this gives you a feeling of instant gratification. The focus is on speaking.', 4, 0, 0, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(80, 75, 15, 'Alex', 'This worked awesomely for me.  This product is perfect for my dry skin.', 5, 0, 1, '2022-06-27 01:41:27', '2022-06-27 01:41:27'),
(81, 78, 14, 'Howard', 'This has to be one of my favorite scents.', 5, 1, 1, '2022-06-28 03:16:45', '2022-06-28 03:16:59'),
(82, 51, 16, 'Annabelle', 'Unlike most powder highlights, it''s very long-lasting.', 4, 1, 1, '2022-06-28 03:20:13', '2022-06-28 03:20:26'),
(83, 118, 0, 'Rebecca Hellon', 'They are very comfortable and easy to go. ', 4, 0, 1, '2022-06-28 03:38:52', '2022-06-28 03:39:13'),
(84, 124, 0, 'Adena Heath', 'I bought these sandals for my summer vacation and I dont love them! They are not comfortable and not stylish.', 1, 1, 1, '2023-12-05 08:34:55', '2023-12-07 01:58:56'),
(85, 124, 0, 'Odesa Hamilton', 'The wedge heel gives me some extra height and the diamante detail adds some sparkle to my outfit. They are easy to slip on and off and they fit true to size. I got many compliments on them and they look great with dresses, shorts, or jeans. They are also very durable and well-made. I have worn them several times and they still look new. I would highly recommend these sandals to anyone looking for a cute and versatile pair of shoes.', 5, 0, 1, '2023-12-05 08:35:25', '2023-12-05 08:35:41'),
(86, 124, 0, 'Adara Brennan', 'Not published review\nNot published review\nNot published review', 3, 0, 0, '2023-12-05 08:36:21', '2023-12-05 08:36:21');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]settings`
--

CREATE TABLE `[[dbprefix]]settings` (
  `setting_id` int NOT NULL AUTO_INCREMENT,
  `store_id` int NOT NULL DEFAULT '0',
  `group` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL,
  `key` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `value` text COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`setting_id`,`store_id`,`group`,`key`),
  KEY `[[dbprefix]]settings_idx` (`value`(500))
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=271 ;

--
-- Dumping data for table `[[dbprefix]]settings`
--

INSERT INTO `[[dbprefix]]settings` VALUES
(1, 0, 'details', 'store_name', 'Web Store Name', '[[regtime]]', '[[regtime]]'),
(2, 0, 'details', 'config_url', '[[softurl]]/', '[[regtime]]', '[[regtime]]'),
(3, 0, 'details', 'config_ssl', '[[config_ssl]]', '[[regtime]]', '[[regtime]]'),
(4, 0, 'details', 'config_ssl_url', '[[config_ssl_url]]', '[[regtime]]', '[[regtime]]'),
(5, 0, 'details', 'config_owner', 'Your Name', '[[regtime]]', '[[regtime]]'),
(6, 0, 'details', 'config_address', '725 River Road, Suite 32-128', '[[regtime]]', '[[regtime]]'),
(7, 0, 'details', 'store_main_email', '[[admin_email]]', '[[regtime]]', '[[regtime]]'),
(8, 0, 'details', 'config_telephone', '123456789', '[[regtime]]', '[[regtime]]'),
(9, 0, 'details', 'config_fax', '', '[[regtime]]', '[[regtime]]'),
(10, 0, 'details', 'config_title_1', 'Your Store', '[[regtime]]', '[[regtime]]'),
(11, 0, 'details', 'config_meta_description_1', 'Web Store Meta Description', '[[regtime]]', '[[regtime]]'),
(12, 0, 'details', 'config_meta_keywords_1', 'keyword1,keyword2,keyword3', '[[regtime]]', '[[regtime]]'),
(13, 0, 'details', 'config_description_1', 'Welcome to web store!', '[[regtime]]', '[[regtime]]'),
(14, 0, 'details', 'config_country_id', '223', '[[regtime]]', '[[regtime]]'),
(15, 0, 'details', 'config_zone_id', '3653', '[[regtime]]', '[[regtime]]'),
(16, 0, 'details', 'config_storefront_language', 'en', '[[regtime]]', '[[regtime]]'),
(17, 0, 'details', 'admin_language', 'en', '[[regtime]]', '[[regtime]]'),
(18, 0, 'details', 'config_currency', 'USD', '[[regtime]]', '[[regtime]]'),
(19, 0, 'details', 'config_currency_auto', '0', '[[regtime]]', '[[regtime]]'),
(20, 0, 'details', 'config_length_class', 'in', '[[regtime]]', '[[regtime]]'),
(21, 0, 'details', 'config_weight_class', 'lb', '[[regtime]]', '[[regtime]]'),
(22, 0, 'details', 'auto_translate_status', '1', '[[regtime]]', '[[regtime]]'),
(23, 0, 'details', 'translate_src_lang_code', 'en', '[[regtime]]', '[[regtime]]'),
(24, 0, 'details', 'translate_override_existing', '0', '[[regtime]]', '[[regtime]]'),
(25, 0, 'details', 'warn_lang_text_missing', '0', '[[regtime]]', '[[regtime]]'),
(26, 0, 'details', 'config_duplicate_contact_us_to_message', '1', '[[regtime]]', '[[regtime]]'),
(27, 0, 'details', 'config_opening_sunday_opens', '', '[[regtime]]', '[[regtime]]'),
(28, 0, 'details', 'config_opening_sunday_closes', '', '[[regtime]]', '[[regtime]]'),
(29, 0, 'details', 'config_opening_monday_opens', '9:00', '[[regtime]]', '[[regtime]]'),
(30, 0, 'details', 'config_opening_monday_closes', '18:00', '[[regtime]]', '[[regtime]]'),
(31, 0, 'details', 'config_opening_tuesday_opens', '9:00', '[[regtime]]', '[[regtime]]'),
(32, 0, 'details', 'config_opening_tuesday_closes', '18:00', '[[regtime]]', '[[regtime]]'),
(33, 0, 'details', 'config_opening_wednesday_opens', '9:00', '[[regtime]]', '[[regtime]]'),
(34, 0, 'details', 'config_opening_wednesday_closes', '18:00', '[[regtime]]', '[[regtime]]'),
(35, 0, 'details', 'config_opening_thursday_opens', '9:00', '[[regtime]]', '[[regtime]]'),
(36, 0, 'details', 'config_opening_thursday_closes', '21:00', '[[regtime]]', '[[regtime]]'),
(37, 0, 'details', 'config_opening_friday_opens', '9:00', '[[regtime]]', '[[regtime]]'),
(38, 0, 'details', 'config_opening_friday_closes', '16:00', '[[regtime]]', '[[regtime]]'),
(39, 0, 'details', 'config_opening_saturday_opens', '', '[[regtime]]', '[[regtime]]'),
(40, 0, 'details', 'config_opening_saturday_closes', '', '[[regtime]]', '[[regtime]]'),
(41, 0, 'details', 'config_postcode', '07020', '[[regtime]]', '[[regtime]]'),
(42, 0, 'details', 'protocol_url', 'https', '[[regtime]]', '[[regtime]]'),
(43, 0, 'details', 'protocol_ssl_url', 'https', '[[regtime]]', '[[regtime]]'),
(44, 0, 'details', 'config_city', 'Edgewater', '[[regtime]]', '[[regtime]]'),
(45, 0, 'details', 'config_latitude', '40.887187', '[[regtime]]', '[[regtime]]'),
(46, 0, 'details', 'config_longitude', '-74.037592', '[[regtime]]', '[[regtime]]'),
(47, 0, 'details', 'translate_method', 'copy_source_text', '[[regtime]]', '[[regtime]]'),
(48, 0, 'details', 'config_tax_class_id', '1', '[[regtime]]', '[[regtime]]'),
(49, 0, 'general', 'config_admin_limit', '20', '[[regtime]]', '[[regtime]]'),
(50, 0, 'general', 'config_stock_display', '1', '[[regtime]]', '[[regtime]]'),
(51, 0, 'general', 'config_nostock_autodisable', '0', '[[regtime]]', '[[regtime]]'),
(52, 0, 'general', 'config_stock_status_id', '0', '[[regtime]]', '[[regtime]]'),
(53, 0, 'general', 'enable_reviews', '1', '[[regtime]]', '[[regtime]]'),
(54, 0, 'general', 'display_reviews', '1', '[[regtime]]', '[[regtime]]'),
(55, 0, 'general', 'config_download', '1', '[[regtime]]', '[[regtime]]'),
(56, 0, 'general', 'config_help_links', '1', '[[regtime]]', '[[regtime]]'),
(57, 0, 'general', 'config_show_tree_data', '1', '[[regtime]]', '[[regtime]]'),
(58, 0, 'general', 'config_embed_status', '1', '[[regtime]]', '[[regtime]]'),
(59, 0, 'general', 'config_embed_click_action', 'modal', '[[regtime]]', '[[regtime]]'),
(60, 0, 'general', 'config_product_default_sort_order', 'date_modified-DESC', '[[regtime]]', '[[regtime]]'),
(61, 0, 'general', 'config_account_create_captcha', '0', '[[regtime]]', '[[regtime]]'),
(62, 0, 'general', 'config_recaptcha_site_key', '', '[[regtime]]', '[[regtime]]'),
(63, 0, 'general', 'config_recaptcha_secret_key', '', '[[regtime]]', '[[regtime]]'),
(64, 0, 'general', 'config_google_analytics_code', '', '[[regtime]]', '[[regtime]]'),
(65, 0, 'checkout', 'starting_invoice_id', '1', '[[regtime]]', '[[regtime]]'),
(66, 0, 'checkout', 'invoice_prefix', 'IN#', '[[regtime]]', '[[regtime]]'),
(67, 0, 'checkout', 'config_cart_weight', '0', '[[regtime]]', '[[regtime]]'),
(68, 0, 'checkout', 'config_shipping_session', '0', '[[regtime]]', '[[regtime]]'),
(69, 0, 'checkout', 'config_tax', '0', '[[regtime]]', '[[regtime]]'),
(70, 0, 'checkout', 'config_tax_store', '1', '[[regtime]]', '[[regtime]]'),
(71, 0, 'checkout', 'config_tax_customer', '0', '[[regtime]]', '[[regtime]]'),
(72, 0, 'checkout', 'config_customer_price', '1', '[[regtime]]', '[[regtime]]'),
(73, 0, 'checkout', 'config_customer_group_id', '1', '[[regtime]]', '[[regtime]]'),
(74, 0, 'checkout', 'config_customer_approval', '0', '[[regtime]]', '[[regtime]]'),
(75, 0, 'checkout', 'config_customer_email_activation', '0', '[[regtime]]', '[[regtime]]'),
(76, 0, 'checkout', 'prevent_email_as_login', '1', '[[regtime]]', '[[regtime]]'),
(77, 0, 'checkout', 'config_guest_checkout', '1', '[[regtime]]', '[[regtime]]'),
(78, 0, 'checkout', 'config_unauth_customer', '1', '[[regtime]]', '[[regtime]]'),
(79, 0, 'checkout', 'config_account_id', '2', '[[regtime]]', '[[regtime]]'),
(80, 0, 'checkout', 'config_checkout_id', '3', '[[regtime]]', '[[regtime]]'),
(81, 0, 'checkout', 'config_stock_checkout', '0', '[[regtime]]', '[[regtime]]'),
(82, 0, 'checkout', 'config_order_status_id', '1', '[[regtime]]', '[[regtime]]'),
(83, 0, 'checkout', 'config_stock_subtract', '0', '[[regtime]]', '[[regtime]]'),
(84, 0, 'checkout', 'config_cart_ajax', '1', '[[regtime]]', '[[regtime]]'),
(85, 0, 'checkout', 'total_order_maximum', '0', '[[regtime]]', '[[regtime]]'),
(86, 0, 'checkout', 'total_order_minimum', '0', '[[regtime]]', '[[regtime]]'),
(87, 0, 'checkout', 'config_shipping_tax_estimate', '1', '[[regtime]]', '[[regtime]]'),
(88, 0, 'checkout', 'config_coupon_on_cart_page', '1', '[[regtime]]', '[[regtime]]'),
(89, 0, 'checkout', 'config_expire_order_days', '30', '[[regtime]]', '[[regtime]]'),
(90, 0, 'checkout', 'config_customer_cancelation_order_status_id', '', '[[regtime]]', '[[regtime]]'),
(91, 0, 'checkout', 'config_zero_customer_balance', '0', '[[regtime]]', '[[regtime]]'),
(92, 0, 'checkout', 'config_start_order_id', '', '[[regtime]]', '[[regtime]]'),
(93, 0, 'checkout', 'fast_checkout_allow_coupon', '1', '[[regtime]]', '[[regtime]]'),
(94, 0, 'checkout', 'fast_checkout_show_order_comment_field', '1', '[[regtime]]', '[[regtime]]'),
(97, 0, 'appearance', 'storefront_width', '100%', '[[regtime]]', '[[regtime]]'),
(98, 0, 'appearance', 'config_logo', '281', '[[regtime]]', '[[regtime]]'),
(99, 0, 'appearance', 'config_mail_logo', '7', '[[regtime]]', '[[regtime]]'),
(100, 0, 'appearance', 'config_icon', '8', '[[regtime]]', '[[regtime]]'),
(101, 0, 'appearance', 'config_catalog_limit', '18', '[[regtime]]', '[[regtime]]'),
(102, 0, 'appearance', 'config_bestseller_limit', '3', '[[regtime]]', '[[regtime]]'),
(103, 0, 'appearance', 'config_featured_limit', '3', '[[regtime]]', '[[regtime]]'),
(104, 0, 'appearance', 'config_latest_limit', '3', '[[regtime]]', '[[regtime]]'),
(105, 0, 'appearance', 'config_special_limit', '3', '[[regtime]]', '[[regtime]]'),
(106, 0, 'appearance', 'config_content_limit', '8', '[[regtime]]', '[[regtime]]'),
(107, 0, 'appearance', 'viewed_products_limit', '3', '[[regtime]]', '[[regtime]]'),
(108, 0, 'appearance', 'config_image_thumb_width', '380', '[[regtime]]', '[[regtime]]'),
(109, 0, 'appearance', 'config_image_thumb_height', '380', '[[regtime]]', '[[regtime]]'),
(110, 0, 'appearance', 'config_image_popup_width', '500', '[[regtime]]', '[[regtime]]'),
(111, 0, 'appearance', 'config_image_popup_height', '500', '[[regtime]]', '[[regtime]]'),
(112, 0, 'appearance', 'config_image_product_width', '250', '[[regtime]]', '[[regtime]]'),
(113, 0, 'appearance', 'config_image_product_height', '250', '[[regtime]]', '[[regtime]]'),
(114, 0, 'appearance', 'config_image_additional_width', '45', '[[regtime]]', '[[regtime]]'),
(115, 0, 'appearance', 'config_image_additional_height', '45', '[[regtime]]', '[[regtime]]'),
(116, 0, 'appearance', 'config_image_related_width', '120', '[[regtime]]', '[[regtime]]'),
(117, 0, 'appearance', 'config_image_related_height', '120', '[[regtime]]', '[[regtime]]'),
(118, 0, 'appearance', 'config_image_cart_width', '75', '[[regtime]]', '[[regtime]]'),
(119, 0, 'appearance', 'config_image_cart_height', '75', '[[regtime]]', '[[regtime]]'),
(120, 0, 'appearance', 'config_image_grid_width', '57', '[[regtime]]', '[[regtime]]'),
(121, 0, 'appearance', 'config_image_grid_height', '57', '[[regtime]]', '[[regtime]]'),
(122, 0, 'appearance', 'config_image_category_height', '120', '[[regtime]]', '[[regtime]]'),
(123, 0, 'appearance', 'config_image_category_width', '120', '[[regtime]]', '[[regtime]]'),
(124, 0, 'appearance', 'config_image_manufacturer_height', '56', '[[regtime]]', '[[regtime]]'),
(125, 0, 'appearance', 'config_image_manufacturer_width', '130', '[[regtime]]', '[[regtime]]'),
(126, 0, 'appearance', 'admin_template', 'default', '[[regtime]]', '[[regtime]]'),
(127, 0, 'appearance', 'admin_width', '100%', '[[regtime]]', '[[regtime]]'),
(128, 0, 'appearance', 'config_storefront_template', 'novator', '[[regtime]]', '[[regtime]]'),
(129, 0, 'appearance', 'config_image_resize_fill_color', '#ffffff', '[[regtime]]', '[[regtime]]'),
(130, 0, 'appearance', 'viewed_products_image_height', '250', '[[regtime]]', '[[regtime]]'),
(131, 0, 'appearance', 'viewed_products_image_width', '250', '[[regtime]]', '[[regtime]]'),
(132, 0, 'mail', 'config_mail_protocol', 'mail', '[[regtime]]', '[[regtime]]'),
(133, 0, 'mail', 'config_mail_parameter', '', '[[regtime]]', '[[regtime]]'),
(134, 0, 'mail', 'config_smtp_host', '', '[[regtime]]', '[[regtime]]'),
(135, 0, 'mail', 'config_smtp_username', '', '[[regtime]]', '[[regtime]]'),
(136, 0, 'mail', 'config_smtp_password', '', '[[regtime]]', '[[regtime]]'),
(137, 0, 'mail', 'config_smtp_port', '25', '[[regtime]]', '[[regtime]]'),
(138, 0, 'mail', 'config_smtp_timeout', '10', '[[regtime]]', '[[regtime]]'),
(139, 0, 'mail', 'config_alert_mail', '0', '[[regtime]]', '[[regtime]]'),
(140, 0, 'im', 'config_storefront_email_status', '1', '[[regtime]]', '[[regtime]]'),
(141, 0, 'im', 'config_admin_email_status', '1', '[[regtime]]', '[[regtime]]'),
(142, 0, 'im', 'config_im_guest_email_status', '1', '[[regtime]]', '[[regtime]]'),
(143, 0, 'im', 'config_im_guest_sms_status', '1', '[[regtime]]', '[[regtime]]'),
(144, 0, 'system', 'core_version', '1.4.4', '[[regtime]]', '[[regtime]]'),
(145, 0, 'system', 'config_session_ttl', '120', '[[regtime]]', '[[regtime]]'),
(146, 0, 'system', 'config_maintenance', '0', '[[regtime]]', '[[regtime]]'),
(147, 0, 'system', 'encryption_key', '12345', '[[regtime]]', '[[regtime]]'),
(148, 0, 'system', 'enable_seo_url', '0', '[[regtime]]', '[[regtime]]'),
(149, 0, 'system', 'config_retina_enable', '0', '[[regtime]]', '[[regtime]]'),
(150, 0, 'system', 'config_image_quality', '95', '[[regtime]]', '[[regtime]]'),
(151, 0, 'system', 'config_compression', '0', '[[regtime]]', '[[regtime]]'),
(152, 0, 'system', 'config_cache_enable', '1', '[[regtime]]', '[[regtime]]'),
(153, 0, 'system', 'config_error_display', '1', '[[regtime]]', '[[regtime]]'),
(154, 0, 'system', 'config_error_log', '1', '[[regtime]]', '[[regtime]]'),
(155, 0, 'system', 'config_debug', '0', '[[regtime]]', '[[regtime]]'),
(156, 0, 'system', 'config_debug_level', '0', '[[regtime]]', '[[regtime]]'),
(157, 0, 'system', 'storefront_template_debug', '0', '[[regtime]]', '[[regtime]]'),
(158, 0, 'system', 'config_error_filename', 'error.txt', '[[regtime]]', '[[regtime]]'),
(159, 0, 'system', 'config_upload_max_size', '16000', '[[regtime]]', '[[regtime]]'),
(160, 0, 'system', 'config_voicecontrol', '1', '[[regtime]]', '[[regtime]]'),
(161, 0, 'system', 'config_system_check', '3', '[[regtime]]', '[[regtime]]'),
(162, 0, 'api', 'config_storefront_api_status', '0', '[[regtime]]', '[[regtime]]'),
(163, 0, 'api', 'config_storefront_api_key', '', '[[regtime]]', '[[regtime]]'),
(164, 0, 'api', 'config_storefront_api_stock_check', '0', '[[regtime]]', '[[regtime]]'),
(165, 0, 'api', 'config_admin_api_status', '0', '[[regtime]]', '[[regtime]]'),
(166, 0, 'api', 'config_admin_api_key', '', '[[regtime]]', '[[regtime]]'),
(167, 0, 'api', 'config_admin_access_ip_list', '', '[[regtime]]', '[[regtime]]'),
(168, 0, 'api', 'task_api_key', '[[task_api_key]]', '[[regtime]]', '[[regtime]]'),
(169, 0, 'sub_total', 'sub_total_sort_order', '1', '[[regtime]]', '[[regtime]]'),
(170, 0, 'sub_total', 'sub_total_calculation_order', '1', '[[regtime]]', '[[regtime]]'),
(171, 0, 'sub_total', 'sub_total_status', '1', '[[regtime]]', '[[regtime]]'),
(172, 0, 'sub_total', 'sub_total_total_type', 'subtotal', '[[regtime]]', '[[regtime]]'),
(173, 0, 'shipping', 'shipping_sort_order', '3', '[[regtime]]', '[[regtime]]'),
(174, 0, 'shipping', 'shipping_calculation_order', '3', '[[regtime]]', '[[regtime]]'),
(175, 0, 'shipping', 'shipping_status', '1', '[[regtime]]', '[[regtime]]'),
(176, 0, 'shipping', 'shipping_total_type', 'shipping', '[[regtime]]', '[[regtime]]'),
(177, 0, 'coupon', 'coupon_status', '1', '[[regtime]]', '[[regtime]]'),
(178, 0, 'coupon', 'coupon_sort_order', '4', '[[regtime]]', '[[regtime]]'),
(179, 0, 'coupon', 'coupon_calculation_order', '4', '[[regtime]]', '[[regtime]]'),
(180, 0, 'coupon', 'coupon_total_type', 'discount', '[[regtime]]', '[[regtime]]'),
(181, 0, 'tax', 'tax_status', '1', '[[regtime]]', '[[regtime]]'),
(182, 0, 'tax', 'tax_sort_order', '5', '[[regtime]]', '[[regtime]]'),
(183, 0, 'tax', 'tax_calculation_order', '2', '[[regtime]]', '[[regtime]]'),
(184, 0, 'tax', 'tax_total_type', 'tax', '[[regtime]]', '[[regtime]]'),
(185, 0, 'balance', 'balance_status', '1', '[[regtime]]', '[[regtime]]'),
(186, 0, 'balance', 'balance_sort_order', '999', '[[regtime]]', '[[regtime]]'),
(187, 0, 'balance', 'balance_calculation_order', '999', '[[regtime]]', '[[regtime]]'),
(188, 0, 'balance', 'balance_total_type', 'balance', '[[regtime]]', '[[regtime]]'),
(189, 0, 'total', 'total_sort_order', '1000', '[[regtime]]', '[[regtime]]'),
(190, 0, 'total', 'total_calculation_order', '1000', '[[regtime]]', '[[regtime]]'),
(191, 0, 'total', 'total_status', '1', '[[regtime]]', '[[regtime]]'),
(192, 0, 'total', 'total_total_type', 'total', '[[regtime]]', '[[regtime]]'),
(193, 0, 'handling', 'handling_calculation_order', '2', '[[regtime]]', '[[regtime]]'),
(194, 0, 'handling', 'handling_status', '0', '[[regtime]]', '[[regtime]]'),
(195, 0, 'handling', 'handling_fee_total_type', 'fee', '[[regtime]]', '[[regtime]]'),
(196, 0, 'banner_manager', 'banner_manager_layout', '', '[[regtime]]', '[[regtime]]'),
(197, 0, 'banner_manager', 'banner_manager_priority', '10', '[[regtime]]', '[[regtime]]'),
(198, 0, 'banner_manager', 'banner_manager_date_installed', '[[regtime]]', '[[regtime]]', '[[regtime]]'),
(199, 0, 'banner_manager', 'store_id', '0', '[[regtime]]', '[[regtime]]'),
(200, 0, 'banner_manager', 'banner_manager_status', '1', '[[regtime]]', '[[regtime]]'),
(201, 0, 'forms_manager', 'forms_manager_priority', '10', '[[regtime]]', '[[regtime]]'),
(202, 0, 'forms_manager', 'forms_manager_date_installed', '[[regtime]]', '[[regtime]]', '[[regtime]]'),
(203, 0, 'forms_manager', 'store_id', '0', '[[regtime]]', '[[regtime]]'),
(204, 0, 'forms_manager', 'forms_manager_status', '1', '[[regtime]]', '[[regtime]]'),
(205, 0, 'forms_manager', 'forms_manager_default_sender_name', '', '[[regtime]]', '[[regtime]]'),
(206, 0, 'forms_manager', 'forms_manager_default_sender_email', '', '[[regtime]]', '[[regtime]]'),
(207, 0, 'forms_manager', 'forms_manager_sort_order', '', '[[regtime]]', '[[regtime]]'),
(208, 0, 'page_builder', 'page_builder_layout', '', '[[regtime]]', '[[regtime]]'),
(209, 0, 'page_builder', 'page_builder_priority', '10000', '[[regtime]]', '[[regtime]]'),
(210, 0, 'page_builder', 'page_builder_date_installed', '2024-12-13 18:30:53', '[[regtime]]', '[[regtime]]'),
(211, 0, 'page_builder', 'page_builder_status', '1', '[[regtime]]', '[[regtime]]'),
(212, 0, 'page_builder', 'page_builder_logging', '1', '[[regtime]]', '[[regtime]]'),
(213, 0, 'page_builder', 'page_builder_sort_order', '1', '[[regtime]]', '[[regtime]]'),
(214, 0, 'page_builder', 'store_id', '0', '[[regtime]]', '[[regtime]]'),
(215, 0, 'config', 'install_date', '[[regtime]]', '[[regtime]]', '[[regtime]]'),
(216, 0, 'default_cod', 'default_cod_sort_order', '1', '[[regtime]]', '[[regtime]]'),
(217, 0, 'default_cod', 'default_cod_order_status_id', '1', '[[regtime]]', '[[regtime]]'),
(218, 0, 'default_cod', 'default_cod_status', '1', '[[regtime]]', '[[regtime]]'),
(219, 0, 'default_cod', 'default_cod_location_id', '0', '[[regtime]]', '[[regtime]]'),
(220, 0, 'default_cod', 'default_cod_autoselect', '1', '[[regtime]]', '[[regtime]]'),
(221, 0, 'default_flat_rate_shipping', 'default_flat_rate_shipping_default_status', '1', '[[regtime]]', '[[regtime]]'),
(222, 0, 'default_flat_rate_shipping', 'default_flat_rate_shipping_default_cost', '2', '[[regtime]]', '[[regtime]]'),
(223, 0, 'default_flat_rate_shipping', 'default_flat_rate_shipping_cost_1', '2', '[[regtime]]', '[[regtime]]'),
(224, 0, 'default_flat_rate_shipping', 'default_flat_rate_shipping_tax_class_id_1', '0', '[[regtime]]', '[[regtime]]'),
(225, 0, 'default_flat_rate_shipping', 'default_flat_rate_shipping_default_tax_class_id', '0', '[[regtime]]', '[[regtime]]'),
(226, 0, 'default_flat_rate_shipping', 'default_flat_rate_shipping_status', '1', '[[regtime]]', '[[regtime]]'),
(227, 0, 'default_flat_rate_shipping', 'default_flat_rate_shipping_sort_order', '1', '[[regtime]]', '[[regtime]]'),
(228, 0, 'default_flat_rate_shipping', 'default_flat_rate_shipping_autoselect', '1', '[[regtime]]', '[[regtime]]'),
(229, 0, 'default_local_delivery', 'default_local_delivery_accept_payments', '0', '[[regtime]]', '[[regtime]]'),
(230, 0, 'default_local_delivery', 'default_local_delivery_layout', '', '[[regtime]]', '[[regtime]]'),
(231, 0, 'default_local_delivery', 'default_local_delivery_priority', '10', '[[regtime]]', '[[regtime]]'),
(232, 0, 'default_local_delivery', 'default_local_delivery_date_installed', '[[regtime]]', '[[regtime]]', '[[regtime]]'),
(233, 0, 'default_local_delivery', 'default_local_delivery_sort_order', '', '[[regtime]]', '[[regtime]]'),
(234, 0, 'default_local_delivery', 'default_local_delivery_shipping_storefront_icon_resource_id', '100257', '[[regtime]]', '[[regtime]]'),
(235, 0, 'default_local_delivery', 'default_local_delivery_autoselect', '0', '[[regtime]]', '[[regtime]]'),
(236, 0, 'default_local_delivery', 'default_local_delivery_shipping_storefront_icon', 'image/18/7a/1.png', '[[regtime]]', '[[regtime]]'),
(237, 0, 'default_local_delivery', 'default_local_delivery_total', '', '[[regtime]]', '[[regtime]]'),
(238, 0, 'default_local_delivery', 'default_local_delivery_postal_codes', '', '[[regtime]]', '[[regtime]]'),
(239, 0, 'default_local_delivery', 'default_local_delivery_cost', '', '[[regtime]]', '[[regtime]]'),
(240, 0, 'default_local_delivery', 'default_local_delivery_status', '1', '[[regtime]]', '[[regtime]]'),
(241, 0, 'default_local_delivery', 'store_id', '0', '[[regtime]]', '[[regtime]]'),
(242, 0, 'checkout', 'fast_checkout_buy_now_status', '1', '[[regtime]]', '[[regtime]]'),
(243, 0, 'checkout', 'fast_checkout_create_account', '1', '[[regtime]]', '[[regtime]]'),
(245, 0, 'novator', 'novator_layout', '', '[[regtime]]', '[[regtime]]'),
(246, 0, 'novator', 'novator_priority', '0', '[[regtime]]', '[[regtime]]'),
(247, 0, 'novator', 'novator_date_installed', '[[regtime]]', '[[regtime]]', '[[regtime]]'),
(248, 0, 'novator', 'novator_sort_order', '', '[[regtime]]', '[[regtime]]'),
(249, 0, 'novator', 'config_logo', '100262', '[[regtime]]', '[[regtime]]'),
(250, 0, 'novator', 'config_image_product_width', '312', '[[regtime]]', '[[regtime]]'),
(251, 0, 'novator', 'config_image_product_height', '400', '[[regtime]]', '[[regtime]]'),
(252, 0, 'novator', 'config_image_additional_width', '90', '[[regtime]]', '[[regtime]]'),
(253, 0, 'novator', 'config_image_additional_height', '90', '[[regtime]]', '[[regtime]]'),
(254, 0, 'novator', 'viewed_products_image_height', '400', '[[regtime]]', '[[regtime]]'),
(255, 0, 'novator', 'viewed_products_image_width', '312', '[[regtime]]', '[[regtime]]'),
(256, 0, 'novator', 'viewed_products_limit', '8', '[[regtime]]', '[[regtime]]'),
(257, 0, 'novator', 'config_image_related_width', '312', '[[regtime]]', '[[regtime]]'),
(258, 0, 'novator', 'config_image_related_height', '400', '[[regtime]]', '[[regtime]]'),
(259, 0, 'novator', 'config_image_thumb_width', '420', '[[regtime]]', '[[regtime]]'),
(260, 0, 'novator', 'config_image_thumb_height', '534', '[[regtime]]', '[[regtime]]'),
(261, 0, 'novator', 'config_image_popup_width', '500', '[[regtime]]', '[[regtime]]'),
(262, 0, 'novator', 'config_image_popup_height', '636', '[[regtime]]', '[[regtime]]'),
(263, 0, 'novator', 'config_bestseller_limit', '4', '[[regtime]]', '[[regtime]]'),
(264, 0, 'novator', 'config_featured_limit', '4', '[[regtime]]', '[[regtime]]'),
(265, 0, 'novator', 'config_latest_limit', '4', '[[regtime]]', '[[regtime]]'),
(266, 0, 'novator', 'config_special_limit', '4', '[[regtime]]', '[[regtime]]'),
(267, 0, 'novator', 'config_catalog_limit', '20', '[[regtime]]', '[[regtime]]'),
(268, 0, 'novator', 'config_content_limit', '20', '[[regtime]]', '[[regtime]]'),
(269, 0, 'novator', 'store_id', '0', '[[regtime]]', '[[regtime]]'),
(270, 0, 'novator', 'novator_status', '1', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shopping_sessions`
--

CREATE TABLE `[[dbprefix]]shopping_sessions` (
  `customer_id` int DEFAULT NULL,
  `order_id` int DEFAULT NULL,
  `type` varchar(255) COLLATE utf8mb4_general_ci NOT NULL,
  `key` varchar(255) COLLATE utf8mb4_general_ci NOT NULL,
  `data` json NOT NULL,
  `date_added` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  UNIQUE KEY `[[dbprefix]]shopping_sessions_text_idx` (`type`,`key`),
  KEY `[[dbprefix]]shopping_sessions_customer_fk` (`customer_id`),
  KEY `[[dbprefix]]shopping_sessions_int_idx` (`customer_id` DESC,`order_id` DESC)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]stock_statuses`
--

CREATE TABLE `[[dbprefix]]stock_statuses` (
  `stock_status_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`stock_status_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]stock_statuses`
--

INSERT INTO `[[dbprefix]]stock_statuses` VALUES
(1, 1, 'Pre-Order');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]stores`
--

CREATE TABLE `[[dbprefix]]stores` (
  `store_id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  `alias` varchar(15) COLLATE utf8mb4_unicode_ci NOT NULL,
  `status` int NOT NULL,
  PRIMARY KEY (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

--
-- Dumping data for table `[[dbprefix]]stores`
--

INSERT INTO `[[dbprefix]]stores` VALUES
(0, 'default', 'default', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]store_descriptions`
--

CREATE TABLE `[[dbprefix]]store_descriptions` (
  `store_id` int NOT NULL,
  `language_id` int NOT NULL,
  `description` longtext COLLATE utf8mb4_unicode_ci COMMENT 'translatable',
  `title` longtext COLLATE utf8mb4_unicode_ci COMMENT 'translatable',
  `meta_description` longtext COLLATE utf8mb4_unicode_ci COMMENT 'translatable',
  `meta_keywords` longtext COLLATE utf8mb4_unicode_ci COMMENT 'translatable',
  PRIMARY KEY (`store_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]suppliers`
--

CREATE TABLE `[[dbprefix]]suppliers` (
  `id` int NOT NULL AUTO_INCREMENT,
  `code` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  `name` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`,`code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]supplier_data`
--

CREATE TABLE `[[dbprefix]]supplier_data` (
  `id` int NOT NULL AUTO_INCREMENT,
  `supplier_code` varchar(100) COLLATE utf8mb4_unicode_ci NOT NULL,
  `object_type_id` int NOT NULL,
  `object_id` int NOT NULL,
  `uid` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'unique id of object from supplier API',
  `data` json NOT NULL COMMENT 'json encoded data',
  `date_added` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`,`supplier_code`,`object_type_id`,`object_id`,`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]tasks`
--

CREATE TABLE `[[dbprefix]]tasks` (
  `task_id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `starter` int DEFAULT NULL COMMENT '0 - storefront, 1 - admin side, 2 - any',
  `status` int DEFAULT '0' COMMENT '0 - disabled, 1 - ready, 2 - running, 3 - failed, 4 - scheduled, 5 - completed',
  `start_time` datetime DEFAULT NULL,
  `last_time_run` timestamp NULL DEFAULT NULL,
  `progress` int NOT NULL DEFAULT '0' COMMENT 'percentage of progress',
  `last_result` int NOT NULL DEFAULT '0' COMMENT '1 - success, 0 - failed',
  `run_interval` int NOT NULL DEFAULT '0' COMMENT 'interval in seconds since last run, 0 - without interval',
  `max_execution_time` int DEFAULT '0',
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`task_id`),
  UNIQUE KEY `task_name_idx` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]task_details`
--

CREATE TABLE `[[dbprefix]]task_details` (
  `task_id` int NOT NULL AUTO_INCREMENT,
  `created_by` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT '',
  `settings` longtext COLLATE utf8mb4_unicode_ci,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`task_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]task_steps`
--

CREATE TABLE `[[dbprefix]]task_steps` (
  `step_id` int NOT NULL AUTO_INCREMENT,
  `task_id` int NOT NULL,
  `sort_order` int DEFAULT '0',
  `status` int DEFAULT '0' COMMENT '0 - disabled, 1 - ready, 2 - running, 3 - failed, 4 - scheduled, 5 - completed',
  `last_time_run` timestamp NULL DEFAULT NULL,
  `last_result` int NOT NULL DEFAULT '0' COMMENT '1 - success, 0 - failed',
  `max_execution_time` int DEFAULT '0',
  `controller` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT '',
  `settings` longtext COLLATE utf8mb4_unicode_ci,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`step_id`),
  KEY `task_steps_idx` (`task_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]tax_classes`
--

CREATE TABLE `[[dbprefix]]tax_classes` (
  `tax_class_id` int NOT NULL AUTO_INCREMENT,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`tax_class_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]tax_classes`
--

INSERT INTO `[[dbprefix]]tax_classes` VALUES
(1, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]tax_class_descriptions`
--

CREATE TABLE `[[dbprefix]]tax_class_descriptions` (
  `tax_class_id` int NOT NULL,
  `language_id` int NOT NULL,
  `title` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  PRIMARY KEY (`tax_class_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]tax_class_descriptions`
--

INSERT INTO `[[dbprefix]]tax_class_descriptions` VALUES
(1, 1, 'Taxable Goods', 'Taxed Products');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]tax_rates`
--

CREATE TABLE `[[dbprefix]]tax_rates` (
  `tax_rate_id` int NOT NULL AUTO_INCREMENT,
  `location_id` int NOT NULL DEFAULT '0',
  `zone_id` int DEFAULT '0',
  `tax_class_id` int NOT NULL,
  `priority` int NOT NULL DEFAULT '1',
  `rate` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `rate_prefix` char(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '%',
  `threshold_condition` char(2) COLLATE utf8mb4_unicode_ci NOT NULL,
  `threshold` decimal(15,4) NOT NULL DEFAULT '0.0000',
  `tax_exempt_groups` text COLLATE utf8mb4_unicode_ci,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`tax_rate_id`),
  KEY `[[dbprefix]]tax_rates_idx` (`location_id`,`zone_id`,`tax_class_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]tax_rates`
--

INSERT INTO `[[dbprefix]]tax_rates` VALUES
(1, 1, 0, 1, 1, '8.5000', '%', '', '0.0000', 'a:1:{i:0;s:1:"0";}', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]tax_rate_descriptions`
--

CREATE TABLE `[[dbprefix]]tax_rate_descriptions` (
  `tax_rate_id` int NOT NULL,
  `language_id` int NOT NULL,
  `description` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  PRIMARY KEY (`tax_rate_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]tax_rate_descriptions`
--

INSERT INTO `[[dbprefix]]tax_rate_descriptions` VALUES
(1, 1, 'Retail 8.5%');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]url_aliases`
--

CREATE TABLE `[[dbprefix]]url_aliases` (
  `url_alias_id` int NOT NULL AUTO_INCREMENT,
  `query` varchar(2048) COLLATE utf8mb4_unicode_ci NOT NULL,
  `query_hash` char(32) COLLATE utf8mb4_unicode_ci GENERATED ALWAYS AS (md5(`query`)) STORED,
  `keyword` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `language_id` int NOT NULL DEFAULT '1',
  PRIMARY KEY (`url_alias_id`),
  UNIQUE KEY `[[dbprefix]]url_aliases_idx` (`keyword`,`language_id`),
  UNIQUE KEY `[[dbprefix]]url_aliases_idx2` (`query_hash`,`language_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=66 ;

--
-- Dumping data for table `[[dbprefix]]url_aliases`
--

INSERT INTO `[[dbprefix]]url_aliases` VALUES
(1, 'check_seo=1', DEFAULT, 'check_seo_url', 1),
(2, 'category_id=36', DEFAULT, 'makeup', 1),
(3, 'content_id=1',DEFAULT, 'about_us', 1),
(4, 'product_id=101', DEFAULT, 'pro-v_color_hair_solutions_color_preserve_shine_conditioner_with_pump', 1),
(5, 'product_id=102', DEFAULT, 'gucci_guilty', 1),
(6, 'manufacturer_id=20', DEFAULT, 'gucci', 1),
(7, 'product_id=103', DEFAULT, 'jasmin_noir_lessence_eau_de_parfum_spray', 1),
(8, 'product_id=104', DEFAULT, 'calvin_klein_obsession_for_women_edp_spray', 1),
(9, 'product_id=105', DEFAULT, 'bvlgari_aqua_eau_de_toilette_spray', 1),
(10, 'product_id=106', DEFAULT, 'omnia_eau_de_toilette', 1),
(11, 'product_id=107', DEFAULT, 'lancome_slimissime_360_slimming_activating_concentrate_unisex_treatment', 1),
(12, 'product_id=108', DEFAULT, 'lancome_hypnose_doll_lashes_mascara_4-piece_gift_set', 1),
(13, 'product_id=109', DEFAULT, 'lancome_visionnaire_advanced_skin_corrector', 1),
(14, 'product_id=110', DEFAULT, 'flora_by_gucci_eau_fraiche', 1),
(15, 'category_id=65', DEFAULT, 'books', 1),
(16, 'category_id=66', DEFAULT, 'audio-cd', 1),
(17, 'category_id=67', DEFAULT, 'paperback', 1),
(18, 'product_id=111', DEFAULT, 'new-french-with-ease-1-book--1-mp3-cd', 1),
(19, 'product_id=112', DEFAULT, 'the-miracle-morning-the-not-so-obvious-secret-guaranteed-to-transform-your-life', 1),
(20, 'product_id=113', DEFAULT, 'paper-towns-by-john-green', 1),
(21, 'product_id=114', DEFAULT, 'allegiant-by-veronica-roth', 1),
(22, 'product_id=115', DEFAULT, 'fiorella-purple-peep-toes', 1),
(23, 'category_id=68', DEFAULT, 'apparel--accessories', 1),
(24, 'category_id=69', DEFAULT, 'shoes', 1),
(25, 'product_id=116', DEFAULT, 'new-ladies-high-wedge-heel-toe-thong-diamante-flip-flop-sandals', 1),
(26, 'product_id=117', DEFAULT, 'ruby-shoo-women', 1),
(27, 'product_id=118', DEFAULT, 'women-high-heel-point-toe-stiletto-sandals-ankle-strap-court-shoes', 1),
(28, 'category_id=70', DEFAULT, 't-shirts', 1),
(29, 'product_id=119', DEFAULT, 'fruit-of-the-loom-t-shirts-5-pack---super-premium', 1),
(30, 'product_id=120', DEFAULT, 'jersey-cotton-striped-polo-shirt', 1),
(31, 'product_id=121', DEFAULT, 'designer-men-casual-formal-double-cuffs-grandad-band-collar-shirt-elegant-tie', 1),
(32, 'product_id=122', DEFAULT, 'mens-fine-cotton-giraffe-polo-shirts', 1),
(33, 'product_id=123', DEFAULT, 'casual-sleeve-baseball-t-shirt', 1),
(34, 'category_id=39', DEFAULT, 'eyes', 1),
(35, 'category_id=52', DEFAULT, 'hair-care', 1),
(36, 'manufacturer_id=11', DEFAULT, 'mac', 1),
(37, 'manufacturer_id=17', DEFAULT, 'pantene', 1),
(38, 'manufacturer_id=16', DEFAULT, 'sephora', 1),
(39, 'manufacturer_id=15', DEFAULT, 'lancôme', 1),
(40, 'manufacturer_id=19', DEFAULT, 'giorgio-armani', 1),
(41, 'manufacturer_id=12', DEFAULT, 'benefit', 1),
(42, 'manufacturer_id=13', DEFAULT, 'calvin-klein', 1),
(43, 'product_id=60', DEFAULT, 'nail-lacquer', 1),
(44, 'product_id=59', DEFAULT, 'viva-glam-lipstick', 1),
(45, 'product_id=57', DEFAULT, 'delicate-oil-free-powder-blush', 1),
(46, 'product_id=61', DEFAULT, 'color-design-eye-brightening-all-in-one-5-shadow', 1),
(47, 'product_id=67', DEFAULT, 'flash-bronzer-body-gel', 1),
(48, 'product_id=63', DEFAULT, 'pour-homme-eau-de-toilette', 1),
(49, 'product_id=73', DEFAULT, 'highlighting-expressions', 1),
(50, 'product_id=79', DEFAULT, 'ck-one-gift-set', 1),
(51, 'product_id=97', DEFAULT, 'eye-rejuvenating-serum', 1),
(52, 'product_id=95', DEFAULT, 'skin-minerals-for-men-cleansing-cream', 1),
(53, 'product_id=90', DEFAULT, 'obsession-night-perfume', 1),
(54, 'product_id=89', DEFAULT, 'secret-obsession-perfume', 1),
(55, 'product_id=88', DEFAULT, 'ck-one-summer-34-oz', 1),
(56, 'product_id=87', DEFAULT, 'man-eau-de-toilette-spray', 1),
(57, 'product_id=86', DEFAULT, 'euphoria-men-intense-eau-de-toilette-spray', 1),
(58, 'product_id=85', DEFAULT, 'forbidden-euphoria-eau-de-parfum-spray', 1),
(59, 'product_id=84', DEFAULT, 'armani-code-pour-femme', 1),
(60, 'product_id=83', DEFAULT, 'armani-code-sport', 1),
(61, 'product_id=82', DEFAULT, 'armani-code-after-shave-balm', 1),
(62, 'product_id=81', DEFAULT, 'armani-eau-de-toilette-spray', 1),
(63, 'product_id=80', DEFAULT, 'acqua-di-gio-pour-homme', 1),
(64, 'product_id=66', DEFAULT, 'total-moisture-facial-cream', 1),
(65, 'product_id=124', DEFAULT, 'new-ladies-high-wedge-heel-toe-thong-diamante-flip-flop-sandals-124', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]users`
--

CREATE TABLE `[[dbprefix]]users` (
  `user_id` int NOT NULL AUTO_INCREMENT,
  `user_group_id` int NOT NULL,
  `username` varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `salt` varchar(8) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `password` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `firstname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `lastname` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `email` varchar(96) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `status` int NOT NULL,
  `ip` varchar(50) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `last_login` datetime DEFAULT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`user_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]users`
--

INSERT INTO `[[dbprefix]]users` VALUES
(1, 1, '[[admin_username]]', '[[SALT]]', '[[admin_pass]]', '', '', '[[admin_email]]', 1, '', NULL, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user_groups`
--

CREATE TABLE `[[dbprefix]]user_groups` (
  `user_group_id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(64) COLLATE utf8mb4_unicode_ci NOT NULL,
  `permission` longtext COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`user_group_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=11 ;

--
-- Dumping data for table `[[dbprefix]]user_groups`
--

INSERT INTO `[[dbprefix]]user_groups` VALUES
(1, 'Top Administrator', '', '[[regtime]]', '[[regtime]]'),
(10, 'Demonstration', '', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user_notifications`
--

CREATE TABLE `[[dbprefix]]user_notifications` (
  `user_id` int NOT NULL,
  `store_id` int NOT NULL,
  `section` tinyint(1) NOT NULL COMMENT '1 - admin, 0 - storefront',
  `sendpoint` varchar(255) NOT NULL,
  `protocol` varchar(30) NOT NULL,
  `uri` text NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`user_id`,`store_id`,`section`,`sendpoint`,`protocol`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user_sessions`
--

CREATE TABLE `[[dbprefix]]user_sessions` (
  `user_id` int NOT NULL,
  `token` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `ip` varchar(50) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `last_active` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`user_id`,`token`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]weight_classes`
--

CREATE TABLE `[[dbprefix]]weight_classes` (
  `weight_class_id` int NOT NULL AUTO_INCREMENT,
  `value` decimal(15,8) NOT NULL DEFAULT '0.00000000',
  `iso_code` varchar(5) COLLATE utf8mb4_unicode_ci NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`weight_class_id`,`iso_code`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=7 ;

--
-- Dumping data for table `[[dbprefix]]weight_classes`
--

INSERT INTO `[[dbprefix]]weight_classes` VALUES
(1, '1.00000000', 'KILO', '[[regtime]]', '[[regtime]]'),
(2, '1000.00000000', 'GRAM', '[[regtime]]', '[[regtime]]'),
(5, '2.20460000', 'PUND', '[[regtime]]', '[[regtime]]'),
(6, '35.27400000', 'USOU', '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]weight_class_descriptions`
--

CREATE TABLE `[[dbprefix]]weight_class_descriptions` (
  `weight_class_id` int NOT NULL,
  `language_id` int NOT NULL,
  `title` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  `unit` varchar(4) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '' COMMENT 'translatable',
  PRIMARY KEY (`weight_class_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]weight_class_descriptions`
--

INSERT INTO `[[dbprefix]]weight_class_descriptions` VALUES
(1, 1, 'Kilogram', 'kg'),
(2, 1, 'Gram', 'g'),
(5, 1, 'Pound', 'lb'),
(6, 1, 'Ounce', 'oz');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]zones`
--

CREATE TABLE `[[dbprefix]]zones` (
  `zone_id` int NOT NULL AUTO_INCREMENT,
  `country_id` int NOT NULL,
  `code` varchar(32) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `status` int NOT NULL DEFAULT '1',
  `sort_order` int NOT NULL DEFAULT '0',
  PRIMARY KEY (`zone_id`,`country_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=4009 ;

--
-- Dumping data for table `[[dbprefix]]zones`
--

INSERT INTO `[[dbprefix]]zones` VALUES
(1, 1, 'BDS', 1, 0),
(2, 1, 'BDG', 1, 0),
(3, 1, 'BGL', 1, 0),
(4, 1, 'BAL', 1, 0),
(5, 1, 'BAM', 1, 0),
(6, 1, 'FRA', 1, 0),
(7, 1, 'FYB', 1, 0),
(8, 1, 'GHA', 1, 0),
(9, 1, 'GHO', 1, 0),
(10, 1, 'HEL', 1, 0),
(11, 1, 'HER', 1, 0),
(12, 1, 'JOW', 1, 0),
(13, 1, 'KAB', 1, 0),
(14, 1, 'KAN', 1, 0),
(15, 1, 'KAP', 1, 0),
(16, 1, 'KHO', 1, 0),
(17, 1, 'KNR', 1, 0),
(18, 1, 'KDZ', 1, 0),
(19, 1, 'LAG', 1, 0),
(20, 1, 'LOW', 1, 0),
(21, 1, 'NAN', 1, 0),
(22, 1, 'NIM', 1, 0),
(23, 1, 'NUR', 1, 0),
(24, 1, 'ORU', 1, 0),
(25, 1, 'PIA', 1, 0),
(26, 1, 'PKA', 1, 0),
(27, 1, 'PAR', 1, 0),
(28, 1, 'SAM', 1, 0),
(29, 1, 'SAR', 1, 0),
(30, 1, 'TAK', 1, 0),
(31, 1, 'WAR', 1, 0),
(32, 1, 'ZAB', 1, 0),
(33, 2, 'BR', 1, 0),
(34, 2, 'BU', 1, 0),
(35, 2, 'DL', 1, 0),
(36, 2, 'DV', 1, 0),
(37, 2, 'DI', 1, 0),
(38, 2, 'DR', 1, 0),
(39, 2, 'EL', 1, 0),
(40, 2, 'ER', 1, 0),
(41, 2, 'FR', 1, 0),
(42, 2, 'GJ', 1, 0),
(43, 2, 'GR', 1, 0),
(44, 2, 'HA', 1, 0),
(45, 2, 'KA', 1, 0),
(46, 2, 'KB', 1, 0),
(47, 2, 'KC', 1, 0),
(48, 2, 'KO', 1, 0),
(49, 2, 'KR', 1, 0),
(50, 2, 'KU', 1, 0),
(51, 2, 'LB', 1, 0),
(52, 2, 'LE', 1, 0),
(53, 2, 'LU', 1, 0),
(54, 2, 'MM', 1, 0),
(55, 2, 'MK', 1, 0),
(56, 2, 'MT', 1, 0),
(57, 2, 'MR', 1, 0),
(58, 2, 'PQ', 1, 0),
(59, 2, 'PR', 1, 0),
(60, 2, 'PG', 1, 0),
(61, 2, 'PU', 1, 0),
(62, 2, 'SH', 1, 0),
(63, 2, 'SK', 1, 0),
(64, 2, 'SR', 1, 0),
(65, 2, 'TE', 1, 0),
(66, 2, 'TP', 1, 0),
(67, 2, 'TR', 1, 0),
(68, 2, 'VL', 1, 0),
(69, 3, 'ADR', 1, 0),
(70, 3, 'ADE', 1, 0),
(71, 3, 'ATE', 1, 0),
(72, 3, 'ALG', 1, 0),
(73, 3, 'ANN', 1, 0),
(74, 3, 'BAT', 1, 0),
(75, 3, 'BEC', 1, 0),
(76, 3, 'BEJ', 1, 0),
(77, 3, 'BIS', 1, 0),
(78, 3, 'BLI', 1, 0),
(79, 3, 'BBA', 1, 0),
(80, 3, 'BOA', 1, 0),
(81, 3, 'BMD', 1, 0),
(82, 3, 'CHL', 1, 0),
(83, 3, 'CON', 1, 0),
(84, 3, 'DJE', 1, 0),
(85, 3, 'EBA', 1, 0),
(86, 3, 'EOU', 1, 0),
(87, 3, 'ETA', 1, 0),
(88, 3, 'GHA', 1, 0),
(89, 3, 'GUE', 1, 0),
(90, 3, 'ILL', 1, 0),
(91, 3, 'JIJ', 1, 0),
(92, 3, 'KHE', 1, 0),
(93, 3, 'LAG', 1, 0),
(94, 3, 'MUA', 1, 0),
(95, 3, 'MED', 1, 0),
(96, 3, 'MIL', 1, 0),
(97, 3, 'MOS', 1, 0),
(98, 3, 'MSI', 1, 0),
(99, 3, 'NAA', 1, 0),
(100, 3, 'ORA', 1, 0),
(101, 3, 'OUA', 1, 0),
(102, 3, 'OEB', 1, 0),
(103, 3, 'REL', 1, 0),
(104, 3, 'SAI', 1, 0),
(105, 3, 'SET', 1, 0),
(106, 3, 'SBA', 1, 0),
(107, 3, 'SKI', 1, 0),
(108, 3, 'SAH', 1, 0),
(109, 3, 'TAM', 1, 0),
(110, 3, 'TEB', 1, 0),
(111, 3, 'TIA', 1, 0),
(112, 3, 'TIN', 1, 0),
(113, 3, 'TIP', 1, 0),
(114, 3, 'TIS', 1, 0),
(115, 3, 'TOU', 1, 0),
(116, 3, 'TLE', 1, 0),
(117, 4, 'E', 1, 0),
(118, 4, 'M', 1, 0),
(119, 4, 'R', 1, 0),
(120, 4, 'S', 1, 0),
(121, 4, 'W', 1, 0),
(122, 5, 'ALV', 1, 0),
(123, 5, 'CAN', 1, 0),
(124, 5, 'ENC', 1, 0),
(125, 5, 'ESE', 1, 0),
(126, 5, 'LMA', 1, 0),
(127, 5, 'ORD', 1, 0),
(128, 5, 'SJL', 1, 0),
(129, 6, 'BGO', 1, 0),
(130, 6, 'BGU', 1, 0),
(131, 6, 'BIE', 1, 0),
(132, 6, 'CAB', 1, 0),
(133, 6, 'CCU', 1, 0),
(134, 6, 'CNO', 1, 0),
(135, 6, 'CUS', 1, 0),
(136, 6, 'CNN', 1, 0),
(137, 6, 'HUA', 1, 0),
(138, 6, 'HUI', 1, 0),
(139, 6, 'LUA', 1, 0),
(140, 6, 'LNO', 1, 0),
(141, 6, 'LSU', 1, 0),
(142, 6, 'MAL', 1, 0),
(143, 6, 'MOX', 1, 0),
(144, 6, 'NAM', 1, 0),
(145, 6, 'UIG', 1, 0),
(146, 6, 'ZAI', 1, 0),
(147, 9, 'ASG', 1, 0),
(148, 9, 'ASJ', 1, 0),
(149, 9, 'ASM', 1, 0),
(150, 9, 'ASL', 1, 0),
(151, 9, 'ASR', 1, 0),
(152, 9, 'ASH', 1, 0),
(153, 9, 'BAR', 1, 0),
(154, 9, 'RED', 1, 0),
(155, 10, 'AN', 1, 0),
(156, 10, 'BA', 1, 0),
(157, 10, 'CA', 1, 0),
(158, 10, 'CH', 1, 0),
(159, 10, 'CU', 1, 0),
(160, 10, 'CO', 1, 0),
(161, 10, 'CR', 1, 0),
(162, 10, 'DF', 1, 0),
(163, 10, 'ER', 1, 0),
(164, 10, 'FO', 1, 0),
(165, 10, 'JU', 1, 0),
(166, 10, 'LP', 1, 0),
(167, 10, 'LR', 1, 0),
(168, 10, 'ME', 1, 0),
(169, 10, 'MI', 1, 0),
(170, 10, 'NE', 1, 0),
(171, 10, 'RN', 1, 0),
(172, 10, 'SA', 1, 0),
(173, 10, 'SJ', 1, 0),
(174, 10, 'SL', 1, 0),
(175, 10, 'SC', 1, 0),
(176, 10, 'SF', 1, 0),
(177, 10, 'SD', 1, 0),
(178, 10, 'TF', 1, 0),
(179, 10, 'TU', 1, 0),
(180, 11, 'AGT', 1, 0),
(181, 11, 'ARR', 1, 0),
(182, 11, 'ARM', 1, 0),
(183, 11, 'GEG', 1, 0),
(184, 11, 'KOT', 1, 0),
(185, 11, 'LOR', 1, 0),
(186, 11, 'SHI', 1, 0),
(187, 11, 'SYU', 1, 0),
(188, 11, 'TAV', 1, 0),
(189, 11, 'VAY', 1, 0),
(190, 11, 'YER', 1, 0),
(191, 13, 'ACT', 1, 0),
(192, 13, 'NSW', 1, 0),
(193, 13, 'NT', 1, 0),
(194, 13, 'QLD', 1, 0),
(195, 13, 'SA', 1, 0),
(196, 13, 'TAS', 1, 0),
(197, 13, 'VIC', 1, 0),
(198, 13, 'WA', 1, 0),
(199, 14, 'BUR', 1, 0),
(200, 14, 'KAR', 1, 0),
(201, 14, 'NOS', 1, 0),
(202, 14, 'OOS', 1, 0),
(203, 14, 'SAL', 1, 0),
(204, 14, 'STE', 1, 0),
(205, 14, 'TIR', 1, 0),
(206, 14, 'VOR', 1, 0),
(207, 14, 'WIE', 1, 0),
(208, 15, 'AB', 1, 0),
(209, 15, 'ABS', 1, 0),
(210, 15, 'AGC', 1, 0),
(211, 15, 'AGM', 1, 0),
(212, 15, 'AGS', 1, 0),
(213, 15, 'AGA', 1, 0),
(214, 15, 'AGU', 1, 0),
(215, 15, 'AST', 1, 0),
(216, 15, 'BA', 1, 0),
(217, 15, 'BAB', 1, 0),
(218, 15, 'BAL', 1, 0),
(219, 15, 'BAR', 1, 0),
(220, 15, 'BEY', 1, 0),
(221, 15, 'BIL', 1, 0),
(222, 15, 'CAB', 1, 0),
(223, 15, 'CAL', 1, 0),
(224, 15, 'CUL', 1, 0),
(225, 15, 'DAS', 1, 0),
(226, 15, 'DAV', 1, 0),
(227, 15, 'FUZ', 1, 0),
(228, 15, 'GA', 1, 0),
(229, 15, 'GAD', 1, 0),
(230, 15, 'GOR', 1, 0),
(231, 15, 'GOY', 1, 0),
(232, 15, 'HAC', 1, 0),
(233, 15, 'IMI', 1, 0),
(234, 15, 'ISM', 1, 0),
(235, 15, 'KAL', 1, 0),
(236, 15, 'KUR', 1, 0),
(237, 15, 'LA', 1, 0),
(238, 15, 'LAC', 1, 0),
(239, 15, 'LAN', 1, 0),
(240, 15, 'LER', 1, 0),
(241, 15, 'MAS', 1, 0),
(242, 15, 'MI', 1, 0),
(243, 15, 'NA', 1, 0),
(244, 15, 'NEF', 1, 0),
(245, 15, 'OGU', 1, 0),
(246, 15, 'ORD', 1, 0),
(247, 15, 'QAB', 1, 0),
(248, 15, 'QAX', 1, 0),
(249, 15, 'QAZ', 1, 0),
(250, 15, 'QOB', 1, 0),
(251, 15, 'QBA', 1, 0),
(252, 15, 'QBI', 1, 0),
(253, 15, 'QUS', 1, 0),
(254, 15, 'SA', 1, 0),
(255, 15, 'SAT', 1, 0),
(256, 15, 'SAB', 1, 0),
(257, 15, 'SAD', 1, 0),
(258, 15, 'SAH', 1, 0),
(259, 15, 'SAK', 1, 0),
(260, 15, 'SAL', 1, 0),
(261, 15, 'SM', 1, 0),
(262, 15, 'SMI', 1, 0),
(263, 15, 'SKR', 1, 0),
(264, 15, 'SMX', 1, 0),
(265, 15, 'SAR', 1, 0),
(266, 15, 'SIY', 1, 0),
(267, 15, 'SS', 1, 0),
(268, 15, 'SUS', 1, 0),
(269, 15, 'TAR', 1, 0),
(270, 15, 'TOV', 1, 0),
(271, 15, 'UCA', 1, 0),
(272, 15, 'XA', 1, 0),
(273, 15, 'XAC', 1, 0),
(274, 15, 'XAN', 1, 0),
(275, 15, 'XIZ', 1, 0),
(276, 15, 'XCI', 1, 0),
(277, 15, 'XVD', 1, 0),
(278, 15, 'YAR', 1, 0),
(279, 15, 'YEV', 1, 0),
(280, 15, 'ZAN', 1, 0),
(281, 15, 'ZAQ', 1, 0),
(282, 15, 'ZAR', 1, 0),
(283, 15, 'NX', 1, 0),
(284, 16, 'ACK', 1, 0),
(285, 16, 'BER', 1, 0),
(286, 16, 'BIM', 1, 0),
(287, 16, 'BLK', 1, 0),
(288, 16, 'CAT', 1, 0),
(289, 16, 'CAB', 1, 0),
(290, 16, 'CAN', 1, 0),
(291, 16, 'CEL', 1, 0),
(292, 16, 'FRE', 1, 0),
(293, 16, 'CRO', 1, 0),
(294, 16, 'EGB', 1, 0),
(295, 16, 'EXU', 1, 0),
(296, 16, 'GRD', 1, 0),
(297, 16, 'HAR', 1, 0),
(298, 16, 'HOP', 1, 0),
(299, 16, 'INA', 1, 0),
(300, 16, 'LNG', 1, 0),
(301, 16, 'MAN', 1, 0),
(302, 16, 'MAY', 1, 0),
(303, 16, 'MOO', 1, 0),
(304, 16, 'NAB', 1, 0),
(305, 16, 'NAN', 1, 0),
(306, 16, 'NEL', 1, 0),
(307, 16, 'RAG', 1, 0),
(308, 16, 'RUM', 1, 0),
(309, 16, 'SAL', 1, 0),
(310, 16, 'SAB', 1, 0),
(311, 16, 'SAN', 1, 0),
(312, 16, 'SEL', 1, 0),
(313, 16, 'SWE', 1, 0),
(314, 16, 'WGB', 1, 0),
(315, 17, 'CAP', 1, 0),
(316, 17, 'CEN', 1, 0),
(317, 17, 'MUH', 1, 0),
(318, 17, 'NOR', 1, 0),
(319, 17, 'SOU', 1, 0),
(320, 18, 'BAR', 1, 0),
(321, 18, 'CHI', 1, 0),
(322, 18, 'DHA', 1, 0),
(323, 18, 'KHU', 1, 0),
(324, 18, 'RAJ', 1, 0),
(325, 18, 'SYL', 1, 0),
(326, 19, 'CC', 1, 0),
(327, 19, 'AND', 1, 0),
(328, 19, 'GEO', 1, 0),
(329, 19, 'JAM', 1, 0),
(330, 19, 'JOH', 1, 0),
(331, 19, 'JOS', 1, 0),
(332, 19, 'LUC', 1, 0),
(333, 19, 'MIC', 1, 0),
(334, 19, 'PET', 1, 0),
(335, 19, 'PHI', 1, 0),
(336, 19, 'THO', 1, 0),
(337, 20, 'BR', 1, 0),
(338, 20, 'HO', 1, 0),
(339, 20, 'HM', 1, 0),
(340, 20, 'HR', 1, 0),
(341, 20, 'MA', 1, 0),
(342, 20, 'MI', 1, 0),
(343, 20, 'VI', 1, 0),
(344, 21, 'VAN', 1, 0),
(345, 21, 'WBR', 1, 0),
(346, 21, 'WHT', 1, 0),
(347, 21, 'WLG', 1, 0),
(348, 21, 'VLI', 1, 0),
(349, 21, 'WLX', 1, 0),
(350, 21, 'WNA', 1, 0),
(351, 21, 'VOV', 1, 0),
(352, 21, 'VBR', 1, 0),
(353, 21, 'VWV', 1, 0),
(354, 22, 'BZ', 1, 0),
(355, 22, 'CY', 1, 0),
(356, 22, 'CR', 1, 0),
(357, 22, 'OW', 1, 0),
(358, 22, 'SC', 1, 0),
(359, 22, 'TO', 1, 0),
(360, 23, 'AL', 1, 0),
(361, 23, 'AK', 1, 0),
(362, 23, 'AQ', 1, 0),
(363, 23, 'BO', 1, 0),
(364, 23, 'CO', 1, 0),
(365, 23, 'DO', 1, 0),
(366, 23, 'KO', 1, 0),
(367, 23, 'LI', 1, 0),
(368, 23, 'MO', 1, 0),
(369, 23, 'OU', 1, 0),
(370, 23, 'PL', 1, 0),
(371, 23, 'ZO', 1, 0),
(372, 24, 'DS', 1, 0),
(373, 24, 'HC', 1, 0),
(374, 24, 'HA', 1, 0),
(375, 24, 'PG', 1, 0),
(376, 24, 'PB', 1, 0),
(377, 24, 'GC', 1, 0),
(378, 24, 'SG', 1, 0),
(379, 24, 'SA', 1, 0),
(380, 24, 'SM', 1, 0),
(381, 24, 'SH', 1, 0),
(382, 24, 'WA', 1, 0),
(383, 25, 'BUM', 1, 0),
(384, 25, 'CHU', 1, 0),
(385, 25, 'DAG', 1, 0),
(386, 25, 'GAS', 1, 0),
(387, 25, 'HAA', 1, 0),
(388, 25, 'LHU', 1, 0),
(389, 25, 'MON', 1, 0),
(390, 25, 'PAR', 1, 0),
(391, 25, 'PEM', 1, 0),
(392, 25, 'PUN', 1, 0),
(393, 25, 'SJO', 1, 0),
(394, 25, 'SAT', 1, 0),
(395, 25, 'SAR', 1, 0),
(396, 25, 'THI', 1, 0),
(397, 25, 'TRG', 1, 0),
(398, 25, 'TRY', 1, 0),
(399, 25, 'TRO', 1, 0),
(400, 25, 'TSI', 1, 0),
(401, 25, 'WPH', 1, 0),
(402, 25, 'ZHE', 1, 0),
(403, 26, 'BEN', 1, 0),
(404, 26, 'CHU', 1, 0),
(405, 26, 'COC', 1, 0),
(406, 26, 'LPZ', 1, 0),
(407, 26, 'ORU', 1, 0),
(408, 26, 'PAN', 1, 0),
(409, 26, 'POT', 1, 0),
(410, 26, 'SCZ', 1, 0),
(411, 26, 'TAR', 1, 0),
(412, 27, 'BRO', 1, 0),
(413, 27, 'FUS', 1, 0),
(414, 27, 'FPO', 1, 0),
(415, 27, 'FTU', 1, 0),
(416, 27, 'FZE', 1, 0),
(417, 27, 'FBP', 1, 0),
(418, 27, 'FSB', 1, 0),
(419, 27, 'FHN', 1, 0),
(420, 27, 'FZH', 1, 0),
(421, 27, 'FSA', 1, 0),
(422, 27, 'FZA', 1, 0),
(423, 27, 'SBL', 1, 0),
(424, 27, 'SDO', 1, 0),
(425, 27, 'SBI', 1, 0),
(426, 27, 'SVL', 1, 0),
(427, 27, 'SSR', 1, 0),
(428, 27, 'SFO', 1, 0),
(429, 27, 'STR', 1, 0),
(430, 28, 'CE', 1, 0),
(431, 28, 'GH', 1, 0),
(432, 28, 'KD', 1, 0),
(433, 28, 'KT', 1, 0),
(434, 28, 'KW', 1, 0),
(435, 28, 'NG', 1, 0),
(436, 28, 'NE', 1, 0),
(437, 28, 'NW', 1, 0),
(438, 28, 'SE', 1, 0),
(439, 28, 'SO', 1, 0),
(440, 30, 'AC', 1, 0),
(441, 30, 'AL', 1, 0),
(442, 30, 'AP', 1, 0),
(443, 30, 'AM', 1, 0),
(444, 30, 'BA', 1, 0),
(445, 30, 'CE', 1, 0),
(446, 30, 'DF', 1, 0),
(447, 30, 'ES', 1, 0),
(448, 30, 'GO', 1, 0),
(449, 30, 'MA', 1, 0),
(450, 30, 'MT', 1, 0),
(451, 30, 'MS', 1, 0),
(452, 30, 'MG', 1, 0),
(453, 30, 'PA', 1, 0),
(454, 30, 'PB', 1, 0),
(455, 30, 'PR', 1, 0),
(456, 30, 'PE', 1, 0),
(457, 30, 'PI', 1, 0),
(458, 30, 'RJ', 1, 0),
(459, 30, 'RN', 1, 0),
(460, 30, 'RS', 1, 0),
(461, 30, 'RO', 1, 0),
(462, 30, 'RR', 1, 0),
(463, 30, 'SC', 1, 0),
(464, 30, 'SP', 1, 0),
(465, 30, 'SE', 1, 0),
(466, 30, 'TO', 1, 0),
(467, 31, 'PB', 1, 0),
(468, 31, 'SI', 1, 0),
(469, 31, 'NI', 1, 0),
(470, 31, 'TB', 1, 0),
(471, 31, 'EA', 1, 0),
(472, 31, 'DI', 1, 0),
(473, 31, 'EG', 1, 0),
(474, 31, 'DG', 1, 0),
(475, 32, 'BEL', 1, 0),
(476, 32, 'BRM', 1, 0),
(477, 32, 'TEM', 1, 0),
(478, 32, 'TUT', 1, 0),
(479, 33, '', 1, 0),
(480, 33, '', 1, 0),
(481, 33, '', 1, 0),
(482, 33, '', 1, 0),
(483, 33, '', 1, 0),
(484, 33, '', 1, 0),
(485, 33, '', 1, 0),
(486, 33, '', 1, 0),
(487, 33, '', 1, 0),
(488, 33, '', 1, 0),
(489, 33, '', 1, 0),
(490, 33, '', 1, 0),
(491, 33, '', 1, 0),
(492, 33, '', 1, 0),
(493, 33, '', 1, 0),
(494, 33, '', 1, 0),
(495, 33, '', 1, 0),
(496, 33, '', 1, 0),
(497, 33, '', 1, 0),
(498, 33, '', 1, 0),
(499, 33, '', 1, 0),
(500, 33, '', 1, 0),
(501, 33, '', 1, 0),
(502, 33, '', 1, 0),
(503, 33, '', 1, 0),
(504, 33, '', 1, 0),
(505, 33, '', 1, 0),
(506, 34, 'BAL', 1, 0),
(507, 34, 'BAM', 1, 0),
(508, 34, 'BAN', 1, 0),
(509, 34, 'BAZ', 1, 0),
(510, 34, 'BOR', 1, 0),
(511, 34, 'BLG', 1, 0),
(512, 34, 'BOK', 1, 0),
(513, 34, 'COM', 1, 0),
(514, 34, 'GAN', 1, 0),
(515, 34, 'GNA', 1, 0),
(516, 34, 'GOU', 1, 0),
(517, 34, 'HOU', 1, 0),
(518, 34, 'IOA', 1, 0),
(519, 34, 'KAD', 1, 0),
(520, 34, 'KEN', 1, 0),
(521, 34, 'KOD', 1, 0),
(522, 34, 'KOP', 1, 0),
(523, 34, 'KOS', 1, 0),
(524, 34, 'KOL', 1, 0),
(525, 34, 'KOT', 1, 0),
(526, 34, 'KOW', 1, 0),
(527, 34, 'LER', 1, 0),
(528, 34, 'LOR', 1, 0),
(529, 34, 'MOU', 1, 0),
(530, 34, 'NAH', 1, 0),
(531, 34, 'NAM', 1, 0),
(532, 34, 'NAY', 1, 0),
(533, 34, 'NOU', 1, 0),
(534, 34, 'OUB', 1, 0),
(535, 34, 'OUD', 1, 0),
(536, 34, 'PAS', 1, 0),
(537, 34, 'PON', 1, 0),
(538, 34, 'SAG', 1, 0),
(539, 34, 'SAM', 1, 0),
(540, 34, 'SEN', 1, 0),
(541, 34, 'SIS', 1, 0),
(542, 34, 'SOM', 1, 0),
(543, 34, 'SOR', 1, 0),
(544, 34, 'TAP', 1, 0),
(545, 34, 'TUY', 1, 0),
(546, 34, 'YAG', 1, 0),
(547, 34, 'YAT', 1, 0),
(548, 34, 'ZIR', 1, 0),
(549, 34, 'ZOD', 1, 0),
(550, 34, 'ZOW', 1, 0),
(551, 35, 'BB', 1, 0),
(552, 35, 'BJ', 1, 0),
(553, 35, 'BR', 1, 0),
(554, 35, 'CA', 1, 0),
(555, 35, 'CI', 1, 0),
(556, 35, 'GI', 1, 0),
(557, 35, 'KR', 1, 0),
(558, 35, 'KY', 1, 0),
(559, 35, 'KI', 1, 0),
(560, 35, 'MA', 1, 0),
(561, 35, 'MU', 1, 0),
(562, 35, 'MY', 1, 0),
(563, 35, 'MW', 1, 0),
(564, 35, 'NG', 1, 0),
(565, 35, 'RT', 1, 0),
(566, 35, 'RY', 1, 0),
(567, 36, 'PP', 1, 0),
(568, 36, 'PS', 1, 0),
(569, 36, 'PA', 1, 0),
(570, 36, 'KB', 1, 0),
(571, 36, 'BM', 1, 0),
(572, 36, 'BA', 1, 0),
(573, 36, 'KM', 1, 0),
(574, 36, 'KN', 1, 0),
(575, 36, 'KU', 1, 0),
(576, 36, 'KO', 1, 0),
(577, 36, 'KT', 1, 0),
(578, 36, 'KP', 1, 0),
(579, 36, 'KL', 1, 0),
(580, 36, 'KK', 1, 0),
(581, 36, 'KR', 1, 0),
(582, 36, 'MK', 1, 0),
(583, 36, 'OM', 1, 0),
(584, 36, 'PU', 1, 0),
(585, 36, 'PR', 1, 0),
(586, 36, 'PG', 1, 0),
(587, 36, 'RK', 1, 0),
(588, 36, 'SI', 1, 0),
(589, 36, 'ST', 1, 0),
(590, 36, 'SR', 1, 0),
(591, 36, 'TK', 1, 0),
(592, 37, 'ADA', 1, 0),
(593, 37, 'CEN', 1, 0),
(594, 37, 'EST', 1, 0),
(595, 37, 'EXN', 1, 0),
(596, 37, 'LIT', 1, 0),
(597, 37, 'NOR', 1, 0),
(598, 37, 'NOT', 1, 0),
(599, 37, 'OUE', 1, 0),
(600, 37, 'SUD', 1, 0),
(601, 37, 'SOU', 1, 0),
(602, 38, 'AB', 1, 0),
(603, 38, 'BC', 1, 0),
(604, 38, 'MB', 1, 0),
(605, 38, 'NB', 1, 0),
(606, 38, 'NL', 1, 0),
(607, 38, 'NT', 1, 0),
(608, 38, 'NS', 1, 0),
(609, 38, 'NU', 1, 0),
(610, 38, 'ON', 1, 0),
(611, 38, 'PE', 1, 0),
(612, 38, 'QC', 1, 0),
(613, 38, 'SK', 1, 0),
(614, 38, 'YT', 1, 0),
(615, 39, 'BV', 1, 0),
(616, 39, 'BR', 1, 0),
(617, 39, 'CS', 1, 0),
(618, 39, 'MA', 1, 0),
(619, 39, 'MO', 1, 0),
(620, 39, 'PA', 1, 0),
(621, 39, 'PN', 1, 0),
(622, 39, 'PR', 1, 0),
(623, 39, 'RG', 1, 0),
(624, 39, 'SL', 1, 0),
(625, 39, 'CA', 1, 0),
(626, 39, 'CR', 1, 0),
(627, 39, 'SD', 1, 0),
(628, 39, 'SF', 1, 0),
(629, 39, 'SN', 1, 0),
(630, 39, 'SV', 1, 0),
(631, 39, 'TA', 1, 0),
(632, 40, 'CR', 1, 0),
(633, 40, 'EA', 1, 0),
(634, 40, 'ML', 1, 0),
(635, 40, 'ST', 1, 0),
(636, 40, 'SP', 1, 0),
(637, 40, 'SK', 1, 0),
(638, 40, 'WD', 1, 0),
(639, 40, 'WN', 1, 0),
(640, 41, 'BBA', 1, 0),
(641, 41, 'BKO', 1, 0),
(642, 41, 'HKO', 1, 0),
(643, 41, 'HMB', 1, 0),
(644, 41, 'KEM', 1, 0),
(645, 41, 'LOB', 1, 0),
(646, 41, 'MKD', 1, 0),
(647, 41, 'MBO', 1, 0),
(648, 41, 'NMM', 1, 0),
(649, 41, 'OMP', 1, 0),
(650, 41, 'OUK', 1, 0),
(651, 41, 'OUH', 1, 0),
(652, 41, 'OPE', 1, 0),
(653, 41, 'VAK', 1, 0),
(654, 41, 'NGR', 1, 0),
(655, 41, 'SMB', 1, 0),
(656, 41, 'BAN', 1, 0),
(657, 42, 'BA', 1, 0),
(658, 42, 'BI', 1, 0),
(659, 42, 'BE', 1, 0),
(660, 42, 'CB', 1, 0),
(661, 42, 'GU', 1, 0),
(662, 42, 'KA', 1, 0),
(663, 42, 'LA', 1, 0),
(664, 42, 'LC', 1, 0),
(665, 42, 'LR', 1, 0),
(666, 42, 'MK', 1, 0),
(667, 42, 'MC', 1, 0),
(668, 42, 'OU', 1, 0),
(669, 42, 'SA', 1, 0),
(670, 42, 'TA', 1, 0),
(671, 43, 'AI', 1, 0),
(672, 43, 'AN', 1, 0),
(673, 43, 'AR', 1, 0),
(674, 43, 'AT', 1, 0),
(675, 43, 'BI', 1, 0),
(676, 43, 'CO', 1, 0),
(677, 43, 'LI', 1, 0),
(678, 43, 'LL', 1, 0),
(679, 43, 'MA', 1, 0),
(680, 43, 'ML', 1, 0),
(681, 43, 'RM', 1, 0),
(682, 43, 'TA', 1, 0),
(683, 43, 'VS', 1, 0),
(684, 44, 'AN', 1, 0),
(685, 44, 'BE', 1, 0),
(686, 44, 'CH', 1, 0),
(687, 44, 'FU', 1, 0),
(688, 44, 'GA', 1, 0),
(689, 44, 'GU', 1, 0),
(690, 44, 'GX', 1, 0),
(691, 44, 'GZ', 1, 0),
(692, 44, 'HA', 1, 0),
(693, 44, 'HB', 1, 0),
(694, 44, 'HL', 1, 0),
(695, 44, 'HE', 1, 0),
(696, 44, 'HK', 1, 0),
(697, 44, 'HU', 1, 0),
(698, 44, 'HN', 1, 0),
(699, 44, 'IM', 1, 0),
(700, 44, 'JI', 1, 0),
(701, 44, 'JX', 1, 0),
(702, 44, 'JL', 1, 0),
(703, 44, 'LI', 1, 0),
(704, 44, 'MA', 1, 0),
(705, 44, 'NI', 1, 0),
(706, 44, 'SH', 1, 0),
(707, 44, 'SA', 1, 0),
(708, 44, 'SG', 1, 0),
(709, 44, 'SX', 1, 0),
(710, 44, 'SI', 1, 0),
(711, 44, 'TI', 1, 0),
(712, 44, 'XI', 1, 0),
(713, 44, 'YU', 1, 0),
(714, 44, 'ZH', 1, 0),
(715, 46, 'D', 1, 0),
(716, 46, 'H', 1, 0),
(717, 46, 'O', 1, 0),
(718, 46, 'S', 1, 0),
(719, 46, 'W', 1, 0),
(720, 47, 'AMZ', 1, 0),
(721, 47, 'ANT', 1, 0),
(722, 47, 'ARA', 1, 0),
(723, 47, 'ATL', 1, 0),
(724, 47, 'BDC', 1, 0),
(725, 47, 'BOL', 1, 0),
(726, 47, 'BOY', 1, 0),
(727, 47, 'CAL', 1, 0),
(728, 47, 'CAQ', 1, 0),
(729, 47, 'CAS', 1, 0),
(730, 47, 'CAU', 1, 0),
(731, 47, 'CES', 1, 0),
(732, 47, 'CHO', 1, 0),
(733, 47, 'COR', 1, 0),
(734, 47, 'CAM', 1, 0),
(735, 47, 'GNA', 1, 0),
(736, 47, 'GJR', 1, 0),
(737, 47, 'GVR', 1, 0),
(738, 47, 'HUI', 1, 0),
(739, 47, 'MAG', 1, 0),
(740, 47, 'MET', 1, 0),
(741, 47, 'NAR', 1, 0),
(742, 47, 'NDS', 1, 0),
(743, 47, 'PUT', 1, 0),
(744, 47, 'QUI', 1, 0),
(745, 47, 'RIS', 1, 0),
(746, 47, 'SAP', 1, 0),
(747, 47, 'SAN', 1, 0),
(748, 47, 'SUC', 1, 0),
(749, 47, 'TOL', 1, 0),
(750, 47, 'VDC', 1, 0),
(751, 47, 'VAU', 1, 0),
(752, 47, 'VIC', 1, 0),
(753, 48, 'G', 1, 0),
(754, 48, 'A', 1, 0),
(755, 48, 'M', 1, 0),
(756, 49, 'BO', 1, 0),
(757, 49, 'BR', 1, 0),
(758, 49, 'CU', 1, 0),
(759, 49, 'CO', 1, 0),
(760, 49, 'KO', 1, 0),
(761, 49, 'LE', 1, 0),
(762, 49, 'LI', 1, 0),
(763, 49, 'NI', 1, 0),
(764, 49, 'PL', 1, 0),
(765, 49, 'PO', 1, 0),
(766, 49, 'SA', 1, 0),
(767, 50, 'PU', 1, 0),
(768, 50, 'RK', 1, 0),
(769, 50, 'MK', 1, 0),
(770, 50, 'PE', 1, 0),
(771, 50, 'NI', 1, 0),
(772, 50, 'SU', 1, 0),
(773, 50, 'PA', 1, 0),
(774, 50, 'AI', 1, 0),
(775, 50, 'MA', 1, 0),
(776, 50, 'TA', 1, 0),
(777, 50, 'MT', 1, 0),
(778, 50, 'AT', 1, 0),
(779, 50, 'MU', 1, 0),
(780, 50, 'RR', 1, 0),
(781, 50, 'MG', 1, 0),
(782, 51, 'AL', 1, 0),
(783, 51, 'CA', 1, 0),
(784, 51, 'GU', 1, 0),
(785, 51, 'HE', 1, 0),
(786, 51, 'LI', 1, 0),
(787, 51, 'PU', 1, 0),
(788, 51, 'SJ', 1, 0),
(789, 52, 'ABE', 1, 0),
(790, 52, 'ABI', 1, 0),
(791, 52, 'ABO', 1, 0),
(792, 52, 'ADI', 1, 0),
(793, 52, 'ADZ', 1, 0),
(794, 52, 'AGB', 1, 0),
(795, 52, 'AGN', 1, 0),
(796, 52, 'ALE', 1, 0),
(797, 52, 'BOC', 1, 0),
(798, 52, 'BAN', 1, 0),
(799, 52, 'BEO', 1, 0),
(800, 52, 'BIA', 1, 0),
(801, 52, 'BDK', 1, 0),
(802, 52, 'BGN', 1, 0),
(803, 52, 'BFL', 1, 0),
(804, 52, 'BKE', 1, 0),
(805, 52, 'BNA', 1, 0),
(806, 52, 'BDL', 1, 0),
(807, 52, 'DKL', 1, 0),
(808, 52, 'DBU', 1, 0),
(809, 52, 'DAL', 1, 0),
(810, 52, 'DAN', 1, 0),
(811, 52, 'DAO', 1, 0),
(812, 52, 'DIM', 1, 0),
(813, 52, 'DIV', 1, 0),
(814, 52, 'DUE', 1, 0),
(815, 52, 'FER', 1, 0),
(816, 52, 'GAG', 1, 0),
(817, 52, 'GBA', 1, 0),
(818, 52, 'GLA', 1, 0),
(819, 52, 'GUI', 1, 0),
(820, 52, 'ISS', 1, 0),
(821, 52, 'JAC', 1, 0),
(822, 52, 'KAT', 1, 0),
(823, 52, 'KOR', 1, 0),
(824, 52, 'LAK', 1, 0),
(825, 52, 'MAN', 1, 0),
(826, 52, 'MKN', 1, 0),
(827, 52, 'MBA', 1, 0),
(828, 52, 'ODI', 1, 0),
(829, 52, 'OUM', 1, 0),
(830, 52, 'SAK', 1, 0),
(831, 52, 'SPE', 1, 0),
(832, 52, 'SAS', 1, 0),
(833, 52, 'SEG', 1, 0),
(834, 52, 'SIN', 1, 0),
(835, 52, 'SOU', 1, 0),
(836, 52, 'TAB', 1, 0),
(837, 52, 'TAN', 1, 0),
(838, 52, 'TIE', 1, 0),
(839, 52, 'TIN', 1, 0),
(840, 52, 'TIA', 1, 0),
(841, 52, 'TBA', 1, 0),
(842, 52, 'TLP', 1, 0),
(843, 52, 'TMD', 1, 0),
(844, 52, 'VAV', 1, 0),
(845, 52, 'YAM', 1, 0),
(846, 52, 'ZUE', 1, 0),
(847, 53, 'BB', 1, 0),
(848, 53, 'CZ', 1, 0),
(849, 53, 'DN', 1, 0),
(850, 53, 'IS', 1, 0),
(851, 53, 'KA', 1, 0),
(852, 53, 'KK', 1, 0),
(853, 53, 'KZ', 1, 0),
(854, 53, 'LS', 1, 0),
(855, 53, 'ME', 1, 0),
(856, 53, 'OB', 1, 0),
(857, 53, 'PS', 1, 0),
(858, 53, 'PG', 1, 0),
(859, 53, 'SI', 1, 0),
(860, 53, 'SM', 1, 0),
(861, 53, 'SB', 1, 0),
(862, 53, 'SD', 1, 0),
(863, 53, 'VA', 1, 0),
(864, 53, 'VP', 1, 0),
(865, 53, 'VS', 1, 0),
(866, 53, 'ZK', 1, 0),
(867, 53, 'ZA', 1, 0),
(868, 54, 'CA', 1, 0),
(869, 54, 'CD', 1, 0),
(870, 54, 'CI', 1, 0),
(871, 54, 'CH', 1, 0),
(872, 54, 'GR', 1, 0),
(873, 54, 'GU', 1, 0),
(874, 54, 'HO', 1, 0),
(875, 54, 'IJ', 1, 0),
(876, 54, 'LH', 1, 0),
(877, 54, 'LT', 1, 0),
(878, 54, 'MA', 1, 0),
(879, 54, 'PR', 1, 0),
(880, 54, 'SS', 1, 0),
(881, 54, 'SC', 1, 0),
(882, 54, 'VC', 1, 0),
(883, 55, 'F', 1, 0),
(884, 55, 'K', 1, 0),
(885, 55, 'A', 1, 0),
(886, 55, 'I', 1, 0),
(887, 55, 'N', 1, 0),
(888, 55, 'P', 1, 0),
(889, 56, 'U', 1, 0),
(890, 56, 'C', 1, 0),
(891, 56, 'B', 1, 0),
(892, 56, 'K', 1, 0),
(893, 56, 'H', 1, 0),
(894, 56, 'L', 1, 0),
(895, 56, 'T', 1, 0),
(896, 56, 'M', 1, 0),
(897, 56, 'E', 1, 0),
(898, 56, 'P', 1, 0),
(899, 56, 'A', 1, 0),
(900, 56, 'S', 1, 0),
(901, 56, 'J', 1, 0),
(902, 56, 'Z', 1, 0),
(903, 57, 'AR', 1, 0),
(904, 57, 'BH', 1, 0),
(905, 57, 'CO', 1, 0),
(906, 57, 'FO', 1, 0),
(907, 57, 'FR', 1, 0),
(908, 57, 'FY', 1, 0),
(909, 57, 'KO', 1, 0),
(910, 57, 'NO', 1, 0),
(911, 57, 'RI', 1, 0),
(912, 57, 'RK', 1, 0),
(913, 57, 'RO', 1, 0),
(914, 57, 'SO', 1, 0),
(915, 57, 'ST', 1, 0),
(916, 57, 'VK', 1, 0),
(917, 57, 'VJ', 1, 0),
(918, 57, 'VB', 1, 0),
(919, 58, 'S', 1, 0),
(920, 58, 'K', 1, 0),
(921, 58, 'J', 1, 0),
(922, 58, 'O', 1, 0),
(923, 58, 'T', 1, 0),
(924, 59, 'AND', 1, 0),
(925, 59, 'DAV', 1, 0),
(926, 59, 'GEO', 1, 0),
(927, 59, 'JOH', 1, 0),
(928, 59, 'JOS', 1, 0),
(929, 59, 'LUK', 1, 0),
(930, 59, 'MAR', 1, 0),
(931, 59, 'PAT', 1, 0),
(932, 59, 'PAU', 1, 0),
(933, 59, 'PET', 1, 0),
(934, 60, 'DN', 1, 0),
(935, 60, 'AZ', 1, 0),
(936, 60, 'BC', 1, 0),
(937, 60, 'BH', 1, 0),
(938, 60, 'DJ', 1, 0),
(939, 60, 'DU', 1, 0),
(940, 60, 'EL', 1, 0),
(941, 60, 'SY', 1, 0),
(942, 60, 'ET', 1, 0),
(943, 60, 'HM', 1, 0),
(944, 60, 'IN', 1, 0),
(945, 60, 'AL', 1, 0),
(946, 60, 'RO', 1, 0),
(947, 60, 'VE', 1, 0),
(948, 60, 'MT', 1, 0),
(949, 60, 'MN', 1, 0),
(950, 60, 'MC', 1, 0),
(951, 60, 'MP', 1, 0),
(952, 60, 'PD', 1, 0),
(953, 60, 'PR', 1, 0),
(954, 60, 'PP', 1, 0),
(955, 60, 'SL', 1, 0),
(956, 60, 'SM', 1, 0),
(957, 60, 'SH', 1, 0),
(958, 60, 'SC', 1, 0),
(959, 60, 'JO', 1, 0),
(960, 60, 'SJ', 1, 0),
(961, 60, 'PM', 1, 0),
(962, 60, 'SA', 1, 0),
(963, 60, 'ST', 1, 0),
(964, 60, 'SD', 1, 0),
(965, 60, 'VA', 1, 0),
(966, 61, 'AL', 1, 0),
(967, 61, 'AN', 1, 0),
(968, 61, 'BA', 1, 0),
(969, 61, 'BO', 1, 0),
(970, 61, 'CO', 1, 0),
(971, 61, 'DI', 1, 0),
(972, 61, 'ER', 1, 0),
(973, 61, 'LA', 1, 0),
(974, 61, 'LI', 1, 0),
(975, 61, 'MT', 1, 0),
(976, 61, 'MF', 1, 0),
(977, 61, 'OE', 1, 0),
(978, 61, 'VI', 1, 0),
(979, 62, 'AZU', 1, 0),
(980, 62, 'BOL', 1, 0),
(981, 62, 'CAN', 1, 0),
(982, 62, 'CAR', 1, 0),
(983, 62, 'CHI', 1, 0),
(984, 62, 'COT', 1, 0),
(985, 62, 'EOR', 1, 0),
(986, 62, 'ESM', 1, 0),
(987, 62, 'GPS', 1, 0),
(988, 62, 'GUA', 1, 0),
(989, 62, 'IMB', 1, 0),
(990, 62, 'LOJ', 1, 0),
(991, 62, 'LRO', 1, 0),
(992, 62, 'MAN', 1, 0),
(993, 62, 'MSA', 1, 0),
(994, 62, 'NAP', 1, 0),
(995, 62, 'ORE', 1, 0),
(996, 62, 'PAS', 1, 0),
(997, 62, 'PIC', 1, 0),
(998, 62, 'SUC', 1, 0),
(999, 62, 'TUN', 1, 0),
(1000, 62, 'ZCH', 1, 0),
(1001, 63, 'DHY', 1, 0),
(1002, 63, 'BAM', 1, 0),
(1003, 63, 'BHY', 1, 0),
(1004, 63, 'FYM', 1, 0),
(1005, 63, 'GBY', 1, 0),
(1006, 63, 'IDR', 1, 0),
(1007, 63, 'IML', 1, 0),
(1008, 63, 'JZH', 1, 0),
(1009, 63, 'MFY', 1, 0),
(1010, 63, 'MNY', 1, 0),
(1011, 63, 'QHR', 1, 0),
(1012, 63, 'QLY', 1, 0),
(1013, 63, 'WJD', 1, 0),
(1014, 63, 'SHQ', 1, 0),
(1015, 63, 'SWY', 1, 0),
(1016, 63, 'ASW', 1, 0),
(1017, 63, 'ASY', 1, 0),
(1018, 63, 'BSW', 1, 0),
(1019, 63, 'BSD', 1, 0),
(1020, 63, 'DMY', 1, 0),
(1021, 63, 'JNS', 1, 0),
(1022, 63, 'KSH', 1, 0),
(1023, 63, 'MAT', 1, 0),
(1024, 63, 'QIN', 1, 0),
(1025, 63, 'SHS', 1, 0),
(1026, 63, 'SUH', 1, 0),
(1027, 64, 'AH', 1, 0),
(1028, 64, 'CA', 1, 0),
(1029, 64, 'CH', 1, 0),
(1030, 64, 'CU', 1, 0),
(1031, 64, 'LB', 1, 0),
(1032, 64, 'PZ', 1, 0),
(1033, 64, 'UN', 1, 0),
(1034, 64, 'MO', 1, 0),
(1035, 64, 'SM', 1, 0),
(1036, 64, 'SS', 1, 0),
(1037, 64, 'SV', 1, 0),
(1038, 64, 'SA', 1, 0),
(1039, 64, 'SO', 1, 0),
(1040, 64, 'US', 1, 0),
(1041, 65, 'AN', 1, 0),
(1042, 65, 'BN', 1, 0),
(1043, 65, 'BS', 1, 0),
(1044, 65, 'CS', 1, 0),
(1045, 65, 'KN', 1, 0),
(1046, 65, 'LI', 1, 0),
(1047, 65, 'WN', 1, 0),
(1048, 66, 'MA', 1, 0),
(1049, 66, 'KE', 1, 0),
(1050, 66, 'DK', 1, 0),
(1051, 66, 'SK', 1, 0),
(1052, 66, 'DE', 1, 0),
(1053, 66, 'BR', 1, 0),
(1054, 67, 'HA', 1, 0),
(1055, 67, 'HI', 1, 0),
(1056, 67, 'IV', 1, 0),
(1057, 67, 'JA', 1, 0),
(1058, 67, 'JO', 1, 0),
(1059, 67, 'LV', 1, 0),
(1060, 67, 'LA', 1, 0),
(1061, 67, 'PA', 1, 0),
(1062, 67, 'PO', 1, 0),
(1063, 67, 'RA', 1, 0),
(1064, 67, 'SA', 1, 0),
(1065, 67, 'TA', 1, 0),
(1066, 67, 'VA', 1, 0),
(1067, 67, 'VI', 1, 0),
(1068, 67, 'VO', 1, 0),
(1069, 68, 'AF', 1, 0),
(1070, 68, 'AH', 1, 0),
(1071, 68, 'BG', 1, 0),
(1072, 68, 'GB', 1, 0),
(1073, 68, 'HR', 1, 0),
(1074, 68, 'OR', 1, 0),
(1075, 68, 'SM', 1, 0),
(1076, 68, 'SN', 1, 0),
(1077, 68, 'TG', 1, 0),
(1078, 68, 'AA', 1, 0),
(1079, 68, 'DD', 1, 0),
(1080, 71, 'C', 1, 0),
(1081, 71, 'N', 1, 0),
(1082, 71, 'E', 1, 0),
(1083, 71, 'W', 1, 0),
(1084, 71, 'R', 1, 0),
(1085, 72, 'AL', 1, 0),
(1086, 72, 'ES', 1, 0),
(1087, 72, 'IS', 1, 0),
(1088, 72, 'LS', 1, 0),
(1089, 72, 'LA', 1, 0),
(1090, 72, 'OU', 1, 0),
(1091, 73, 'AL', 1, 0),
(1092, 73, 'AQ', 1, 0),
(1093, 73, 'AU', 1, 0),
(1094, 73, 'BR', 1, 0),
(1095, 73, 'BU', 1, 0),
(1096, 73, 'CE', 1, 0),
(1097, 73, 'CH', 1, 0),
(1098, 73, 'CO', 1, 0),
(1099, 73, 'FR', 1, 0),
(1100, 73, 'LA', 1, 0),
(1101, 73, 'LI', 1, 0),
(1102, 73, 'LO', 1, 0),
(1103, 73, 'MI', 1, 0),
(1104, 73, 'NO', 1, 0),
(1105, 73, 'NR', 1, 0),
(1106, 73, 'PA', 1, 0),
(1107, 73, 'PI', 1, 0),
(1108, 73, 'PO', 1, 0),
(1109, 73, 'PR', 1, 0),
(1110, 73, 'RH', 1, 0),
(1111, 73, 'RI', 1, 0),
(1112, 73, 'WE', 1, 0),
(1113, 74, 'Et', 1, 0),
(1114, 74, '01', 1, 0),
(1115, 74, '02', 1, 0),
(1116, 74, '03', 1, 0),
(1117, 74, '04', 1, 0),
(1118, 74, '05', 1, 0),
(1119, 74, '06', 1, 0),
(1120, 74, '07', 1, 0),
(1121, 74, '08', 1, 0),
(1122, 74, '09', 1, 0),
(1123, 74, '10', 1, 0),
(1124, 74, '11', 1, 0),
(1125, 74, '12', 1, 0),
(1126, 74, '13', 1, 0),
(1127, 74, '14', 1, 0),
(1128, 74, '15', 1, 0),
(1129, 74, '16', 1, 0),
(1130, 74, '17', 1, 0),
(1131, 74, '18', 1, 0),
(1132, 74, '19', 1, 0),
(1133, 74, '2A', 1, 0),
(1134, 74, '2B', 1, 0),
(1135, 74, '21', 1, 0),
(1136, 74, '22', 1, 0),
(1137, 74, '23', 1, 0),
(1138, 74, '24', 1, 0),
(1139, 74, '25', 1, 0),
(1140, 74, '26', 1, 0),
(1141, 74, '27', 1, 0),
(1142, 74, '28', 1, 0),
(1143, 74, '29', 1, 0),
(1144, 74, '30', 1, 0),
(1145, 74, '31', 1, 0),
(1146, 74, '32', 1, 0),
(1147, 74, '33', 1, 0),
(1148, 74, '34', 1, 0),
(1149, 74, '35', 1, 0),
(1150, 74, '36', 1, 0),
(1151, 74, '37', 1, 0),
(1152, 74, '38', 1, 0),
(1153, 74, '39', 1, 0),
(1154, 74, '40', 1, 0),
(1155, 74, '41', 1, 0),
(1156, 74, '42', 1, 0),
(1157, 74, '43', 1, 0),
(1158, 74, '44', 1, 0),
(1159, 74, '45', 1, 0),
(1160, 74, '46', 1, 0),
(1161, 74, '47', 1, 0),
(1162, 74, '48', 1, 0),
(1163, 74, '49', 1, 0),
(1164, 74, '50', 1, 0),
(1165, 74, '51', 1, 0),
(1166, 74, '52', 1, 0),
(1167, 74, '53', 1, 0),
(1168, 74, '54', 1, 0),
(1169, 74, '55', 1, 0),
(1170, 74, '56', 1, 0),
(1171, 74, '57', 1, 0),
(1172, 74, '58', 1, 0),
(1173, 74, '59', 1, 0),
(1174, 74, '60', 1, 0),
(1175, 74, '61', 1, 0),
(1176, 74, '62', 1, 0),
(1177, 74, '63', 1, 0),
(1178, 74, '64', 1, 0),
(1179, 74, '65', 1, 0),
(1180, 74, '66', 1, 0),
(1181, 74, '67', 1, 0),
(1182, 74, '68', 1, 0),
(1183, 74, '69', 1, 0),
(1184, 74, '70', 1, 0),
(1185, 74, '71', 1, 0),
(1186, 74, '72', 1, 0),
(1187, 74, '73', 1, 0),
(1188, 74, '74', 1, 0),
(1189, 74, '75', 1, 0),
(1190, 74, '76', 1, 0),
(1191, 74, '77', 1, 0),
(1192, 74, '78', 1, 0),
(1193, 74, '79', 1, 0),
(1194, 74, '80', 1, 0),
(1195, 74, '81', 1, 0),
(1196, 74, '82', 1, 0),
(1197, 74, '83', 1, 0),
(1198, 74, '84', 1, 0),
(1199, 74, '85', 1, 0),
(1200, 74, '86', 1, 0),
(1201, 74, '87', 1, 0),
(1202, 74, '88', 1, 0),
(1203, 74, '89', 1, 0),
(1204, 74, '90', 1, 0),
(1205, 74, '91', 1, 0),
(1206, 74, '92', 1, 0),
(1207, 74, '93', 1, 0),
(1208, 74, '94', 1, 0),
(1209, 74, '95', 1, 0),
(1210, 76, 'M', 1, 0),
(1211, 76, 'T', 1, 0),
(1212, 76, 'I', 1, 0),
(1213, 76, 'V', 1, 0),
(1214, 76, 'S', 1, 0),
(1215, 77, 'C', 1, 0),
(1216, 77, 'K', 1, 0),
(1217, 77, 'A', 1, 0),
(1218, 77, 'P', 1, 0),
(1219, 77, 'D', 1, 0),
(1220, 78, 'ES', 1, 0),
(1221, 78, 'HO', 1, 0),
(1222, 78, 'MO', 1, 0),
(1223, 78, 'NG', 1, 0),
(1224, 78, 'NY', 1, 0),
(1225, 78, 'OI', 1, 0),
(1226, 78, 'OL', 1, 0),
(1227, 78, 'OM', 1, 0),
(1228, 78, 'WN', 1, 0),
(1229, 79, 'BJ', 1, 0),
(1230, 79, 'BS', 1, 0),
(1231, 79, 'BR', 1, 0),
(1232, 79, 'JA', 1, 0),
(1233, 79, 'KA', 1, 0),
(1234, 79, 'KE', 1, 0),
(1235, 79, 'KU', 1, 0),
(1236, 79, 'MA', 1, 0),
(1237, 79, 'LR', 1, 0),
(1238, 79, 'CR', 1, 0),
(1239, 79, 'NB', 1, 0),
(1240, 79, 'UR', 1, 0),
(1241, 79, 'WE', 1, 0),
(1242, 80, 'AB', 1, 0),
(1243, 80, 'AJ', 1, 0),
(1244, 80, 'TB', 1, 0),
(1245, 80, 'GU', 1, 0),
(1246, 80, 'IM', 1, 0),
(1247, 80, 'KA', 1, 0),
(1248, 80, 'KK', 1, 0),
(1249, 80, 'MM', 1, 0),
(1250, 80, 'RL', 1, 0),
(1251, 80, 'SZ', 1, 0),
(1252, 80, 'SJ', 1, 0),
(1253, 80, 'SK', 1, 0),
(1254, 81, 'BAW', 1, 0),
(1255, 81, 'BAY', 1, 0),
(1256, 81, 'BER', 1, 0),
(1257, 81, 'BRG', 1, 0),
(1258, 81, 'BRE', 1, 0),
(1259, 81, 'HAM', 1, 0),
(1260, 81, 'HES', 1, 0),
(1261, 81, 'MEC', 1, 0),
(1262, 81, 'NDS', 1, 0),
(1263, 81, 'NRW', 1, 0),
(1264, 81, 'RHE', 1, 0),
(1265, 81, 'SAR', 1, 0),
(1266, 81, 'SAS', 1, 0),
(1267, 81, 'SAC', 1, 0),
(1268, 81, 'SCN', 1, 0),
(1269, 81, 'THE', 1, 0),
(1270, 82, 'AS', 1, 0),
(1271, 82, 'BA', 1, 0),
(1272, 82, 'CE', 1, 0),
(1273, 82, 'EA', 1, 0),
(1274, 82, 'GA', 1, 0),
(1275, 82, 'NO', 1, 0),
(1276, 82, 'UE', 1, 0),
(1277, 82, 'UW', 1, 0),
(1278, 82, 'VO', 1, 0),
(1279, 82, 'WE', 1, 0),
(1280, 84, 'AT', 1, 0),
(1281, 84, 'CN', 1, 0),
(1282, 84, 'CM', 1, 0),
(1283, 84, 'CR', 1, 0),
(1284, 84, 'EM', 1, 0),
(1285, 84, 'EP', 1, 0),
(1286, 84, 'II', 1, 0),
(1287, 84, 'NA', 1, 0),
(1288, 84, 'PP', 1, 0),
(1289, 84, 'SA', 1, 0),
(1290, 84, 'TH', 1, 0),
(1291, 84, 'WG', 1, 0),
(1292, 84, 'WM', 1, 0),
(1293, 85, 'A', 1, 0),
(1294, 85, 'T', 1, 0),
(1295, 85, 'K', 1, 0),
(1296, 86, 'A', 1, 0),
(1297, 86, 'D', 1, 0),
(1298, 86, 'G', 1, 0),
(1299, 86, 'J', 1, 0),
(1300, 86, 'M', 1, 0),
(1301, 86, 'P', 1, 0),
(1302, 86, 'C', 1, 0),
(1303, 86, 'Q', 1, 0),
(1304, 89, 'AV', 1, 0),
(1305, 89, 'BV', 1, 0),
(1306, 89, 'CM', 1, 0),
(1307, 89, 'CQ', 1, 0),
(1308, 89, 'PE', 1, 0),
(1309, 89, 'PR', 1, 0),
(1310, 89, 'QC', 1, 0),
(1311, 89, 'ES', 1, 0),
(1312, 89, 'GU', 1, 0),
(1313, 89, 'HU', 1, 0),
(1314, 89, 'IZ', 1, 0),
(1315, 89, 'JA', 1, 0),
(1316, 89, 'JU', 1, 0),
(1317, 89, 'QZ', 1, 0),
(1318, 89, 'RE', 1, 0),
(1319, 89, 'ST', 1, 0),
(1320, 89, 'SM', 1, 0),
(1321, 89, 'SR', 1, 0),
(1322, 89, 'SO', 1, 0),
(1323, 89, 'SU', 1, 0),
(1324, 89, 'TO', 1, 0),
(1325, 89, 'ZA', 1, 0),
(1326, 90, 'CNK', 1, 0),
(1327, 90, 'BYL', 1, 0),
(1328, 90, 'BFA', 1, 0),
(1329, 90, 'BOK', 1, 0),
(1330, 90, 'COY', 1, 0),
(1331, 90, 'DBL', 1, 0),
(1332, 90, 'DLB', 1, 0),
(1333, 90, 'DGR', 1, 0),
(1334, 90, 'DBR', 1, 0),
(1335, 90, 'FRN', 1, 0),
(1336, 90, 'FRC', 1, 0),
(1337, 90, 'FRI', 1, 0),
(1338, 90, 'GAO', 1, 0),
(1339, 90, 'GCD', 1, 0),
(1340, 90, 'KNK', 1, 0),
(1341, 90, 'KRN', 1, 0),
(1342, 90, 'KND', 1, 0),
(1343, 90, 'KSD', 1, 0),
(1344, 90, 'KBA', 1, 0),
(1345, 90, 'KDA', 1, 0),
(1346, 90, 'KRA', 1, 0),
(1347, 90, 'LAB', 1, 0),
(1348, 90, 'LLM', 1, 0),
(1349, 90, 'LOL', 1, 0),
(1350, 90, 'MCT', 1, 0),
(1351, 90, 'MAL', 1, 0),
(1352, 90, 'MAM', 1, 0),
(1353, 90, 'MAN', 1, 0),
(1354, 90, 'NZR', 1, 0),
(1355, 90, 'PIT', 1, 0),
(1356, 90, 'SIG', 1, 0),
(1357, 90, 'TLM', 1, 0),
(1358, 90, 'TOG', 1, 0),
(1359, 90, 'YOM', 1, 0),
(1360, 91, 'BF', 1, 0),
(1361, 91, 'BB', 1, 0),
(1362, 91, 'BS', 1, 0),
(1363, 91, 'BL', 1, 0),
(1364, 91, 'CA', 1, 0),
(1365, 91, 'GA', 1, 0),
(1366, 91, 'OI', 1, 0),
(1367, 91, 'QU', 1, 0),
(1368, 91, 'TO', 1, 0),
(1369, 92, 'BW', 1, 0),
(1370, 92, 'CM', 1, 0),
(1371, 92, 'DM', 1, 0),
(1372, 92, 'EC', 1, 0),
(1373, 92, 'EW', 1, 0),
(1374, 92, 'MB', 1, 0),
(1375, 92, 'PM', 1, 0),
(1376, 92, 'PI', 1, 0),
(1377, 92, 'UD', 1, 0),
(1378, 92, 'UT', 1, 0),
(1379, 93, 'AR', 1, 0),
(1380, 93, 'CE', 1, 0),
(1381, 93, 'GA', 1, 0),
(1382, 93, 'ND', 1, 0),
(1383, 93, 'NE', 1, 0),
(1384, 93, 'NO', 1, 0),
(1385, 93, 'OU', 1, 0),
(1386, 93, 'SD', 1, 0),
(1387, 93, 'SE', 1, 0),
(1388, 94, 'F', 1, 0),
(1389, 94, 'M', 1, 0),
(1390, 94, 'S', 1, 0),
(1391, 94, 'H', 1, 0),
(1392, 95, 'AT', 1, 0),
(1393, 95, 'CH', 1, 0),
(1394, 95, 'CL', 1, 0),
(1395, 95, 'CM', 1, 0),
(1396, 95, 'CP', 1, 0),
(1397, 95, 'CR', 1, 0),
(1398, 95, 'PA', 1, 0),
(1399, 95, 'FM', 1, 0),
(1400, 95, 'GD', 1, 0),
(1401, 95, 'IN', 1, 0),
(1402, 95, 'IB', 1, 0),
(1403, 95, 'PZ', 1, 0),
(1404, 95, 'LE', 1, 0),
(1405, 95, 'OC', 1, 0),
(1406, 95, 'OL', 1, 0),
(1407, 95, 'SB', 1, 0),
(1408, 95, 'VA', 1, 0),
(1409, 95, 'YO', 1, 0),
(1410, 96, 'HCW', 1, 0),
(1411, 96, 'HEA', 1, 0),
(1412, 96, 'HSO', 1, 0),
(1413, 96, 'HWC', 1, 0),
(1414, 96, 'KKC', 1, 0),
(1415, 96, 'KKT', 1, 0),
(1416, 96, 'KSS', 1, 0),
(1417, 96, 'KWT', 1, 0),
(1418, 96, 'KYT', 1, 0),
(1419, 96, 'NIS', 1, 0),
(1420, 96, 'NKT', 1, 0),
(1421, 96, 'NNO', 1, 0),
(1422, 96, 'NSK', 1, 0),
(1423, 96, 'NST', 1, 0),
(1424, 96, 'NTP', 1, 0),
(1425, 96, 'NTW', 1, 0),
(1426, 96, 'NTM', 1, 0),
(1427, 96, 'NYL', 1, 0),
(1428, 97, 'BK', 1, 0),
(1429, 97, 'BA', 1, 0),
(1430, 97, 'BE', 1, 0),
(1431, 97, 'BS', 1, 0),
(1432, 97, 'BZ', 1, 0),
(1433, 97, 'BU', 1, 0),
(1434, 97, 'CS', 1, 0),
(1435, 97, 'DE', 1, 0),
(1436, 97, 'DU', 1, 0),
(1437, 97, 'EG', 1, 0),
(1438, 97, 'FE', 1, 0),
(1439, 97, 'GY', 1, 0),
(1440, 97, 'GM', 1, 0),
(1441, 97, 'HB', 1, 0),
(1442, 97, 'HE', 1, 0),
(1443, 97, 'HO', 1, 0),
(1444, 97, 'JN', 1, 0),
(1445, 97, 'KA', 1, 0),
(1446, 97, 'KE', 1, 0),
(1447, 97, 'KO', 1, 0),
(1448, 97, 'MI', 1, 0),
(1449, 97, 'NA', 1, 0),
(1450, 97, 'NO', 1, 0),
(1451, 97, 'NY', 1, 0),
(1452, 97, 'PE', 1, 0),
(1453, 97, 'PS', 1, 0),
(1454, 97, 'SO', 1, 0),
(1455, 97, 'SP', 1, 0),
(1456, 97, 'SS', 1, 0),
(1457, 97, 'SZ', 1, 0),
(1458, 97, 'SE', 1, 0),
(1459, 97, 'SL', 1, 0),
(1460, 97, 'SM', 1, 0),
(1461, 97, 'TA', 1, 0),
(1462, 97, 'TO', 1, 0),
(1463, 97, 'VA', 1, 0),
(1464, 97, 'VE', 1, 0),
(1465, 97, 'ZA', 1, 0),
(1466, 97, 'ZZ', 1, 0),
(1467, 98, 'AL', 1, 0),
(1468, 98, 'HF', 1, 0),
(1469, 98, 'NE', 1, 0),
(1470, 98, 'NV', 1, 0),
(1471, 98, 'SL', 1, 0),
(1472, 98, 'SN', 1, 0),
(1473, 98, 'VF', 1, 0),
(1474, 98, 'VL', 1, 0),
(1475, 99, 'AN', 1, 0),
(1476, 99, 'AP', 1, 0),
(1477, 99, 'AR', 1, 0),
(1478, 99, 'AS', 1, 0),
(1479, 99, 'BI', 1, 0),
(1480, 99, 'CH', 1, 0),
(1481, 99, 'DA', 1, 0),
(1482, 99, 'DM', 1, 0),
(1483, 99, 'DE', 1, 0),
(1484, 99, 'GO', 1, 0),
(1485, 99, 'GU', 1, 0),
(1486, 99, 'HA', 1, 0),
(1487, 99, 'HP', 1, 0),
(1488, 99, 'JA', 1, 0),
(1489, 99, 'KA', 1, 0),
(1490, 99, 'KE', 1, 0),
(1491, 99, 'LI', 1, 0),
(1492, 99, 'MP', 1, 0),
(1493, 99, 'MA', 1, 0),
(1494, 99, 'MN', 1, 0),
(1495, 99, 'ME', 1, 0),
(1496, 99, 'MI', 1, 0),
(1497, 99, 'NA', 1, 0),
(1498, 99, 'OR', 1, 0),
(1499, 99, 'PO', 1, 0),
(1500, 99, 'PU', 1, 0),
(1501, 99, 'RA', 1, 0),
(1502, 99, 'SI', 1, 0),
(1503, 99, 'TN', 1, 0),
(1504, 99, 'TR', 1, 0),
(1505, 99, 'UP', 1, 0),
(1506, 99, 'WB', 1, 0),
(1507, 100, 'AC', 1, 0),
(1508, 100, 'BA', 1, 0),
(1509, 100, 'BT', 1, 0),
(1510, 100, 'BE', 1, 0),
(1511, 100, 'BD', 1, 0),
(1512, 100, 'GO', 1, 0),
(1513, 100, 'JK', 1, 0),
(1514, 100, 'JA', 1, 0),
(1515, 100, 'JB', 1, 0),
(1516, 100, 'JT', 1, 0),
(1517, 100, 'JI', 1, 0),
(1518, 100, 'KB', 1, 0),
(1519, 100, 'KS', 1, 0),
(1520, 100, 'KT', 1, 0),
(1521, 100, 'KI', 1, 0),
(1522, 100, 'BB', 1, 0),
(1523, 100, 'LA', 1, 0),
(1524, 100, 'MA', 1, 0),
(1525, 100, 'MU', 1, 0),
(1526, 100, 'NB', 1, 0),
(1527, 100, 'NT', 1, 0),
(1528, 100, 'PA', 1, 0),
(1529, 100, 'RI', 1, 0),
(1530, 100, 'SN', 1, 0),
(1531, 100, 'ST', 1, 0),
(1532, 100, 'SG', 1, 0),
(1533, 100, 'SA', 1, 0),
(1534, 100, 'SB', 1, 0),
(1535, 100, 'SS', 1, 0),
(1536, 100, 'SU', 1, 0),
(1537, 100, 'YO', 1, 0),
(1538, 101, 'TEH', 1, 0),
(1539, 101, 'QOM', 1, 0),
(1540, 101, 'MKZ', 1, 0),
(1541, 101, 'QAZ', 1, 0),
(1542, 101, 'GIL', 1, 0),
(1543, 101, 'ARD', 1, 0),
(1544, 101, 'ZAN', 1, 0),
(1545, 101, 'EAZ', 1, 0),
(1546, 101, 'WEZ', 1, 0),
(1547, 101, 'KRD', 1, 0),
(1548, 101, 'HMD', 1, 0),
(1549, 101, 'KRM', 1, 0),
(1550, 101, 'ILM', 1, 0),
(1551, 101, 'LRS', 1, 0),
(1552, 101, 'KZT', 1, 0),
(1553, 101, 'CMB', 1, 0),
(1554, 101, 'KBA', 1, 0),
(1555, 101, 'BSH', 1, 0),
(1556, 101, 'FAR', 1, 0),
(1557, 101, 'HRM', 1, 0),
(1558, 101, 'SBL', 1, 0),
(1559, 101, 'KRB', 1, 0),
(1560, 101, 'YZD', 1, 0),
(1561, 101, 'EFH', 1, 0),
(1562, 101, 'SMN', 1, 0),
(1563, 101, 'MZD', 1, 0),
(1564, 101, 'GLS', 1, 0),
(1565, 101, 'NKH', 1, 0),
(1566, 101, 'RKH', 1, 0),
(1567, 101, 'SKH', 1, 0),
(1568, 102, 'BD', 1, 0),
(1569, 102, 'SD', 1, 0),
(1570, 102, 'DY', 1, 0),
(1571, 102, 'WS', 1, 0),
(1572, 102, 'MY', 1, 0),
(1573, 102, 'BA', 1, 0),
(1574, 102, 'DQ', 1, 0),
(1575, 102, 'MU', 1, 0),
(1576, 102, 'QA', 1, 0),
(1577, 102, 'BB', 1, 0),
(1578, 102, 'KB', 1, 0),
(1579, 102, 'NJ', 1, 0),
(1580, 102, 'AB', 1, 0),
(1581, 102, 'NN', 1, 0),
(1582, 102, 'DH', 1, 0),
(1583, 102, 'AL', 1, 0),
(1584, 102, 'TM', 1, 0),
(1585, 102, 'SL', 1, 0),
(1586, 103, 'CA', 1, 0),
(1587, 103, 'CV', 1, 0),
(1588, 103, 'CL', 1, 0),
(1589, 103, 'CO', 1, 0),
(1590, 103, 'DO', 1, 0),
(1591, 103, 'DU', 1, 0),
(1592, 103, 'GA', 1, 0),
(1593, 103, 'KE', 1, 0),
(1594, 103, 'KI', 1, 0),
(1595, 103, 'KL', 1, 0),
(1596, 103, 'LA', 1, 0),
(1597, 103, 'LE', 1, 0),
(1598, 103, 'LI', 1, 0),
(1599, 103, 'LO', 1, 0),
(1600, 103, 'LU', 1, 0),
(1601, 103, 'MA', 1, 0),
(1602, 103, 'ME', 1, 0),
(1603, 103, 'MO', 1, 0),
(1604, 103, 'OF', 1, 0),
(1605, 103, 'RO', 1, 0),
(1606, 103, 'SL', 1, 0),
(1607, 103, 'TI', 1, 0),
(1608, 103, 'WA', 1, 0),
(1609, 103, 'WE', 1, 0),
(1610, 103, 'WX', 1, 0),
(1611, 103, 'WI', 1, 0),
(1612, 104, 'BS', 1, 0),
(1613, 104, 'BH', 1, 0),
(1614, 104, 'EA', 1, 0),
(1615, 104, 'GA', 1, 0),
(1616, 104, 'HA', 1, 0),
(1617, 104, 'JM', 1, 0),
(1618, 104, 'JE', 1, 0),
(1619, 104, 'NE', 1, 0),
(1620, 104, 'SE', 1, 0),
(1621, 104, 'SH', 1, 0),
(1622, 104, 'TA', 1, 0),
(1643, 106, 'CLA', 1, 0),
(1644, 106, 'HAN', 1, 0),
(1645, 106, 'KIN', 1, 0),
(1646, 106, 'MAN', 1, 0),
(1647, 106, 'POR', 1, 0),
(1648, 106, 'AND', 1, 0),
(1649, 106, 'ANN', 1, 0),
(1650, 106, 'CAT', 1, 0),
(1651, 106, 'ELI', 1, 0),
(1652, 106, 'JAM', 1, 0),
(1653, 106, 'MAR', 1, 0),
(1654, 106, 'THO', 1, 0),
(1655, 106, 'TRL', 1, 0),
(1656, 106, 'WML', 1, 0),
(1657, 107, 'AI', 1, 0),
(1658, 107, 'AK', 1, 0),
(1659, 107, 'AO', 1, 0),
(1660, 107, 'CH', 1, 0),
(1661, 107, 'EH', 1, 0),
(1662, 107, 'FK', 1, 0),
(1663, 107, 'FU', 1, 0),
(1664, 107, 'FS', 1, 0),
(1665, 107, 'GI', 1, 0),
(1666, 107, 'GU', 1, 0),
(1667, 107, 'HI', 1, 0),
(1668, 107, 'HO', 1, 0),
(1669, 107, 'HY', 1, 0),
(1670, 107, 'IB', 1, 0),
(1671, 107, 'IS', 1, 0),
(1672, 107, 'IW', 1, 0),
(1673, 107, 'KA', 1, 0),
(1674, 107, 'KG', 1, 0),
(1675, 107, 'KN', 1, 0),
(1676, 107, 'KO', 1, 0),
(1677, 107, 'KU', 1, 0),
(1678, 107, 'KY', 1, 0),
(1679, 107, 'MI', 1, 0),
(1680, 107, 'MY', 1, 0),
(1681, 107, 'MZ', 1, 0),
(1682, 107, 'NA', 1, 0),
(1683, 107, 'NG', 1, 0),
(1684, 107, 'NR', 1, 0),
(1685, 107, 'NI', 1, 0),
(1686, 107, 'OI', 1, 0),
(1687, 107, 'OK', 1, 0),
(1688, 107, 'ON', 1, 0),
(1689, 107, 'OS', 1, 0),
(1690, 107, 'SA', 1, 0),
(1691, 107, 'SI', 1, 0),
(1692, 107, 'SH', 1, 0),
(1693, 107, 'SM', 1, 0),
(1694, 107, 'SZ', 1, 0),
(1695, 107, 'TO', 1, 0),
(1696, 107, 'TS', 1, 0),
(1697, 107, 'TK', 1, 0),
(1698, 107, 'TT', 1, 0),
(1699, 107, 'TY', 1, 0),
(1700, 107, 'WA', 1, 0),
(1701, 107, 'YA', 1, 0),
(1702, 107, 'YM', 1, 0),
(1703, 107, 'YN', 1, 0),
(1704, 108, 'AM', 1, 0),
(1705, 108, 'AJ', 1, 0),
(1706, 108, 'AA', 1, 0),
(1707, 108, 'AB', 1, 0),
(1708, 108, 'AK', 1, 0),
(1709, 108, 'AL', 1, 0),
(1710, 108, 'AT', 1, 0),
(1711, 108, 'AZ', 1, 0),
(1712, 108, 'IR', 1, 0),
(1713, 108, 'JA', 1, 0),
(1714, 108, 'MA', 1, 0),
(1715, 108, 'MD', 1, 0),
(1716, 109, 'AL', 1, 0),
(1717, 109, 'AC', 1, 0),
(1718, 109, 'AM', 1, 0),
(1719, 109, 'AQ', 1, 0),
(1720, 109, 'AS', 1, 0),
(1721, 109, 'AT', 1, 0),
(1722, 109, 'BA', 1, 0),
(1723, 109, 'BY', 1, 0),
(1724, 109, 'MA', 1, 0),
(1725, 109, 'ON', 1, 0),
(1726, 109, 'PA', 1, 0),
(1727, 109, 'QA', 1, 0),
(1728, 109, 'QO', 1, 0),
(1729, 109, 'QY', 1, 0),
(1730, 109, 'SH', 1, 0),
(1731, 109, 'SO', 1, 0),
(1732, 109, 'ZH', 1, 0),
(1733, 110, 'CE', 1, 0),
(1734, 110, 'CO', 1, 0),
(1735, 110, 'EA', 1, 0),
(1736, 110, 'NA', 1, 0),
(1737, 110, 'NE', 1, 0),
(1738, 110, 'NY', 1, 0),
(1739, 110, 'RV', 1, 0),
(1740, 110, 'WE', 1, 0),
(1741, 111, 'AG', 1, 0),
(1742, 111, 'AM', 1, 0),
(1743, 111, 'AK', 1, 0),
(1744, 111, 'AO', 1, 0),
(1745, 111, 'BA', 1, 0),
(1746, 111, 'BE', 1, 0),
(1747, 111, 'bT', 1, 0),
(1748, 111, 'KA', 1, 0),
(1749, 111, 'KR', 1, 0),
(1750, 111, 'KU', 1, 0),
(1751, 111, 'MI', 1, 0),
(1752, 111, 'MN', 1, 0),
(1753, 111, 'ME', 1, 0),
(1754, 111, 'NI', 1, 0),
(1755, 111, 'NO', 1, 0),
(1756, 111, 'ON', 1, 0),
(1757, 111, 'TT', 1, 0),
(1758, 111, 'TR', 1, 0),
(1759, 111, 'TM', 1, 0),
(1760, 111, 'TW', 1, 0),
(1761, 111, 'TE', 1, 0),
(1762, 112, 'CHA', 1, 0),
(1763, 112, 'HAB', 1, 0),
(1764, 112, 'HAN', 1, 0),
(1765, 112, 'HWB', 1, 0),
(1766, 112, 'HWN', 1, 0),
(1767, 112, 'KAN', 1, 0),
(1768, 112, 'PYB', 1, 0),
(1769, 112, 'PYN', 1, 0),
(1770, 112, 'YAN', 1, 0),
(1771, 112, 'NAJ', 1, 0),
(1772, 112, 'PYO', 1, 0),
(1773, 113, 'CO', 1, 0),
(1774, 113, 'CH', 1, 0),
(1775, 113, 'CD', 1, 0),
(1776, 113, 'CB', 1, 0),
(1777, 113, 'CN', 1, 0),
(1778, 113, 'IG', 1, 0),
(1779, 113, 'KA', 1, 0),
(1780, 113, 'KG', 1, 0),
(1781, 113, 'KD', 1, 0),
(1782, 113, 'KB', 1, 0),
(1783, 113, 'KN', 1, 0),
(1784, 113, 'PG', 1, 0),
(1785, 113, 'SO', 1, 0),
(1786, 113, 'TA', 1, 0),
(1787, 113, 'TG', 1, 0),
(1788, 114, 'AL', 1, 0),
(1789, 114, 'AA', 1, 0),
(1790, 114, 'AF', 1, 0),
(1791, 114, 'AJ', 1, 0),
(1792, 114, 'HA', 1, 0),
(1793, 115, 'GB', 1, 0),
(1794, 115, 'B', 1, 0),
(1795, 115, 'C', 1, 0),
(1796, 115, 'J', 1, 0),
(1797, 115, 'N', 1, 0),
(1798, 115, 'O', 1, 0),
(1799, 115, 'T', 1, 0),
(1800, 115, 'Y', 1, 0),
(1801, 116, 'VT', 1, 0),
(1802, 116, 'AT', 1, 0),
(1803, 116, 'BK', 1, 0),
(1804, 116, 'BL', 1, 0),
(1805, 116, 'CH', 1, 0),
(1806, 116, 'HO', 1, 0),
(1807, 116, 'KH', 1, 0),
(1808, 116, 'LM', 1, 0),
(1809, 116, 'LP', 1, 0),
(1810, 116, 'OU', 1, 0),
(1811, 116, 'PH', 1, 0),
(1812, 116, 'SL', 1, 0),
(1813, 116, 'SV', 1, 0),
(1814, 116, 'VI', 1, 0),
(1815, 116, 'XA', 1, 0),
(1816, 116, 'XE', 1, 0),
(1817, 116, 'XI', 1, 0),
(1818, 116, 'XN', 1, 0),
(1819, 117, 'AIZ', 1, 0),
(1820, 117, 'ALU', 1, 0),
(1821, 117, 'BAL', 1, 0),
(1822, 117, 'BAU', 1, 0),
(1823, 117, 'CES', 1, 0),
(1824, 117, 'DGR', 1, 0),
(1825, 117, 'DOB', 1, 0),
(1826, 117, 'GUL', 1, 0),
(1827, 117, 'JEK', 1, 0),
(1828, 117, 'JGR', 1, 0),
(1829, 117, 'KRA', 1, 0),
(1830, 117, 'KUL', 1, 0),
(1831, 117, 'LPR', 1, 0),
(1832, 117, 'LIM', 1, 0),
(1833, 117, 'LUD', 1, 0),
(1834, 117, 'MAD', 1, 0),
(1835, 117, 'OGR', 1, 0),
(1836, 117, 'PRE', 1, 0),
(1837, 117, 'RZR', 1, 0),
(1838, 117, 'RGR', 1, 0),
(1839, 117, 'SAL', 1, 0),
(1840, 117, 'TAL', 1, 0),
(1841, 117, 'TUK', 1, 0),
(1842, 117, 'VLK', 1, 0),
(1843, 117, 'VLM', 1, 0),
(1844, 117, 'VSR', 1, 0),
(1845, 117, 'DGV', 1, 0),
(1846, 117, 'JGV', 1, 0),
(1847, 117, 'JUR', 1, 0),
(1848, 117, 'LPK', 1, 0),
(1849, 117, 'RZK', 1, 0),
(1850, 117, 'RGA', 1, 0),
(1851, 117, 'VSL', 1, 0),
(1852, 119, 'BE', 1, 0),
(1853, 119, 'BB', 1, 0),
(1854, 119, 'LE', 1, 0),
(1855, 119, 'MF', 1, 0),
(1856, 119, 'MS', 1, 0),
(1857, 119, 'MH', 1, 0),
(1858, 119, 'MK', 1, 0),
(1859, 119, 'QN', 1, 0),
(1860, 119, 'QT', 1, 0),
(1861, 119, 'TT', 1, 0),
(1862, 120, 'BI', 1, 0),
(1863, 120, 'BG', 1, 0),
(1864, 120, 'GB', 1, 0),
(1865, 120, 'CM', 1, 0),
(1866, 120, 'GG', 1, 0),
(1867, 120, 'GK', 1, 0),
(1868, 120, 'LO', 1, 0),
(1869, 120, 'MG', 1, 0),
(1870, 120, 'ML', 1, 0),
(1871, 120, 'MS', 1, 0),
(1872, 120, 'NB', 1, 0),
(1873, 120, 'RC', 1, 0),
(1874, 120, 'SN', 1, 0),
(1875, 121, 'AJ', 1, 0),
(1876, 121, 'AZ', 1, 0),
(1877, 121, 'FA', 1, 0),
(1878, 121, 'JA', 1, 0),
(1879, 121, 'JU', 1, 0),
(1880, 121, 'KH', 1, 0),
(1881, 121, 'KU', 1, 0),
(1882, 121, 'NK', 1, 0),
(1883, 121, 'AS', 1, 0),
(1884, 121, 'AW', 1, 0),
(1885, 121, 'ZA', 1, 0),
(1886, 121, 'BA', 1, 0),
(1887, 121, 'DA', 1, 0),
(1888, 121, 'GD', 1, 0),
(1889, 121, 'GY', 1, 0),
(1890, 121, 'MI', 1, 0),
(1891, 121, 'MZ', 1, 0),
(1892, 121, 'SB', 1, 0),
(1893, 121, 'SW', 1, 0),
(1894, 121, 'SU', 1, 0),
(1895, 121, 'TL', 1, 0),
(1896, 121, 'TH', 1, 0),
(1897, 121, 'TU', 1, 0),
(1898, 121, 'YA', 1, 0),
(1899, 121, 'ZL', 1, 0),
(1900, 122, 'V', 1, 0),
(1901, 122, 'A', 1, 0),
(1902, 122, 'B', 1, 0),
(1903, 122, 'N', 1, 0),
(1904, 122, 'E', 1, 0),
(1905, 122, 'M', 1, 0),
(1906, 122, 'T', 1, 0),
(1907, 122, 'R', 1, 0),
(1908, 122, 'G', 1, 0),
(1909, 122, 'L', 1, 0),
(1910, 122, 'P', 1, 0),
(1911, 123, 'AL', 1, 0),
(1912, 123, 'KA', 1, 0),
(1913, 123, 'KL', 1, 0),
(1914, 123, 'MA', 1, 0),
(1915, 123, 'PA', 1, 0),
(1916, 123, 'SI', 1, 0),
(1917, 123, 'TA', 1, 0),
(1918, 123, 'TE', 1, 0),
(1919, 123, 'UT', 1, 0),
(1920, 123, 'VI', 1, 0),
(1921, 124, 'DD', 1, 0),
(1922, 124, 'DC', 1, 0),
(1923, 124, 'DR', 1, 0),
(1924, 124, 'DV', 1, 0),
(1925, 124, 'DW', 1, 0),
(1926, 124, 'GG', 1, 0),
(1927, 124, 'GE', 1, 0),
(1928, 124, 'GR', 1, 0),
(1929, 124, 'LL', 1, 0),
(1930, 124, 'LC', 1, 0),
(1931, 124, 'LE', 1, 0),
(1932, 124, 'LM', 1, 0),
(1933, 125, 'OLF', 1, 0),
(1934, 125, 'ANT', 1, 0),
(1935, 125, 'LAZ', 1, 0),
(1936, 125, 'CAT', 1, 0),
(1937, 125, 'LAW', 1, 0),
(1938, 127, 'AN', 1, 0),
(1939, 127, 'AS', 1, 0),
(1940, 127, 'FN', 1, 0),
(1941, 127, 'MJ', 1, 0),
(1942, 127, 'TM', 1, 0),
(1943, 127, 'TL', 1, 0),
(1944, 128, 'BLK', 1, 0),
(1945, 128, 'BLT', 1, 0),
(1946, 128, 'CKW', 1, 0),
(1947, 128, 'CRD', 1, 0),
(1948, 128, 'CTP', 1, 0),
(1949, 128, 'DDZ', 1, 0),
(1950, 128, 'DWA', 1, 0),
(1951, 128, 'KRG', 1, 0),
(1952, 128, 'KSG', 1, 0),
(1953, 128, 'LKM', 1, 0),
(1954, 128, 'LLG', 1, 0),
(1955, 128, 'MCG', 1, 0),
(1956, 128, 'MGC', 1, 0),
(1957, 128, 'MCH', 1, 0),
(1958, 128, 'MLJ', 1, 0),
(1959, 128, 'MWZ', 1, 0),
(1960, 128, 'MZM', 1, 0),
(1961, 128, 'NTU', 1, 0),
(1962, 128, 'NKB', 1, 0),
(1963, 128, 'NKH', 1, 0),
(1964, 128, 'NSJ', 1, 0),
(1965, 128, 'NTI', 1, 0),
(1966, 128, 'PHL', 1, 0),
(1967, 128, 'RMP', 1, 0),
(1968, 128, 'SLM', 1, 0),
(1969, 128, 'THY', 1, 0),
(1970, 128, 'ZBA', 1, 0),
(1971, 129, 'JO', 1, 0),
(1972, 129, 'KE', 1, 0),
(1973, 129, 'KL', 1, 0),
(1974, 129, 'LA', 1, 0),
(1975, 129, 'ME', 1, 0),
(1976, 129, 'NS', 1, 0),
(1977, 129, 'PA', 1, 0),
(1978, 129, 'PE', 1, 0),
(1979, 129, 'PR', 1, 0),
(1980, 129, 'PP', 1, 0),
(1981, 129, 'SA', 1, 0),
(1982, 129, 'SR', 1, 0),
(1983, 129, 'SE', 1, 0),
(1984, 129, 'TE', 1, 0),
(1985, 129, 'WP', 1, 0),
(1986, 130, 'THU', 1, 0),
(1987, 130, 'THD', 1, 0),
(1988, 130, 'MLU', 1, 0),
(1989, 130, 'MLD', 1, 0),
(1990, 130, 'MAU', 1, 0),
(1991, 130, 'MAD', 1, 0),
(1992, 130, 'FAA', 1, 0),
(1993, 130, 'MAA', 1, 0),
(1994, 130, 'AAU', 1, 0),
(1995, 130, 'AAD', 1, 0),
(1996, 130, 'FEA', 1, 0),
(1997, 130, 'MUA', 1, 0),
(1998, 130, 'NAU', 1, 0),
(1999, 130, 'NAD', 1, 0),
(2000, 130, 'KLH', 1, 0),
(2001, 130, 'HDH', 1, 0),
(2002, 130, 'HAU', 1, 0),
(2003, 130, 'HAD', 1, 0),
(2004, 130, 'FMU', 1, 0),
(2005, 130, 'ADD', 1, 0),
(2006, 131, 'GA', 1, 0),
(2007, 131, 'KY', 1, 0),
(2008, 131, 'KD', 1, 0),
(2009, 131, 'KL', 1, 0),
(2010, 131, 'MP', 1, 0),
(2011, 131, 'SG', 1, 0),
(2012, 131, 'SK', 1, 0),
(2013, 131, 'TB', 1, 0),
(2014, 131, 'CD', 1, 0),
(2015, 132, 'ATT', 1, 0),
(2016, 132, 'BAL', 1, 0),
(2017, 132, 'BGU', 1, 0),
(2018, 132, 'BKK', 1, 0),
(2019, 132, 'BRZ', 1, 0),
(2020, 132, 'BOR', 1, 0),
(2021, 132, 'DIN', 1, 0),
(2022, 132, 'FGU', 1, 0),
(2023, 132, 'FLO', 1, 0),
(2024, 132, 'GDJ', 1, 0),
(2025, 132, 'GZR', 1, 0),
(2026, 132, 'GRG', 1, 0),
(2027, 132, 'GXQ', 1, 0),
(2028, 132, 'HMR', 1, 0),
(2029, 132, 'IKL', 1, 0),
(2030, 132, 'ISL', 1, 0),
(2031, 132, 'KLK', 1, 0),
(2032, 132, 'KRK', 1, 0),
(2033, 132, 'LIJ', 1, 0),
(2034, 132, 'LUQ', 1, 0),
(2035, 132, 'MRS', 1, 0),
(2036, 132, 'MKL', 1, 0),
(2037, 132, 'MXL', 1, 0),
(2038, 132, 'MDN', 1, 0),
(2039, 132, 'MEL', 1, 0),
(2040, 132, 'MGR', 1, 0),
(2041, 132, 'MST', 1, 0),
(2042, 132, 'MQA', 1, 0),
(2043, 132, 'MSI', 1, 0),
(2044, 132, 'MTF', 1, 0),
(2045, 132, 'NAX', 1, 0),
(2046, 132, 'PAO', 1, 0),
(2047, 132, 'PEM', 1, 0),
(2048, 132, 'PIE', 1, 0),
(2049, 132, 'QOR', 1, 0),
(2050, 132, 'QRE', 1, 0),
(2051, 132, 'RAB', 1, 0),
(2052, 132, 'SAF', 1, 0),
(2053, 132, 'SGI', 1, 0),
(2054, 132, 'SLU', 1, 0),
(2055, 132, 'SPB', 1, 0),
(2056, 132, 'SGW', 1, 0),
(2057, 132, 'SVE', 1, 0),
(2058, 132, 'SIG', 1, 0),
(2059, 132, 'SLM', 1, 0),
(2060, 132, 'SWQ', 1, 0),
(2061, 132, 'TXB', 1, 0),
(2062, 132, 'TRX', 1, 0),
(2063, 132, 'VLT', 1, 0),
(2064, 132, 'XGJ', 1, 0),
(2065, 132, 'ZBR', 1, 0),
(2066, 132, 'ZBG', 1, 0),
(2067, 132, 'ZJT', 1, 0),
(2068, 132, 'ZRQ', 1, 0),
(2069, 132, 'FNT', 1, 0),
(2070, 132, 'GHJ', 1, 0),
(2071, 132, 'GHR', 1, 0),
(2072, 132, 'GHS', 1, 0),
(2073, 132, 'KRC', 1, 0),
(2074, 132, 'MUN', 1, 0),
(2075, 132, 'NAD', 1, 0),
(2076, 132, 'QAL', 1, 0),
(2077, 132, 'VIC', 1, 0),
(2078, 132, 'SLA', 1, 0),
(2079, 132, 'SNT', 1, 0),
(2080, 132, 'ZAG', 1, 0),
(2081, 132, 'XEW', 1, 0),
(2082, 132, 'ZEB', 1, 0),
(2083, 133, 'ALG', 1, 0),
(2084, 133, 'ALL', 1, 0),
(2085, 133, 'ALK', 1, 0),
(2086, 133, 'ARN', 1, 0),
(2087, 133, 'AUR', 1, 0),
(2088, 133, 'BKR', 1, 0),
(2089, 133, 'BKN', 1, 0),
(2090, 133, 'BKK', 1, 0),
(2091, 133, 'EBN', 1, 0),
(2092, 133, 'ENT', 1, 0),
(2093, 133, 'EKB', 1, 0),
(2094, 133, 'JBT', 1, 0),
(2095, 133, 'JLT', 1, 0),
(2096, 133, 'JEM', 1, 0),
(2097, 133, 'KIL', 1, 0),
(2098, 133, 'KWJ', 1, 0),
(2099, 133, 'LAE', 1, 0),
(2100, 133, 'LIB', 1, 0),
(2101, 133, 'LKP', 1, 0),
(2102, 133, 'MJR', 1, 0),
(2103, 133, 'MLP', 1, 0),
(2104, 133, 'MJT', 1, 0),
(2105, 133, 'MIL', 1, 0),
(2106, 133, 'NMK', 1, 0),
(2107, 133, 'NAM', 1, 0),
(2108, 133, 'RGL', 1, 0),
(2109, 133, 'RGK', 1, 0),
(2110, 133, 'TOK', 1, 0),
(2111, 133, 'UJA', 1, 0),
(2112, 133, 'UJL', 1, 0),
(2113, 133, 'UTK', 1, 0),
(2114, 133, 'WTH', 1, 0),
(2115, 133, 'WTJ', 1, 0),
(2116, 135, 'AD', 1, 0),
(2117, 135, 'AS', 1, 0),
(2118, 135, 'BR', 1, 0),
(2119, 135, 'DN', 1, 0),
(2120, 135, 'GO', 1, 0),
(2121, 135, 'GM', 1, 0),
(2122, 135, 'HC', 1, 0),
(2123, 135, 'HG', 1, 0),
(2124, 135, 'IN', 1, 0),
(2125, 135, 'TA', 1, 0),
(2126, 135, 'TZ', 1, 0),
(2127, 135, 'TR', 1, 0),
(2128, 135, 'NO', 1, 0),
(2129, 136, 'BR', 1, 0),
(2130, 136, 'CU', 1, 0),
(2131, 136, 'PU', 1, 0),
(2132, 136, 'QB', 1, 0),
(2133, 136, 'VP', 1, 0),
(2134, 136, 'AG', 1, 0),
(2135, 136, 'CC', 1, 0),
(2136, 136, 'RO', 1, 0),
(2137, 136, 'BL', 1, 0),
(2138, 136, 'FL', 1, 0),
(2139, 136, 'GP', 1, 0),
(2140, 136, 'MO', 1, 0),
(2141, 136, 'PA', 1, 0),
(2142, 136, 'PW', 1, 0),
(2143, 136, 'PL', 1, 0),
(2144, 136, 'RR', 1, 0),
(2145, 136, 'SA', 1, 0),
(2146, 138, 'BN', 1, 0),
(2147, 138, 'BS', 1, 0),
(2148, 138, 'CA', 1, 0),
(2149, 138, 'CI', 1, 0),
(2150, 138, 'CH', 1, 0),
(2151, 138, 'CZ', 1, 0),
(2152, 138, 'CL', 1, 0),
(2153, 138, 'DF', 1, 0),
(2154, 138, 'DU', 1, 0),
(2155, 138, 'GA', 1, 0),
(2156, 138, 'GE', 1, 0),
(2157, 138, 'HI', 1, 0),
(2158, 138, 'JA', 1, 0),
(2159, 138, 'ME', 1, 0),
(2160, 138, 'MI', 1, 0),
(2161, 138, 'MO', 1, 0),
(2162, 138, 'NA', 1, 0),
(2163, 138, 'NL', 1, 0),
(2164, 138, 'OA', 1, 0),
(2165, 138, 'PU', 1, 0),
(2166, 138, 'QA', 1, 0),
(2167, 138, 'QR', 1, 0),
(2168, 138, 'SA', 1, 0),
(2169, 138, 'SI', 1, 0),
(2170, 138, 'SO', 1, 0),
(2171, 138, 'TB', 1, 0),
(2172, 138, 'TM', 1, 0),
(2173, 138, 'TL', 1, 0),
(2174, 138, 'VE', 1, 0),
(2175, 138, 'YU', 1, 0),
(2176, 138, 'ZA', 1, 0),
(2177, 139, 'C', 1, 0),
(2178, 139, 'K', 1, 0),
(2179, 139, 'P', 1, 0),
(2180, 139, 'Y', 1, 0),
(2181, 140, 'GA', 1, 0),
(2182, 140, 'CU', 1, 0),
(2183, 140, 'BA', 1, 0),
(2184, 140, 'CA', 1, 0),
(2185, 140, 'ED', 1, 0),
(2186, 140, 'LA', 1, 0),
(2187, 140, 'OR', 1, 0),
(2188, 140, 'SO', 1, 0),
(2189, 140, 'TI', 1, 0),
(2190, 140, 'UN', 1, 0),
(2191, 140, 'SN', 1, 0),
(2192, 141, 'FV', 1, 0),
(2193, 141, 'LC', 1, 0),
(2194, 141, 'MV', 1, 0),
(2195, 141, 'MC', 1, 0),
(2196, 142, '1', 1, 0),
(2197, 142, '035', 1, 0),
(2198, 142, '037', 1, 0),
(2199, 142, '039', 1, 0),
(2200, 142, '041', 1, 0),
(2201, 142, '043', 1, 0),
(2202, 142, '046', 1, 0),
(2203, 142, '047', 1, 0),
(2204, 142, '049', 1, 0),
(2205, 142, '051', 1, 0),
(2206, 142, '053', 1, 0),
(2207, 142, '055', 1, 0),
(2208, 142, '057', 1, 0),
(2209, 142, '059', 1, 0),
(2210, 142, '061', 1, 0),
(2211, 142, '063', 1, 0),
(2212, 142, '064', 1, 0),
(2213, 142, '065', 1, 0),
(2214, 142, '067', 1, 0),
(2215, 142, '069', 1, 0),
(2216, 142, '071', 1, 0),
(2217, 142, '073', 1, 0),
(2218, 143, 'A', 1, 0),
(2219, 143, 'G', 1, 0),
(2220, 143, 'P', 1, 0),
(2221, 144, 'AGD', 1, 0),
(2222, 144, 'HOC', 1, 0),
(2223, 144, 'AZI', 1, 0),
(2224, 144, 'BME', 1, 0),
(2225, 144, 'BSL', 1, 0),
(2226, 144, 'BLM', 1, 0),
(2227, 144, 'CBL', 1, 0),
(2228, 144, 'CHA', 1, 0),
(2229, 144, 'EJA', 1, 0),
(2230, 144, 'EKS', 1, 0),
(2231, 144, 'ERA', 1, 0),
(2232, 144, 'ESS', 1, 0),
(2233, 144, 'FES', 1, 0),
(2234, 144, 'FIG', 1, 0),
(2235, 144, 'GLM', 1, 0),
(2236, 144, 'IFR', 1, 0),
(2237, 144, 'KEN', 1, 0),
(2238, 144, 'KHM', 1, 0),
(2239, 144, 'KHN', 1, 0),
(2240, 144, 'KHO', 1, 0),
(2241, 144, 'LYN', 1, 0),
(2242, 144, 'LAR', 1, 0),
(2243, 144, 'MRK', 1, 0),
(2244, 144, 'MKN', 1, 0),
(2245, 144, 'NAD', 1, 0),
(2246, 144, 'ORZ', 1, 0),
(2247, 144, 'OUJ', 1, 0),
(2248, 144, 'RSA', 1, 0),
(2249, 144, 'SAF', 1, 0),
(2250, 144, 'SET', 1, 0),
(2251, 144, 'SKA', 1, 0),
(2252, 144, 'TGR', 1, 0),
(2253, 144, 'TAN', 1, 0),
(2254, 144, 'TAO', 1, 0),
(2255, 144, 'TRD', 1, 0),
(2256, 144, 'TAT', 1, 0),
(2257, 144, 'TAZ', 1, 0),
(2258, 144, 'TET', 1, 0),
(2259, 144, 'TIZ', 1, 0),
(2260, 144, 'ADK', 1, 0),
(2261, 144, 'BJD', 1, 0),
(2262, 144, 'ESM', 1, 0),
(2263, 145, 'CD', 1, 0),
(2264, 145, 'GZ', 1, 0),
(2265, 145, 'IN', 1, 0),
(2266, 145, 'MN', 1, 0),
(2267, 145, 'MC', 1, 0),
(2268, 145, 'MP', 1, 0),
(2269, 145, 'NA', 1, 0),
(2270, 145, 'NI', 1, 0),
(2271, 145, 'SO', 1, 0),
(2272, 145, 'TE', 1, 0),
(2273, 145, 'ZA', 1, 0),
(2274, 146, 'AY', 1, 0),
(2275, 146, 'BG', 1, 0),
(2276, 146, 'MG', 1, 0),
(2277, 146, 'MD', 1, 0),
(2278, 146, 'SG', 1, 0),
(2279, 146, 'TN', 1, 0);
INSERT INTO `[[dbprefix]]zones` VALUES
(2280, 146, 'YG', 1, 0),
(2281, 146, 'CH', 1, 0),
(2282, 146, 'KC', 1, 0),
(2283, 146, 'KH', 1, 0),
(2284, 146, 'KN', 1, 0),
(2285, 146, 'MN', 1, 0),
(2286, 146, 'RK', 1, 0),
(2287, 146, 'SH', 1, 0),
(2288, 147, 'CA', 1, 0),
(2289, 147, 'ER', 1, 0),
(2290, 147, 'HA', 1, 0),
(2291, 147, 'KR', 1, 0),
(2292, 147, 'KV', 1, 0),
(2293, 147, 'KH', 1, 0),
(2294, 147, 'KU', 1, 0),
(2295, 147, 'OW', 1, 0),
(2296, 147, 'OK', 1, 0),
(2297, 147, 'OT', 1, 0),
(2298, 147, 'ON', 1, 0),
(2299, 147, 'OO', 1, 0),
(2300, 147, 'OJ', 1, 0),
(2301, 148, 'AO', 1, 0),
(2302, 148, 'AA', 1, 0),
(2303, 148, 'AT', 1, 0),
(2304, 148, 'AI', 1, 0),
(2305, 148, 'BA', 1, 0),
(2306, 148, 'BO', 1, 0),
(2307, 148, 'BU', 1, 0),
(2308, 148, 'DE', 1, 0),
(2309, 148, 'EW', 1, 0),
(2310, 148, 'IJ', 1, 0),
(2311, 148, 'ME', 1, 0),
(2312, 148, 'NI', 1, 0),
(2313, 148, 'UA', 1, 0),
(2314, 148, 'YA', 1, 0),
(2315, 149, 'BA', 1, 0),
(2316, 149, 'BH', 1, 0),
(2317, 149, 'DH', 1, 0),
(2318, 149, 'GA', 1, 0),
(2319, 149, 'JA', 1, 0),
(2320, 149, 'KA', 1, 0),
(2321, 149, 'KO', 1, 0),
(2322, 149, 'LU', 1, 0),
(2323, 149, 'MA', 1, 0),
(2324, 149, 'ME', 1, 0),
(2325, 149, 'NA', 1, 0),
(2326, 149, 'RA', 1, 0),
(2327, 149, 'SA', 1, 0),
(2328, 149, 'SE', 1, 0),
(2329, 150, 'DR', 1, 0),
(2330, 150, 'FL', 1, 0),
(2331, 150, 'FR', 1, 0),
(2332, 150, 'GE', 1, 0),
(2333, 150, 'GR', 1, 0),
(2334, 150, 'LI', 1, 0),
(2335, 150, 'NB', 1, 0),
(2336, 150, 'NH', 1, 0),
(2337, 150, 'OV', 1, 0),
(2338, 150, 'UT', 1, 0),
(2339, 150, 'ZE', 1, 0),
(2340, 150, 'ZH', 1, 0),
(2341, 152, 'L', 1, 0),
(2342, 152, 'N', 1, 0),
(2343, 152, 'S', 1, 0),
(2344, 153, 'AUK', 1, 0),
(2345, 153, 'BOP', 1, 0),
(2346, 153, 'CAN', 1, 0),
(2347, 153, 'COR', 1, 0),
(2348, 153, 'GIS', 1, 0),
(2349, 153, 'FIO', 1, 0),
(2350, 153, 'HKB', 1, 0),
(2351, 153, 'MBH', 1, 0),
(2352, 153, 'MWT', 1, 0),
(2353, 153, 'MCM', 1, 0),
(2354, 153, 'NSN', 1, 0),
(2355, 153, 'NTL', 1, 0),
(2356, 153, 'OTA', 1, 0),
(2357, 153, 'STL', 1, 0),
(2358, 153, 'TKI', 1, 0),
(2359, 153, 'WGN', 1, 0),
(2360, 153, 'WKO', 1, 0),
(2361, 153, 'WAI', 1, 0),
(2362, 153, 'WTC', 1, 0),
(2363, 154, 'AN', 1, 0),
(2364, 154, 'AS', 1, 0),
(2365, 154, 'BO', 1, 0),
(2366, 154, 'CA', 1, 0),
(2367, 154, 'CI', 1, 0),
(2368, 154, 'CO', 1, 0),
(2369, 154, 'ES', 1, 0),
(2370, 154, 'GR', 1, 0),
(2371, 154, 'JI', 1, 0),
(2372, 154, 'LE', 1, 0),
(2373, 154, 'MD', 1, 0),
(2374, 154, 'MN', 1, 0),
(2375, 154, 'MS', 1, 0),
(2376, 154, 'MT', 1, 0),
(2377, 154, 'NS', 1, 0),
(2378, 154, 'RS', 1, 0),
(2379, 154, 'RI', 1, 0),
(2380, 155, 'AG', 1, 0),
(2381, 155, 'DF', 1, 0),
(2382, 155, 'DS', 1, 0),
(2383, 155, 'MA', 1, 0),
(2384, 155, 'NM', 1, 0),
(2385, 155, 'TH', 1, 0),
(2386, 155, 'TL', 1, 0),
(2387, 155, 'ZD', 1, 0),
(2388, 156, 'AB', 1, 0),
(2389, 156, 'CT', 1, 0),
(2390, 156, 'AD', 1, 0),
(2391, 156, 'AK', 1, 0),
(2392, 156, 'AN', 1, 0),
(2393, 156, 'BC', 1, 0),
(2394, 156, 'BY', 1, 0),
(2395, 156, 'BN', 1, 0),
(2396, 156, 'BO', 1, 0),
(2397, 156, 'CR', 1, 0),
(2398, 156, 'DE', 1, 0),
(2399, 156, 'EB', 1, 0),
(2400, 156, 'ED', 1, 0),
(2401, 156, 'EK', 1, 0),
(2402, 156, 'EN', 1, 0),
(2403, 156, 'GO', 1, 0),
(2404, 156, 'IM', 1, 0),
(2405, 156, 'JI', 1, 0),
(2406, 156, 'KD', 1, 0),
(2407, 156, 'KN', 1, 0),
(2408, 156, 'KT', 1, 0),
(2409, 156, 'KE', 1, 0),
(2410, 156, 'KO', 1, 0),
(2411, 156, 'KW', 1, 0),
(2412, 156, 'LA', 1, 0),
(2413, 156, 'NA', 1, 0),
(2414, 156, 'NI', 1, 0),
(2415, 156, 'OG', 1, 0),
(2416, 156, 'ONG', 1, 0),
(2417, 156, 'OS', 1, 0),
(2418, 156, 'OY', 1, 0),
(2419, 156, 'PL', 1, 0),
(2420, 156, 'RI', 1, 0),
(2421, 156, 'SO', 1, 0),
(2422, 156, 'TA', 1, 0),
(2423, 156, 'YO', 1, 0),
(2424, 156, 'ZA', 1, 0),
(2425, 159, 'N', 1, 0),
(2426, 159, 'R', 1, 0),
(2427, 159, 'S', 1, 0),
(2428, 159, 'T', 1, 0),
(2429, 160, 'AK', 1, 0),
(2430, 160, 'AA', 1, 0),
(2431, 160, 'BU', 1, 0),
(2432, 160, 'FM', 1, 0),
(2433, 160, 'HM', 1, 0),
(2434, 160, 'HL', 1, 0),
(2435, 160, 'MR', 1, 0),
(2436, 160, 'NT', 1, 0),
(2437, 160, 'NL', 1, 0),
(2438, 160, 'OF', 1, 0),
(2439, 160, 'OP', 1, 0),
(2440, 160, 'OL', 1, 0),
(2441, 160, 'RL', 1, 0),
(2442, 160, 'ST', 1, 0),
(2443, 160, 'SJ', 1, 0),
(2444, 160, 'SV', 1, 0),
(2445, 160, 'TM', 1, 0),
(2446, 160, 'TR', 1, 0),
(2447, 160, 'VA', 1, 0),
(2448, 160, 'VF', 1, 0),
(2449, 161, 'DA', 1, 0),
(2450, 161, 'BA', 1, 0),
(2451, 161, 'WU', 1, 0),
(2452, 161, 'SH', 1, 0),
(2453, 161, 'ZA', 1, 0),
(2454, 161, 'MA', 1, 0),
(2455, 161, 'MU', 1, 0),
(2456, 161, 'ZU', 1, 0),
(2457, 162, 'B', 1, 0),
(2458, 162, 'T', 1, 0),
(2459, 162, 'I', 1, 0),
(2460, 162, 'N', 1, 0),
(2461, 162, 'P', 1, 0),
(2462, 162, 'S', 1, 0),
(2463, 163, 'AM', 1, 0),
(2464, 163, 'AR', 1, 0),
(2465, 163, 'AN', 1, 0),
(2466, 163, 'HA', 1, 0),
(2467, 163, 'KA', 1, 0),
(2468, 163, 'KO', 1, 0),
(2469, 163, 'ME', 1, 0),
(2470, 163, 'NA', 1, 0),
(2471, 163, 'NG', 1, 0),
(2472, 163, 'ND', 1, 0),
(2473, 163, 'NT', 1, 0),
(2474, 163, 'NC', 1, 0),
(2475, 163, 'NR', 1, 0),
(2476, 163, 'NW', 1, 0),
(2477, 163, 'PE', 1, 0),
(2478, 163, 'SO', 1, 0),
(2479, 164, 'BT', 1, 0),
(2480, 164, 'CH', 1, 0),
(2481, 164, 'CC', 1, 0),
(2482, 164, 'CL', 1, 0),
(2483, 164, 'DA', 1, 0),
(2484, 164, 'HE', 1, 0),
(2485, 164, 'LS', 1, 0),
(2486, 164, 'PA', 1, 0),
(2487, 164, 'SB', 1, 0),
(2488, 164, 'VG', 1, 0),
(2489, 165, 'BV', 1, 0),
(2490, 165, 'CE', 1, 0),
(2491, 165, 'CH', 1, 0),
(2492, 165, 'EH', 1, 0),
(2493, 165, 'EB', 1, 0),
(2494, 165, 'ES', 1, 0),
(2495, 165, 'EN', 1, 0),
(2496, 165, 'GU', 1, 0),
(2497, 165, 'MD', 1, 0),
(2498, 165, 'MN', 1, 0),
(2499, 165, 'MB', 1, 0),
(2500, 165, 'MR', 1, 0),
(2501, 165, 'NC', 1, 0),
(2502, 165, 'NI', 1, 0),
(2503, 165, 'NO', 1, 0),
(2504, 165, 'SA', 1, 0),
(2505, 165, 'SH', 1, 0),
(2506, 165, 'WE', 1, 0),
(2507, 165, 'WH', 1, 0),
(2508, 165, 'WB', 1, 0),
(2509, 166, 'AG', 1, 0),
(2510, 166, 'AN', 1, 0),
(2511, 166, 'AM', 1, 0),
(2512, 166, 'AS', 1, 0),
(2513, 166, 'BO', 1, 0),
(2514, 166, 'CG', 1, 0),
(2515, 166, 'CZ', 1, 0),
(2516, 166, 'CN', 1, 0),
(2517, 166, 'CE', 1, 0),
(2518, 166, 'CC', 1, 0),
(2519, 166, 'CD', 1, 0),
(2520, 166, 'GU', 1, 0),
(2521, 166, 'IT', 1, 0),
(2522, 166, 'MI', 1, 0),
(2523, 166, 'NE', 1, 0),
(2524, 166, 'PA', 1, 0),
(2525, 166, 'PH', 1, 0),
(2526, 166, 'SP', 1, 0),
(2527, 167, 'AM', 1, 0),
(2528, 167, 'AN', 1, 0),
(2529, 167, 'AP', 1, 0),
(2530, 167, 'AR', 1, 0),
(2531, 167, 'AY', 1, 0),
(2532, 167, 'CJ', 1, 0),
(2533, 167, 'CL', 1, 0),
(2534, 167, 'CU', 1, 0),
(2535, 167, 'HV', 1, 0),
(2536, 167, 'HO', 1, 0),
(2537, 167, 'IC', 1, 0),
(2538, 167, 'JU', 1, 0),
(2539, 167, 'LD', 1, 0),
(2540, 167, 'LY', 1, 0),
(2541, 167, 'LI', 1, 0),
(2542, 167, 'LO', 1, 0),
(2543, 167, 'MD', 1, 0),
(2544, 167, 'MO', 1, 0),
(2545, 167, 'PA', 1, 0),
(2546, 167, 'PI', 1, 0),
(2547, 167, 'PU', 1, 0),
(2548, 167, 'SM', 1, 0),
(2549, 167, 'TA', 1, 0),
(2550, 167, 'TU', 1, 0),
(2551, 167, 'UC', 1, 0),
(2552, 168, 'ABR', 1, 0),
(2553, 168, 'ANO', 1, 0),
(2554, 168, 'ASU', 1, 0),
(2555, 168, 'AKL', 1, 0),
(2556, 168, 'ALB', 1, 0),
(2557, 168, 'ANT', 1, 0),
(2558, 168, 'APY', 1, 0),
(2559, 168, 'AUR', 1, 0),
(2560, 168, 'BAS', 1, 0),
(2561, 168, 'BTA', 1, 0),
(2562, 168, 'BTE', 1, 0),
(2563, 168, 'BTG', 1, 0),
(2564, 168, 'BLR', 1, 0),
(2565, 168, 'BEN', 1, 0),
(2566, 168, 'BOL', 1, 0),
(2567, 168, 'BUK', 1, 0),
(2568, 168, 'BUL', 1, 0),
(2569, 168, 'CAG', 1, 0),
(2570, 168, 'CNO', 1, 0),
(2571, 168, 'CSU', 1, 0),
(2572, 168, 'CAM', 1, 0),
(2573, 168, 'CAP', 1, 0),
(2574, 168, 'CAT', 1, 0),
(2575, 168, 'CAV', 1, 0),
(2576, 168, 'CEB', 1, 0),
(2577, 168, 'CMP', 1, 0),
(2578, 168, 'DNO', 1, 0),
(2579, 168, 'DSU', 1, 0),
(2580, 168, 'DOR', 1, 0),
(2581, 168, 'ESA', 1, 0),
(2582, 168, 'GUI', 1, 0),
(2583, 168, 'IFU', 1, 0),
(2584, 168, 'INO', 1, 0),
(2585, 168, 'ISU', 1, 0),
(2586, 168, 'ILO', 1, 0),
(2587, 168, 'ISA', 1, 0),
(2588, 168, 'KAL', 1, 0),
(2589, 168, 'LAG', 1, 0),
(2590, 168, 'LNO', 1, 0),
(2591, 168, 'LSU', 1, 0),
(2592, 168, 'UNI', 1, 0),
(2593, 168, 'LEY', 1, 0),
(2594, 168, 'MAG', 1, 0),
(2595, 168, 'MRN', 1, 0),
(2596, 168, 'MSB', 1, 0),
(2597, 168, 'MIC', 1, 0),
(2598, 168, 'MIR', 1, 0),
(2599, 168, 'MSC', 1, 0),
(2600, 168, 'MOR', 1, 0),
(2601, 168, 'MOP', 1, 0),
(2602, 168, 'NOC', 1, 0),
(2603, 168, 'NOR', 1, 0),
(2604, 168, 'NCT', 1, 0),
(2605, 168, 'NSM', 1, 0),
(2606, 168, 'NEC', 1, 0),
(2607, 168, 'NVZ', 1, 0),
(2608, 168, 'PLW', 1, 0),
(2609, 168, 'PMP', 1, 0),
(2610, 168, 'PNG', 1, 0),
(2611, 168, 'QZN', 1, 0),
(2612, 168, 'QRN', 1, 0),
(2613, 168, 'RIZ', 1, 0),
(2614, 168, 'ROM', 1, 0),
(2615, 168, 'SMR', 1, 0),
(2616, 168, 'SRG', 1, 0),
(2617, 168, 'SQJ', 1, 0),
(2618, 168, 'SRS', 1, 0),
(2619, 168, 'SCO', 1, 0),
(2620, 168, 'SLE', 1, 0),
(2621, 168, 'SKU', 1, 0),
(2622, 168, 'SLU', 1, 0),
(2623, 168, 'SNO', 1, 0),
(2624, 168, 'SSU', 1, 0),
(2625, 168, 'TAR', 1, 0),
(2626, 168, 'TAW', 1, 0),
(2627, 168, 'ZBL', 1, 0),
(2628, 168, 'ZNO', 1, 0),
(2629, 168, 'ZSU', 1, 0),
(2630, 168, 'ZSI', 1, 0),
(2631, 170, 'DO', 1, 0),
(2632, 170, 'KP', 1, 0),
(2633, 170, 'LO', 1, 0),
(2634, 170, 'LL', 1, 0),
(2635, 170, 'LU', 1, 0),
(2636, 170, 'ML', 1, 0),
(2637, 170, 'MZ', 1, 0),
(2638, 170, 'OP', 1, 0),
(2639, 170, 'PP', 1, 0),
(2640, 170, 'PL', 1, 0),
(2641, 170, 'PM', 1, 0),
(2642, 170, 'SL', 1, 0),
(2643, 170, 'SW', 1, 0),
(2644, 170, 'WM', 1, 0),
(2645, 170, 'WP', 1, 0),
(2646, 170, 'ZA', 1, 0),
(2647, 198, 'P', 1, 0),
(2648, 198, 'M', 1, 0),
(2649, 171, 'AC', 1, 0),
(2650, 171, 'AV', 1, 0),
(2651, 171, 'BE', 1, 0),
(2652, 171, 'BR', 1, 0),
(2653, 171, 'BA', 1, 0),
(2654, 171, 'CB', 1, 0),
(2655, 171, 'CO', 1, 0),
(2656, 171, 'EV', 1, 0),
(2657, 171, 'FA', 1, 0),
(2658, 171, 'GU', 1, 0),
(2659, 171, 'LE', 1, 0),
(2660, 171, 'LI', 1, 0),
(2661, 171, 'ME', 1, 0),
(2662, 171, 'PO', 1, 0),
(2663, 171, 'PR', 1, 0),
(2664, 171, 'SA', 1, 0),
(2665, 171, 'SE', 1, 0),
(2666, 171, 'VC', 1, 0),
(2667, 171, 'VR', 1, 0),
(2668, 171, 'VI', 1, 0),
(2669, 173, 'DW', 1, 0),
(2670, 173, 'GW', 1, 0),
(2671, 173, 'JM', 1, 0),
(2672, 173, 'KR', 1, 0),
(2673, 173, 'WK', 1, 0),
(2674, 173, 'RN', 1, 0),
(2675, 173, 'JB', 1, 0),
(2676, 173, 'MS', 1, 0),
(2677, 173, 'UD', 1, 0),
(2678, 173, 'UL', 1, 0),
(2679, 175, 'AB', 1, 0),
(2680, 175, 'AR', 1, 0),
(2681, 175, 'AG', 1, 0),
(2682, 175, 'BC', 1, 0),
(2683, 175, 'BH', 1, 0),
(2684, 175, 'BN', 1, 0),
(2685, 175, 'BT', 1, 0),
(2686, 175, 'BV', 1, 0),
(2687, 175, 'BR', 1, 0),
(2688, 175, 'B', 1, 0),
(2689, 175, 'BZ', 1, 0),
(2690, 175, 'CS', 1, 0),
(2691, 175, 'CL', 1, 0),
(2692, 175, 'CJ', 1, 0),
(2693, 175, 'CT', 1, 0),
(2694, 175, 'CV', 1, 0),
(2695, 175, 'DB', 1, 0),
(2696, 175, 'DJ', 1, 0),
(2697, 175, 'GL', 1, 0),
(2698, 175, 'GR', 1, 0),
(2699, 175, 'GJ', 1, 0),
(2700, 175, 'HR', 1, 0),
(2701, 175, 'HD', 1, 0),
(2702, 175, 'IL', 1, 0),
(2703, 175, 'IS', 1, 0),
(2704, 175, 'IF', 1, 0),
(2705, 175, 'MM', 1, 0),
(2706, 175, 'MH', 1, 0),
(2707, 175, 'MS', 1, 0),
(2708, 175, 'NT', 1, 0),
(2709, 175, 'OT', 1, 0),
(2710, 175, 'PH', 1, 0),
(2711, 175, 'SM', 1, 0),
(2712, 175, 'SJ', 1, 0),
(2713, 175, 'SB', 1, 0),
(2714, 175, 'SV', 1, 0),
(2715, 175, 'TR', 1, 0),
(2716, 175, 'TM', 1, 0),
(2717, 175, 'TL', 1, 0),
(2718, 175, 'VS', 1, 0),
(2719, 175, 'VL', 1, 0),
(2720, 175, 'VN', 1, 0),
(2721, 176, 'KK', 1, 0),
(2722, 176, 'AB', 1, 0),
(2723, 176, 'CHU', 1, 0),
(2724, 176, 'ARK', 1, 0),
(2725, 176, 'AST', 1, 0),
(2726, 176, 'ALT', 1, 0),
(2727, 176, 'BEL', 1, 0),
(2728, 176, 'YEV', 1, 0),
(2729, 176, 'AMU', 1, 0),
(2730, 176, 'BRY', 1, 0),
(2731, 176, 'CU', 1, 0),
(2732, 176, 'CHE', 1, 0),
(2733, 176, 'KC', 1, 0),
(2734, 176, 'ZAB', 1, 0),
(2735, 176, 'TDN', 1, 0),
(2736, 176, 'KL', 1, 0),
(2737, 176, 'MOS', 1, 0),
(2738, 176, 'AL', 1, 0),
(2739, 176, 'CE', 1, 0),
(2740, 176, 'IRK', 1, 0),
(2741, 176, 'IVA', 1, 0),
(2742, 176, 'UD', 1, 0),
(2743, 176, 'KGD', 1, 0),
(2744, 176, 'KLU', 1, 0),
(2745, 176, 'KIR', 1, 0),
(2746, 176, 'TA', 1, 0),
(2747, 176, 'KEM', 1, 0),
(2748, 176, 'KHA', 1, 0),
(2749, 176, 'KHM', 1, 0),
(2750, 176, 'KOS', 1, 0),
(2751, 176, 'KDA', 1, 0),
(2752, 176, 'KYA', 1, 0),
(2753, 176, 'KPO', 1, 0),
(2754, 176, 'KGN', 1, 0),
(2755, 176, 'KRS', 1, 0),
(2756, 176, 'TY', 1, 0),
(2757, 176, 'LIP', 1, 0),
(2758, 176, 'MAG', 1, 0),
(2759, 176, 'DA', 1, 0),
(2760, 176, 'AD', 1, 0),
(2761, 176, 'MOW', 1, 0),
(2762, 176, 'MUR', 1, 0),
(2763, 176, 'KB', 1, 0),
(2764, 176, 'NEN', 1, 0),
(2765, 176, 'IN', 1, 0),
(2766, 176, 'NIZ', 1, 0),
(2767, 176, 'NGR', 1, 0),
(2768, 176, 'NVS', 1, 0),
(2769, 176, 'OMS', 1, 0),
(2770, 176, 'ORL', 1, 0),
(2771, 176, 'ORE', 1, 0),
(2772, 176, 'LEN', 1, 0),
(2773, 176, 'PNZ', 1, 0),
(2774, 176, 'PER', 1, 0),
(2775, 176, 'KAM', 1, 0),
(2776, 176, 'KR', 1, 0),
(2777, 176, 'PSK', 1, 0),
(2778, 176, 'ROS', 1, 0),
(2779, 176, 'RYA', 1, 0),
(2780, 176, 'YAN', 1, 0),
(2781, 176, 'SAM', 1, 0),
(2782, 176, 'MO', 1, 0),
(2783, 176, 'SAR', 1, 0),
(2784, 176, 'SMO', 1, 0),
(2785, 176, 'SPE', 1, 0),
(2786, 176, 'STA', 1, 0),
(2787, 176, 'KO', 1, 0),
(2788, 176, 'TAM', 1, 0),
(2789, 176, 'TOM', 1, 0),
(2790, 176, 'TUL', 1, 0),
(2791, 176, 'EO', 1, 0),
(2792, 176, 'TVE', 1, 0),
(2793, 176, 'TYU', 1, 0),
(2794, 176, 'BA', 1, 0),
(2795, 176, 'ULY', 1, 0),
(2796, 176, 'BU', 1, 0),
(2797, 176, 'UOB', 1, 0),
(2798, 176, 'SE', 1, 0),
(2799, 176, 'VLA', 1, 0),
(2800, 176, 'PRI', 1, 0),
(2801, 176, 'VGG', 1, 0),
(2802, 176, 'VLG', 1, 0),
(2803, 176, 'VOR', 1, 0),
(2804, 176, 'SAK', 1, 0),
(2805, 176, 'SA', 1, 0),
(2806, 176, 'YAR', 1, 0),
(2807, 176, 'SVE', 1, 0),
(2808, 176, 'ME', 1, 0),
(2809, 177, 'BU', 1, 0),
(2810, 177, 'BY', 1, 0),
(2811, 177, 'CY', 1, 0),
(2812, 177, 'GK', 1, 0),
(2813, 177, 'GS', 1, 0),
(2814, 177, 'GT', 1, 0),
(2815, 177, 'KG', 1, 0),
(2816, 177, 'KY', 1, 0),
(2817, 177, 'KR', 1, 0),
(2818, 177, 'KV', 1, 0),
(2819, 177, 'RU', 1, 0),
(2820, 177, 'UM', 1, 0),
(2821, 178, 'CCN', 1, 0),
(2822, 178, 'SAS', 1, 0),
(2823, 178, 'SGB', 1, 0),
(2824, 178, 'SGG', 1, 0),
(2825, 178, 'SJW', 1, 0),
(2826, 178, 'SJC', 1, 0),
(2827, 178, 'SJF', 1, 0),
(2828, 178, 'SMC', 1, 0),
(2829, 178, 'CAP', 1, 0),
(2830, 178, 'CHA', 1, 0),
(2831, 178, 'SPB', 1, 0),
(2832, 178, 'STL', 1, 0),
(2833, 178, 'STM', 1, 0),
(2834, 178, 'TPP', 1, 0),
(2835, 179, 'AR', 1, 0),
(2836, 179, 'CA', 1, 0),
(2837, 179, 'CH', 1, 0),
(2838, 179, 'DA', 1, 0),
(2839, 179, 'DE', 1, 0),
(2840, 179, 'GI', 1, 0),
(2841, 179, 'LA', 1, 0),
(2842, 179, 'MI', 1, 0),
(2843, 179, 'PR', 1, 0),
(2844, 179, 'SO', 1, 0),
(2845, 179, 'VF', 1, 0),
(2846, 180, 'C', 1, 0),
(2847, 180, 'R', 1, 0),
(2848, 180, 'A', 1, 0),
(2849, 180, 'D', 1, 0),
(2850, 180, 'G', 1, 0),
(2851, 180, 'P', 1, 0),
(2852, 181, 'AN', 1, 0),
(2853, 181, 'AI', 1, 0),
(2854, 181, 'AT', 1, 0),
(2855, 181, 'FA', 1, 0),
(2856, 181, 'GE', 1, 0),
(2857, 181, 'GF', 1, 0),
(2858, 181, 'PA', 1, 0),
(2859, 181, 'SA', 1, 0),
(2860, 181, 'TU', 1, 0),
(2861, 181, 'VF', 1, 0),
(2862, 181, 'VS', 1, 0),
(2863, 182, 'AC', 1, 0),
(2864, 182, 'BM', 1, 0),
(2865, 182, 'CH', 1, 0),
(2866, 182, 'DO', 1, 0),
(2867, 182, 'FA', 1, 0),
(2868, 182, 'FI', 1, 0),
(2869, 182, 'MO', 1, 0),
(2870, 182, 'SM', 1, 0),
(2871, 182, 'SE', 1, 0),
(2872, 183, 'S', 1, 0),
(2873, 183, 'P', 1, 0),
(2874, 184, 'BH', 1, 0),
(2875, 184, 'HS', 1, 0),
(2876, 184, 'JF', 1, 0),
(2877, 184, 'MD', 1, 0),
(2878, 184, 'QS', 1, 0),
(2879, 184, 'RD', 1, 0),
(2880, 184, 'AQ', 1, 0),
(2881, 184, 'AS', 1, 0),
(2882, 184, 'HL', 1, 0),
(2883, 184, 'JZ', 1, 0),
(2884, 184, 'ML', 1, 0),
(2885, 184, 'NR', 1, 0),
(2886, 184, 'TB', 1, 0),
(2887, 185, 'DA', 1, 0),
(2888, 185, 'DI', 1, 0),
(2889, 185, 'FA', 1, 0),
(2890, 185, 'KA', 1, 0),
(2891, 185, 'KO', 1, 0),
(2892, 185, 'LO', 1, 0),
(2893, 185, 'MA', 1, 0),
(2894, 185, 'SL', 1, 0),
(2895, 185, 'TA', 1, 0),
(2896, 185, 'TH', 1, 0),
(2897, 185, 'ZI', 1, 0),
(2898, 186, 'AP', 1, 0),
(2899, 186, 'AB', 1, 0),
(2900, 186, 'AE', 1, 0),
(2901, 186, 'AL', 1, 0),
(2902, 186, 'AR', 1, 0),
(2903, 186, 'BL', 1, 0),
(2904, 186, 'BS', 1, 0),
(2905, 186, 'BV', 1, 0),
(2906, 186, 'BA', 1, 0),
(2907, 186, 'BO', 1, 0),
(2908, 186, 'CA', 1, 0),
(2909, 186, 'GL', 1, 0),
(2910, 186, 'GM', 1, 0),
(2911, 186, 'GP', 1, 0),
(2912, 186, 'DG', 1, 0),
(2913, 186, 'RA', 1, 0),
(2914, 186, 'MB', 1, 0),
(2915, 186, 'MF', 1, 0),
(2916, 186, 'PL', 1, 0),
(2917, 186, 'PR', 1, 0),
(2918, 186, 'PG', 1, 0),
(2919, 186, 'SL', 1, 0),
(2920, 186, 'TA', 1, 0),
(2921, 187, 'E', 1, 0),
(2922, 187, 'N', 1, 0),
(2923, 187, 'S', 1, 0),
(2924, 187, 'W', 1, 0),
(2925, 189, 'BA', 1, 0),
(2926, 189, 'BR', 1, 0),
(2927, 189, 'KO', 1, 0),
(2928, 189, 'NI', 1, 0),
(2929, 189, 'PR', 1, 0),
(2930, 189, 'TC', 1, 0),
(2931, 189, 'TV', 1, 0),
(2932, 189, 'ZI', 1, 0),
(2933, 191, 'CE', 1, 0),
(2934, 191, 'CH', 1, 0),
(2935, 191, 'GC', 1, 0),
(2936, 191, 'HO', 1, 0),
(2937, 191, 'IS', 1, 0),
(2938, 191, 'MK', 1, 0),
(2939, 191, 'ML', 1, 0),
(2940, 191, 'RB', 1, 0),
(2941, 191, 'TM', 1, 0),
(2942, 191, 'WE', 1, 0),
(2943, 192, 'AW', 1, 0),
(2944, 192, 'BK', 1, 0),
(2945, 192, 'BN', 1, 0),
(2946, 192, 'BR', 1, 0),
(2947, 192, 'BY', 1, 0),
(2948, 192, 'GA', 1, 0),
(2949, 192, 'GE', 1, 0),
(2950, 192, 'HI', 1, 0),
(2951, 192, 'JD', 1, 0),
(2952, 192, 'JH', 1, 0),
(2953, 192, 'MU', 1, 0),
(2954, 192, 'NU', 1, 0),
(2955, 192, 'SA', 1, 0),
(2956, 192, 'SD', 1, 0),
(2957, 192, 'SH', 1, 0),
(2958, 192, 'SL', 1, 0),
(2959, 192, 'TO', 1, 0),
(2960, 192, 'WG', 1, 0),
(2961, 193, 'EC', 1, 0),
(2962, 193, 'FS', 1, 0),
(2963, 193, 'GT', 1, 0),
(2964, 193, 'KN', 1, 0),
(2965, 193, 'LP', 1, 0),
(2966, 193, 'MP', 1, 0),
(2967, 193, 'NW', 1, 0),
(2968, 193, 'NC', 1, 0),
(2969, 193, 'WC', 1, 0),
(2970, 195, 'CA', 1, 0),
(2971, 195, 'AL', 1, 0),
(2972, 195, 'AB', 1, 0),
(2973, 195, 'AC', 1, 0),
(2974, 195, 'AM', 1, 0),
(2975, 195, 'AS', 1, 0),
(2976, 195, 'AV', 1, 0),
(2977, 195, 'BJ', 1, 0),
(2978, 195, 'IB', 1, 0),
(2979, 195, 'BA', 1, 0),
(2980, 195, 'BU', 1, 0),
(2981, 195, 'CC', 1, 0),
(2982, 195, 'CZ', 1, 0),
(2983, 195, 'CT', 1, 0),
(2984, 195, 'CL', 1, 0),
(2985, 195, 'CE', 1, 0),
(2986, 195, 'CR', 1, 0),
(2987, 195, 'CD', 1, 0),
(2988, 195, 'CU', 1, 0),
(2989, 195, 'GI', 1, 0),
(2990, 195, 'GD', 1, 0),
(2991, 195, 'GJ', 1, 0),
(2992, 195, 'GP', 1, 0),
(2993, 195, 'HL', 1, 0),
(2994, 195, 'HS', 1, 0),
(2995, 195, 'JN', 1, 0),
(2996, 195, 'RJ', 1, 0),
(2997, 195, 'PM', 1, 0),
(2998, 195, 'LE', 1, 0),
(2999, 195, 'LL', 1, 0),
(3000, 195, 'LG', 1, 0),
(3001, 195, 'MD', 1, 0),
(3002, 195, 'MA', 1, 0),
(3003, 195, 'ML', 1, 0),
(3004, 195, 'MU', 1, 0),
(3005, 195, 'NV', 1, 0),
(3006, 195, 'OU', 1, 0),
(3007, 195, 'PL', 1, 0),
(3008, 195, 'PO', 1, 0),
(3009, 195, 'SL', 1, 0),
(3010, 195, 'SC', 1, 0),
(3011, 195, 'SG', 1, 0),
(3012, 195, 'SV', 1, 0),
(3013, 195, 'SO', 1, 0),
(3014, 195, 'TA', 1, 0),
(3015, 195, 'TE', 1, 0),
(3016, 195, 'TO', 1, 0),
(3017, 195, 'VC', 1, 0),
(3018, 195, 'VD', 1, 0),
(3019, 195, 'VZ', 1, 0),
(3020, 195, 'ZM', 1, 0),
(3021, 195, 'ZR', 1, 0),
(3022, 196, 'CE', 1, 0),
(3023, 196, 'EA', 1, 0),
(3024, 196, 'NC', 1, 0),
(3025, 196, 'NO', 1, 0),
(3026, 196, 'NW', 1, 0),
(3027, 196, 'SA', 1, 0),
(3028, 196, 'SO', 1, 0),
(3029, 196, 'UV', 1, 0),
(3030, 196, 'WE', 1, 0),
(3031, 197, 'A', 1, 0),
(3032, 197, 'S', 1, 0),
(3033, 197, 'T', 1, 0),
(3034, 199, 'ANL', 1, 0),
(3035, 199, 'BAM', 1, 0),
(3036, 199, 'BRT', 1, 0),
(3037, 199, 'JZR', 1, 0),
(3038, 199, 'KRT', 1, 0),
(3039, 199, 'QDR', 1, 0),
(3040, 199, 'WDH', 1, 0),
(3041, 199, 'ANB', 1, 0),
(3042, 199, 'ANZ', 1, 0),
(3043, 199, 'ASH', 1, 0),
(3044, 199, 'BJA', 1, 0),
(3045, 199, 'GIS', 1, 0),
(3046, 199, 'GBG', 1, 0),
(3047, 199, 'GDA', 1, 0),
(3048, 199, 'GKU', 1, 0),
(3049, 199, 'JDA', 1, 0),
(3050, 199, 'JKU', 1, 0),
(3051, 199, 'JQL', 1, 0),
(3052, 199, 'KSL', 1, 0),
(3053, 199, 'NNL', 1, 0),
(3054, 199, 'SBG', 1, 0),
(3055, 199, 'SDA', 1, 0),
(3056, 199, 'SKU', 1, 0),
(3057, 199, 'SIS', 1, 0),
(3058, 199, 'SNR', 1, 0),
(3059, 199, 'WRB', 1, 0),
(3060, 200, 'BR', 1, 0),
(3061, 200, 'CM', 1, 0),
(3062, 200, 'CR', 1, 0),
(3063, 200, 'MA', 1, 0),
(3064, 200, 'NI', 1, 0),
(3065, 200, 'PA', 1, 0),
(3066, 200, 'PM', 1, 0),
(3067, 200, 'SA', 1, 0),
(3068, 200, 'SI', 1, 0),
(3069, 200, 'WA', 1, 0),
(3070, 202, 'H', 1, 0),
(3071, 202, 'L', 1, 0),
(3072, 202, 'M', 1, 0),
(3073, 202, 'S', 1, 0),
(3074, 203, 'K', 1, 0),
(3075, 203, 'W', 1, 0),
(3076, 203, 'X', 1, 0),
(3077, 203, 'I', 1, 0),
(3078, 203, 'N', 1, 0),
(3079, 203, 'Z', 1, 0),
(3080, 203, 'F', 1, 0),
(3081, 203, 'H', 1, 0),
(3082, 203, 'G', 1, 0),
(3083, 203, 'BD', 1, 0),
(3084, 203, 'T', 1, 0),
(3085, 203, 'E', 1, 0),
(3086, 203, 'M', 1, 0),
(3087, 203, 'D', 1, 0),
(3088, 203, 'AB', 1, 0),
(3089, 203, 'C', 1, 0),
(3090, 203, 'S', 1, 0),
(3091, 203, 'AC', 1, 0),
(3092, 203, 'Y', 1, 0),
(3093, 203, 'U', 1, 0),
(3094, 203, 'O', 1, 0),
(3095, 204, 'AG', 1, 0),
(3096, 204, 'AR', 1, 0),
(3097, 204, 'AI', 1, 0),
(3098, 204, 'BS', 1, 0),
(3099, 204, 'BL', 1, 0),
(3100, 204, 'BE', 1, 0),
(3101, 204, 'FR', 1, 0),
(3102, 204, 'GE', 1, 0),
(3103, 204, 'GL', 1, 0),
(3104, 204, 'GR', 1, 0),
(3105, 204, 'JU', 1, 0),
(3106, 204, 'LU', 1, 0),
(3107, 204, 'NE', 1, 0),
(3108, 204, 'NW', 1, 0),
(3109, 204, 'OW', 1, 0),
(3110, 204, 'SG', 1, 0),
(3111, 204, 'SH', 1, 0),
(3112, 204, 'SZ', 1, 0),
(3113, 204, 'SO', 1, 0),
(3114, 204, 'TG', 1, 0),
(3115, 204, 'TI', 1, 0),
(3116, 204, 'UR', 1, 0),
(3117, 204, 'VS', 1, 0),
(3118, 204, 'VD', 1, 0),
(3119, 204, 'ZG', 1, 0),
(3120, 204, 'ZH', 1, 0),
(3121, 205, 'HA', 1, 0),
(3122, 205, 'LA', 1, 0),
(3123, 205, 'QU', 1, 0),
(3124, 205, 'RQ', 1, 0),
(3125, 205, 'SU', 1, 0),
(3126, 205, 'DA', 1, 0),
(3127, 205, 'DZ', 1, 0),
(3128, 205, 'DI', 1, 0),
(3129, 205, 'HL', 1, 0),
(3130, 205, 'HM', 1, 0),
(3131, 205, 'HI', 1, 0),
(3132, 205, 'ID', 1, 0),
(3133, 205, 'RD', 1, 0),
(3134, 205, 'TA', 1, 0),
(3135, 206, 'CH', 1, 0),
(3136, 206, 'CI', 1, 0),
(3137, 206, 'HS', 1, 0),
(3138, 206, 'HL', 1, 0),
(3139, 206, 'IL', 1, 0),
(3140, 206, 'KH', 1, 0),
(3141, 206, 'KM', 1, 0),
(3142, 206, 'LC', 1, 0),
(3143, 206, 'ML', 1, 0),
(3144, 206, 'NT', 1, 0),
(3145, 206, 'PH', 1, 0),
(3146, 206, 'PT', 1, 0),
(3147, 206, 'TG', 1, 0),
(3148, 206, 'TA', 1, 0),
(3149, 206, 'TP', 1, 0),
(3150, 206, 'TT', 1, 0),
(3151, 206, 'TY', 1, 0),
(3152, 206, 'YL', 1, 0),
(3153, 206, 'CC', 1, 0),
(3154, 206, 'CL', 1, 0),
(3155, 206, 'HC', 1, 0),
(3156, 206, 'TH', 1, 0),
(3157, 206, 'TN', 1, 0),
(3158, 206, 'KC', 1, 0),
(3159, 206, 'TC', 1, 0),
(3160, 207, 'GB', 1, 0),
(3161, 207, 'KT', 1, 0),
(3162, 207, 'SU', 1, 0),
(3163, 208, 'AR', 1, 0),
(3164, 208, 'DS', 1, 0),
(3165, 208, 'DO', 1, 0),
(3166, 208, 'IR', 1, 0),
(3167, 208, 'KA', 1, 0),
(3168, 208, 'KI', 1, 0),
(3169, 208, 'KJ', 1, 0),
(3170, 208, 'LN', 1, 0),
(3171, 208, 'MY', 1, 0),
(3172, 208, 'MR', 1, 0),
(3173, 208, 'MB', 1, 0),
(3174, 208, 'MO', 1, 0),
(3175, 208, 'MT', 1, 0),
(3176, 208, 'MW', 1, 0),
(3177, 208, 'PN', 1, 0),
(3178, 208, 'PS', 1, 0),
(3179, 208, 'PW', 1, 0),
(3180, 208, 'RK', 1, 0),
(3181, 208, 'RV', 1, 0),
(3182, 208, 'SH', 1, 0),
(3183, 208, 'SI', 1, 0),
(3184, 208, 'TB', 1, 0),
(3185, 208, 'TN', 1, 0),
(3186, 208, 'ZC', 1, 0),
(3187, 208, 'ZN', 1, 0),
(3188, 208, 'ZU', 1, 0),
(3189, 209, 'Amnat Charoen', 1, 0),
(3190, 209, 'Ang Thong', 1, 0),
(3191, 209, 'Ayutthaya', 1, 0),
(3192, 209, 'Bangkok', 1, 0),
(3193, 209, 'Buriram', 1, 0),
(3194, 209, 'Chachoengsao', 1, 0),
(3195, 209, 'Chai Nat', 1, 0),
(3196, 209, 'Chaiyaphum', 1, 0),
(3197, 209, 'Chanthaburi', 1, 0),
(3198, 209, 'Chiang Mai', 1, 0),
(3199, 209, 'Chiang Rai', 1, 0),
(3200, 209, 'Chon Buri', 1, 0),
(3201, 209, 'Chumphon', 1, 0),
(3202, 209, 'Kalasin', 1, 0),
(3203, 209, 'Kamphaeng Phet', 1, 0),
(3204, 209, 'Kanchanaburi', 1, 0),
(3205, 209, 'Khon Kaen', 1, 0),
(3206, 209, 'Krabi', 1, 0),
(3207, 209, 'Lampang', 1, 0),
(3208, 209, 'Lamphun', 1, 0),
(3209, 209, 'Loei', 1, 0),
(3210, 209, 'Lop Buri', 1, 0),
(3211, 209, 'Mae Hong Son', 1, 0),
(3212, 209, 'Maha Sarakham', 1, 0),
(3213, 209, 'Mukdahan', 1, 0),
(3214, 209, 'Nakhon Nayok', 1, 0),
(3215, 209, 'Nakhon Pathom', 1, 0),
(3216, 209, 'Nakhon Phanom', 1, 0),
(3217, 209, 'Nakhon Ratchasima', 1, 0),
(3218, 209, 'Nakhon Sawan', 1, 0),
(3219, 209, 'Nakhon Si Thammarat', 1, 0),
(3220, 209, 'Nan', 1, 0),
(3221, 209, 'Narathiwat', 1, 0),
(3222, 209, 'Nong Bua Lamphu', 1, 0),
(3223, 209, 'Nong Khai', 1, 0),
(3224, 209, 'Nonthaburi', 1, 0),
(3225, 209, 'Pathum Thani', 1, 0),
(3226, 209, 'Pattani', 1, 0),
(3227, 209, 'Phangnga', 1, 0),
(3228, 209, 'Phatthalung', 1, 0),
(3229, 209, 'Phayao', 1, 0),
(3230, 209, 'Phetchabun', 1, 0),
(3231, 209, 'Phetchaburi', 1, 0),
(3232, 209, 'Phichit', 1, 0),
(3233, 209, 'Phitsanulok', 1, 0),
(3234, 209, 'Phrae', 1, 0),
(3235, 209, 'Phuket', 1, 0),
(3236, 209, 'Prachin Buri', 1, 0),
(3237, 209, 'Prachuap Khiri Khan', 1, 0),
(3238, 209, 'Ranong', 1, 0),
(3239, 209, 'Ratchaburi', 1, 0),
(3240, 209, 'Rayong', 1, 0),
(3241, 209, 'Roi Et', 1, 0),
(3242, 209, 'Sa Kaeo', 1, 0),
(3243, 209, 'Sakon Nakhon', 1, 0),
(3244, 209, 'Samut Prakan', 1, 0),
(3245, 209, 'Samut Sakhon', 1, 0),
(3246, 209, 'Samut Songkhram', 1, 0),
(3247, 209, 'Sara Buri', 1, 0),
(3248, 209, 'Satun', 1, 0),
(3249, 209, 'Sing Buri', 1, 0),
(3250, 209, 'Sisaket', 1, 0),
(3251, 209, 'Songkhla', 1, 0),
(3252, 209, 'Sukhothai', 1, 0),
(3253, 209, 'Suphan Buri', 1, 0),
(3254, 209, 'Surat Thani', 1, 0),
(3255, 209, 'Surin', 1, 0),
(3256, 209, 'Tak', 1, 0),
(3257, 209, 'Trang', 1, 0),
(3258, 209, 'Trat', 1, 0),
(3259, 209, 'Ubon Ratchathani', 1, 0),
(3260, 209, 'Udon Thani', 1, 0),
(3261, 209, 'Uthai Thani', 1, 0),
(3262, 209, 'Uttaradit', 1, 0),
(3263, 209, 'Yala', 1, 0),
(3264, 209, 'Yasothon', 1, 0),
(3265, 210, 'K', 1, 0),
(3266, 210, 'P', 1, 0),
(3267, 210, 'S', 1, 0),
(3268, 210, 'C', 1, 0),
(3269, 210, 'M', 1, 0),
(3270, 211, 'A', 1, 0),
(3271, 211, 'F', 1, 0),
(3272, 211, 'N', 1, 0),
(3273, 212, 'H', 1, 0),
(3274, 212, 'T', 1, 0),
(3275, 212, 'V', 1, 0),
(3276, 213, 'CT', 1, 0),
(3277, 213, 'DM', 1, 0),
(3278, 213, 'MR', 1, 0),
(3279, 213, 'PD', 1, 0),
(3280, 213, 'PT', 1, 0),
(3281, 213, 'SG', 1, 0),
(3282, 213, 'SL', 1, 0),
(3283, 213, 'SI', 1, 0),
(3284, 213, 'TP', 1, 0),
(3285, 213, 'PS', 1, 0),
(3286, 213, 'SF', 1, 0),
(3287, 213, 'AR', 1, 0),
(3288, 213, 'PF', 1, 0),
(3289, 213, 'CH', 1, 0),
(3290, 213, 'TO', 1, 0),
(3291, 214, 'AR', 1, 0),
(3292, 214, 'BJ', 1, 0),
(3293, 214, 'BA', 1, 0),
(3294, 214, 'BI', 1, 0),
(3295, 214, 'GB', 1, 0),
(3296, 214, 'GF', 1, 0),
(3297, 214, 'JE', 1, 0),
(3298, 214, 'KR', 1, 0),
(3299, 214, 'KS', 1, 0),
(3300, 214, 'KB', 1, 0),
(3301, 214, 'KF', 1, 0),
(3302, 214, 'MH', 1, 0),
(3303, 214, 'MN', 1, 0),
(3304, 214, 'ME', 1, 0),
(3305, 214, 'MO', 1, 0),
(3306, 214, 'NA', 1, 0),
(3307, 214, 'SF', 1, 0),
(3308, 214, 'SD', 1, 0),
(3309, 214, 'SL', 1, 0),
(3310, 214, 'SO', 1, 0),
(3311, 214, 'TA', 1, 0),
(3312, 214, 'TO', 1, 0),
(3313, 214, 'TU', 1, 0),
(3314, 214, 'ZA', 1, 0),
(3315, 215, 'ADA', 1, 0),
(3316, 215, 'ADI', 1, 0),
(3317, 215, 'AFY', 1, 0),
(3318, 215, 'AGR', 1, 0),
(3319, 215, 'AKS', 1, 0),
(3320, 215, 'AMA', 1, 0),
(3321, 215, 'ANK', 1, 0),
(3322, 215, 'ANT', 1, 0),
(3323, 215, 'ARD', 1, 0),
(3324, 215, 'ART', 1, 0),
(3325, 215, 'AYI', 1, 0),
(3326, 215, 'BAL', 1, 0),
(3327, 215, 'BAR', 1, 0),
(3328, 215, 'BAT', 1, 0),
(3329, 215, 'BAY', 1, 0),
(3330, 215, 'BIL', 1, 0),
(3331, 215, 'BIN', 1, 0),
(3332, 215, 'BIT', 1, 0),
(3333, 215, 'BOL', 1, 0),
(3334, 215, 'BRD', 1, 0),
(3335, 215, 'BRS', 1, 0),
(3336, 215, 'CKL', 1, 0),
(3337, 215, 'CKR', 1, 0),
(3338, 215, 'COR', 1, 0),
(3339, 215, 'DEN', 1, 0),
(3340, 215, 'DIY', 1, 0),
(3341, 215, 'DUZ', 1, 0),
(3342, 215, 'EDI', 1, 0),
(3343, 215, 'ELA', 1, 0),
(3344, 215, 'EZC', 1, 0),
(3345, 215, 'EZR', 1, 0),
(3346, 215, 'ESK', 1, 0),
(3347, 215, 'GAZ', 1, 0),
(3348, 215, 'GIR', 1, 0),
(3349, 215, 'GMS', 1, 0),
(3350, 215, 'HKR', 1, 0),
(3351, 215, 'HTY', 1, 0),
(3352, 215, 'IGD', 1, 0),
(3353, 215, 'ISP', 1, 0),
(3354, 215, 'IST', 1, 0),
(3355, 215, 'IZM', 1, 0),
(3356, 215, 'KAH', 1, 0),
(3357, 215, 'KRB', 1, 0),
(3358, 215, 'KRM', 1, 0),
(3359, 215, 'KRS', 1, 0),
(3360, 215, 'KAS', 1, 0),
(3361, 215, 'KAY', 1, 0),
(3362, 215, 'KLS', 1, 0),
(3363, 215, 'KRK', 1, 0),
(3364, 215, 'KLR', 1, 0),
(3365, 215, 'KRH', 1, 0),
(3366, 215, 'KOC', 1, 0),
(3367, 215, 'KON', 1, 0),
(3368, 215, 'KUT', 1, 0),
(3369, 215, 'MAL', 1, 0),
(3370, 215, 'MAN', 1, 0),
(3371, 215, 'MAR', 1, 0),
(3372, 215, 'MER', 1, 0),
(3373, 215, 'MUG', 1, 0),
(3374, 215, 'MUS', 1, 0),
(3375, 215, 'NEV', 1, 0),
(3376, 215, 'NIG', 1, 0),
(3377, 215, 'ORD', 1, 0),
(3378, 215, 'OSM', 1, 0),
(3379, 215, 'RIZ', 1, 0),
(3380, 215, 'SAK', 1, 0),
(3381, 215, 'SAM', 1, 0),
(3382, 215, 'SAN', 1, 0),
(3383, 215, 'SII', 1, 0),
(3384, 215, 'SIN', 1, 0),
(3385, 215, 'SIR', 1, 0),
(3386, 215, 'SIV', 1, 0),
(3387, 215, 'TEL', 1, 0),
(3388, 215, 'TOK', 1, 0),
(3389, 215, 'TRA', 1, 0),
(3390, 215, 'TUN', 1, 0),
(3391, 215, 'USK', 1, 0),
(3392, 215, 'VAN', 1, 0),
(3393, 215, 'YAL', 1, 0),
(3394, 215, 'YOZ', 1, 0),
(3395, 215, 'ZON', 1, 0),
(3396, 216, 'A', 1, 0),
(3397, 216, 'B', 1, 0),
(3398, 216, 'D', 1, 0),
(3399, 216, 'L', 1, 0),
(3400, 216, 'M', 1, 0),
(3401, 217, 'AC', 1, 0),
(3402, 217, 'DC', 1, 0),
(3403, 217, 'FC', 1, 0),
(3404, 217, 'LW', 1, 0),
(3405, 217, 'RC', 1, 0),
(3406, 217, 'PN', 1, 0),
(3407, 217, 'SL', 1, 0),
(3408, 217, 'GT', 1, 0),
(3409, 217, 'SC', 1, 0),
(3410, 217, 'EC', 1, 0),
(3411, 217, 'MC', 1, 0),
(3412, 217, 'NC', 1, 0),
(3413, 217, 'PR', 1, 0),
(3414, 217, 'WC', 1, 0),
(3415, 218, 'NMG', 1, 0),
(3416, 218, 'NLK', 1, 0),
(3417, 218, 'NTO', 1, 0),
(3418, 218, 'FUN', 1, 0),
(3419, 218, 'NME', 1, 0),
(3420, 218, 'NUI', 1, 0),
(3421, 218, 'NFT', 1, 0),
(3422, 218, 'NLL', 1, 0),
(3423, 218, 'VAI', 1, 0),
(3424, 219, 'KAL', 1, 0),
(3425, 219, 'KMP', 1, 0),
(3426, 219, 'KAY', 1, 0),
(3427, 219, 'KIB', 1, 0),
(3428, 219, 'LUW', 1, 0),
(3429, 219, 'MAS', 1, 0),
(3430, 219, 'MPI', 1, 0),
(3431, 219, 'MUB', 1, 0),
(3432, 219, 'MUK', 1, 0),
(3433, 219, 'NKS', 1, 0),
(3434, 219, 'RAK', 1, 0),
(3435, 219, 'SEM', 1, 0),
(3436, 219, 'WAK', 1, 0),
(3437, 219, 'BUG', 1, 0),
(3438, 219, 'BUS', 1, 0),
(3439, 219, 'IGA', 1, 0),
(3440, 219, 'JIN', 1, 0),
(3441, 219, 'KAB', 1, 0),
(3442, 219, 'KML', 1, 0),
(3443, 219, 'KPC', 1, 0),
(3444, 219, 'KTK', 1, 0),
(3445, 219, 'KUM', 1, 0),
(3446, 219, 'MAY', 1, 0),
(3447, 219, 'MBA', 1, 0),
(3448, 219, 'PAL', 1, 0),
(3449, 219, 'SIR', 1, 0),
(3450, 219, 'SOR', 1, 0),
(3451, 219, 'TOR', 1, 0),
(3452, 219, 'ADJ', 1, 0),
(3453, 219, 'APC', 1, 0),
(3454, 219, 'ARU', 1, 0),
(3455, 219, 'GUL', 1, 0),
(3456, 219, 'KIT', 1, 0),
(3457, 219, 'KOT', 1, 0),
(3458, 219, 'LIR', 1, 0),
(3459, 219, 'MRT', 1, 0),
(3460, 219, 'MOY', 1, 0),
(3461, 219, 'NAK', 1, 0),
(3462, 219, 'NEB', 1, 0),
(3463, 219, 'PAD', 1, 0),
(3464, 219, 'YUM', 1, 0),
(3465, 219, 'BUN', 1, 0),
(3466, 219, 'BSH', 1, 0),
(3467, 219, 'HOI', 1, 0),
(3468, 219, 'KBL', 1, 0),
(3469, 219, 'KAR', 1, 0),
(3470, 219, 'KAM', 1, 0),
(3471, 219, 'KAN', 1, 0),
(3472, 219, 'KAS', 1, 0),
(3473, 219, 'KBA', 1, 0),
(3474, 219, 'KIS', 1, 0),
(3475, 219, 'KYE', 1, 0),
(3476, 219, 'MSN', 1, 0),
(3477, 219, 'MBR', 1, 0),
(3478, 219, 'NTU', 1, 0),
(3479, 219, 'RUK', 1, 0),
(3480, 220, 'CK', 1, 0),
(3481, 220, 'CH', 1, 0),
(3482, 220, 'CV', 1, 0),
(3483, 220, 'CR', 1, 0),
(3484, 220, 'DN', 1, 0),
(3485, 220, 'DO', 1, 0),
(3486, 220, 'IV', 1, 0),
(3487, 220, 'KL', 1, 0),
(3488, 220, 'KM', 1, 0),
(3489, 220, 'KR', 1, 0),
(3490, 220, 'KV', 1, 0),
(3491, 220, 'KS', 1, 0),
(3492, 220, 'LU', 1, 0),
(3493, 220, 'LV', 1, 0),
(3494, 220, 'MY', 1, 0),
(3495, 220, 'OD', 1, 0),
(3496, 220, 'PO', 1, 0),
(3497, 220, 'RI', 1, 0),
(3498, 220, 'SE', 1, 0),
(3499, 220, 'SU', 1, 0),
(3500, 220, 'TE', 1, 0),
(3501, 220, 'VI', 1, 0),
(3502, 220, 'VO', 1, 0),
(3503, 220, 'ZK', 1, 0),
(3504, 220, 'ZA', 1, 0),
(3505, 220, 'ZH', 1, 0),
(3506, 221, 'AZ', 1, 0),
(3507, 221, 'AJ', 1, 0),
(3508, 221, 'FU', 1, 0),
(3509, 221, 'SH', 1, 0),
(3510, 221, 'DU', 1, 0),
(3511, 221, 'RK', 1, 0),
(3512, 221, 'UQ', 1, 0),
(3513, 222, 'ABN', 1, 0),
(3514, 222, 'ABNS', 1, 0),
(3515, 222, 'ANG', 1, 0),
(3516, 222, 'AGS', 1, 0),
(3517, 222, 'ARY', 1, 0),
(3518, 222, 'BEDS', 1, 0),
(3519, 222, 'BERKS', 1, 0),
(3520, 222, 'BLA', 1, 0),
(3521, 222, 'BRI', 1, 0),
(3522, 222, 'BSTL', 1, 0),
(3523, 222, 'BUCKS', 1, 0),
(3524, 222, 'CAE', 1, 0),
(3525, 222, 'CAMBS', 1, 0),
(3526, 222, 'CDF', 1, 0),
(3527, 222, 'CARM', 1, 0),
(3528, 222, 'CDGN', 1, 0),
(3529, 222, 'CHES', 1, 0),
(3530, 222, 'CLACK', 1, 0),
(3531, 222, 'CON', 1, 0),
(3532, 222, 'CORN', 1, 0),
(3533, 222, 'DNBG', 1, 0),
(3534, 222, 'DERBY', 1, 0),
(3535, 222, 'DVN', 1, 0),
(3536, 222, 'DOR', 1, 0),
(3537, 222, 'DGL', 1, 0),
(3538, 222, 'DUND', 1, 0),
(3539, 222, 'DHM', 1, 0),
(3540, 222, 'ARYE', 1, 0),
(3541, 222, 'DUNBE', 1, 0),
(3542, 222, 'LOTE', 1, 0),
(3543, 222, 'RENE', 1, 0),
(3544, 222, 'ERYS', 1, 0),
(3545, 222, 'SXE', 1, 0),
(3546, 222, 'EDIN', 1, 0),
(3547, 222, 'ESX', 1, 0),
(3548, 222, 'FALK', 1, 0),
(3549, 222, 'FFE', 1, 0),
(3550, 222, 'FLINT', 1, 0),
(3551, 222, 'GLAS', 1, 0),
(3552, 222, 'GLOS', 1, 0),
(3553, 222, 'LDN', 1, 0),
(3554, 222, 'MCH', 1, 0),
(3555, 222, 'GDD', 1, 0),
(3556, 222, 'HANTS', 1, 0),
(3557, 222, 'HWR', 1, 0),
(3558, 222, 'HERTS', 1, 0),
(3559, 222, 'HLD', 1, 0),
(3560, 222, 'IVER', 1, 0),
(3561, 222, 'IOW', 1, 0),
(3562, 222, 'KNT', 1, 0),
(3563, 222, 'LANCS', 1, 0),
(3564, 222, 'LEICS', 1, 0),
(3565, 222, 'LINCS', 1, 0),
(3566, 222, 'MSY', 1, 0),
(3567, 222, 'MERT', 1, 0),
(3568, 222, 'MLOT', 1, 0),
(3569, 222, 'MMOUTH', 1, 0),
(3570, 222, 'MORAY', 1, 0),
(3571, 222, 'NPRTAL', 1, 0),
(3572, 222, 'NEWPT', 1, 0),
(3573, 222, 'NOR', 1, 0),
(3574, 222, 'ARYN', 1, 0),
(3575, 222, 'LANN', 1, 0),
(3576, 222, 'YSN', 1, 0),
(3577, 222, 'NHM', 1, 0),
(3578, 222, 'NLD', 1, 0),
(3579, 222, 'NOT', 1, 0),
(3580, 222, 'ORK', 1, 0),
(3581, 222, 'OFE', 1, 0),
(3582, 222, 'PEM', 1, 0),
(3583, 222, 'PERTH', 1, 0),
(3584, 222, 'PWS', 1, 0),
(3585, 222, 'REN', 1, 0),
(3586, 222, 'RHON', 1, 0),
(3587, 222, 'RUT', 1, 0),
(3588, 222, 'BOR', 1, 0),
(3589, 222, 'SHET', 1, 0),
(3590, 222, 'SPE', 1, 0),
(3591, 222, 'SOM', 1, 0),
(3592, 222, 'ARYS', 1, 0),
(3593, 222, 'LANS', 1, 0),
(3594, 222, 'YSS', 1, 0),
(3595, 222, 'SFD', 1, 0),
(3596, 222, 'STIR', 1, 0),
(3597, 222, 'SFK', 1, 0),
(3598, 222, 'SRY', 1, 0),
(3599, 222, 'SWAN', 1, 0),
(3600, 222, 'TORF', 1, 0),
(3601, 222, 'TWR', 1, 0),
(3602, 222, 'VGLAM', 1, 0),
(3603, 222, 'WARKS', 1, 0),
(3604, 222, 'WDUN', 1, 0),
(3605, 222, 'WLOT', 1, 0),
(3606, 222, 'WMD', 1, 0),
(3607, 222, 'SXW', 1, 0),
(3608, 222, 'YSW', 1, 0),
(3609, 222, 'WIL', 1, 0),
(3610, 222, 'WLT', 1, 0),
(3611, 222, 'WORCS', 1, 0),
(3612, 222, 'WRX', 1, 0),
(3613, 223, 'AL', 1, 0),
(3614, 223, 'AK', 1, 0),
(3615, 223, 'AS', 1, 0),
(3616, 223, 'AZ', 1, 0),
(3617, 223, 'AR', 1, 0),
(3618, 223, 'AF', 1, 0),
(3619, 223, 'AA', 1, 0),
(3620, 223, 'AC', 1, 0),
(3621, 223, 'AE', 1, 0),
(3622, 223, 'AM', 1, 0),
(3623, 223, 'AP', 1, 0),
(3624, 223, 'CA', 1, 0),
(3625, 223, 'CO', 1, 0),
(3626, 223, 'CT', 1, 0),
(3627, 223, 'DE', 1, 0),
(3628, 223, 'DC', 1, 0),
(3629, 223, 'FM', 1, 0),
(3630, 223, 'FL', 1, 0),
(3631, 223, 'GA', 1, 0),
(3632, 223, 'GU', 1, 0),
(3633, 223, 'HI', 1, 0),
(3634, 223, 'ID', 1, 0),
(3635, 223, 'IL', 1, 0),
(3636, 223, 'IN', 1, 0),
(3637, 223, 'IA', 1, 0),
(3638, 223, 'KS', 1, 0),
(3639, 223, 'KY', 1, 0),
(3640, 223, 'LA', 1, 0),
(3641, 223, 'ME', 1, 0),
(3642, 223, 'MH', 1, 0),
(3643, 223, 'MD', 1, 0),
(3644, 223, 'MA', 1, 0),
(3645, 223, 'MI', 1, 0),
(3646, 223, 'MN', 1, 0),
(3647, 223, 'MS', 1, 0),
(3648, 223, 'MO', 1, 0),
(3649, 223, 'MT', 1, 0),
(3650, 223, 'NE', 1, 0),
(3651, 223, 'NV', 1, 0),
(3652, 223, 'NH', 1, 0),
(3653, 223, 'NJ', 1, 0),
(3654, 223, 'NM', 1, 0),
(3655, 223, 'NY', 1, 0),
(3656, 223, 'NC', 1, 0),
(3657, 223, 'ND', 1, 0),
(3658, 223, 'MP', 1, 0),
(3659, 223, 'OH', 1, 0),
(3660, 223, 'OK', 1, 0),
(3661, 223, 'OR', 1, 0),
(3662, 223, 'PW', 1, 0),
(3663, 223, 'PA', 1, 0),
(3664, 223, 'PR', 1, 0),
(3665, 223, 'RI', 1, 0),
(3666, 223, 'SC', 1, 0),
(3667, 223, 'SD', 1, 0),
(3668, 223, 'TN', 1, 0),
(3669, 223, 'TX', 1, 0),
(3670, 223, 'UT', 1, 0),
(3671, 223, 'VT', 1, 0),
(3672, 223, 'VI', 1, 0),
(3673, 223, 'VA', 1, 0),
(3674, 223, 'WA', 1, 0),
(3675, 223, 'WV', 1, 0),
(3676, 223, 'WI', 1, 0),
(3677, 223, 'WY', 1, 0),
(3678, 224, 'BI', 1, 0),
(3679, 224, 'HI', 1, 0),
(3680, 224, 'JI', 1, 0),
(3681, 224, 'JA', 1, 0),
(3682, 224, 'KR', 1, 0),
(3683, 224, 'MA', 1, 0),
(3684, 224, 'NI', 1, 0),
(3685, 224, 'PA', 1, 0),
(3686, 224, 'WI', 1, 0),
(3687, 225, 'AR', 1, 0),
(3688, 225, 'CA', 1, 0),
(3689, 225, 'CL', 1, 0),
(3690, 225, 'CO', 1, 0),
(3691, 225, 'DU', 1, 0),
(3692, 225, 'FS', 1, 0),
(3693, 225, 'FA', 1, 0),
(3694, 225, 'LA', 1, 0),
(3695, 225, 'MA', 1, 0),
(3696, 225, 'MO', 1, 0),
(3697, 225, 'PA', 1, 0),
(3698, 225, 'RN', 1, 0),
(3699, 225, 'RV', 1, 0),
(3700, 225, 'RO', 1, 0),
(3701, 225, 'SL', 1, 0),
(3702, 225, 'SJ', 1, 0),
(3703, 225, 'SO', 1, 0),
(3704, 225, 'TA', 1, 0),
(3705, 225, 'TT', 1, 0),
(3706, 226, 'AN', 1, 0),
(3707, 226, 'BU', 1, 0),
(3708, 226, 'FA', 1, 0),
(3709, 226, 'JI', 1, 0),
(3710, 226, 'NG', 1, 0),
(3711, 226, 'NW', 1, 0),
(3712, 226, 'QA', 1, 0),
(3713, 226, 'QR', 1, 0),
(3714, 226, 'SA', 1, 0),
(3715, 226, 'SI', 1, 0),
(3716, 226, 'SU', 1, 0),
(3717, 226, 'TK', 1, 0),
(3718, 226, 'TO', 1, 0),
(3719, 226, 'XO', 1, 0),
(3720, 227, 'MA', 1, 0),
(3721, 227, 'PE', 1, 0),
(3722, 227, 'SA', 1, 0),
(3723, 227, 'SH', 1, 0),
(3724, 227, 'TA', 1, 0),
(3725, 227, 'TO', 1, 0),
(3726, 229, 'AM', 1, 0),
(3727, 229, 'AN', 1, 0),
(3728, 229, 'AP', 1, 0),
(3729, 229, 'AR', 1, 0),
(3730, 229, 'BA', 1, 0),
(3731, 229, 'BO', 1, 0),
(3732, 229, 'CA', 1, 0),
(3733, 229, 'CO', 1, 0),
(3734, 229, 'DA', 1, 0),
(3735, 229, 'DF', 1, 0),
(3736, 229, 'DI', 1, 0),
(3737, 229, 'FA', 1, 0),
(3738, 229, 'GU', 1, 0),
(3739, 229, 'LA', 1, 0),
(3740, 229, 'ME', 1, 0),
(3741, 229, 'MI', 1, 0),
(3742, 229, 'MO', 1, 0),
(3743, 229, 'NE', 1, 0),
(3744, 229, 'PO', 1, 0),
(3745, 229, 'SU', 1, 0),
(3746, 229, 'TA', 1, 0),
(3747, 229, 'TR', 1, 0),
(3748, 229, 'VA', 1, 0),
(3749, 229, 'YA', 1, 0),
(3750, 229, 'ZU', 1, 0),
(3751, 230, 'AG', 1, 0),
(3752, 230, 'BG', 1, 0),
(3753, 230, 'BK', 1, 0),
(3754, 230, 'BL', 1, 0),
(3755, 230, 'BC', 1, 0),
(3756, 230, 'BR', 1, 0),
(3757, 230, 'BN', 1, 0),
(3758, 230, 'BH', 1, 0),
(3759, 230, 'BU', 1, 0),
(3760, 230, 'BP', 1, 0),
(3761, 230, 'BT', 1, 0),
(3762, 230, 'CM', 1, 0),
(3763, 230, 'CT', 1, 0),
(3764, 230, 'CB', 1, 0),
(3765, 230, 'DL', 1, 0),
(3766, 230, 'DG', 1, 0),
(3767, 230, 'DN', 1, 0),
(3768, 230, 'DB', 1, 0),
(3769, 230, 'DI', 1, 0),
(3770, 230, 'DT', 1, 0),
(3771, 230, 'GL', 1, 0),
(3772, 230, 'HG', 1, 0),
(3773, 230, 'HD', 1, 0),
(3774, 230, 'HP', 1, 0),
(3775, 230, 'HM', 1, 0),
(3776, 230, 'HI', 1, 0),
(3777, 230, 'HT', 1, 0),
(3778, 230, 'HH', 1, 0),
(3779, 230, 'HB', 1, 0),
(3780, 230, 'HC', 1, 0),
(3781, 230, 'HU', 1, 0),
(3782, 230, 'HY', 1, 0),
(3783, 232, 'C', 1, 0),
(3784, 232, 'J', 1, 0),
(3785, 232, 'T', 1, 0),
(3786, 233, 'A', 1, 0),
(3787, 233, 'S', 1, 0),
(3788, 233, 'W', 1, 0),
(3789, 235, 'AB', 1, 0),
(3790, 235, 'AD', 1, 0),
(3791, 235, 'AM', 1, 0),
(3792, 235, 'BA', 1, 0),
(3793, 235, 'DA', 1, 0),
(3794, 235, 'DH', 1, 0),
(3795, 235, 'HD', 1, 0),
(3796, 235, 'HJ', 1, 0),
(3797, 235, 'HU', 1, 0),
(3798, 235, 'IB', 1, 0),
(3799, 235, 'JA', 1, 0),
(3800, 235, 'LA', 1, 0),
(3801, 235, 'MA', 1, 0),
(3802, 235, 'MR', 1, 0),
(3803, 235, 'MW', 1, 0),
(3804, 235, 'SD', 1, 0),
(3805, 235, 'SN', 1, 0),
(3806, 235, 'SH', 1, 0),
(3807, 235, 'TA', 1, 0),
(3808, 236, 'AND', 1, 0),
(3809, 236, 'BAR', 1, 0),
(3810, 236, 'BER', 1, 0),
(3811, 236, 'BIP', 1, 0),
(3812, 49, 'BC', 1, 0),
(3813, 49, 'BN', 1, 0),
(3814, 49, 'EQ', 1, 0),
(3815, 49, 'KA', 1, 0),
(3816, 49, 'KE', 1, 0),
(3817, 49, 'KN', 1, 0),
(3818, 49, 'KW', 1, 0),
(3819, 49, 'MA', 1, 0),
(3820, 49, 'NK', 1, 0),
(3821, 49, 'OR', 1, 0),
(3822, 49, 'SK', 1, 0),
(3823, 238, 'CE', 1, 0),
(3824, 238, 'CB', 1, 0),
(3825, 238, 'EA', 1, 0),
(3826, 238, 'LP', 1, 0),
(3827, 238, 'LK', 1, 0),
(3828, 238, 'NO', 1, 0),
(3829, 238, 'NW', 1, 0),
(3830, 238, 'SO', 1, 0),
(3831, 238, 'WE', 1, 0),
(3832, 239, 'BU', 1, 0),
(3833, 239, 'HA', 1, 0),
(3834, 239, 'ML', 1, 0),
(3835, 239, 'MC', 1, 0),
(3836, 239, 'ME', 1, 0),
(3837, 239, 'MW', 1, 0),
(3838, 239, 'MV', 1, 0),
(3839, 239, 'MN', 1, 0),
(3840, 239, 'MS', 1, 0),
(3841, 239, 'MD', 1, 0),
(3842, 105, 'AG', 1, 0),
(3843, 105, 'AL', 1, 0),
(3844, 105, 'AN', 1, 0),
(3845, 105, 'AO', 1, 0),
(3846, 105, 'AR', 1, 0),
(3847, 105, 'AP', 1, 0),
(3848, 105, 'AT', 1, 0),
(3849, 105, 'AV', 1, 0),
(3850, 105, 'BA', 1, 0),
(3851, 105, 'BL', 1, 0),
(3852, 105, 'BN', 1, 0),
(3853, 105, 'BG', 1, 0),
(3854, 105, 'BI', 1, 0),
(3855, 105, 'BO', 1, 0),
(3856, 105, 'BZ', 1, 0),
(3857, 105, 'BS', 1, 0),
(3858, 105, 'BR', 1, 0),
(3859, 105, 'CA', 1, 0),
(3860, 105, 'CL', 1, 0),
(3861, 105, 'CB', 1, 0),
(3862, 105, 'CI', 1, 0),
(3863, 105, 'CE', 1, 0),
(3864, 105, 'CT', 1, 0),
(3865, 105, 'CZ', 1, 0),
(3866, 105, 'CH', 1, 0),
(3867, 105, 'CO', 1, 0),
(3868, 105, 'CS', 1, 0),
(3869, 105, 'CR', 1, 0),
(3870, 105, 'KR', 1, 0),
(3871, 105, 'CN', 1, 0),
(3872, 105, 'EN', 1, 0),
(3873, 105, 'FE', 1, 0),
(3874, 105, 'FI', 1, 0),
(3875, 105, 'FG', 1, 0),
(3876, 105, 'FC', 1, 0),
(3877, 105, 'FR', 1, 0),
(3878, 105, 'GE', 1, 0),
(3879, 105, 'GO', 1, 0),
(3880, 105, 'GR', 1, 0),
(3881, 105, 'IM', 1, 0),
(3882, 105, 'IS', 1, 0),
(3883, 105, 'AQ', 1, 0),
(3884, 105, 'SP', 1, 0),
(3885, 105, 'LT', 1, 0),
(3886, 105, 'LE', 1, 0),
(3887, 105, 'LC', 1, 0),
(3888, 105, 'LI', 1, 0),
(3889, 105, 'LO', 1, 0),
(3890, 105, 'LU', 1, 0),
(3891, 105, 'MC', 1, 0),
(3892, 105, 'MN', 1, 0),
(3893, 105, 'MS', 1, 0),
(3894, 105, 'MT', 1, 0),
(3895, 105, 'VS', 1, 0),
(3896, 105, 'ME', 1, 0),
(3897, 105, 'MI', 1, 0),
(3898, 105, 'MO', 1, 0),
(3899, 105, 'NA', 1, 0),
(3900, 105, 'NO', 1, 0),
(3901, 105, 'NU', 1, 0),
(3902, 105, 'OG', 1, 0),
(3903, 105, 'OT', 1, 0),
(3904, 105, 'OR', 1, 0),
(3905, 105, 'PD', 1, 0),
(3906, 105, 'PA', 1, 0),
(3907, 105, 'PR', 1, 0),
(3908, 105, 'PV', 1, 0),
(3909, 105, 'PG', 1, 0),
(3910, 105, 'PU', 1, 0),
(3911, 105, 'PE', 1, 0),
(3912, 105, 'PC', 1, 0),
(3913, 105, 'PI', 1, 0),
(3914, 105, 'PT', 1, 0),
(3915, 105, 'PN', 1, 0),
(3916, 105, 'PZ', 1, 0),
(3917, 105, 'PO', 1, 0),
(3918, 105, 'RG', 1, 0),
(3919, 105, 'RA', 1, 0),
(3920, 105, 'RC', 1, 0),
(3921, 105, 'RE', 1, 0),
(3922, 105, 'RI', 1, 0),
(3923, 105, 'RN', 1, 0),
(3924, 105, 'RM', 1, 0),
(3925, 105, 'RO', 1, 0),
(3926, 105, 'SA', 1, 0),
(3927, 105, 'SS', 1, 0),
(3928, 105, 'SV', 1, 0),
(3929, 105, 'SI', 1, 0),
(3930, 105, 'SR', 1, 0),
(3931, 105, 'SO', 1, 0),
(3932, 105, 'TA', 1, 0),
(3933, 105, 'TE', 1, 0),
(3934, 105, 'TR', 1, 0),
(3935, 105, 'TO', 1, 0),
(3936, 105, 'TP', 1, 0),
(3937, 105, 'TN', 1, 0),
(3938, 105, 'TV', 1, 0),
(3939, 105, 'TS', 1, 0),
(3940, 105, 'UD', 1, 0),
(3941, 105, 'VA', 1, 0),
(3942, 105, 'VE', 1, 0),
(3943, 105, 'VB', 1, 0),
(3944, 105, 'VC', 1, 0),
(3945, 105, 'VR', 1, 0),
(3946, 105, 'VV', 1, 0),
(3947, 105, 'VI', 1, 0),
(3948, 105, 'VT', 1, 0),
(3949, 240, '', 1, 0),
(3950, 240, '', 1, 0),
(3951, 240, '', 1, 0),
(3952, 240, '', 1, 0),
(3953, 240, '', 1, 0),
(3954, 240, '', 1, 0),
(3955, 190, 'MR', 1, 0),
(3956, 190, 'DR', 1, 0),
(3957, 190, 'CR', 1, 0),
(3958, 190, 'SV', 1, 0),
(3959, 190, 'CV', 1, 0),
(3960, 190, 'LS', 1, 0),
(3961, 190, 'SS', 1, 0),
(3962, 190, 'LC', 1, 0),
(3963, 190, 'CS', 1, 0),
(3964, 190, 'UC', 1, 0),
(3965, 190, 'GZ', 1, 0),
(3966, 190, 'CK', 1, 0),
(3967, 188, 'SG', 1, 0),
(3968, 168, 'MTM', 1, 0),
(3969, 236, 'BDV', 1, 0),
(3970, 236, 'CET', 1, 0),
(3971, 236, 'DNG', 1, 0),
(3972, 236, 'GSN', 1, 0),
(3973, 236, 'HGN', 1, 0),
(3974, 236, 'KLN', 1, 0),
(3975, 236, 'KOR', 1, 0),
(3976, 236, 'MKC', 1, 0),
(3977, 236, 'NKS', 1, 0),
(3978, 236, 'PTN', 1, 0),
(3979, 236, 'PLV', 1, 0),
(3980, 236, 'PVL', 1, 0),
(3981, 236, 'PZN', 1, 0),
(3982, 236, 'PGC', 1, 0),
(3983, 236, 'ROZ', 1, 0),
(3984, 236, 'SNK', 1, 0),
(3985, 236, 'TVT', 1, 0),
(3986, 236, 'TZI', 1, 0),
(3987, 236, 'ULN', 1, 0),
(3988, 236, 'ZBK', 1, 0),
(3989, 241, 'VDN', 1, 0),
(3990, 241, 'BGD', 1, 0),
(3991, 241, 'SWS', 1, 0),
(3992, 241, 'SES', 1, 0),
(3993, 241, 'KMT', 1, 0),
(3994, 242, 'FRZ', 1, 0),
(3995, 242, 'GKV', 1, 0),
(3996, 242, 'GLN', 1, 0),
(3997, 242, 'MTR', 1, 0),
(3998, 242, 'PJA', 1, 0),
(3999, 242, 'PRN', 1, 0),
(4000, 242, 'PRZ', 1, 0),
(4001, 126, 'ESN', 1, 0),
(4002, 126, 'NTN', 1, 0),
(4003, 126, 'PLG', 1, 0),
(4004, 126, 'POL', 1, 0),
(4005, 126, 'SKP', 1, 0),
(4006, 126, 'SEN', 1, 0),
(4007, 126, 'SWN', 1, 0),
(4008, 126, 'VDR', 1, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]zones_to_locations`
--

CREATE TABLE `[[dbprefix]]zones_to_locations` (
  `zone_to_location_id` int NOT NULL AUTO_INCREMENT,
  `country_id` int NOT NULL,
  `zone_id` int NOT NULL DEFAULT '0',
  `location_id` int NOT NULL,
  `date_added` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
  `date_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`zone_to_location_id`),
  KEY `[[dbprefix]]zones_to_locations_idx` (`country_id`,`zone_id`,`location_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci AUTO_INCREMENT=80 ;

--
-- Dumping data for table `[[dbprefix]]zones_to_locations`
--

INSERT INTO `[[dbprefix]]zones_to_locations` VALUES
(2, 223, 3613, 1, '[[regtime]]', '[[regtime]]'),
(3, 223, 3614, 1, '[[regtime]]', '[[regtime]]'),
(4, 223, 3615, 1, '[[regtime]]', '[[regtime]]'),
(5, 223, 3616, 1, '[[regtime]]', '[[regtime]]'),
(6, 223, 3617, 1, '[[regtime]]', '[[regtime]]'),
(7, 223, 3618, 1, '[[regtime]]', '[[regtime]]'),
(8, 223, 3619, 1, '[[regtime]]', '[[regtime]]'),
(9, 223, 3620, 1, '[[regtime]]', '[[regtime]]'),
(10, 223, 3621, 1, '[[regtime]]', '[[regtime]]'),
(11, 223, 3622, 1, '[[regtime]]', '[[regtime]]'),
(12, 223, 3623, 1, '[[regtime]]', '[[regtime]]'),
(13, 223, 3624, 1, '[[regtime]]', '[[regtime]]'),
(14, 223, 3625, 1, '[[regtime]]', '[[regtime]]'),
(15, 223, 3626, 1, '[[regtime]]', '[[regtime]]'),
(16, 223, 3627, 1, '[[regtime]]', '[[regtime]]'),
(17, 223, 3628, 1, '[[regtime]]', '[[regtime]]'),
(18, 223, 3629, 1, '[[regtime]]', '[[regtime]]'),
(19, 223, 3630, 1, '[[regtime]]', '[[regtime]]'),
(20, 223, 3631, 1, '[[regtime]]', '[[regtime]]'),
(21, 223, 3632, 1, '[[regtime]]', '[[regtime]]'),
(22, 223, 3633, 1, '[[regtime]]', '[[regtime]]'),
(23, 223, 3634, 1, '[[regtime]]', '[[regtime]]'),
(24, 223, 3635, 1, '[[regtime]]', '[[regtime]]'),
(25, 223, 3636, 1, '[[regtime]]', '[[regtime]]'),
(26, 223, 3637, 1, '[[regtime]]', '[[regtime]]'),
(27, 223, 3638, 1, '[[regtime]]', '[[regtime]]'),
(28, 223, 3639, 1, '[[regtime]]', '[[regtime]]'),
(29, 223, 3640, 1, '[[regtime]]', '[[regtime]]'),
(30, 223, 3641, 1, '[[regtime]]', '[[regtime]]'),
(31, 223, 3642, 1, '[[regtime]]', '[[regtime]]'),
(32, 223, 3643, 1, '[[regtime]]', '[[regtime]]'),
(33, 223, 3644, 1, '[[regtime]]', '[[regtime]]'),
(34, 223, 3645, 1, '[[regtime]]', '[[regtime]]'),
(35, 223, 3646, 1, '[[regtime]]', '[[regtime]]'),
(36, 223, 3647, 1, '[[regtime]]', '[[regtime]]'),
(37, 223, 3648, 1, '[[regtime]]', '[[regtime]]'),
(38, 223, 3649, 1, '[[regtime]]', '[[regtime]]'),
(39, 223, 3650, 1, '[[regtime]]', '[[regtime]]'),
(40, 223, 3651, 1, '[[regtime]]', '[[regtime]]'),
(41, 223, 3652, 1, '[[regtime]]', '[[regtime]]'),
(42, 223, 3653, 1, '[[regtime]]', '[[regtime]]'),
(43, 223, 3654, 1, '[[regtime]]', '[[regtime]]'),
(44, 223, 3655, 1, '[[regtime]]', '[[regtime]]'),
(45, 223, 3656, 1, '[[regtime]]', '[[regtime]]'),
(46, 223, 3657, 1, '[[regtime]]', '[[regtime]]'),
(47, 223, 3658, 1, '[[regtime]]', '[[regtime]]'),
(48, 223, 3659, 1, '[[regtime]]', '[[regtime]]'),
(49, 223, 3660, 1, '[[regtime]]', '[[regtime]]'),
(50, 223, 3661, 1, '[[regtime]]', '[[regtime]]'),
(51, 223, 3662, 1, '[[regtime]]', '[[regtime]]'),
(52, 223, 3663, 1, '[[regtime]]', '[[regtime]]'),
(53, 223, 3664, 1, '[[regtime]]', '[[regtime]]'),
(54, 223, 3665, 1, '[[regtime]]', '[[regtime]]'),
(55, 223, 3666, 1, '[[regtime]]', '[[regtime]]'),
(56, 223, 3667, 1, '[[regtime]]', '[[regtime]]'),
(57, 223, 3668, 1, '[[regtime]]', '[[regtime]]'),
(58, 223, 3669, 1, '[[regtime]]', '[[regtime]]'),
(59, 223, 3670, 1, '[[regtime]]', '[[regtime]]'),
(60, 223, 3671, 1, '[[regtime]]', '[[regtime]]'),
(61, 223, 3672, 1, '[[regtime]]', '[[regtime]]'),
(62, 223, 3673, 1, '[[regtime]]', '[[regtime]]'),
(63, 223, 3674, 1, '[[regtime]]', '[[regtime]]'),
(64, 223, 3675, 1, '[[regtime]]', '[[regtime]]'),
(65, 223, 3676, 1, '[[regtime]]', '[[regtime]]'),
(66, 223, 3677, 1, '[[regtime]]', '[[regtime]]'),
(67, 38, 602, 2, '[[regtime]]', '[[regtime]]'),
(68, 38, 603, 2, '[[regtime]]', '[[regtime]]'),
(69, 38, 604, 2, '[[regtime]]', '[[regtime]]'),
(70, 38, 605, 2, '[[regtime]]', '[[regtime]]'),
(71, 38, 606, 2, '[[regtime]]', '[[regtime]]'),
(72, 38, 607, 2, '[[regtime]]', '[[regtime]]'),
(73, 38, 608, 2, '[[regtime]]', '[[regtime]]'),
(74, 38, 609, 2, '[[regtime]]', '[[regtime]]'),
(75, 38, 610, 2, '[[regtime]]', '[[regtime]]'),
(76, 38, 611, 2, '[[regtime]]', '[[regtime]]'),
(77, 38, 612, 2, '[[regtime]]', '[[regtime]]'),
(78, 38, 613, 2, '[[regtime]]', '[[regtime]]'),
(79, 38, 614, 2, '[[regtime]]', '[[regtime]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]zone_descriptions`
--

CREATE TABLE `[[dbprefix]]zone_descriptions` (
  `zone_id` int NOT NULL,
  `language_id` int NOT NULL,
  `name` varchar(128) COLLATE utf8mb4_unicode_ci NOT NULL COMMENT 'translatable',
  PRIMARY KEY (`zone_id`,`language_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

--
-- Dumping data for table `[[dbprefix]]zone_descriptions`
--

INSERT INTO `[[dbprefix]]zone_descriptions` VALUES
(1, 1, 'Badakhshan'),
(2, 1, 'Badghis'),
(3, 1, 'Baghlan'),
(4, 1, 'Balkh'),
(5, 1, 'Bamian'),
(6, 1, 'Farah'),
(7, 1, 'Faryab'),
(8, 1, 'Ghazni'),
(9, 1, 'Ghowr'),
(10, 1, 'Helmand'),
(11, 1, 'Herat'),
(12, 1, 'Jowzjan'),
(13, 1, 'Kabul'),
(14, 1, 'Kandahar'),
(15, 1, 'Kapisa'),
(16, 1, 'Khost'),
(17, 1, 'Konar'),
(18, 1, 'Kondoz'),
(19, 1, 'Laghman'),
(20, 1, 'Lowgar'),
(21, 1, 'Nangrahar'),
(22, 1, 'Nimruz'),
(23, 1, 'Nurestan'),
(24, 1, 'Oruzgan'),
(25, 1, 'Paktia'),
(26, 1, 'Paktika'),
(27, 1, 'Parwan'),
(28, 1, 'Samangan'),
(29, 1, 'Sar-e Pol'),
(30, 1, 'Takhar'),
(31, 1, 'Wardak'),
(32, 1, 'Zabol'),
(33, 1, 'Berat'),
(34, 1, 'Bulqize'),
(35, 1, 'Delvine'),
(36, 1, 'Devoll'),
(37, 1, 'Diber'),
(38, 1, 'Durres'),
(39, 1, 'Elbasan'),
(40, 1, 'Kolonje'),
(41, 1, 'Fier'),
(42, 1, 'Gjirokaster'),
(43, 1, 'Gramsh'),
(44, 1, 'Has'),
(45, 1, 'Kavaje'),
(46, 1, 'Kurbin'),
(47, 1, 'Kucove'),
(48, 1, 'Korce'),
(49, 1, 'Kruje'),
(50, 1, 'Kukes'),
(51, 1, 'Librazhd'),
(52, 1, 'Lezhe'),
(53, 1, 'Lushnje'),
(54, 1, 'Malesi e Madhe'),
(55, 1, 'Mallakaster'),
(56, 1, 'Mat'),
(57, 1, 'Mirdite'),
(58, 1, 'Peqin'),
(59, 1, 'Permet'),
(60, 1, 'Pogradec'),
(61, 1, 'Puke'),
(62, 1, 'Shkoder'),
(63, 1, 'Skrapar'),
(64, 1, 'Sarande'),
(65, 1, 'Tepelene'),
(66, 1, 'Tropoje'),
(67, 1, 'Tirane'),
(68, 1, 'Vlore'),
(69, 1, 'Adrar'),
(70, 1, 'Ain Defla'),
(71, 1, 'Ain Temouchent'),
(72, 1, 'Alger'),
(73, 1, 'Annaba'),
(74, 1, 'Batna'),
(75, 1, 'Bechar'),
(76, 1, 'Bejaia'),
(77, 1, 'Biskra'),
(78, 1, 'Blida'),
(79, 1, 'Bordj Bou Arreridj'),
(80, 1, 'Bouira'),
(81, 1, 'Boumerdes'),
(82, 1, 'Chlef'),
(83, 1, 'Constantine'),
(84, 1, 'Djelfa'),
(85, 1, 'El Bayadh'),
(86, 1, 'El Oued'),
(87, 1, 'El Tarf'),
(88, 1, 'Ghardaia'),
(89, 1, 'Guelma'),
(90, 1, 'Illizi'),
(91, 1, 'Jijel'),
(92, 1, 'Khenchela'),
(93, 1, 'Laghouat'),
(94, 1, 'Muaskar'),
(95, 1, 'Medea'),
(96, 1, 'Mila'),
(97, 1, 'Mostaganem'),
(98, 1, 'M''Sila'),
(99, 1, 'Naama'),
(100, 1, 'Oran'),
(101, 1, 'Ouargla'),
(102, 1, 'Oum el-Bouaghi'),
(103, 1, 'Relizane'),
(104, 1, 'Saida'),
(105, 1, 'Setif'),
(106, 1, 'Sidi Bel Abbes'),
(107, 1, 'Skikda'),
(108, 1, 'Souk Ahras'),
(109, 1, 'Tamanghasset'),
(110, 1, 'Tebessa'),
(111, 1, 'Tiaret'),
(112, 1, 'Tindouf'),
(113, 1, 'Tipaza'),
(114, 1, 'Tissemsilt'),
(115, 1, 'Tizi Ouzou'),
(116, 1, 'Tlemcen'),
(117, 1, 'Eastern'),
(118, 1, 'Manu''a'),
(119, 1, 'Rose Island'),
(120, 1, 'Swains Island'),
(121, 1, 'Western'),
(122, 1, 'Andorra la Vella'),
(123, 1, 'Canillo'),
(124, 1, 'Encamp'),
(125, 1, 'Escaldes-Engordany'),
(126, 1, 'La Massana'),
(127, 1, 'Ordino'),
(128, 1, 'Sant Julia de Loria'),
(129, 1, 'Bengo'),
(130, 1, 'Benguela'),
(131, 1, 'Bie'),
(132, 1, 'Cabinda'),
(133, 1, 'Cuando-Cubango'),
(134, 1, 'Cuanza Norte'),
(135, 1, 'Cuanza Sul'),
(136, 1, 'Cunene'),
(137, 1, 'Huambo'),
(138, 1, 'Huila'),
(139, 1, 'Luanda'),
(140, 1, 'Lunda Norte'),
(141, 1, 'Lunda Sul'),
(142, 1, 'Malange'),
(143, 1, 'Moxico'),
(144, 1, 'Namibe'),
(145, 1, 'Uige'),
(146, 1, 'Zaire'),
(147, 1, 'Saint George'),
(148, 1, 'Saint John'),
(149, 1, 'Saint Mary'),
(150, 1, 'Saint Paul'),
(151, 1, 'Saint Peter'),
(152, 1, 'Saint Philip'),
(153, 1, 'Barbuda'),
(154, 1, 'Redonda'),
(155, 1, 'Antartida e Islas del Atlantico'),
(156, 1, 'Buenos Aires'),
(157, 1, 'Catamarca'),
(158, 1, 'Chaco'),
(159, 1, 'Chubut'),
(160, 1, 'Cordoba'),
(161, 1, 'Corrientes'),
(162, 1, 'Distrito Federal'),
(163, 1, 'Entre Rios'),
(164, 1, 'Formosa'),
(165, 1, 'Jujuy'),
(166, 1, 'La Pampa'),
(167, 1, 'La Rioja'),
(168, 1, 'Mendoza'),
(169, 1, 'Misiones'),
(170, 1, 'Neuquen'),
(171, 1, 'Rio Negro'),
(172, 1, 'Salta'),
(173, 1, 'San Juan'),
(174, 1, 'San Luis'),
(175, 1, 'Santa Cruz'),
(176, 1, 'Santa Fe'),
(177, 1, 'Santiago del Estero'),
(178, 1, 'Tierra del Fuego'),
(179, 1, 'Tucuman'),
(180, 1, 'Aragatsotn'),
(181, 1, 'Ararat'),
(182, 1, 'Armavir'),
(183, 1, 'Geghark''unik'''),
(184, 1, 'Kotayk'''),
(185, 1, 'Lorri'),
(186, 1, 'Shirak'),
(187, 1, 'Syunik'''),
(188, 1, 'Tavush'),
(189, 1, 'Vayots'' Dzor'),
(190, 1, 'Yerevan'),
(191, 1, 'Australian Capital Territory'),
(192, 1, 'New South Wales'),
(193, 1, 'Northern Territory'),
(194, 1, 'Queensland'),
(195, 1, 'South Australia'),
(196, 1, 'Tasmania'),
(197, 1, 'Victoria'),
(198, 1, 'Western Australia'),
(199, 1, 'Burgenland'),
(200, 1, 'Kärnten'),
(201, 1, 'Nieder&ouml;sterreich'),
(202, 1, 'Ober&ouml;sterreich'),
(203, 1, 'Salzburg'),
(204, 1, 'Steiermark'),
(205, 1, 'Tirol'),
(206, 1, 'Vorarlberg'),
(207, 1, 'Wien'),
(208, 1, 'Ali Bayramli'),
(209, 1, 'Abseron'),
(210, 1, 'AgcabAdi'),
(211, 1, 'Agdam'),
(212, 1, 'Agdas'),
(213, 1, 'Agstafa'),
(214, 1, 'Agsu'),
(215, 1, 'Astara'),
(216, 1, 'Baki'),
(217, 1, 'BabAk'),
(218, 1, 'BalakAn'),
(219, 1, 'BArdA'),
(220, 1, 'Beylaqan'),
(221, 1, 'Bilasuvar'),
(222, 1, 'Cabrayil'),
(223, 1, 'Calilabab'),
(224, 1, 'Culfa'),
(225, 1, 'Daskasan'),
(226, 1, 'Davaci'),
(227, 1, 'Fuzuli'),
(228, 1, 'Ganca'),
(229, 1, 'Gadabay'),
(230, 1, 'Goranboy'),
(231, 1, 'Goycay'),
(232, 1, 'Haciqabul'),
(233, 1, 'Imisli'),
(234, 1, 'Ismayilli'),
(235, 1, 'Kalbacar'),
(236, 1, 'Kurdamir'),
(237, 1, 'Lankaran'),
(238, 1, 'Lacin'),
(239, 1, 'Lankaran'),
(240, 1, 'Lerik'),
(241, 1, 'Masalli'),
(242, 1, 'Mingacevir'),
(243, 1, 'Naftalan'),
(244, 1, 'Neftcala'),
(245, 1, 'Oguz'),
(246, 1, 'Ordubad'),
(247, 1, 'Qabala'),
(248, 1, 'Qax'),
(249, 1, 'Qazax'),
(250, 1, 'Qobustan'),
(251, 1, 'Quba'),
(252, 1, 'Qubadli'),
(253, 1, 'Qusar'),
(254, 1, 'Saki'),
(255, 1, 'Saatli'),
(256, 1, 'Sabirabad'),
(257, 1, 'Sadarak'),
(258, 1, 'Sahbuz'),
(259, 1, 'Saki'),
(260, 1, 'Salyan'),
(261, 1, 'Sumqayit'),
(262, 1, 'Samaxi'),
(263, 1, 'Samkir'),
(264, 1, 'Samux'),
(265, 1, 'Sarur'),
(266, 1, 'Siyazan'),
(267, 1, 'Susa'),
(268, 1, 'Susa'),
(269, 1, 'Tartar'),
(270, 1, 'Tovuz'),
(271, 1, 'Ucar'),
(272, 1, 'Xankandi'),
(273, 1, 'Xacmaz'),
(274, 1, 'Xanlar'),
(275, 1, 'Xizi'),
(276, 1, 'Xocali'),
(277, 1, 'Xocavand'),
(278, 1, 'Yardimli'),
(279, 1, 'Yevlax'),
(280, 1, 'Zangilan'),
(281, 1, 'Zaqatala'),
(282, 1, 'Zardab'),
(283, 1, 'Naxcivan'),
(284, 1, 'Acklins'),
(285, 1, 'Berry Islands'),
(286, 1, 'Bimini'),
(287, 1, 'Black Point'),
(288, 1, 'Cat Island'),
(289, 1, 'Central Abaco'),
(290, 1, 'Central Andros'),
(291, 1, 'Central Eleuthera'),
(292, 1, 'City of Freeport'),
(293, 1, 'Crooked Island'),
(294, 1, 'East Grand Bahama'),
(295, 1, 'Exuma'),
(296, 1, 'Grand Cay'),
(297, 1, 'Harbour Island'),
(298, 1, 'Hope Town'),
(299, 1, 'Inagua'),
(300, 1, 'Long Island'),
(301, 1, 'Mangrove Cay'),
(302, 1, 'Mayaguana'),
(303, 1, 'Moore''s Island'),
(304, 1, 'North Abaco'),
(305, 1, 'North Andros'),
(306, 1, 'North Eleuthera'),
(307, 1, 'Ragged Island'),
(308, 1, 'Rum Cay'),
(309, 1, 'San Salvador'),
(310, 1, 'South Abaco'),
(311, 1, 'South Andros'),
(312, 1, 'South Eleuthera'),
(313, 1, 'Spanish Wells'),
(314, 1, 'West Grand Bahama'),
(315, 1, 'Capital'),
(316, 1, 'Central'),
(317, 1, 'Muharraq'),
(318, 1, 'Northern'),
(319, 1, 'Southern'),
(320, 1, 'Barisal'),
(321, 1, 'Chittagong'),
(322, 1, 'Dhaka'),
(323, 1, 'Khulna'),
(324, 1, 'Rajshahi'),
(325, 1, 'Sylhet'),
(326, 1, 'Christ Church'),
(327, 1, 'Saint Andrew'),
(328, 1, 'Saint George'),
(329, 1, 'Saint James'),
(330, 1, 'Saint John'),
(331, 1, 'Saint Joseph'),
(332, 1, 'Saint Lucy'),
(333, 1, 'Saint Michael'),
(334, 1, 'Saint Peter'),
(335, 1, 'Saint Philip'),
(336, 1, 'Saint Thomas'),
(337, 1, 'Brestskaya (Brest)'),
(338, 1, 'Homyel''skaya (Homyel'')'),
(339, 1, 'Horad Minsk'),
(340, 1, 'Hrodzyenskaya (Hrodna)'),
(341, 1, 'Mahilyowskaya (Mahilyow)'),
(342, 1, 'Minskaya'),
(343, 1, 'Vitsyebskaya (Vitsyebsk)'),
(344, 1, 'Antwerpen'),
(345, 1, 'Brabant Wallon'),
(346, 1, 'Hainaut'),
(347, 1, 'Liege'),
(348, 1, 'Limburg'),
(349, 1, 'Luxembourg'),
(350, 1, 'Namur'),
(351, 1, 'Oost-Vlaanderen'),
(352, 1, 'Vlaams Brabant'),
(353, 1, 'West-Vlaanderen'),
(354, 1, 'Belize'),
(355, 1, 'Cayo'),
(356, 1, 'Corozal'),
(357, 1, 'Orange Walk'),
(358, 1, 'Stann Creek'),
(359, 1, 'Toledo'),
(360, 1, 'Alibori'),
(361, 1, 'Atakora'),
(362, 1, 'Atlantique'),
(363, 1, 'Borgou'),
(364, 1, 'Collines'),
(365, 1, 'Donga'),
(366, 1, 'Kouffo'),
(367, 1, 'Littoral'),
(368, 1, 'Mono'),
(369, 1, 'Oueme'),
(370, 1, 'Plateau'),
(371, 1, 'Zou'),
(372, 1, 'Devonshire'),
(373, 1, 'Hamilton City'),
(374, 1, 'Hamilton'),
(375, 1, 'Paget'),
(376, 1, 'Pembroke'),
(377, 1, 'Saint George City'),
(378, 1, 'Saint George''s'),
(379, 1, 'Sandys'),
(380, 1, 'Smith''s'),
(381, 1, 'Southampton'),
(382, 1, 'Warwick'),
(383, 1, 'Bumthang'),
(384, 1, 'Chukha'),
(385, 1, 'Dagana'),
(386, 1, 'Gasa'),
(387, 1, 'Haa'),
(388, 1, 'Lhuntse'),
(389, 1, 'Mongar'),
(390, 1, 'Paro'),
(391, 1, 'Pemagatshel'),
(392, 1, 'Punakha'),
(393, 1, 'Samdrup Jongkhar'),
(394, 1, 'Samtse'),
(395, 1, 'Sarpang'),
(396, 1, 'Thimphu'),
(397, 1, 'Trashigang'),
(398, 1, 'Trashiyangste'),
(399, 1, 'Trongsa'),
(400, 1, 'Tsirang'),
(401, 1, 'Wangdue Phodrang'),
(402, 1, 'Zhemgang'),
(403, 1, 'Beni'),
(404, 1, 'Chuquisaca'),
(405, 1, 'Cochabamba'),
(406, 1, 'La Paz'),
(407, 1, 'Oruro'),
(408, 1, 'Pando'),
(409, 1, 'Potosi'),
(410, 1, 'Santa Cruz'),
(411, 1, 'Tarija'),
(412, 1, 'Brcko district'),
(413, 1, 'Unsko-Sanski Kanton'),
(414, 1, 'Posavski Kanton'),
(415, 1, 'Tuzlanski Kanton'),
(416, 1, 'Zenicko-Dobojski Kanton'),
(417, 1, 'Bosanskopodrinjski Kanton'),
(418, 1, 'Srednjebosanski Kanton'),
(419, 1, 'Hercegovacko-neretvanski Kanton'),
(420, 1, 'Zapadnohercegovacka Zupanija'),
(421, 1, 'Kanton Sarajevo'),
(422, 1, 'Zapadnobosanska'),
(423, 1, 'Banja Luka'),
(424, 1, 'Doboj'),
(425, 1, 'Bijeljina'),
(426, 1, 'Vlasenica'),
(427, 1, 'Sarajevo-Romanija or Sokolac'),
(428, 1, 'Foca'),
(429, 1, 'Trebinje'),
(430, 1, 'Central'),
(431, 1, 'Ghanzi'),
(432, 1, 'Kgalagadi'),
(433, 1, 'Kgatleng'),
(434, 1, 'Kweneng'),
(435, 1, 'Ngamiland'),
(436, 1, 'North East'),
(437, 1, 'North West'),
(438, 1, 'South East'),
(439, 1, 'Southern'),
(440, 1, 'Acre'),
(441, 1, 'Alagoas'),
(442, 1, 'Amapa'),
(443, 1, 'Amazonas'),
(444, 1, 'Bahia'),
(445, 1, 'Ceara'),
(446, 1, 'Distrito Federal'),
(447, 1, 'Espirito Santo'),
(448, 1, 'Goias'),
(449, 1, 'Maranhao'),
(450, 1, 'Mato Grosso'),
(451, 1, 'Mato Grosso do Sul'),
(452, 1, 'Minas Gerais'),
(453, 1, 'Para'),
(454, 1, 'Paraiba'),
(455, 1, 'Parana'),
(456, 1, 'Pernambuco'),
(457, 1, 'Piaui'),
(458, 1, 'Rio de Janeiro'),
(459, 1, 'Rio Grande do Norte'),
(460, 1, 'Rio Grande do Sul'),
(461, 1, 'Rondonia'),
(462, 1, 'Roraima'),
(463, 1, 'Santa Catarina'),
(464, 1, 'Sao Paulo'),
(465, 1, 'Sergipe'),
(466, 1, 'Tocantins'),
(467, 1, 'Peros Banhos'),
(468, 1, 'Salomon Islands'),
(469, 1, 'Nelsons Island'),
(470, 1, 'Three Brothers'),
(471, 1, 'Eagle Islands'),
(472, 1, 'Danger Island'),
(473, 1, 'Egmont Islands'),
(474, 1, 'Diego Garcia'),
(475, 1, 'Belait'),
(476, 1, 'Brunei and Muara'),
(477, 1, 'Temburong'),
(478, 1, 'Tutong'),
(479, 1, 'Blagoevgrad'),
(480, 1, 'Burgas'),
(481, 1, 'Dobrich'),
(482, 1, 'Gabrovo'),
(483, 1, 'Haskovo'),
(484, 1, 'Kardjali'),
(485, 1, 'Kyustendil'),
(486, 1, 'Lovech'),
(487, 1, 'Montana'),
(488, 1, 'Pazardjik'),
(489, 1, 'Pernik'),
(490, 1, 'Pleven'),
(491, 1, 'Plovdiv'),
(492, 1, 'Razgrad'),
(493, 1, 'Shumen'),
(494, 1, 'Silistra'),
(495, 1, 'Sliven'),
(496, 1, 'Smolyan'),
(497, 1, 'Sofia'),
(498, 1, 'Sofia - town'),
(499, 1, 'Stara Zagora'),
(500, 1, 'Targovishte'),
(501, 1, 'Varna'),
(502, 1, 'Veliko Tarnovo'),
(503, 1, 'Vidin'),
(504, 1, 'Vratza'),
(505, 1, 'Yambol'),
(506, 1, 'Bale'),
(507, 1, 'Bam'),
(508, 1, 'Banwa'),
(509, 1, 'Bazega'),
(510, 1, 'Bougouriba'),
(511, 1, 'Boulgou'),
(512, 1, 'Boulkiemde'),
(513, 1, 'Comoe'),
(514, 1, 'Ganzourgou'),
(515, 1, 'Gnagna'),
(516, 1, 'Gourma'),
(517, 1, 'Houet'),
(518, 1, 'Ioba'),
(519, 1, 'Kadiogo'),
(520, 1, 'Kenedougou'),
(521, 1, 'Komondjari'),
(522, 1, 'Kompienga'),
(523, 1, 'Kossi'),
(524, 1, 'Koulpelogo'),
(525, 1, 'Kouritenga'),
(526, 1, 'Kourweogo'),
(527, 1, 'Leraba'),
(528, 1, 'Loroum'),
(529, 1, 'Mouhoun'),
(530, 1, 'Nahouri'),
(531, 1, 'Namentenga'),
(532, 1, 'Nayala'),
(533, 1, 'Noumbiel'),
(534, 1, 'Oubritenga'),
(535, 1, 'Oudalan'),
(536, 1, 'Passore'),
(537, 1, 'Poni'),
(538, 1, 'Sanguie'),
(539, 1, 'Sanmatenga'),
(540, 1, 'Seno'),
(541, 1, 'Sissili'),
(542, 1, 'Soum'),
(543, 1, 'Sourou'),
(544, 1, 'Tapoa'),
(545, 1, 'Tuy'),
(546, 1, 'Yagha'),
(547, 1, 'Yatenga'),
(548, 1, 'Ziro'),
(549, 1, 'Zondoma'),
(550, 1, 'Zoundweogo'),
(551, 1, 'Bubanza'),
(552, 1, 'Bujumbura'),
(553, 1, 'Bururi'),
(554, 1, 'Cankuzo'),
(555, 1, 'Cibitoke'),
(556, 1, 'Gitega'),
(557, 1, 'Karuzi'),
(558, 1, 'Kayanza'),
(559, 1, 'Kirundo'),
(560, 1, 'Makamba'),
(561, 1, 'Muramvya'),
(562, 1, 'Muyinga'),
(563, 1, 'Mwaro'),
(564, 1, 'Ngozi'),
(565, 1, 'Rutana'),
(566, 1, 'Ruyigi'),
(567, 1, 'Phnom Penh'),
(568, 1, 'Preah Seihanu (Kompong Som or Sihanoukville)'),
(569, 1, 'Pailin'),
(570, 1, 'Keb'),
(571, 1, 'Banteay Meanchey'),
(572, 1, 'Battambang'),
(573, 1, 'Kampong Cham'),
(574, 1, 'Kampong Chhnang'),
(575, 1, 'Kampong Speu'),
(576, 1, 'Kampong Som'),
(577, 1, 'Kampong Thom'),
(578, 1, 'Kampot'),
(579, 1, 'Kandal'),
(580, 1, 'Kaoh Kong'),
(581, 1, 'Kratie'),
(582, 1, 'Mondul Kiri'),
(583, 1, 'Oddar Meancheay'),
(584, 1, 'Pursat'),
(585, 1, 'Preah Vihear'),
(586, 1, 'Prey Veng'),
(587, 1, 'Ratanak Kiri'),
(588, 1, 'Siemreap'),
(589, 1, 'Stung Treng'),
(590, 1, 'Svay Rieng'),
(591, 1, 'Takeo'),
(592, 1, 'Adamawa (Adamaoua)'),
(593, 1, 'Centre'),
(594, 1, 'East (Est)'),
(595, 1, 'Extreme North (Extreme-Nord)'),
(596, 1, 'Littoral'),
(597, 1, 'North (Nord)'),
(598, 1, 'Northwest (Nord-Ouest)'),
(599, 1, 'West (Ouest)'),
(600, 1, 'South (Sud)'),
(601, 1, 'Southwest (Sud-Ouest).'),
(602, 1, 'Alberta'),
(603, 1, 'British Columbia'),
(604, 1, 'Manitoba'),
(605, 1, 'New Brunswick'),
(606, 1, 'Newfoundland and Labrador'),
(607, 1, 'Northwest Territories'),
(608, 1, 'Nova Scotia'),
(609, 1, 'Nunavut'),
(610, 1, 'Ontario'),
(611, 1, 'Prince Edward Island'),
(612, 1, 'Qu&eacute;bec'),
(613, 1, 'Saskatchewan'),
(614, 1, 'Yukon Territory'),
(615, 1, 'Boa Vista'),
(616, 1, 'Brava'),
(617, 1, 'Calheta de Sao Miguel'),
(618, 1, 'Maio'),
(619, 1, 'Mosteiros'),
(620, 1, 'Paul'),
(621, 1, 'Porto Novo'),
(622, 1, 'Praia'),
(623, 1, 'Ribeira Grande'),
(624, 1, 'Sal'),
(625, 1, 'Santa Catarina'),
(626, 1, 'Santa Cruz'),
(627, 1, 'Sao Domingos'),
(628, 1, 'Sao Filipe'),
(629, 1, 'Sao Nicolau'),
(630, 1, 'Sao Vicente'),
(631, 1, 'Tarrafal'),
(632, 1, 'Creek'),
(633, 1, 'Eastern'),
(634, 1, 'Midland'),
(635, 1, 'South Town'),
(636, 1, 'Spot Bay'),
(637, 1, 'Stake Bay'),
(638, 1, 'West End'),
(639, 1, 'Western'),
(640, 1, 'Bamingui-Bangoran'),
(641, 1, 'Basse-Kotto'),
(642, 1, 'Haute-Kotto'),
(643, 1, 'Haut-Mbomou'),
(644, 1, 'Kemo'),
(645, 1, 'Lobaye'),
(646, 1, 'Mambere-KadeÔ'),
(647, 1, 'Mbomou'),
(648, 1, 'Nana-Mambere'),
(649, 1, 'Ombella-M''Poko'),
(650, 1, 'Ouaka'),
(651, 1, 'Ouham'),
(652, 1, 'Ouham-Pende'),
(653, 1, 'Vakaga'),
(654, 1, 'Nana-Grebizi'),
(655, 1, 'Sangha-Mbaere'),
(656, 1, 'Bangui'),
(657, 1, 'Batha'),
(658, 1, 'Biltine'),
(659, 1, 'Borkou-Ennedi-Tibesti'),
(660, 1, 'Chari-Baguirmi'),
(661, 1, 'Guera'),
(662, 1, 'Kanem'),
(663, 1, 'Lac'),
(664, 1, 'Logone Occidental'),
(665, 1, 'Logone Oriental'),
(666, 1, 'Mayo-Kebbi'),
(667, 1, 'Moyen-Chari'),
(668, 1, 'Ouaddai'),
(669, 1, 'Salamat'),
(670, 1, 'Tandjile'),
(671, 1, 'Aisen del General Carlos Ibanez'),
(672, 1, 'Antofagasta'),
(673, 1, 'Araucania'),
(674, 1, 'Atacama'),
(675, 1, 'Bio-Bio'),
(676, 1, 'Coquimbo'),
(677, 1, 'Libertador General Bernardo O''Hi'),
(678, 1, 'Los Lagos'),
(679, 1, 'Magallanes y de la Antartica Chi'),
(680, 1, 'Maule'),
(681, 1, 'Region Metropolitana'),
(682, 1, 'Tarapaca'),
(683, 1, 'Valparaiso'),
(684, 1, 'Anhui'),
(685, 1, 'Beijing'),
(686, 1, 'Chongqing'),
(687, 1, 'Fujian'),
(688, 1, 'Gansu'),
(689, 1, 'Guangdong'),
(690, 1, 'Guangxi'),
(691, 1, 'Guizhou'),
(692, 1, 'Hainan'),
(693, 1, 'Hebei'),
(694, 1, 'Heilongjiang'),
(695, 1, 'Henan'),
(696, 1, 'Hong Kong'),
(697, 1, 'Hubei'),
(698, 1, 'Hunan'),
(699, 1, 'Inner Mongolia'),
(700, 1, 'Jiangsu'),
(701, 1, 'Jiangxi'),
(702, 1, 'Jilin'),
(703, 1, 'Liaoning'),
(704, 1, 'Macau'),
(705, 1, 'Ningxia'),
(706, 1, 'Shaanxi'),
(707, 1, 'Shandong'),
(708, 1, 'Shanghai'),
(709, 1, 'Shanxi'),
(710, 1, 'Sichuan'),
(711, 1, 'Tianjin'),
(712, 1, 'Xinjiang'),
(713, 1, 'Yunnan'),
(714, 1, 'Zhejiang'),
(715, 1, 'Direction Island'),
(716, 1, 'Home Island'),
(717, 1, 'Horsburgh Island'),
(718, 1, 'South Island'),
(719, 1, 'West Island'),
(720, 1, 'Amazonas'),
(721, 1, 'Antioquia'),
(722, 1, 'Arauca'),
(723, 1, 'Atlantico'),
(724, 1, 'Bogota D.C.'),
(725, 1, 'Bolivar'),
(726, 1, 'Boyaca'),
(727, 1, 'Caldas'),
(728, 1, 'Caqueta'),
(729, 1, 'Casanare'),
(730, 1, 'Cauca'),
(731, 1, 'Cesar'),
(732, 1, 'Choco'),
(733, 1, 'Cordoba'),
(734, 1, 'Cundinamarca'),
(735, 1, 'Guainia'),
(736, 1, 'Guajira'),
(737, 1, 'Guaviare'),
(738, 1, 'Huila'),
(739, 1, 'Magdalena'),
(740, 1, 'Meta'),
(741, 1, 'Narino'),
(742, 1, 'Norte de Santander'),
(743, 1, 'Putumayo'),
(744, 1, 'Quindio'),
(745, 1, 'Risaralda'),
(746, 1, 'San Andres y Providencia'),
(747, 1, 'Santander'),
(748, 1, 'Sucre'),
(749, 1, 'Tolima'),
(750, 1, 'Valle del Cauca'),
(751, 1, 'Vaupes'),
(752, 1, 'Vichada'),
(753, 1, 'Grande Comore'),
(754, 1, 'Anjouan'),
(755, 1, 'Moheli'),
(756, 1, 'Bouenza'),
(757, 1, 'Brazzaville'),
(758, 1, 'Cuvette'),
(759, 1, 'Cuvette-Ouest'),
(760, 1, 'Kouilou'),
(761, 1, 'Lekoumou'),
(762, 1, 'Likouala'),
(763, 1, 'Niari'),
(764, 1, 'Plateaux'),
(765, 1, 'Pool'),
(766, 1, 'Sangha'),
(767, 1, 'Pukapuka'),
(768, 1, 'Rakahanga'),
(769, 1, 'Manihiki'),
(770, 1, 'Penrhyn'),
(771, 1, 'Nassau Island'),
(772, 1, 'Surwarrow'),
(773, 1, 'Palmerston'),
(774, 1, 'Aitutaki'),
(775, 1, 'Manuae'),
(776, 1, 'Takutea'),
(777, 1, 'Mitiaro'),
(778, 1, 'Atiu'),
(779, 1, 'Mauke'),
(780, 1, 'Rarotonga'),
(781, 1, 'Mangaia'),
(782, 1, 'Alajuela'),
(783, 1, 'Cartago'),
(784, 1, 'Guanacaste'),
(785, 1, 'Heredia'),
(786, 1, 'Limon'),
(787, 1, 'Puntarenas'),
(788, 1, 'San Jose'),
(789, 1, 'Abengourou'),
(790, 1, 'Abidjan'),
(791, 1, 'Aboisso'),
(792, 1, 'Adiake'),
(793, 1, 'Adzope'),
(794, 1, 'Agboville'),
(795, 1, 'Agnibilekrou'),
(796, 1, 'Alepe'),
(797, 1, 'Bocanda'),
(798, 1, 'Bangolo'),
(799, 1, 'Beoumi'),
(800, 1, 'Biankouma'),
(801, 1, 'Bondoukou'),
(802, 1, 'Bongouanou'),
(803, 1, 'Bouafle'),
(804, 1, 'Bouake'),
(805, 1, 'Bouna'),
(806, 1, 'Boundiali'),
(807, 1, 'Dabakala'),
(808, 1, 'Dabou'),
(809, 1, 'Daloa'),
(810, 1, 'Danane'),
(811, 1, 'Daoukro'),
(812, 1, 'Dimbokro'),
(813, 1, 'Divo'),
(814, 1, 'Duekoue'),
(815, 1, 'Ferkessedougou'),
(816, 1, 'Gagnoa'),
(817, 1, 'Grand-Bassam'),
(818, 1, 'Grand-Lahou'),
(819, 1, 'Guiglo'),
(820, 1, 'Issia'),
(821, 1, 'Jacqueville'),
(822, 1, 'Katiola'),
(823, 1, 'Korhogo'),
(824, 1, 'Lakota'),
(825, 1, 'Man'),
(826, 1, 'Mankono'),
(827, 1, 'Mbahiakro'),
(828, 1, 'Odienne'),
(829, 1, 'Oume'),
(830, 1, 'Sakassou'),
(831, 1, 'San-Pedro'),
(832, 1, 'Sassandra'),
(833, 1, 'Seguela'),
(834, 1, 'Sinfra'),
(835, 1, 'Soubre'),
(836, 1, 'Tabou'),
(837, 1, 'Tanda'),
(838, 1, 'Tiebissou'),
(839, 1, 'Tingrela'),
(840, 1, 'Tiassale'),
(841, 1, 'Touba'),
(842, 1, 'Toulepleu'),
(843, 1, 'Toumodi'),
(844, 1, 'Vavoua'),
(845, 1, 'Yamoussoukro'),
(846, 1, 'Zuenoula'),
(847, 1, 'Bjelovar-Bilogora'),
(848, 1, 'City of Zagreb'),
(849, 1, 'Dubrovnik-Neretva'),
(850, 1, 'Istra'),
(851, 1, 'Karlovac'),
(852, 1, 'Koprivnica-Krizevci'),
(853, 1, 'Krapina-Zagorje'),
(854, 1, 'Lika-Senj'),
(855, 1, 'Medimurje'),
(856, 1, 'Osijek-Baranja'),
(857, 1, 'Pozega-Slavonia'),
(858, 1, 'Primorje-Gorski Kotar'),
(859, 1, 'Sibenik'),
(860, 1, 'Sisak-Moslavina'),
(861, 1, 'Slavonski Brod-Posavina'),
(862, 1, 'Split-Dalmatia'),
(863, 1, 'Varazdin'),
(864, 1, 'Virovitica-Podravina'),
(865, 1, 'Vukovar-Srijem'),
(866, 1, 'Zadar-Knin'),
(867, 1, 'Zagreb'),
(868, 1, 'Camaguey'),
(869, 1, 'Ciego de Avila'),
(870, 1, 'Cienfuegos'),
(871, 1, 'Ciudad de La Habana'),
(872, 1, 'Granma'),
(873, 1, 'Guantanamo'),
(874, 1, 'Holguin'),
(875, 1, 'Isla de la Juventud'),
(876, 1, 'La Habana'),
(877, 1, 'Las Tunas'),
(878, 1, 'Matanzas'),
(879, 1, 'Pinar del Rio'),
(880, 1, 'Sancti Spiritus'),
(881, 1, 'Santiago de Cuba'),
(882, 1, 'Villa Clara'),
(883, 1, 'Famagusta'),
(884, 1, 'Kyrenia'),
(885, 1, 'Larnaca'),
(886, 1, 'Limassol'),
(887, 1, 'Nicosia'),
(888, 1, 'Paphos'),
(889, 1, 'Ustecky'),
(890, 1, 'Jihocesky'),
(891, 1, 'Jihomoravsky'),
(892, 1, 'Karlovarsky'),
(893, 1, 'Kralovehradecky'),
(894, 1, 'Liberecky'),
(895, 1, 'Moravskoslezsky'),
(896, 1, 'Olomoucky'),
(897, 1, 'Pardubicky'),
(898, 1, 'Plzensky'),
(899, 1, 'Praha'),
(900, 1, 'Stredocesky'),
(901, 1, 'Vysocina'),
(902, 1, 'Zlinsky'),
(903, 1, 'Arhus'),
(904, 1, 'Bornholm'),
(905, 1, 'Copenhagen'),
(906, 1, 'Faroe Islands'),
(907, 1, 'Frederiksborg'),
(908, 1, 'Fyn'),
(909, 1, 'Kobenhavn'),
(910, 1, 'Nordjylland'),
(911, 1, 'Ribe'),
(912, 1, 'Ringkobing'),
(913, 1, 'Roskilde'),
(914, 1, 'Sonderjylland'),
(915, 1, 'Storstrom'),
(916, 1, 'Vejle'),
(917, 1, 'Vestj&aelig;lland'),
(918, 1, 'Viborg'),
(919, 1, '''Ali Sabih'),
(920, 1, 'Dikhil'),
(921, 1, 'Djibouti'),
(922, 1, 'Obock'),
(923, 1, 'Tadjoura'),
(924, 1, 'Saint Andrew Parish'),
(925, 1, 'Saint David Parish'),
(926, 1, 'Saint George Parish'),
(927, 1, 'Saint John Parish'),
(928, 1, 'Saint Joseph Parish'),
(929, 1, 'Saint Luke Parish'),
(930, 1, 'Saint Mark Parish'),
(931, 1, 'Saint Patrick Parish'),
(932, 1, 'Saint Paul Parish'),
(933, 1, 'Saint Peter Parish'),
(934, 1, 'Distrito Nacional'),
(935, 1, 'Azua'),
(936, 1, 'Baoruco'),
(937, 1, 'Barahona'),
(938, 1, 'Dajabon'),
(939, 1, 'Duarte'),
(940, 1, 'Elias Pina'),
(941, 1, 'El Seybo'),
(942, 1, 'Espaillat'),
(943, 1, 'Hato Mayor'),
(944, 1, 'Independencia'),
(945, 1, 'La Altagracia'),
(946, 1, 'La Romana'),
(947, 1, 'La Vega'),
(948, 1, 'Maria Trinidad Sanchez'),
(949, 1, 'Monsenor Nouel'),
(950, 1, 'Monte Cristi'),
(951, 1, 'Monte Plata'),
(952, 1, 'Pedernales'),
(953, 1, 'Peravia (Bani)'),
(954, 1, 'Puerto Plata'),
(955, 1, 'Salcedo'),
(956, 1, 'Samana'),
(957, 1, 'Sanchez Ramirez'),
(958, 1, 'San Cristobal'),
(959, 1, 'San Jose de Ocoa'),
(960, 1, 'San Juan'),
(961, 1, 'San Pedro de Macoris'),
(962, 1, 'Santiago'),
(963, 1, 'Santiago Rodriguez'),
(964, 1, 'Santo Domingo'),
(965, 1, 'Valverde'),
(966, 1, 'Aileu'),
(967, 1, 'Ainaro'),
(968, 1, 'Baucau'),
(969, 1, 'Bobonaro'),
(970, 1, 'Cova Lima'),
(971, 1, 'Dili'),
(972, 1, 'Ermera'),
(973, 1, 'Lautem'),
(974, 1, 'Liquica'),
(975, 1, 'Manatuto'),
(976, 1, 'Manufahi'),
(977, 1, 'Oecussi'),
(978, 1, 'Viqueque'),
(979, 1, 'Azuay'),
(980, 1, 'Bolivar'),
(981, 1, 'Ca&ntilde;ar'),
(982, 1, 'Carchi'),
(983, 1, 'Chimborazo'),
(984, 1, 'Cotopaxi'),
(985, 1, 'El Oro'),
(986, 1, 'Esmeraldas'),
(987, 1, 'Gal&aacute;pagos'),
(988, 1, 'Guayas'),
(989, 1, 'Imbabura'),
(990, 1, 'Loja'),
(991, 1, 'Los Rios'),
(992, 1, 'Manab&iacute;'),
(993, 1, 'Morona Santiago'),
(994, 1, 'Napo'),
(995, 1, 'Orellana'),
(996, 1, 'Pastaza'),
(997, 1, 'Pichincha'),
(998, 1, 'Sucumb&iacute;os'),
(999, 1, 'Tungurahua'),
(1000, 1, 'Zamora Chinchipe'),
(1001, 1, 'Ad Daqahliyah'),
(1002, 1, 'Al Bahr al Ahmar'),
(1003, 1, 'Al Buhayrah'),
(1004, 1, 'Al Fayyum'),
(1005, 1, 'Al Gharbiyah'),
(1006, 1, 'Al Iskandariyah'),
(1007, 1, 'Al Isma''iliyah'),
(1008, 1, 'Al Jizah'),
(1009, 1, 'Al Minufiyah'),
(1010, 1, 'Al Minya'),
(1011, 1, 'Al Qahirah'),
(1012, 1, 'Al Qalyubiyah'),
(1013, 1, 'Al Wadi al Jadid'),
(1014, 1, 'Ash Sharqiyah'),
(1015, 1, 'As Suways'),
(1016, 1, 'Aswan'),
(1017, 1, 'Asyut'),
(1018, 1, 'Bani Suwayf'),
(1019, 1, 'Bur Sa''id'),
(1020, 1, 'Dumyat'),
(1021, 1, 'Janub Sina'''),
(1022, 1, 'Kafr ash Shaykh'),
(1023, 1, 'Matruh'),
(1024, 1, 'Qina'),
(1025, 1, 'Shamal Sina'''),
(1026, 1, 'Suhaj'),
(1027, 1, 'Ahuachapan'),
(1028, 1, 'Cabanas'),
(1029, 1, 'Chalatenango'),
(1030, 1, 'Cuscatlan'),
(1031, 1, 'La Libertad'),
(1032, 1, 'La Paz'),
(1033, 1, 'La Union'),
(1034, 1, 'Morazan'),
(1035, 1, 'San Miguel'),
(1036, 1, 'San Salvador'),
(1037, 1, 'San Vicente'),
(1038, 1, 'Santa Ana'),
(1039, 1, 'Sonsonate'),
(1040, 1, 'Usulutan'),
(1041, 1, 'Provincia Annobon'),
(1042, 1, 'Provincia Bioko Norte'),
(1043, 1, 'Provincia Bioko Sur'),
(1044, 1, 'Provincia Centro Sur'),
(1045, 1, 'Provincia Kie-Ntem'),
(1046, 1, 'Provincia Litoral'),
(1047, 1, 'Provincia Wele-Nzas'),
(1048, 1, 'Central (Maekel)'),
(1049, 1, 'Anseba (Keren)'),
(1050, 1, 'Southern Red Sea (Debub-Keih-Bahri)'),
(1051, 1, 'Northern Red Sea (Semien-Keih-Bahri)'),
(1052, 1, 'Southern (Debub)'),
(1053, 1, 'Gash-Barka (Barentu)'),
(1054, 1, 'Harjumaa (Tallinn)'),
(1055, 1, 'Hiiumaa (Kardla)'),
(1056, 1, 'Ida-Virumaa (Johvi)'),
(1057, 1, 'Jarvamaa (Paide)'),
(1058, 1, 'Jogevamaa (Jogeva)'),
(1059, 1, 'Laane-Virumaa (Rakvere)'),
(1060, 1, 'Laanemaa (Haapsalu)'),
(1061, 1, 'Parnumaa (Parnu)'),
(1062, 1, 'Polvamaa (Polva)'),
(1063, 1, 'Raplamaa (Rapla)'),
(1064, 1, 'Saaremaa (Kuessaare)'),
(1065, 1, 'Tartumaa (Tartu)'),
(1066, 1, 'Valgamaa (Valga)'),
(1067, 1, 'Viljandimaa (Viljandi)'),
(1068, 1, 'Vorumaa (Voru)'),
(1069, 1, 'Afar'),
(1070, 1, 'Amhara'),
(1071, 1, 'Benishangul-Gumaz'),
(1072, 1, 'Gambela'),
(1073, 1, 'Hariai'),
(1074, 1, 'Oromia'),
(1075, 1, 'Somali'),
(1076, 1, 'Southern Nations - Nationalities and Peoples Region'),
(1077, 1, 'Tigray'),
(1078, 1, 'Addis Ababa'),
(1079, 1, 'Dire Dawa'),
(1080, 1, 'Central Division'),
(1081, 1, 'Northern Division'),
(1082, 1, 'Eastern Division'),
(1083, 1, 'Western Division'),
(1084, 1, 'Rotuma'),
(1085, 1, 'Ahvenanmaan Laani'),
(1086, 1, 'Etela-Suomen Laani'),
(1087, 1, 'Ita-Suomen Laani'),
(1088, 1, 'Lansi-Suomen Laani'),
(1089, 1, 'Lapin Lanani'),
(1090, 1, 'Oulun Laani'),
(1091, 1, 'Alsace'),
(1092, 1, 'Aquitaine'),
(1093, 1, 'Auvergne'),
(1094, 1, 'Brittany'),
(1095, 1, 'Burgundy'),
(1096, 1, 'Center Loire Valley'),
(1097, 1, 'Champagne'),
(1098, 1, 'Corse'),
(1099, 1, 'France Comte'),
(1100, 1, 'Languedoc Roussillon'),
(1101, 1, 'Limousin'),
(1102, 1, 'Lorraine'),
(1103, 1, 'Midi Pyrenees'),
(1104, 1, 'Nord Pas de Calais'),
(1105, 1, 'Normandy'),
(1106, 1, 'Paris / Ill de France'),
(1107, 1, 'Picardie'),
(1108, 1, 'Poitou Charente'),
(1109, 1, 'Provence'),
(1110, 1, 'Rhone Alps'),
(1111, 1, 'Riviera'),
(1112, 1, 'Western Loire Valley'),
(1113, 1, 'Etranger'),
(1114, 1, 'Ain'),
(1115, 1, 'Aisne'),
(1116, 1, 'Allier'),
(1117, 1, 'Alpes de Haute Provence'),
(1118, 1, 'Hautes-Alpes'),
(1119, 1, 'Alpes Maritimes'),
(1120, 1, 'Ard&egrave;che'),
(1121, 1, 'Ardennes'),
(1122, 1, 'Ari&egrave;ge'),
(1123, 1, 'Aube'),
(1124, 1, 'Aude'),
(1125, 1, 'Aveyron'),
(1126, 1, 'Bouches du Rh&ocirc;ne'),
(1127, 1, 'Calvados'),
(1128, 1, 'Cantal'),
(1129, 1, 'Charente'),
(1130, 1, 'Charente Maritime'),
(1131, 1, 'Cher'),
(1132, 1, 'Corr&egrave;ze'),
(1133, 1, 'Corse du Sud'),
(1134, 1, 'Haute Corse'),
(1135, 1, 'C&ocirc;te d&#039;or'),
(1136, 1, 'C&ocirc;tes d&#039;Armor'),
(1137, 1, 'Creuse'),
(1138, 1, 'Dordogne'),
(1139, 1, 'Doubs'),
(1140, 1, 'Dr&ocirc;me'),
(1141, 1, 'Eure'),
(1142, 1, 'Eure et Loir'),
(1143, 1, 'Finist&egrave;re'),
(1144, 1, 'Gard'),
(1145, 1, 'Haute Garonne'),
(1146, 1, 'Gers'),
(1147, 1, 'Gironde'),
(1148, 1, 'H&eacute;rault'),
(1149, 1, 'Ille et Vilaine'),
(1150, 1, 'Indre'),
(1151, 1, 'Indre et Loire'),
(1152, 1, 'Is&eacute;re'),
(1153, 1, 'Jura'),
(1154, 1, 'Landes'),
(1155, 1, 'Loir et Cher'),
(1156, 1, 'Loire'),
(1157, 1, 'Haute Loire'),
(1158, 1, 'Loire Atlantique'),
(1159, 1, 'Loiret'),
(1160, 1, 'Lot'),
(1161, 1, 'Lot et Garonne'),
(1162, 1, 'Loz&egrave;re'),
(1163, 1, 'Maine et Loire'),
(1164, 1, 'Manche'),
(1165, 1, 'Marne'),
(1166, 1, 'Haute Marne'),
(1167, 1, 'Mayenne'),
(1168, 1, 'Meurthe et Moselle'),
(1169, 1, 'Meuse'),
(1170, 1, 'Morbihan'),
(1171, 1, 'Moselle'),
(1172, 1, 'Ni&egrave;vre'),
(1173, 1, 'Nord'),
(1174, 1, 'Oise'),
(1175, 1, 'Orne'),
(1176, 1, 'Pas de Calais'),
(1177, 1, 'Puy de D&ocirc;me'),
(1178, 1, 'Pyr&eacute;n&eacute;es Atlantiques'),
(1179, 1, 'Hautes Pyr&eacute;n&eacute;es'),
(1180, 1, 'Pyr&eacute;n&eacute;es Orientales'),
(1181, 1, 'Bas Rhin'),
(1182, 1, 'Haut Rhin'),
(1183, 1, 'Rh&ocirc;ne'),
(1184, 1, 'Haute Sa&ocirc;ne'),
(1185, 1, 'Sa&ocirc;ne et Loire'),
(1186, 1, 'Sarthe'),
(1187, 1, 'Savoie'),
(1188, 1, 'Haute Savoie'),
(1189, 1, 'Paris'),
(1190, 1, 'Seine Maritime'),
(1191, 1, 'Seine et Marne'),
(1192, 1, 'Yvelines'),
(1193, 1, 'Deux S&egrave;vres'),
(1194, 1, 'Somme'),
(1195, 1, 'Tarn'),
(1196, 1, 'Tarn et Garonne'),
(1197, 1, 'Var'),
(1198, 1, 'Vaucluse'),
(1199, 1, 'Vend&eacute;e'),
(1200, 1, 'Vienne'),
(1201, 1, 'Haute Vienne'),
(1202, 1, 'Vosges'),
(1203, 1, 'Yonne'),
(1204, 1, 'Territoire de Belfort'),
(1205, 1, 'Essonne'),
(1206, 1, 'Hauts de Seine'),
(1207, 1, 'Seine St-Denis'),
(1208, 1, 'Val de Marne'),
(1209, 1, 'Val d''Oise'),
(1210, 1, 'Archipel des Marquises'),
(1211, 1, 'Archipel des Tuamotu'),
(1212, 1, 'Archipel des Tubuai'),
(1213, 1, 'Iles du Vent'),
(1214, 1, 'Iles Sous-le-Vent'),
(1215, 1, 'Iles Crozet'),
(1216, 1, 'Iles Kerguelen'),
(1217, 1, 'Ile Amsterdam'),
(1218, 1, 'Ile Saint-Paul'),
(1219, 1, 'Adelie Land'),
(1220, 1, 'Estuaire'),
(1221, 1, 'Haut-Ogooue'),
(1222, 1, 'Moyen-Ogooue'),
(1223, 1, 'Ngounie'),
(1224, 1, 'Nyanga'),
(1225, 1, 'Ogooue-Ivindo'),
(1226, 1, 'Ogooue-Lolo'),
(1227, 1, 'Ogooue-Maritime'),
(1228, 1, 'Woleu-Ntem'),
(1229, 1, 'Banjul'),
(1230, 1, 'Basse'),
(1231, 1, 'Brikama'),
(1232, 1, 'Janjangbure'),
(1233, 1, 'Kanifeng'),
(1234, 1, 'Kerewan'),
(1235, 1, 'Kuntaur'),
(1236, 1, 'Mansakonko'),
(1237, 1, 'Lower River'),
(1238, 1, 'Central River'),
(1239, 1, 'North Bank'),
(1240, 1, 'Upper River'),
(1241, 1, 'Western'),
(1242, 1, 'Abkhazia'),
(1243, 1, 'Ajaria'),
(1244, 1, 'Tbilisi'),
(1245, 1, 'Guria'),
(1246, 1, 'Imereti'),
(1247, 1, 'Kakheti'),
(1248, 1, 'Kvemo Kartli'),
(1249, 1, 'Mtskheta-Mtianeti'),
(1250, 1, 'Racha Lechkhumi and Kvemo Svanet'),
(1251, 1, 'Samegrelo-Zemo Svaneti'),
(1252, 1, 'Samtskhe-Javakheti'),
(1253, 1, 'Shida Kartli'),
(1254, 1, 'Baden-W&uuml;rttemberg'),
(1255, 1, 'Bayern'),
(1256, 1, 'Berlin'),
(1257, 1, 'Brandenburg'),
(1258, 1, 'Bremen'),
(1259, 1, 'Hamburg'),
(1260, 1, 'Hessen'),
(1261, 1, 'Mecklenburg-Vorpommern'),
(1262, 1, 'Niedersachsen'),
(1263, 1, 'Nordrhein-Westfalen'),
(1264, 1, 'Rheinland-Pfalz'),
(1265, 1, 'Saarland'),
(1266, 1, 'Sachsen'),
(1267, 1, 'Sachsen-Anhalt'),
(1268, 1, 'Schleswig-Holstein'),
(1269, 1, 'Th&uuml;ringen'),
(1270, 1, 'Ashanti Region'),
(1271, 1, 'Brong-Ahafo Region'),
(1272, 1, 'Central Region'),
(1273, 1, 'Eastern Region'),
(1274, 1, 'Greater Accra Region'),
(1275, 1, 'Northern Region'),
(1276, 1, 'Upper East Region'),
(1277, 1, 'Upper West Region'),
(1278, 1, 'Volta Region'),
(1279, 1, 'Western Region'),
(1280, 1, 'Attica'),
(1281, 1, 'Central Greece'),
(1282, 1, 'Central Macedonia'),
(1283, 1, 'Crete'),
(1284, 1, 'East Macedonia and Thrace'),
(1285, 1, 'Epirus'),
(1286, 1, 'Ionian Islands'),
(1287, 1, 'North Aegean'),
(1288, 1, 'Peloponnesos'),
(1289, 1, 'South Aegean'),
(1290, 1, 'Thessaly'),
(1291, 1, 'West Greece'),
(1292, 1, 'West Macedonia'),
(1293, 1, 'Avannaa'),
(1294, 1, 'Tunu'),
(1295, 1, 'Kitaa'),
(1296, 1, 'Saint Andrew'),
(1297, 1, 'Saint David'),
(1298, 1, 'Saint George'),
(1299, 1, 'Saint John'),
(1300, 1, 'Saint Mark'),
(1301, 1, 'Saint Patrick'),
(1302, 1, 'Carriacou'),
(1303, 1, 'Petit Martinique'),
(1304, 1, 'Alta Verapaz'),
(1305, 1, 'Baja Verapaz'),
(1306, 1, 'Chimaltenango'),
(1307, 1, 'Chiquimula'),
(1308, 1, 'El Peten'),
(1309, 1, 'El Progreso'),
(1310, 1, 'El Quiche'),
(1311, 1, 'Escuintla'),
(1312, 1, 'Guatemala'),
(1313, 1, 'Huehuetenango'),
(1314, 1, 'Izabal'),
(1315, 1, 'Jalapa'),
(1316, 1, 'Jutiapa'),
(1317, 1, 'Quetzaltenango'),
(1318, 1, 'Retalhuleu'),
(1319, 1, 'Sacatepequez'),
(1320, 1, 'San Marcos'),
(1321, 1, 'Santa Rosa'),
(1322, 1, 'Solola'),
(1323, 1, 'Suchitepequez'),
(1324, 1, 'Totonicapan'),
(1325, 1, 'Zacapa'),
(1326, 1, 'Conakry'),
(1327, 1, 'Beyla'),
(1328, 1, 'Boffa'),
(1329, 1, 'Boke'),
(1330, 1, 'Coyah'),
(1331, 1, 'Dabola'),
(1332, 1, 'Dalaba'),
(1333, 1, 'Dinguiraye'),
(1334, 1, 'Dubreka'),
(1335, 1, 'Faranah'),
(1336, 1, 'Forecariah'),
(1337, 1, 'Fria'),
(1338, 1, 'Gaoual'),
(1339, 1, 'Gueckedou'),
(1340, 1, 'Kankan'),
(1341, 1, 'Kerouane'),
(1342, 1, 'Kindia'),
(1343, 1, 'Kissidougou'),
(1344, 1, 'Koubia'),
(1345, 1, 'Koundara'),
(1346, 1, 'Kouroussa'),
(1347, 1, 'Labe'),
(1348, 1, 'Lelouma'),
(1349, 1, 'Lola'),
(1350, 1, 'Macenta'),
(1351, 1, 'Mali'),
(1352, 1, 'Mamou'),
(1353, 1, 'Mandiana'),
(1354, 1, 'Nzerekore'),
(1355, 1, 'Pita'),
(1356, 1, 'Siguiri'),
(1357, 1, 'Telimele'),
(1358, 1, 'Tougue'),
(1359, 1, 'Yomou'),
(1360, 1, 'Bafata Region'),
(1361, 1, 'Biombo Region'),
(1362, 1, 'Bissau Region'),
(1363, 1, 'Bolama Region'),
(1364, 1, 'Cacheu Region'),
(1365, 1, 'Gabu Region'),
(1366, 1, 'Oio Region'),
(1367, 1, 'Quinara Region'),
(1368, 1, 'Tombali Region'),
(1369, 1, 'Barima-Waini'),
(1370, 1, 'Cuyuni-Mazaruni'),
(1371, 1, 'Demerara-Mahaica'),
(1372, 1, 'East Berbice-Corentyne'),
(1373, 1, 'Essequibo Islands-West Demerara'),
(1374, 1, 'Mahaica-Berbice'),
(1375, 1, 'Pomeroon-Supenaam'),
(1376, 1, 'Potaro-Siparuni'),
(1377, 1, 'Upper Demerara-Berbice'),
(1378, 1, 'Upper Takutu-Upper Essequibo'),
(1379, 1, 'Artibonite'),
(1380, 1, 'Centre'),
(1381, 1, 'Grand''Anse'),
(1382, 1, 'Nord'),
(1383, 1, 'Nord-Est'),
(1384, 1, 'Nord-Ouest'),
(1385, 1, 'Ouest'),
(1386, 1, 'Sud'),
(1387, 1, 'Sud-Est'),
(1388, 1, 'Flat Island'),
(1389, 1, 'McDonald Island'),
(1390, 1, 'Shag Island'),
(1391, 1, 'Heard Island'),
(1392, 1, 'Atlantida'),
(1393, 1, 'Choluteca'),
(1394, 1, 'Colon'),
(1395, 1, 'Comayagua'),
(1396, 1, 'Copan'),
(1397, 1, 'Cortes'),
(1398, 1, 'El Paraiso'),
(1399, 1, 'Francisco Morazan'),
(1400, 1, 'Gracias a Dios'),
(1401, 1, 'Intibuca'),
(1402, 1, 'Islas de la Bahia (Bay Islands)'),
(1403, 1, 'La Paz'),
(1404, 1, 'Lempira'),
(1405, 1, 'Ocotepeque'),
(1406, 1, 'Olancho'),
(1407, 1, 'Santa Barbara'),
(1408, 1, 'Valle'),
(1409, 1, 'Yoro'),
(1410, 1, 'Central and Western Hong Kong Island'),
(1411, 1, 'Eastern Hong Kong Island'),
(1412, 1, 'Southern Hong Kong Island'),
(1413, 1, 'Wan Chai Hong Kong Island'),
(1414, 1, 'Kowloon City Kowloon'),
(1415, 1, 'Kwun Tong Kowloon'),
(1416, 1, 'Sham Shui Po Kowloon'),
(1417, 1, 'Wong Tai Sin Kowloon'),
(1418, 1, 'Yau Tsim Mong Kowloon'),
(1419, 1, 'Islands New Territories'),
(1420, 1, 'Kwai Tsing New Territories'),
(1421, 1, 'North New Territories'),
(1422, 1, 'Sai Kung New Territories'),
(1423, 1, 'Sha Tin New Territories'),
(1424, 1, 'Tai Po New Territories'),
(1425, 1, 'Tsuen Wan New Territories'),
(1426, 1, 'Tuen Mun New Territories'),
(1427, 1, 'Yuen Long New Territories'),
(1428, 1, 'Bacs-Kiskun'),
(1429, 1, 'Baranya'),
(1430, 1, 'Bekes'),
(1431, 1, 'Bekescsaba'),
(1432, 1, 'Borsod-Abauj-Zemplen'),
(1433, 1, 'Budapest'),
(1434, 1, 'Csongrad'),
(1435, 1, 'Debrecen'),
(1436, 1, 'Dunaujvaros'),
(1437, 1, 'Eger'),
(1438, 1, 'Fejer'),
(1439, 1, 'Gyor'),
(1440, 1, 'Gyor-Moson-Sopron'),
(1441, 1, 'Hajdu-Bihar'),
(1442, 1, 'Heves'),
(1443, 1, 'Hodmezovasarhely'),
(1444, 1, 'Jasz-Nagykun-Szolnok'),
(1445, 1, 'Kaposvar'),
(1446, 1, 'Kecskemet'),
(1447, 1, 'Komarom-Esztergom'),
(1448, 1, 'Miskolc'),
(1449, 1, 'Nagykanizsa'),
(1450, 1, 'Nograd'),
(1451, 1, 'Nyiregyhaza'),
(1452, 1, 'Pecs'),
(1453, 1, 'Pest'),
(1454, 1, 'Somogy'),
(1455, 1, 'Sopron'),
(1456, 1, 'Szabolcs-Szatmar-Bereg'),
(1457, 1, 'Szeged'),
(1458, 1, 'Szekesfehervar'),
(1459, 1, 'Szolnok'),
(1460, 1, 'Szombathely'),
(1461, 1, 'Tatabanya'),
(1462, 1, 'Tolna'),
(1463, 1, 'Vas'),
(1464, 1, 'Veszprem'),
(1465, 1, 'Zala'),
(1466, 1, 'Zalaegerszeg'),
(1467, 1, 'Austurland'),
(1468, 1, 'Hofuoborgarsvaeoi'),
(1469, 1, 'Norourland eystra'),
(1470, 1, 'Norourland vestra'),
(1471, 1, 'Suourland'),
(1472, 1, 'Suournes'),
(1473, 1, 'Vestfiroir'),
(1474, 1, 'Vesturland'),
(1475, 1, 'Andaman and Nicobar Islands'),
(1476, 1, 'Andhra Pradesh'),
(1477, 1, 'Arunachal Pradesh'),
(1478, 1, 'Assam'),
(1479, 1, 'Bihar'),
(1480, 1, 'Chandigarh'),
(1481, 1, 'Dadra and Nagar Haveli'),
(1482, 1, 'Daman and Diu'),
(1483, 1, 'Delhi'),
(1484, 1, 'Goa'),
(1485, 1, 'Gujarat'),
(1486, 1, 'Haryana'),
(1487, 1, 'Himachal Pradesh'),
(1488, 1, 'Jammu and Kashmir'),
(1489, 1, 'Karnataka'),
(1490, 1, 'Kerala'),
(1491, 1, 'Lakshadweep Islands'),
(1492, 1, 'Madhya Pradesh'),
(1493, 1, 'Maharashtra'),
(1494, 1, 'Manipur'),
(1495, 1, 'Meghalaya'),
(1496, 1, 'Mizoram'),
(1497, 1, 'Nagaland'),
(1498, 1, 'Orissa'),
(1499, 1, 'Pondicherry'),
(1500, 1, 'Punjab'),
(1501, 1, 'Rajasthan'),
(1502, 1, 'Sikkim'),
(1503, 1, 'Tamil Nadu'),
(1504, 1, 'Tripura'),
(1505, 1, 'Uttar Pradesh'),
(1506, 1, 'West Bengal'),
(1507, 1, 'Aceh'),
(1508, 1, 'Bali'),
(1509, 1, 'Banten'),
(1510, 1, 'Bengkulu'),
(1511, 1, 'BoDeTaBek'),
(1512, 1, 'Gorontalo'),
(1513, 1, 'Jakarta Raya'),
(1514, 1, 'Jambi'),
(1515, 1, 'Jawa Barat'),
(1516, 1, 'Jawa Tengah'),
(1517, 1, 'Jawa Timur'),
(1518, 1, 'Kalimantan Barat'),
(1519, 1, 'Kalimantan Selatan'),
(1520, 1, 'Kalimantan Tengah'),
(1521, 1, 'Kalimantan Timur'),
(1522, 1, 'Kepulauan Bangka Belitung'),
(1523, 1, 'Lampung'),
(1524, 1, 'Maluku'),
(1525, 1, 'Maluku Utara'),
(1526, 1, 'Nusa Tenggara Barat'),
(1527, 1, 'Nusa Tenggara Timur'),
(1528, 1, 'Papua'),
(1529, 1, 'Riau'),
(1530, 1, 'Sulawesi Selatan'),
(1531, 1, 'Sulawesi Tengah'),
(1532, 1, 'Sulawesi Tenggara'),
(1533, 1, 'Sulawesi Utara'),
(1534, 1, 'Sumatera Barat'),
(1535, 1, 'Sumatera Selatan'),
(1536, 1, 'Sumatera Utara'),
(1537, 1, 'Yogyakarta'),
(1538, 1, 'Tehran'),
(1539, 1, 'Qom'),
(1540, 1, 'Markazi'),
(1541, 1, 'Qazvin'),
(1542, 1, 'Gilan'),
(1543, 1, 'Ardabil'),
(1544, 1, 'Zanjan'),
(1545, 1, 'East Azarbaijan'),
(1546, 1, 'West Azarbaijan'),
(1547, 1, 'Kurdistan'),
(1548, 1, 'Hamadan'),
(1549, 1, 'Kermanshah'),
(1550, 1, 'Ilam'),
(1551, 1, 'Lorestan'),
(1552, 1, 'Khuzestan'),
(1553, 1, 'Chahar Mahaal and Bakhtiari'),
(1554, 1, 'Kohkiluyeh and Buyer Ahmad'),
(1555, 1, 'Bushehr'),
(1556, 1, 'Fars'),
(1557, 1, 'Hormozgan'),
(1558, 1, 'Sistan and Baluchistan'),
(1559, 1, 'Kerman'),
(1560, 1, 'Yazd'),
(1561, 1, 'Esfahan'),
(1562, 1, 'Semnan'),
(1563, 1, 'Mazandaran'),
(1564, 1, 'Golestan'),
(1565, 1, 'North Khorasan'),
(1566, 1, 'Razavi Khorasan'),
(1567, 1, 'South Khorasan'),
(1568, 1, 'Baghdad'),
(1569, 1, 'Salah ad Din'),
(1570, 1, 'Diyala'),
(1571, 1, 'Wasit'),
(1572, 1, 'Maysan'),
(1573, 1, 'Al Basrah'),
(1574, 1, 'Dhi Qar'),
(1575, 1, 'Al Muthanna'),
(1576, 1, 'Al Qadisyah'),
(1577, 1, 'Babil'),
(1578, 1, 'Al Karbala'),
(1579, 1, 'An Najaf'),
(1580, 1, 'Al Anbar'),
(1581, 1, 'Ninawa'),
(1582, 1, 'Dahuk'),
(1583, 1, 'Arbil'),
(1584, 1, 'At Ta''mim'),
(1585, 1, 'As Sulaymaniyah'),
(1586, 1, 'Carlow'),
(1587, 1, 'Cavan'),
(1588, 1, 'Clare'),
(1589, 1, 'Cork'),
(1590, 1, 'Donegal'),
(1591, 1, 'Dublin'),
(1592, 1, 'Galway'),
(1593, 1, 'Kerry'),
(1594, 1, 'Kildare'),
(1595, 1, 'Kilkenny'),
(1596, 1, 'Laois'),
(1597, 1, 'Leitrim'),
(1598, 1, 'Limerick'),
(1599, 1, 'Longford'),
(1600, 1, 'Louth'),
(1601, 1, 'Mayo'),
(1602, 1, 'Meath'),
(1603, 1, 'Monaghan'),
(1604, 1, 'Offaly'),
(1605, 1, 'Roscommon'),
(1606, 1, 'Sligo'),
(1607, 1, 'Tipperary'),
(1608, 1, 'Waterford'),
(1609, 1, 'Westmeath'),
(1610, 1, 'Wexford'),
(1611, 1, 'Wicklow'),
(1612, 1, 'Be''er Sheva'),
(1613, 1, 'Bika''at Hayarden'),
(1614, 1, 'Eilat and Arava'),
(1615, 1, 'Galil'),
(1616, 1, 'Haifa'),
(1617, 1, 'Jehuda Mountains'),
(1618, 1, 'Jerusalem'),
(1619, 1, 'Negev'),
(1620, 1, 'Semaria'),
(1621, 1, 'Sharon'),
(1622, 1, 'Tel Aviv (Gosh Dan)'),
(1643, 1, 'Clarendon Parish'),
(1644, 1, 'Hanover Parish'),
(1645, 1, 'Kingston Parish'),
(1646, 1, 'Manchester Parish'),
(1647, 1, 'Portland Parish'),
(1648, 1, 'Saint Andrew Parish'),
(1649, 1, 'Saint Ann Parish'),
(1650, 1, 'Saint Catherine Parish'),
(1651, 1, 'Saint Elizabeth Parish'),
(1652, 1, 'Saint James Parish'),
(1653, 1, 'Saint Mary Parish'),
(1654, 1, 'Saint Thomas Parish'),
(1655, 1, 'Trelawny Parish'),
(1656, 1, 'Westmoreland Parish'),
(1657, 1, 'Aichi'),
(1658, 1, 'Akita'),
(1659, 1, 'Aomori'),
(1660, 1, 'Chiba'),
(1661, 1, 'Ehime'),
(1662, 1, 'Fukui'),
(1663, 1, 'Fukuoka'),
(1664, 1, 'Fukushima'),
(1665, 1, 'Gifu'),
(1666, 1, 'Gumma'),
(1667, 1, 'Hiroshima'),
(1668, 1, 'Hokkaido'),
(1669, 1, 'Hyogo'),
(1670, 1, 'Ibaraki'),
(1671, 1, 'Ishikawa'),
(1672, 1, 'Iwate'),
(1673, 1, 'Kagawa'),
(1674, 1, 'Kagoshima'),
(1675, 1, 'Kanagawa'),
(1676, 1, 'Kochi'),
(1677, 1, 'Kumamoto'),
(1678, 1, 'Kyoto'),
(1679, 1, 'Mie'),
(1680, 1, 'Miyagi'),
(1681, 1, 'Miyazaki'),
(1682, 1, 'Nagano'),
(1683, 1, 'Nagasaki'),
(1684, 1, 'Nara'),
(1685, 1, 'Niigata'),
(1686, 1, 'Oita'),
(1687, 1, 'Okayama'),
(1688, 1, 'Okinawa'),
(1689, 1, 'Osaka'),
(1690, 1, 'Saga'),
(1691, 1, 'Saitama'),
(1692, 1, 'Shiga'),
(1693, 1, 'Shimane'),
(1694, 1, 'Shizuoka'),
(1695, 1, 'Tochigi'),
(1696, 1, 'Tokushima'),
(1697, 1, 'Tokyo'),
(1698, 1, 'Tottori'),
(1699, 1, 'Toyama'),
(1700, 1, 'Wakayama'),
(1701, 1, 'Yamagata'),
(1702, 1, 'Yamaguchi'),
(1703, 1, 'Yamanashi'),
(1704, 1, '''Amman'),
(1705, 1, 'Ajlun'),
(1706, 1, 'Al ''Aqabah'),
(1707, 1, 'Al Balqa'''),
(1708, 1, 'Al Karak'),
(1709, 1, 'Al Mafraq'),
(1710, 1, 'At Tafilah'),
(1711, 1, 'Az Zarqa'''),
(1712, 1, 'Irbid'),
(1713, 1, 'Jarash'),
(1714, 1, 'Ma''an'),
(1715, 1, 'Madaba'),
(1716, 1, 'Almaty'),
(1717, 1, 'Almaty City'),
(1718, 1, 'Aqmola'),
(1719, 1, 'Aqtobe'),
(1720, 1, 'Astana City'),
(1721, 1, 'Atyrau'),
(1722, 1, 'Batys Qazaqstan'),
(1723, 1, 'Bayqongyr City'),
(1724, 1, 'Mangghystau'),
(1725, 1, 'Ongtustik Qazaqstan'),
(1726, 1, 'Pavlodar'),
(1727, 1, 'Qaraghandy'),
(1728, 1, 'Qostanay'),
(1729, 1, 'Qyzylorda'),
(1730, 1, 'Shyghys Qazaqstan'),
(1731, 1, 'Soltustik Qazaqstan'),
(1732, 1, 'Zhambyl'),
(1733, 1, 'Central'),
(1734, 1, 'Coast'),
(1735, 1, 'Eastern'),
(1736, 1, 'Nairobi Area'),
(1737, 1, 'North Eastern'),
(1738, 1, 'Nyanza'),
(1739, 1, 'Rift Valley'),
(1740, 1, 'Western'),
(1741, 1, 'Abaiang'),
(1742, 1, 'Abemama'),
(1743, 1, 'Aranuka'),
(1744, 1, 'Arorae'),
(1745, 1, 'Banaba'),
(1746, 1, 'Beru'),
(1747, 1, 'Butaritari'),
(1748, 1, 'Kanton'),
(1749, 1, 'Kiritimati'),
(1750, 1, 'Kuria'),
(1751, 1, 'Maiana'),
(1752, 1, 'Makin'),
(1753, 1, 'Marakei'),
(1754, 1, 'Nikunau'),
(1755, 1, 'Nonouti'),
(1756, 1, 'Onotoa'),
(1757, 1, 'Tabiteuea'),
(1758, 1, 'Tabuaeran'),
(1759, 1, 'Tamana'),
(1760, 1, 'Tarawa'),
(1761, 1, 'Teraina'),
(1762, 1, 'Chagang-do'),
(1763, 1, 'Hamgyong-bukto'),
(1764, 1, 'Hamgyong-namdo'),
(1765, 1, 'Hwanghae-bukto'),
(1766, 1, 'Hwanghae-namdo'),
(1767, 1, 'Kangwon-do'),
(1768, 1, 'P''yongan-bukto'),
(1769, 1, 'P''yongan-namdo'),
(1770, 1, 'Ryanggang-do (Yanggang-do)'),
(1771, 1, 'Rason Directly Governed City'),
(1772, 1, 'P''yongyang Special City'),
(1773, 1, 'Ch''ungch''ong-bukto'),
(1774, 1, 'Ch''ungch''ong-namdo'),
(1775, 1, 'Cheju-do'),
(1776, 1, 'Cholla-bukto'),
(1777, 1, 'Cholla-namdo'),
(1778, 1, 'Inch''on-gwangyoksi'),
(1779, 1, 'Kangwon-do'),
(1780, 1, 'Kwangju-gwangyoksi'),
(1781, 1, 'Kyonggi-do'),
(1782, 1, 'Kyongsang-bukto'),
(1783, 1, 'Kyongsang-namdo'),
(1784, 1, 'Pusan-gwangyoksi'),
(1785, 1, 'Soul-t''ukpyolsi'),
(1786, 1, 'Taegu-gwangyoksi'),
(1787, 1, 'Taejon-gwangyoksi'),
(1788, 1, 'Al ''Asimah'),
(1789, 1, 'Al Ahmadi'),
(1790, 1, 'Al Farwaniyah'),
(1791, 1, 'Al Jahra'''),
(1792, 1, 'Hawalli'),
(1793, 1, 'Bishkek'),
(1794, 1, 'Batken'),
(1795, 1, 'Chu'),
(1796, 1, 'Jalal-Abad'),
(1797, 1, 'Naryn'),
(1798, 1, 'Osh'),
(1799, 1, 'Talas'),
(1800, 1, 'Ysyk-Kol'),
(1801, 1, 'Vientiane'),
(1802, 1, 'Attapu'),
(1803, 1, 'Bokeo'),
(1804, 1, 'Bolikhamxai'),
(1805, 1, 'Champasak'),
(1806, 1, 'Houaphan'),
(1807, 1, 'Khammouan'),
(1808, 1, 'Louang Namtha'),
(1809, 1, 'Louangphabang'),
(1810, 1, 'Oudomxai'),
(1811, 1, 'Phongsali'),
(1812, 1, 'Salavan'),
(1813, 1, 'Savannakhet'),
(1814, 1, 'Vientiane'),
(1815, 1, 'Xaignabouli'),
(1816, 1, 'Xekong'),
(1817, 1, 'Xiangkhoang'),
(1818, 1, 'Xaisomboun'),
(1819, 1, 'Aizkraukles Rajons'),
(1820, 1, 'Aluksnes Rajons'),
(1821, 1, 'Balvu Rajons'),
(1822, 1, 'Bauskas Rajons'),
(1823, 1, 'Cesu Rajons'),
(1824, 1, 'Daugavpils Rajons'),
(1825, 1, 'Dobeles Rajons'),
(1826, 1, 'Gulbenes Rajons'),
(1827, 1, 'Jekabpils Rajons'),
(1828, 1, 'Jelgavas Rajons'),
(1829, 1, 'Kraslavas Rajons'),
(1830, 1, 'Kuldigas Rajons'),
(1831, 1, 'Liepajas Rajons'),
(1832, 1, 'Limbazu Rajons'),
(1833, 1, 'Ludzas Rajons'),
(1834, 1, 'Madonas Rajons'),
(1835, 1, 'Ogres Rajons'),
(1836, 1, 'Preilu Rajons'),
(1837, 1, 'Rezeknes Rajons'),
(1838, 1, 'Rigas Rajons'),
(1839, 1, 'Saldus Rajons'),
(1840, 1, 'Talsu Rajons'),
(1841, 1, 'Tukuma Rajons'),
(1842, 1, 'Valkas Rajons'),
(1843, 1, 'Valmieras Rajons'),
(1844, 1, 'Ventspils Rajons'),
(1845, 1, 'Daugavpils'),
(1846, 1, 'Jelgava'),
(1847, 1, 'Jurmala'),
(1848, 1, 'Liepaja'),
(1849, 1, 'Rezekne'),
(1850, 1, 'Riga'),
(1851, 1, 'Ventspils'),
(1852, 1, 'Berea'),
(1853, 1, 'Butha-Buthe'),
(1854, 1, 'Leribe'),
(1855, 1, 'Mafeteng'),
(1856, 1, 'Maseru'),
(1857, 1, 'Mohale''s Hoek'),
(1858, 1, 'Mokhotlong'),
(1859, 1, 'Qacha''s Nek'),
(1860, 1, 'Quthing'),
(1861, 1, 'Thaba-Tseka'),
(1862, 1, 'Bomi'),
(1863, 1, 'Bong'),
(1864, 1, 'Grand Bassa'),
(1865, 1, 'Grand Cape Mount'),
(1866, 1, 'Grand Gedeh'),
(1867, 1, 'Grand Kru'),
(1868, 1, 'Lofa'),
(1869, 1, 'Margibi'),
(1870, 1, 'Maryland'),
(1871, 1, 'Montserrado'),
(1872, 1, 'Nimba'),
(1873, 1, 'River Cess'),
(1874, 1, 'Sinoe'),
(1875, 1, 'Ajdabiya'),
(1876, 1, 'Al ''Aziziyah'),
(1877, 1, 'Al Fatih'),
(1878, 1, 'Al Jabal al Akhdar'),
(1879, 1, 'Al Jufrah'),
(1880, 1, 'Al Khums'),
(1881, 1, 'Al Kufrah'),
(1882, 1, 'An Nuqat al Khams'),
(1883, 1, 'Ash Shati'''),
(1884, 1, 'Awbari'),
(1885, 1, 'Az Zawiyah'),
(1886, 1, 'Banghazi'),
(1887, 1, 'Darnah'),
(1888, 1, 'Ghadamis'),
(1889, 1, 'Gharyan'),
(1890, 1, 'Misratah'),
(1891, 1, 'Murzuq'),
(1892, 1, 'Sabha'),
(1893, 1, 'Sawfajjin'),
(1894, 1, 'Surt'),
(1895, 1, 'Tarabulus (Tripoli)'),
(1896, 1, 'Tarhunah'),
(1897, 1, 'Tubruq'),
(1898, 1, 'Yafran'),
(1899, 1, 'Zlitan'),
(1900, 1, 'Vaduz'),
(1901, 1, 'Schaan'),
(1902, 1, 'Balzers'),
(1903, 1, 'Triesen'),
(1904, 1, 'Eschen'),
(1905, 1, 'Mauren'),
(1906, 1, 'Triesenberg'),
(1907, 1, 'Ruggell'),
(1908, 1, 'Gamprin'),
(1909, 1, 'Schellenberg'),
(1910, 1, 'Planken'),
(1911, 1, 'Alytus'),
(1912, 1, 'Kaunas'),
(1913, 1, 'Klaipeda'),
(1914, 1, 'Marijampole'),
(1915, 1, 'Panevezys'),
(1916, 1, 'Siauliai'),
(1917, 1, 'Taurage'),
(1918, 1, 'Telsiai'),
(1919, 1, 'Utena'),
(1920, 1, 'Vilnius'),
(1921, 1, 'Diekirch'),
(1922, 1, 'Clervaux'),
(1923, 1, 'Redange'),
(1924, 1, 'Vianden'),
(1925, 1, 'Wiltz'),
(1926, 1, 'Grevenmacher'),
(1927, 1, 'Echternach'),
(1928, 1, 'Remich'),
(1929, 1, 'Luxembourg'),
(1930, 1, 'Capellen'),
(1931, 1, 'Esch-sur-Alzette'),
(1932, 1, 'Mersch'),
(1933, 1, 'Our Lady Fatima Parish'),
(1934, 1, 'St. Anthony Parish'),
(1935, 1, 'St. Lazarus Parish'),
(1936, 1, 'Cathedral Parish'),
(1937, 1, 'St. Lawrence Parish'),
(1938, 1, 'Antananarivo'),
(1939, 1, 'Antsiranana'),
(1940, 1, 'Fianarantsoa'),
(1941, 1, 'Mahajanga'),
(1942, 1, 'Toamasina'),
(1943, 1, 'Toliara'),
(1944, 1, 'Balaka'),
(1945, 1, 'Blantyre'),
(1946, 1, 'Chikwawa'),
(1947, 1, 'Chiradzulu'),
(1948, 1, 'Chitipa'),
(1949, 1, 'Dedza'),
(1950, 1, 'Dowa'),
(1951, 1, 'Karonga'),
(1952, 1, 'Kasungu'),
(1953, 1, 'Likoma'),
(1954, 1, 'Lilongwe'),
(1955, 1, 'Machinga'),
(1956, 1, 'Mangochi'),
(1957, 1, 'Mchinji'),
(1958, 1, 'Mulanje'),
(1959, 1, 'Mwanza'),
(1960, 1, 'Mzimba'),
(1961, 1, 'Ntcheu'),
(1962, 1, 'Nkhata Bay'),
(1963, 1, 'Nkhotakota'),
(1964, 1, 'Nsanje'),
(1965, 1, 'Ntchisi'),
(1966, 1, 'Phalombe'),
(1967, 1, 'Rumphi'),
(1968, 1, 'Salima'),
(1969, 1, 'Thyolo'),
(1970, 1, 'Zomba'),
(1971, 1, 'Johor'),
(1972, 1, 'Kedah'),
(1973, 1, 'Kelantan'),
(1974, 1, 'Labuan'),
(1975, 1, 'Melaka'),
(1976, 1, 'Negeri Sembilan'),
(1977, 1, 'Pahang'),
(1978, 1, 'Perak'),
(1979, 1, 'Perlis'),
(1980, 1, 'Pulau Pinang'),
(1981, 1, 'Sabah'),
(1982, 1, 'Sarawak'),
(1983, 1, 'Selangor'),
(1984, 1, 'Terengganu'),
(1985, 1, 'Wilayah Persekutuan'),
(1986, 1, 'Thiladhunmathi Uthuru'),
(1987, 1, 'Thiladhunmathi Dhekunu'),
(1988, 1, 'Miladhunmadulu Uthuru'),
(1989, 1, 'Miladhunmadulu Dhekunu'),
(1990, 1, 'Maalhosmadulu Uthuru'),
(1991, 1, 'Maalhosmadulu Dhekunu'),
(1992, 1, 'Faadhippolhu'),
(1993, 1, 'Male Atoll'),
(1994, 1, 'Ari Atoll Uthuru'),
(1995, 1, 'Ari Atoll Dheknu'),
(1996, 1, 'Felidhe Atoll'),
(1997, 1, 'Mulaku Atoll'),
(1998, 1, 'Nilandhe Atoll Uthuru'),
(1999, 1, 'Nilandhe Atoll Dhekunu'),
(2000, 1, 'Kolhumadulu'),
(2001, 1, 'Hadhdhunmathi'),
(2002, 1, 'Huvadhu Atoll Uthuru'),
(2003, 1, 'Huvadhu Atoll Dhekunu'),
(2004, 1, 'Fua Mulaku'),
(2005, 1, 'Addu'),
(2006, 1, 'Gao'),
(2007, 1, 'Kayes'),
(2008, 1, 'Kidal'),
(2009, 1, 'Koulikoro'),
(2010, 1, 'Mopti'),
(2011, 1, 'Segou'),
(2012, 1, 'Sikasso'),
(2013, 1, 'Tombouctou'),
(2014, 1, 'Bamako Capital District'),
(2015, 1, 'Attard'),
(2016, 1, 'Balzan'),
(2017, 1, 'Birgu'),
(2018, 1, 'Birkirkara'),
(2019, 1, 'Birzebbuga'),
(2020, 1, 'Bormla'),
(2021, 1, 'Dingli'),
(2022, 1, 'Fgura'),
(2023, 1, 'Floriana'),
(2024, 1, 'Gudja'),
(2025, 1, 'Gzira'),
(2026, 1, 'Gargur'),
(2027, 1, 'Gaxaq'),
(2028, 1, 'Hamrun'),
(2029, 1, 'Iklin'),
(2030, 1, 'Isla'),
(2031, 1, 'Kalkara'),
(2032, 1, 'Kirkop'),
(2033, 1, 'Lija'),
(2034, 1, 'Luqa'),
(2035, 1, 'Marsa'),
(2036, 1, 'Marsaskala'),
(2037, 1, 'Marsaxlokk'),
(2038, 1, 'Mdina'),
(2039, 1, 'Melliea'),
(2040, 1, 'Mgarr'),
(2041, 1, 'Mosta'),
(2042, 1, 'Mqabba'),
(2043, 1, 'Msida'),
(2044, 1, 'Mtarfa'),
(2045, 1, 'Naxxar'),
(2046, 1, 'Paola'),
(2047, 1, 'Pembroke'),
(2048, 1, 'Pieta'),
(2049, 1, 'Qormi'),
(2050, 1, 'Qrendi'),
(2051, 1, 'Rabat'),
(2052, 1, 'Safi'),
(2053, 1, 'San Giljan'),
(2054, 1, 'Santa Lucija'),
(2055, 1, 'San Pawl il-Bahar'),
(2056, 1, 'San Gwann'),
(2057, 1, 'Santa Venera'),
(2058, 1, 'Siggiewi'),
(2059, 1, 'Sliema'),
(2060, 1, 'Swieqi'),
(2061, 1, 'Ta Xbiex'),
(2062, 1, 'Tarxien'),
(2063, 1, 'Valletta'),
(2064, 1, 'Xgajra'),
(2065, 1, 'Zabbar'),
(2066, 1, 'Zebbug'),
(2067, 1, 'Zejtun'),
(2068, 1, 'Zurrieq'),
(2069, 1, 'Fontana'),
(2070, 1, 'Ghajnsielem'),
(2071, 1, 'Gharb'),
(2072, 1, 'Ghasri'),
(2073, 1, 'Kercem'),
(2074, 1, 'Munxar'),
(2075, 1, 'Nadur'),
(2076, 1, 'Qala'),
(2077, 1, 'Victoria'),
(2078, 1, 'San Lawrenz'),
(2079, 1, 'Sannat'),
(2080, 1, 'Xagra'),
(2081, 1, 'Xewkija'),
(2082, 1, 'Zebbug'),
(2083, 1, 'Ailinginae'),
(2084, 1, 'Ailinglaplap'),
(2085, 1, 'Ailuk'),
(2086, 1, 'Arno'),
(2087, 1, 'Aur'),
(2088, 1, 'Bikar'),
(2089, 1, 'Bikini'),
(2090, 1, 'Bokak'),
(2091, 1, 'Ebon'),
(2092, 1, 'Enewetak'),
(2093, 1, 'Erikub'),
(2094, 1, 'Jabat'),
(2095, 1, 'Jaluit'),
(2096, 1, 'Jemo'),
(2097, 1, 'Kili'),
(2098, 1, 'Kwajalein'),
(2099, 1, 'Lae'),
(2100, 1, 'Lib'),
(2101, 1, 'Likiep'),
(2102, 1, 'Majuro'),
(2103, 1, 'Maloelap'),
(2104, 1, 'Mejit'),
(2105, 1, 'Mili'),
(2106, 1, 'Namorik'),
(2107, 1, 'Namu'),
(2108, 1, 'Rongelap'),
(2109, 1, 'Rongrik'),
(2110, 1, 'Toke'),
(2111, 1, 'Ujae'),
(2112, 1, 'Ujelang'),
(2113, 1, 'Utirik'),
(2114, 1, 'Wotho'),
(2115, 1, 'Wotje'),
(2116, 1, 'Adrar'),
(2117, 1, 'Assaba'),
(2118, 1, 'Brakna'),
(2119, 1, 'Dakhlet Nouadhibou'),
(2120, 1, 'Gorgol'),
(2121, 1, 'Guidimaka'),
(2122, 1, 'Hodh Ech Chargui'),
(2123, 1, 'Hodh El Gharbi'),
(2124, 1, 'Inchiri'),
(2125, 1, 'Tagant'),
(2126, 1, 'Tiris Zemmour'),
(2127, 1, 'Trarza'),
(2128, 1, 'Nouakchott'),
(2129, 1, 'Beau Bassin-Rose Hill'),
(2130, 1, 'Curepipe'),
(2131, 1, 'Port Louis'),
(2132, 1, 'Quatre Bornes'),
(2133, 1, 'Vacoas-Phoenix'),
(2134, 1, 'Agalega Islands'),
(2135, 1, 'Cargados Carajos Shoals (Saint Brandon Islands)'),
(2136, 1, 'Rodrigues'),
(2137, 1, 'Black River'),
(2138, 1, 'Flacq'),
(2139, 1, 'Grand Port'),
(2140, 1, 'Moka'),
(2141, 1, 'Pamplemousses'),
(2142, 1, 'Plaines Wilhems'),
(2143, 1, 'Port Louis'),
(2144, 1, 'Riviere du Rempart'),
(2145, 1, 'Savanne'),
(2146, 1, 'Baja California Norte'),
(2147, 1, 'Baja California Sur'),
(2148, 1, 'Campeche'),
(2149, 1, 'Chiapas'),
(2150, 1, 'Chihuahua'),
(2151, 1, 'Coahuila de Zaragoza'),
(2152, 1, 'Colima'),
(2153, 1, 'Distrito Federal'),
(2154, 1, 'Durango'),
(2155, 1, 'Guanajuato'),
(2156, 1, 'Guerrero'),
(2157, 1, 'Hidalgo'),
(2158, 1, 'Jalisco'),
(2159, 1, 'Mexico'),
(2160, 1, 'Michoacan de Ocampo'),
(2161, 1, 'Morelos'),
(2162, 1, 'Nayarit'),
(2163, 1, 'Nuevo Leon'),
(2164, 1, 'Oaxaca'),
(2165, 1, 'Puebla'),
(2166, 1, 'Queretaro de Arteaga'),
(2167, 1, 'Quintana Roo'),
(2168, 1, 'San Luis Potosi'),
(2169, 1, 'Sinaloa'),
(2170, 1, 'Sonora'),
(2171, 1, 'Tabasco'),
(2172, 1, 'Tamaulipas'),
(2173, 1, 'Tlaxcala'),
(2174, 1, 'Veracruz-Llave'),
(2175, 1, 'Yucatan'),
(2176, 1, 'Zacatecas'),
(2177, 1, 'Chuuk'),
(2178, 1, 'Kosrae'),
(2179, 1, 'Pohnpei'),
(2180, 1, 'Yap'),
(2181, 1, 'Gagauzia'),
(2182, 1, 'Chisinau'),
(2183, 1, 'Balti'),
(2184, 1, 'Cahul'),
(2185, 1, 'Edinet'),
(2186, 1, 'Lapusna'),
(2187, 1, 'Orhei'),
(2188, 1, 'Soroca'),
(2189, 1, 'Tighina'),
(2190, 1, 'Ungheni'),
(2191, 1, 'St‚nga Nistrului'),
(2192, 1, 'Fontvieille'),
(2193, 1, 'La Condamine'),
(2194, 1, 'Monaco-Ville'),
(2195, 1, 'Monte-Carlo'),
(2196, 1, 'Ulanbaatar'),
(2197, 1, 'Orhon'),
(2198, 1, 'Darhan uul'),
(2199, 1, 'Hentiy'),
(2200, 1, 'Hovsgol'),
(2201, 1, 'Hovd'),
(2202, 1, 'Uvs'),
(2203, 1, 'Tov'),
(2204, 1, 'Selenge'),
(2205, 1, 'Suhbaatar'),
(2206, 1, 'Omnogovi'),
(2207, 1, 'Ovorhangay'),
(2208, 1, 'Dzavhan'),
(2209, 1, 'DundgovL'),
(2210, 1, 'Dornod'),
(2211, 1, 'Dornogov'),
(2212, 1, 'Govi-Sumber'),
(2213, 1, 'Govi-Altay'),
(2214, 1, 'Bulgan'),
(2215, 1, 'Bayanhongor'),
(2216, 1, 'Bayan-Olgiy'),
(2217, 1, 'Arhangay'),
(2218, 1, 'Saint Anthony'),
(2219, 1, 'Saint Georges'),
(2220, 1, 'Saint Peter'),
(2221, 1, 'Agadir'),
(2222, 1, 'Al Hoceima'),
(2223, 1, 'Azilal'),
(2224, 1, 'Beni Mellal'),
(2225, 1, 'Ben Slimane'),
(2226, 1, 'Boulemane'),
(2227, 1, 'Casablanca'),
(2228, 1, 'Chaouen'),
(2229, 1, 'El Jadida'),
(2230, 1, 'El Kelaa des Sraghna'),
(2231, 1, 'Er Rachidia'),
(2232, 1, 'Essaouira'),
(2233, 1, 'Fes'),
(2234, 1, 'Figuig'),
(2235, 1, 'Guelmim'),
(2236, 1, 'Ifrane'),
(2237, 1, 'Kenitra'),
(2238, 1, 'Khemisset'),
(2239, 1, 'Khenifra'),
(2240, 1, 'Khouribga'),
(2241, 1, 'Laayoune'),
(2242, 1, 'Larache'),
(2243, 1, 'Marrakech'),
(2244, 1, 'Meknes'),
(2245, 1, 'Nador'),
(2246, 1, 'Ouarzazate'),
(2247, 1, 'Oujda'),
(2248, 1, 'Rabat-Sale'),
(2249, 1, 'Safi'),
(2250, 1, 'Settat'),
(2251, 1, 'Sidi Kacem'),
(2252, 1, 'Tangier'),
(2253, 1, 'Tan-Tan'),
(2254, 1, 'Taounate'),
(2255, 1, 'Taroudannt'),
(2256, 1, 'Tata'),
(2257, 1, 'Taza'),
(2258, 1, 'Tetouan'),
(2259, 1, 'Tiznit'),
(2260, 1, 'Ad Dakhla'),
(2261, 1, 'Boujdour'),
(2262, 1, 'Es Smara'),
(2263, 1, 'Cabo Delgado'),
(2264, 1, 'Gaza'),
(2265, 1, 'Inhambane'),
(2266, 1, 'Manica'),
(2267, 1, 'Maputo (city)'),
(2268, 1, 'Maputo'),
(2269, 1, 'Nampula'),
(2270, 1, 'Niassa'),
(2271, 1, 'Sofala');
INSERT INTO `[[dbprefix]]zone_descriptions` VALUES
(2272, 1, 'Tete'),
(2273, 1, 'Zambezia'),
(2274, 1, 'Ayeyarwady'),
(2275, 1, 'Bago'),
(2276, 1, 'Magway'),
(2277, 1, 'Mandalay'),
(2278, 1, 'Sagaing'),
(2279, 1, 'Tanintharyi'),
(2280, 1, 'Yangon'),
(2281, 1, 'Chin State'),
(2282, 1, 'Kachin State'),
(2283, 1, 'Kayah State'),
(2284, 1, 'Kayin State'),
(2285, 1, 'Mon State'),
(2286, 1, 'Rakhine State'),
(2287, 1, 'Shan State'),
(2288, 1, 'Caprivi'),
(2289, 1, 'Erongo'),
(2290, 1, 'Hardap'),
(2291, 1, 'Karas'),
(2292, 1, 'Kavango'),
(2293, 1, 'Khomas'),
(2294, 1, 'Kunene'),
(2295, 1, 'Ohangwena'),
(2296, 1, 'Omaheke'),
(2297, 1, 'Omusati'),
(2298, 1, 'Oshana'),
(2299, 1, 'Oshikoto'),
(2300, 1, 'Otjozondjupa'),
(2301, 1, 'Aiwo'),
(2302, 1, 'Anabar'),
(2303, 1, 'Anetan'),
(2304, 1, 'Anibare'),
(2305, 1, 'Baiti'),
(2306, 1, 'Boe'),
(2307, 1, 'Buada'),
(2308, 1, 'Denigomodu'),
(2309, 1, 'Ewa'),
(2310, 1, 'Ijuw'),
(2311, 1, 'Meneng'),
(2312, 1, 'Nibok'),
(2313, 1, 'Uaboe'),
(2314, 1, 'Yaren'),
(2315, 1, 'Bagmati'),
(2316, 1, 'Bheri'),
(2317, 1, 'Dhawalagiri'),
(2318, 1, 'Gandaki'),
(2319, 1, 'Janakpur'),
(2320, 1, 'Karnali'),
(2321, 1, 'Kosi'),
(2322, 1, 'Lumbini'),
(2323, 1, 'Mahakali'),
(2324, 1, 'Mechi'),
(2325, 1, 'Narayani'),
(2326, 1, 'Rapti'),
(2327, 1, 'Sagarmatha'),
(2328, 1, 'Seti'),
(2329, 1, 'Drenthe'),
(2330, 1, 'Flevoland'),
(2331, 1, 'Friesland'),
(2332, 1, 'Gelderland'),
(2333, 1, 'Groningen'),
(2334, 1, 'Limburg'),
(2335, 1, 'Noord Brabant'),
(2336, 1, 'Noord Holland'),
(2337, 1, 'Overijssel'),
(2338, 1, 'Utrecht'),
(2339, 1, 'Zeeland'),
(2340, 1, 'Zuid Holland'),
(2341, 1, 'Iles Loyaute'),
(2342, 1, 'Nord'),
(2343, 1, 'Sud'),
(2344, 1, 'Auckland'),
(2345, 1, 'Bay of Plenty'),
(2346, 1, 'Canterbury'),
(2347, 1, 'Coromandel'),
(2348, 1, 'Gisborne'),
(2349, 1, 'Fiordland'),
(2350, 1, 'Hawke''s Bay'),
(2351, 1, 'Marlborough'),
(2352, 1, 'Manawatu-Wanganui'),
(2353, 1, 'Mt Cook-Mackenzie'),
(2354, 1, 'Nelson'),
(2355, 1, 'Northland'),
(2356, 1, 'Otago'),
(2357, 1, 'Southland'),
(2358, 1, 'Taranaki'),
(2359, 1, 'Wellington'),
(2360, 1, 'Waikato'),
(2361, 1, 'Wairprarapa'),
(2362, 1, 'West Coast'),
(2363, 1, 'Atlantico Norte'),
(2364, 1, 'Atlantico Sur'),
(2365, 1, 'Boaco'),
(2366, 1, 'Carazo'),
(2367, 1, 'Chinandega'),
(2368, 1, 'Chontales'),
(2369, 1, 'Esteli'),
(2370, 1, 'Granada'),
(2371, 1, 'Jinotega'),
(2372, 1, 'Leon'),
(2373, 1, 'Madriz'),
(2374, 1, 'Managua'),
(2375, 1, 'Masaya'),
(2376, 1, 'Matagalpa'),
(2377, 1, 'Nuevo Segovia'),
(2378, 1, 'Rio San Juan'),
(2379, 1, 'Rivas'),
(2380, 1, 'Agadez'),
(2381, 1, 'Diffa'),
(2382, 1, 'Dosso'),
(2383, 1, 'Maradi'),
(2384, 1, 'Niamey'),
(2385, 1, 'Tahoua'),
(2386, 1, 'Tillaberi'),
(2387, 1, 'Zinder'),
(2388, 1, 'Abia'),
(2389, 1, 'Abuja Federal Capital Territory'),
(2390, 1, 'Adamawa'),
(2391, 1, 'Akwa Ibom'),
(2392, 1, 'Anambra'),
(2393, 1, 'Bauchi'),
(2394, 1, 'Bayelsa'),
(2395, 1, 'Benue'),
(2396, 1, 'Borno'),
(2397, 1, 'Cross River'),
(2398, 1, 'Delta'),
(2399, 1, 'Ebonyi'),
(2400, 1, 'Edo'),
(2401, 1, 'Ekiti'),
(2402, 1, 'Enugu'),
(2403, 1, 'Gombe'),
(2404, 1, 'Imo'),
(2405, 1, 'Jigawa'),
(2406, 1, 'Kaduna'),
(2407, 1, 'Kano'),
(2408, 1, 'Katsina'),
(2409, 1, 'Kebbi'),
(2410, 1, 'Kogi'),
(2411, 1, 'Kwara'),
(2412, 1, 'Lagos'),
(2413, 1, 'Nassarawa'),
(2414, 1, 'Niger'),
(2415, 1, 'Ogun'),
(2416, 1, 'Ondo'),
(2417, 1, 'Osun'),
(2418, 1, 'Oyo'),
(2419, 1, 'Plateau'),
(2420, 1, 'Rivers'),
(2421, 1, 'Sokoto'),
(2422, 1, 'Taraba'),
(2423, 1, 'Yobe'),
(2424, 1, 'Zamfara'),
(2425, 1, 'Northern Islands'),
(2426, 1, 'Rota'),
(2427, 1, 'Saipan'),
(2428, 1, 'Tinian'),
(2429, 1, 'Akershus'),
(2430, 1, 'Aust-Agder'),
(2431, 1, 'Buskerud'),
(2432, 1, 'Finnmark'),
(2433, 1, 'Hedmark'),
(2434, 1, 'Hordaland'),
(2435, 1, 'More og Romdal'),
(2436, 1, 'Nord-Trondelag'),
(2437, 1, 'Nordland'),
(2438, 1, 'Ostfold'),
(2439, 1, 'Oppland'),
(2440, 1, 'Oslo'),
(2441, 1, 'Rogaland'),
(2442, 1, 'Sor-Trondelag'),
(2443, 1, 'Sogn og Fjordane'),
(2444, 1, 'Svalbard'),
(2445, 1, 'Telemark'),
(2446, 1, 'Troms'),
(2447, 1, 'Vest-Agder'),
(2448, 1, 'Vestfold'),
(2449, 1, 'Ad Dakhiliyah'),
(2450, 1, 'Al Batinah'),
(2451, 1, 'Al Wusta'),
(2452, 1, 'Ash Sharqiyah'),
(2453, 1, 'Az Zahirah'),
(2454, 1, 'Masqat'),
(2455, 1, 'Musandam'),
(2456, 1, 'Zufar'),
(2457, 1, 'Balochistan'),
(2458, 1, 'Federally Administered Tribal Areas'),
(2459, 1, 'Islamabad Capital Territory'),
(2460, 1, 'North-West Frontier'),
(2461, 1, 'Punjab'),
(2462, 1, 'Sindh'),
(2463, 1, 'Aimeliik'),
(2464, 1, 'Airai'),
(2465, 1, 'Angaur'),
(2466, 1, 'Hatohobei'),
(2467, 1, 'Kayangel'),
(2468, 1, 'Koror'),
(2469, 1, 'Melekeok'),
(2470, 1, 'Ngaraard'),
(2471, 1, 'Ngarchelong'),
(2472, 1, 'Ngardmau'),
(2473, 1, 'Ngatpang'),
(2474, 1, 'Ngchesar'),
(2475, 1, 'Ngeremlengui'),
(2476, 1, 'Ngiwal'),
(2477, 1, 'Peleliu'),
(2478, 1, 'Sonsorol'),
(2479, 1, 'Bocas del Toro'),
(2480, 1, 'Chiriqui'),
(2481, 1, 'Cocle'),
(2482, 1, 'Colon'),
(2483, 1, 'Darien'),
(2484, 1, 'Herrera'),
(2485, 1, 'Los Santos'),
(2486, 1, 'Panama'),
(2487, 1, 'San Blas'),
(2488, 1, 'Veraguas'),
(2489, 1, 'Bougainville'),
(2490, 1, 'Central'),
(2491, 1, 'Chimbu'),
(2492, 1, 'Eastern Highlands'),
(2493, 1, 'East New Britain'),
(2494, 1, 'East Sepik'),
(2495, 1, 'Enga'),
(2496, 1, 'Gulf'),
(2497, 1, 'Madang'),
(2498, 1, 'Manus'),
(2499, 1, 'Milne Bay'),
(2500, 1, 'Morobe'),
(2501, 1, 'National Capital'),
(2502, 1, 'New Ireland'),
(2503, 1, 'Northern'),
(2504, 1, 'Sandaun'),
(2505, 1, 'Southern Highlands'),
(2506, 1, 'Western'),
(2507, 1, 'Western Highlands'),
(2508, 1, 'West New Britain'),
(2509, 1, 'Alto Paraguay'),
(2510, 1, 'Alto Parana'),
(2511, 1, 'Amambay'),
(2512, 1, 'Asuncion'),
(2513, 1, 'Boqueron'),
(2514, 1, 'Caaguazu'),
(2515, 1, 'Caazapa'),
(2516, 1, 'Canindeyu'),
(2517, 1, 'Central'),
(2518, 1, 'Concepcion'),
(2519, 1, 'Cordillera'),
(2520, 1, 'Guaira'),
(2521, 1, 'Itapua'),
(2522, 1, 'Misiones'),
(2523, 1, 'Neembucu'),
(2524, 1, 'Paraguari'),
(2525, 1, 'Presidente Hayes'),
(2526, 1, 'San Pedro'),
(2527, 1, 'Amazonas'),
(2528, 1, 'Ancash'),
(2529, 1, 'Apurimac'),
(2530, 1, 'Arequipa'),
(2531, 1, 'Ayacucho'),
(2532, 1, 'Cajamarca'),
(2533, 1, 'Callao'),
(2534, 1, 'Cusco'),
(2535, 1, 'Huancavelica'),
(2536, 1, 'Huanuco'),
(2537, 1, 'Ica'),
(2538, 1, 'Junin'),
(2539, 1, 'La Libertad'),
(2540, 1, 'Lambayeque'),
(2541, 1, 'Lima'),
(2542, 1, 'Loreto'),
(2543, 1, 'Madre de Dios'),
(2544, 1, 'Moquegua'),
(2545, 1, 'Pasco'),
(2546, 1, 'Piura'),
(2547, 1, 'Puno'),
(2548, 1, 'San Martin'),
(2549, 1, 'Tacna'),
(2550, 1, 'Tumbes'),
(2551, 1, 'Ucayali'),
(2552, 1, 'Abra'),
(2553, 1, 'Agusan del Norte'),
(2554, 1, 'Agusan del Sur'),
(2555, 1, 'Aklan'),
(2556, 1, 'Albay'),
(2557, 1, 'Antique'),
(2558, 1, 'Apayao'),
(2559, 1, 'Aurora'),
(2560, 1, 'Basilan'),
(2561, 1, 'Bataan'),
(2562, 1, 'Batanes'),
(2563, 1, 'Batangas'),
(2564, 1, 'Biliran'),
(2565, 1, 'Benguet'),
(2566, 1, 'Bohol'),
(2567, 1, 'Bukidnon'),
(2568, 1, 'Bulacan'),
(2569, 1, 'Cagayan'),
(2570, 1, 'Camarines Norte'),
(2571, 1, 'Camarines Sur'),
(2572, 1, 'Camiguin'),
(2573, 1, 'Capiz'),
(2574, 1, 'Catanduanes'),
(2575, 1, 'Cavite'),
(2576, 1, 'Cebu'),
(2577, 1, 'Compostela'),
(2578, 1, 'Davao del Norte'),
(2579, 1, 'Davao del Sur'),
(2580, 1, 'Davao Oriental'),
(2581, 1, 'Eastern Samar'),
(2582, 1, 'Guimaras'),
(2583, 1, 'Ifugao'),
(2584, 1, 'Ilocos Norte'),
(2585, 1, 'Ilocos Sur'),
(2586, 1, 'Iloilo'),
(2587, 1, 'Isabela'),
(2588, 1, 'Kalinga'),
(2589, 1, 'Laguna'),
(2590, 1, 'Lanao del Norte'),
(2591, 1, 'Lanao del Sur'),
(2592, 1, 'La Union'),
(2593, 1, 'Leyte'),
(2594, 1, 'Maguindanao'),
(2595, 1, 'Marinduque'),
(2596, 1, 'Masbate'),
(2597, 1, 'Mindoro Occidental'),
(2598, 1, 'Mindoro Oriental'),
(2599, 1, 'Misamis Occidental'),
(2600, 1, 'Misamis Oriental'),
(2601, 1, 'Mountain'),
(2602, 1, 'Negros Occidental'),
(2603, 1, 'Negros Oriental'),
(2604, 1, 'North Cotabato'),
(2605, 1, 'Northern Samar'),
(2606, 1, 'Nueva Ecija'),
(2607, 1, 'Nueva Vizcaya'),
(2608, 1, 'Palawan'),
(2609, 1, 'Pampanga'),
(2610, 1, 'Pangasinan'),
(2611, 1, 'Quezon'),
(2612, 1, 'Quirino'),
(2613, 1, 'Rizal'),
(2614, 1, 'Romblon'),
(2615, 1, 'Samar'),
(2616, 1, 'Sarangani'),
(2617, 1, 'Siquijor'),
(2618, 1, 'Sorsogon'),
(2619, 1, 'South Cotabato'),
(2620, 1, 'Southern Leyte'),
(2621, 1, 'Sultan Kudarat'),
(2622, 1, 'Sulu'),
(2623, 1, 'Surigao del Norte'),
(2624, 1, 'Surigao del Sur'),
(2625, 1, 'Tarlac'),
(2626, 1, 'Tawi-Tawi'),
(2627, 1, 'Zambales'),
(2628, 1, 'Zamboanga del Norte'),
(2629, 1, 'Zamboanga del Sur'),
(2630, 1, 'Zamboanga Sibugay'),
(2631, 1, 'Dolnoslaskie'),
(2632, 1, 'Kujawsko-Pomorskie'),
(2633, 1, 'Lodzkie'),
(2634, 1, 'Lubelskie'),
(2635, 1, 'Lubuskie'),
(2636, 1, 'Malopolskie'),
(2637, 1, 'Mazowieckie'),
(2638, 1, 'Opolskie'),
(2639, 1, 'Podkarpackie'),
(2640, 1, 'Podlaskie'),
(2641, 1, 'Pomorskie'),
(2642, 1, 'Slaskie'),
(2643, 1, 'Swietokrzyskie'),
(2644, 1, 'Warminsko-Mazurskie'),
(2645, 1, 'Wielkopolskie'),
(2646, 1, 'Zachodniopomorskie'),
(2647, 1, 'Saint Pierre'),
(2648, 1, 'Miquelon'),
(2649, 1, 'A&ccedil;ores'),
(2650, 1, 'Aveiro'),
(2651, 1, 'Beja'),
(2652, 1, 'Braga'),
(2653, 1, 'Bragan&ccedil;a'),
(2654, 1, 'Castelo Branco'),
(2655, 1, 'Coimbra'),
(2656, 1, '&Eacute;vora'),
(2657, 1, 'Faro'),
(2658, 1, 'Guarda'),
(2659, 1, 'Leiria'),
(2660, 1, 'Lisboa'),
(2661, 1, 'Madeira'),
(2662, 1, 'Portalegre'),
(2663, 1, 'Porto'),
(2664, 1, 'Santar&eacute;m'),
(2665, 1, 'Set&uacute;bal'),
(2666, 1, 'Viana do Castelo'),
(2667, 1, 'Vila Real'),
(2668, 1, 'Viseu'),
(2669, 1, 'Ad Dawhah'),
(2670, 1, 'Al Ghuwayriyah'),
(2671, 1, 'Al Jumayliyah'),
(2672, 1, 'Al Khawr'),
(2673, 1, 'Al Wakrah'),
(2674, 1, 'Ar Rayyan'),
(2675, 1, 'Jarayan al Batinah'),
(2676, 1, 'Madinat ash Shamal'),
(2677, 1, 'Umm Sa''id'),
(2678, 1, 'Umm Salal'),
(2679, 1, 'Alba'),
(2680, 1, 'Arad'),
(2681, 1, 'Arges'),
(2682, 1, 'Bacau'),
(2683, 1, 'Bihor'),
(2684, 1, 'Bistrita-Nasaud'),
(2685, 1, 'Botosani'),
(2686, 1, 'Brasov'),
(2687, 1, 'Braila'),
(2688, 1, 'Bucuresti'),
(2689, 1, 'Buzau'),
(2690, 1, 'Caras-Severin'),
(2691, 1, 'Calarasi'),
(2692, 1, 'Cluj'),
(2693, 1, 'Constanta'),
(2694, 1, 'Covasna'),
(2695, 1, 'Dimbovita'),
(2696, 1, 'Dolj'),
(2697, 1, 'Galati'),
(2698, 1, 'Giurgiu'),
(2699, 1, 'Gorj'),
(2700, 1, 'Harghita'),
(2701, 1, 'Hunedoara'),
(2702, 1, 'Ialomita'),
(2703, 1, 'Iasi'),
(2704, 1, 'Ilfov'),
(2705, 1, 'Maramures'),
(2706, 1, 'Mehedinti'),
(2707, 1, 'Mures'),
(2708, 1, 'Neamt'),
(2709, 1, 'Olt'),
(2710, 1, 'Prahova'),
(2711, 1, 'Satu-Mare'),
(2712, 1, 'Salaj'),
(2713, 1, 'Sibiu'),
(2714, 1, 'Suceava'),
(2715, 1, 'Teleorman'),
(2716, 1, 'Timis'),
(2717, 1, 'Tulcea'),
(2718, 1, 'Vaslui'),
(2719, 1, 'Valcea'),
(2720, 1, 'Vrancea'),
(2721, 1, 'Republic of Khakassia'),
(2722, 1, 'Aginsky Buryatsky AO'),
(2723, 1, 'Chukotka Autonomous Okrug'),
(2724, 1, 'Arkhangelsk Region'),
(2725, 1, 'Astrakhan Oblast'),
(2726, 1, 'Altai Krai'),
(2727, 1, 'Belgorod Oblast'),
(2728, 1, 'Jewish Autonomous Oblast'),
(2729, 1, 'Amur Region'),
(2730, 1, 'Bryansk Oblast'),
(2731, 1, 'Chuvash Republic'),
(2732, 1, 'Chelyabinsk Region'),
(2733, 1, 'Karachay-Cherkess Republic'),
(2734, 1, 'Zabaykalsky Krai'),
(2735, 1, 'Taymyr Dolgano-Nenets Autonomous Okrug'),
(2736, 1, 'Republic of Kalmykia'),
(2737, 1, 'Moscow Oblast'),
(2738, 1, 'Altai Republic'),
(2739, 1, 'Chechen Republic'),
(2740, 1, 'Irkutsk Oblast'),
(2741, 1, 'Ivanovo Oblast'),
(2742, 1, 'Udmurtia'),
(2743, 1, 'Kaliningrad Oblast'),
(2744, 1, 'Kaluzhskaya oblast'),
(2745, 1, 'Kirov Oblast'),
(2746, 1, 'Republic of Tatarstan'),
(2747, 1, 'Kemerovo region'),
(2748, 1, 'Khabarovsk Krai'),
(2749, 1, 'Khanty–Mansi Autonomous Okrug – Yugra'),
(2750, 1, 'Kostroma Oblast'),
(2751, 1, 'Krasnodar Krai'),
(2752, 1, 'Krasnoyarsk Krai'),
(2753, 1, 'Komi-Permyatsky AO'),
(2754, 1, 'Kurgan Oblast'),
(2755, 1, 'Kursk Region'),
(2756, 1, 'Respublika Tyva'),
(2757, 1, 'Lipetsk Region'),
(2758, 1, 'Magadan Oblast'),
(2759, 1, 'Republic of Dagestan'),
(2760, 1, 'Republic of Adygea'),
(2761, 1, 'Moscow'),
(2762, 1, 'Murmansk Oblast'),
(2763, 1, 'Kabardino-Balkar Republic'),
(2764, 1, 'Nenets Autonomous Okrug'),
(2765, 1, 'Republic of Ingushetia'),
(2766, 1, 'Nizhegorodskaya oblast'),
(2767, 1, 'Novgorod Oblast'),
(2768, 1, 'Novosibirsk Oblast'),
(2769, 1, 'Omsk Oblast'),
(2770, 1, 'Oryol Oblast'),
(2771, 1, 'Orenburg Oblast'),
(2772, 1, 'Leningrad Oblast'),
(2773, 1, 'Penza Oblast'),
(2774, 1, 'Perm Krai'),
(2775, 1, 'Kamchatka Krai'),
(2776, 1, 'Republic of Karelia'),
(2777, 1, 'Pskov Oblast'),
(2778, 1, 'Rostov Region'),
(2779, 1, 'Ryazan Oblast'),
(2780, 1, 'Yamalo-Nenets Autonomous Okrug'),
(2781, 1, 'Samara Region'),
(2782, 1, 'Republic of Mordovia'),
(2783, 1, 'Saratov Region'),
(2784, 1, 'Smolensk Oblast'),
(2785, 1, 'Saint Petersburg'),
(2786, 1, 'Stavropol Krai'),
(2787, 1, 'Komi Republic'),
(2788, 1, 'Tambov Region'),
(2789, 1, 'Tomsk Oblast'),
(2790, 1, 'Tula Region'),
(2791, 1, 'Evenkysky AO'),
(2792, 1, 'Tver Oblast'),
(2793, 1, 'Tyumen Oblast'),
(2794, 1, 'Republic of Bashkortostan'),
(2795, 1, 'Ulyanovsk Oblast'),
(2796, 1, 'Republic of Buryatia'),
(2797, 1, 'Ust-Orda Buryat Okrug'),
(2798, 1, 'North Ossetia-Alania'),
(2799, 1, 'Vladimir Oblast'),
(2800, 1, 'Primorsky Krai'),
(2801, 1, 'Volgograd Oblast'),
(2802, 1, 'Vologda Oblast'),
(2803, 1, 'Voronezh Oblast'),
(2804, 1, 'Sakhalin Oblast'),
(2805, 1, 'Sakha Republic'),
(2806, 1, 'Yaroslavl Oblast'),
(2807, 1, 'Sverdlovsk Oblast'),
(2808, 1, 'Mari El Republic'),
(2809, 1, 'Butare'),
(2810, 1, 'Byumba'),
(2811, 1, 'Cyangugu'),
(2812, 1, 'Gikongoro'),
(2813, 1, 'Gisenyi'),
(2814, 1, 'Gitarama'),
(2815, 1, 'Kibungo'),
(2816, 1, 'Kibuye'),
(2817, 1, 'Kigali Rurale'),
(2818, 1, 'Kigali-ville'),
(2819, 1, 'Ruhengeri'),
(2820, 1, 'Umutara'),
(2821, 1, 'Christ Church Nichola Town'),
(2822, 1, 'Saint Anne Sandy Point'),
(2823, 1, 'Saint George Basseterre'),
(2824, 1, 'Saint George Gingerland'),
(2825, 1, 'Saint James Windward'),
(2826, 1, 'Saint John Capesterre'),
(2827, 1, 'Saint John Figtree'),
(2828, 1, 'Saint Mary Cayon'),
(2829, 1, 'Saint Paul Capesterre'),
(2830, 1, 'Saint Paul Charlestown'),
(2831, 1, 'Saint Peter Basseterre'),
(2832, 1, 'Saint Thomas Lowland'),
(2833, 1, 'Saint Thomas Middle Island'),
(2834, 1, 'Trinity Palmetto Point'),
(2835, 1, 'Anse-la-Raye'),
(2836, 1, 'Castries'),
(2837, 1, 'Choiseul'),
(2838, 1, 'Dauphin'),
(2839, 1, 'Dennery'),
(2840, 1, 'Gros-Islet'),
(2841, 1, 'Laborie'),
(2842, 1, 'Micoud'),
(2843, 1, 'Praslin'),
(2844, 1, 'Soufriere'),
(2845, 1, 'Vieux-Fort'),
(2846, 1, 'Charlotte'),
(2847, 1, 'Grenadines'),
(2848, 1, 'Saint Andrew'),
(2849, 1, 'Saint David'),
(2850, 1, 'Saint George'),
(2851, 1, 'Saint Patrick'),
(2852, 1, 'A''ana'),
(2853, 1, 'Aiga-i-le-Tai'),
(2854, 1, 'Atua'),
(2855, 1, 'Fa''asaleleaga'),
(2856, 1, 'Gaga''emauga'),
(2857, 1, 'Gagaifomauga'),
(2858, 1, 'Palauli'),
(2859, 1, 'Satupa''itea'),
(2860, 1, 'Tuamasaga'),
(2861, 1, 'Va''a-o-Fonoti'),
(2862, 1, 'Vaisigano'),
(2863, 1, 'Acquaviva'),
(2864, 1, 'Borgo Maggiore'),
(2865, 1, 'Chiesanuova'),
(2866, 1, 'Domagnano'),
(2867, 1, 'Faetano'),
(2868, 1, 'Fiorentino'),
(2869, 1, 'Montegiardino'),
(2870, 1, 'Citta di San Marino'),
(2871, 1, 'Serravalle'),
(2872, 1, 'Sao Tome'),
(2873, 1, 'Principe'),
(2874, 1, 'Al Bahah'),
(2875, 1, 'Al Hudud ash Shamaliyah'),
(2876, 1, 'Al Jawf'),
(2877, 1, 'Al Madinah'),
(2878, 1, 'Al Qasim'),
(2879, 1, 'Ar Riyad'),
(2880, 1, 'Ash Sharqiyah (Eastern)'),
(2881, 1, '''Asir'),
(2882, 1, 'Ha''il'),
(2883, 1, 'Jizan'),
(2884, 1, 'Makkah'),
(2885, 1, 'Najran'),
(2886, 1, 'Tabuk'),
(2887, 1, 'Dakar'),
(2888, 1, 'Diourbel'),
(2889, 1, 'Fatick'),
(2890, 1, 'Kaolack'),
(2891, 1, 'Kolda'),
(2892, 1, 'Louga'),
(2893, 1, 'Matam'),
(2894, 1, 'Saint-Louis'),
(2895, 1, 'Tambacounda'),
(2896, 1, 'Thies'),
(2897, 1, 'Ziguinchor'),
(2898, 1, 'Anse aux Pins'),
(2899, 1, 'Anse Boileau'),
(2900, 1, 'Anse Etoile'),
(2901, 1, 'Anse Louis'),
(2902, 1, 'Anse Royale'),
(2903, 1, 'Baie Lazare'),
(2904, 1, 'Baie Sainte Anne'),
(2905, 1, 'Beau Vallon'),
(2906, 1, 'Bel Air'),
(2907, 1, 'Bel Ombre'),
(2908, 1, 'Cascade'),
(2909, 1, 'Glacis'),
(2910, 1, 'Grand'' Anse (on Mahe)'),
(2911, 1, 'Grand'' Anse (on Praslin)'),
(2912, 1, 'La Digue'),
(2913, 1, 'La Riviere Anglaise'),
(2914, 1, 'Mont Buxton'),
(2915, 1, 'Mont Fleuri'),
(2916, 1, 'Plaisance'),
(2917, 1, 'Pointe La Rue'),
(2918, 1, 'Port Glaud'),
(2919, 1, 'Saint Louis'),
(2920, 1, 'Takamaka'),
(2921, 1, 'Eastern'),
(2922, 1, 'Northern'),
(2923, 1, 'Southern'),
(2924, 1, 'Western'),
(2925, 1, 'Banskobystrický'),
(2926, 1, 'Bratislavský'),
(2927, 1, 'Košický'),
(2928, 1, 'Nitriansky'),
(2929, 1, 'Prešovský'),
(2930, 1, 'Trenčiansky'),
(2931, 1, 'Trnavský'),
(2932, 1, 'Žilinský'),
(2933, 1, 'Central'),
(2934, 1, 'Choiseul'),
(2935, 1, 'Guadalcanal'),
(2936, 1, 'Honiara'),
(2937, 1, 'Isabel'),
(2938, 1, 'Makira'),
(2939, 1, 'Malaita'),
(2940, 1, 'Rennell and Bellona'),
(2941, 1, 'Temotu'),
(2942, 1, 'Western'),
(2943, 1, 'Awdal'),
(2944, 1, 'Bakool'),
(2945, 1, 'Banaadir'),
(2946, 1, 'Bari'),
(2947, 1, 'Bay'),
(2948, 1, 'Galguduud'),
(2949, 1, 'Gedo'),
(2950, 1, 'Hiiraan'),
(2951, 1, 'Jubbada Dhexe'),
(2952, 1, 'Jubbada Hoose'),
(2953, 1, 'Mudug'),
(2954, 1, 'Nugaal'),
(2955, 1, 'Sanaag'),
(2956, 1, 'Shabeellaha Dhexe'),
(2957, 1, 'Shabeellaha Hoose'),
(2958, 1, 'Sool'),
(2959, 1, 'Togdheer'),
(2960, 1, 'Woqooyi Galbeed'),
(2961, 1, 'Eastern Cape'),
(2962, 1, 'Free State'),
(2963, 1, 'Gauteng'),
(2964, 1, 'KwaZulu-Natal'),
(2965, 1, 'Limpopo'),
(2966, 1, 'Mpumalanga'),
(2967, 1, 'North West'),
(2968, 1, 'Northern Cape'),
(2969, 1, 'Western Cape'),
(2970, 1, 'La Coru&ntilde;a'),
(2971, 1, '&Aacute;lava'),
(2972, 1, 'Albacete'),
(2973, 1, 'Alicante'),
(2974, 1, 'Almeria'),
(2975, 1, 'Asturias'),
(2976, 1, '&Aacute;vila'),
(2977, 1, 'Badajoz'),
(2978, 1, 'Baleares'),
(2979, 1, 'Barcelona'),
(2980, 1, 'Burgos'),
(2981, 1, 'C&aacute;ceres'),
(2982, 1, 'C&aacute;diz'),
(2983, 1, 'Cantabria'),
(2984, 1, 'Castell&oacute;n'),
(2985, 1, 'Ceuta'),
(2986, 1, 'Ciudad Real'),
(2987, 1, 'C&oacute;rdoba'),
(2988, 1, 'Cuenca'),
(2989, 1, 'Girona'),
(2990, 1, 'Granada'),
(2991, 1, 'Guadalajara'),
(2992, 1, 'Guip&uacute;zcoa'),
(2993, 1, 'Huelva'),
(2994, 1, 'Huesca'),
(2995, 1, 'Ja&eacute;n'),
(2996, 1, 'La Rioja'),
(2997, 1, 'Las Palmas'),
(2998, 1, 'Leon'),
(2999, 1, 'Lleida'),
(3000, 1, 'Lugo'),
(3001, 1, 'Madrid'),
(3002, 1, 'Malaga'),
(3003, 1, 'Melilla'),
(3004, 1, 'Murcia'),
(3005, 1, 'Navarra'),
(3006, 1, 'Ourense'),
(3007, 1, 'Palencia'),
(3008, 1, 'Pontevedra'),
(3009, 1, 'Salamanca'),
(3010, 1, 'Santa Cruz de Tenerife'),
(3011, 1, 'Segovia'),
(3012, 1, 'Sevilla'),
(3013, 1, 'Soria'),
(3014, 1, 'Tarragona'),
(3015, 1, 'Teruel'),
(3016, 1, 'Toledo'),
(3017, 1, 'Valencia'),
(3018, 1, 'Valladolid'),
(3019, 1, 'Vizcaya'),
(3020, 1, 'Zamora'),
(3021, 1, 'Zaragoza'),
(3022, 1, 'Central'),
(3023, 1, 'Eastern'),
(3024, 1, 'North Central'),
(3025, 1, 'Northern'),
(3026, 1, 'North Western'),
(3027, 1, 'Sabaragamuwa'),
(3028, 1, 'Southern'),
(3029, 1, 'Uva'),
(3030, 1, 'Western'),
(3031, 1, 'Ascension'),
(3032, 1, 'Saint Helena'),
(3033, 1, 'Tristan da Cunha'),
(3034, 1, 'A''ali an Nil'),
(3035, 1, 'Al Bahr al Ahmar'),
(3036, 1, 'Al Buhayrat'),
(3037, 1, 'Al Jazirah'),
(3038, 1, 'Al Khartum'),
(3039, 1, 'Al Qadarif'),
(3040, 1, 'Al Wahdah'),
(3041, 1, 'An Nil al Abyad'),
(3042, 1, 'An Nil al Azraq'),
(3043, 1, 'Ash Shamaliyah'),
(3044, 1, 'Bahr al Jabal'),
(3045, 1, 'Gharb al Istiwa''iyah'),
(3046, 1, 'Gharb Bahr al Ghazal'),
(3047, 1, 'Gharb Darfur'),
(3048, 1, 'Gharb Kurdufan'),
(3049, 1, 'Janub Darfur'),
(3050, 1, 'Janub Kurdufan'),
(3051, 1, 'Junqali'),
(3052, 1, 'Kassala'),
(3053, 1, 'Nahr an Nil'),
(3054, 1, 'Shamal Bahr al Ghazal'),
(3055, 1, 'Shamal Darfur'),
(3056, 1, 'Shamal Kurdufan'),
(3057, 1, 'Sharq al Istiwa''iyah'),
(3058, 1, 'Sinnar'),
(3059, 1, 'Warab'),
(3060, 1, 'Brokopondo'),
(3061, 1, 'Commewijne'),
(3062, 1, 'Coronie'),
(3063, 1, 'Marowijne'),
(3064, 1, 'Nickerie'),
(3065, 1, 'Para'),
(3066, 1, 'Paramaribo'),
(3067, 1, 'Saramacca'),
(3068, 1, 'Sipaliwini'),
(3069, 1, 'Wanica'),
(3070, 1, 'Hhohho'),
(3071, 1, 'Lubombo'),
(3072, 1, 'Manzini'),
(3073, 1, 'Shishelweni'),
(3074, 1, 'Blekinge'),
(3075, 1, 'Dalama'),
(3076, 1, 'G&auml;vleborg'),
(3077, 1, 'Gotland'),
(3078, 1, 'Halland'),
(3079, 1, 'J&auml;mtland'),
(3080, 1, 'J&ouml;nk&ouml;ping'),
(3081, 1, 'Kalmar'),
(3082, 1, 'Kronoberg'),
(3083, 1, 'Norrbotten'),
(3084, 1, '&Ouml;rebro'),
(3085, 1, '&Ouml;sterg&ouml;tland'),
(3086, 1, 'Sk&aring;ne'),
(3087, 1, 'S&ouml;dermanland'),
(3088, 1, 'Stockholm'),
(3089, 1, 'Uppsala'),
(3090, 1, 'V&auml;rmland'),
(3091, 1, 'V&auml;sterbotten'),
(3092, 1, 'V&auml;sternorrland'),
(3093, 1, 'V&auml;stmanland'),
(3094, 1, 'V&auml;stra G&ouml;taland'),
(3095, 1, 'Aargau'),
(3096, 1, 'Appenzell Ausserrhoden'),
(3097, 1, 'Appenzell Innerrhoden'),
(3098, 1, 'Basel-Stadt'),
(3099, 1, 'Basel-Landschaft'),
(3100, 1, 'Bern'),
(3101, 1, 'Fribourg'),
(3102, 1, 'Gen&egrave;ve'),
(3103, 1, 'Glarus'),
(3104, 1, 'Graub&uuml;nden'),
(3105, 1, 'Jura'),
(3106, 1, 'Luzern'),
(3107, 1, 'Neuch&acirc;tel'),
(3108, 1, 'Nidwald'),
(3109, 1, 'Obwald'),
(3110, 1, 'St. Gallen'),
(3111, 1, 'Schaffhausen'),
(3112, 1, 'Schwyz'),
(3113, 1, 'Solothurn'),
(3114, 1, 'Thurgau'),
(3115, 1, 'Ticino'),
(3116, 1, 'Uri'),
(3117, 1, 'Valais'),
(3118, 1, 'Vaud'),
(3119, 1, 'Zug'),
(3120, 1, 'Z&uuml;rich'),
(3121, 1, 'Al Hasakah'),
(3122, 1, 'Al Ladhiqiyah'),
(3123, 1, 'Al Qunaytirah'),
(3124, 1, 'Ar Raqqah'),
(3125, 1, 'As Suwayda'),
(3126, 1, 'Dara'),
(3127, 1, 'Dayr az Zawr'),
(3128, 1, 'Dimashq'),
(3129, 1, 'Halab'),
(3130, 1, 'Hamah'),
(3131, 1, 'Hims'),
(3132, 1, 'Idlib'),
(3133, 1, 'Rif Dimashq'),
(3134, 1, 'Tartus'),
(3135, 1, 'Chang-hua'),
(3136, 1, 'Chia-i'),
(3137, 1, 'Hsin-chu'),
(3138, 1, 'Hua-lien'),
(3139, 1, 'I-lan'),
(3140, 1, 'Kao-hsiung county'),
(3141, 1, 'Kin-men'),
(3142, 1, 'Lien-chiang'),
(3143, 1, 'Miao-li'),
(3144, 1, 'Nan-t''ou'),
(3145, 1, 'P''eng-hu'),
(3146, 1, 'P''ing-tung'),
(3147, 1, 'T''ai-chung'),
(3148, 1, 'T''ai-nan'),
(3149, 1, 'T''ai-pei county'),
(3150, 1, 'T''ai-tung'),
(3151, 1, 'T''ao-yuan'),
(3152, 1, 'Yun-lin'),
(3153, 1, 'Chia-i city'),
(3154, 1, 'Chi-lung'),
(3155, 1, 'Hsin-chu'),
(3156, 1, 'T''ai-chung'),
(3157, 1, 'T''ai-nan'),
(3158, 1, 'Kao-hsiung city'),
(3159, 1, 'T''ai-pei city'),
(3160, 1, 'Gorno-Badakhstan'),
(3161, 1, 'Khatlon'),
(3162, 1, 'Sughd'),
(3163, 1, 'Arusha'),
(3164, 1, 'Dar es Salaam'),
(3165, 1, 'Dodoma'),
(3166, 1, 'Iringa'),
(3167, 1, 'Kagera'),
(3168, 1, 'Kigoma'),
(3169, 1, 'Kilimanjaro'),
(3170, 1, 'Lindi'),
(3171, 1, 'Manyara'),
(3172, 1, 'Mara'),
(3173, 1, 'Mbeya'),
(3174, 1, 'Morogoro'),
(3175, 1, 'Mtwara'),
(3176, 1, 'Mwanza'),
(3177, 1, 'Pemba North'),
(3178, 1, 'Pemba South'),
(3179, 1, 'Pwani'),
(3180, 1, 'Rukwa'),
(3181, 1, 'Ruvuma'),
(3182, 1, 'Shinyanga'),
(3183, 1, 'Singida'),
(3184, 1, 'Tabora'),
(3185, 1, 'Tanga'),
(3186, 1, 'Zanzibar Central/South'),
(3187, 1, 'Zanzibar North'),
(3188, 1, 'Zanzibar Urban/West'),
(3189, 1, 'Amnat Charoen'),
(3190, 1, 'Ang Thong'),
(3191, 1, 'Ayutthaya'),
(3192, 1, 'Bangkok'),
(3193, 1, 'Buriram'),
(3194, 1, 'Chachoengsao'),
(3195, 1, 'Chai Nat'),
(3196, 1, 'Chaiyaphum'),
(3197, 1, 'Chanthaburi'),
(3198, 1, 'Chiang Mai'),
(3199, 1, 'Chiang Rai'),
(3200, 1, 'Chon Buri'),
(3201, 1, 'Chumphon'),
(3202, 1, 'Kalasin'),
(3203, 1, 'Kamphaeng Phet'),
(3204, 1, 'Kanchanaburi'),
(3205, 1, 'Khon Kaen'),
(3206, 1, 'Krabi'),
(3207, 1, 'Lampang'),
(3208, 1, 'Lamphun'),
(3209, 1, 'Loei'),
(3210, 1, 'Lop Buri'),
(3211, 1, 'Mae Hong Son'),
(3212, 1, 'Maha Sarakham'),
(3213, 1, 'Mukdahan'),
(3214, 1, 'Nakhon Nayok'),
(3215, 1, 'Nakhon Pathom'),
(3216, 1, 'Nakhon Phanom'),
(3217, 1, 'Nakhon Ratchasima'),
(3218, 1, 'Nakhon Sawan'),
(3219, 1, 'Nakhon Si Thammarat'),
(3220, 1, 'Nan'),
(3221, 1, 'Narathiwat'),
(3222, 1, 'Nong Bua Lamphu'),
(3223, 1, 'Nong Khai'),
(3224, 1, 'Nonthaburi'),
(3225, 1, 'Pathum Thani'),
(3226, 1, 'Pattani'),
(3227, 1, 'Phangnga'),
(3228, 1, 'Phatthalung'),
(3229, 1, 'Phayao'),
(3230, 1, 'Phetchabun'),
(3231, 1, 'Phetchaburi'),
(3232, 1, 'Phichit'),
(3233, 1, 'Phitsanulok'),
(3234, 1, 'Phrae'),
(3235, 1, 'Phuket'),
(3236, 1, 'Prachin Buri'),
(3237, 1, 'Prachuap Khiri Khan'),
(3238, 1, 'Ranong'),
(3239, 1, 'Ratchaburi'),
(3240, 1, 'Rayong'),
(3241, 1, 'Roi Et'),
(3242, 1, 'Sa Kaeo'),
(3243, 1, 'Sakon Nakhon'),
(3244, 1, 'Samut Prakan'),
(3245, 1, 'Samut Sakhon'),
(3246, 1, 'Samut Songkhram'),
(3247, 1, 'Sara Buri'),
(3248, 1, 'Satun'),
(3249, 1, 'Sing Buri'),
(3250, 1, 'Sisaket'),
(3251, 1, 'Songkhla'),
(3252, 1, 'Sukhothai'),
(3253, 1, 'Suphan Buri'),
(3254, 1, 'Surat Thani'),
(3255, 1, 'Surin'),
(3256, 1, 'Tak'),
(3257, 1, 'Trang'),
(3258, 1, 'Trat'),
(3259, 1, 'Ubon Ratchathani'),
(3260, 1, 'Udon Thani'),
(3261, 1, 'Uthai Thani'),
(3262, 1, 'Uttaradit'),
(3263, 1, 'Yala'),
(3264, 1, 'Yasothon'),
(3265, 1, 'Kara'),
(3266, 1, 'Plateaux'),
(3267, 1, 'Savanes'),
(3268, 1, 'Centrale'),
(3269, 1, 'Maritime'),
(3270, 1, 'Atafu'),
(3271, 1, 'Fakaofo'),
(3272, 1, 'Nukunonu'),
(3273, 1, 'Ha''apai'),
(3274, 1, 'Tongatapu'),
(3275, 1, 'Vava''u'),
(3276, 1, 'Couva/Tabaquite/Talparo'),
(3277, 1, 'Diego Martin'),
(3278, 1, 'Mayaro/Rio Claro'),
(3279, 1, 'Penal/Debe'),
(3280, 1, 'Princes Town'),
(3281, 1, 'Sangre Grande'),
(3282, 1, 'San Juan/Laventille'),
(3283, 1, 'Siparia'),
(3284, 1, 'Tunapuna/Piarco'),
(3285, 1, 'Port of Spain'),
(3286, 1, 'San Fernando'),
(3287, 1, 'Arima'),
(3288, 1, 'Point Fortin'),
(3289, 1, 'Chaguanas'),
(3290, 1, 'Tobago'),
(3291, 1, 'Ariana'),
(3292, 1, 'Beja'),
(3293, 1, 'Ben Arous'),
(3294, 1, 'Bizerte'),
(3295, 1, 'Gabes'),
(3296, 1, 'Gafsa'),
(3297, 1, 'Jendouba'),
(3298, 1, 'Kairouan'),
(3299, 1, 'Kasserine'),
(3300, 1, 'Kebili'),
(3301, 1, 'Kef'),
(3302, 1, 'Mahdia'),
(3303, 1, 'Manouba'),
(3304, 1, 'Medenine'),
(3305, 1, 'Monastir'),
(3306, 1, 'Nabeul'),
(3307, 1, 'Sfax'),
(3308, 1, 'Sidi'),
(3309, 1, 'Siliana'),
(3310, 1, 'Sousse'),
(3311, 1, 'Tataouine'),
(3312, 1, 'Tozeur'),
(3313, 1, 'Tunis'),
(3314, 1, 'Zaghouan'),
(3315, 1, 'Adana'),
(3316, 1, 'Adiyaman'),
(3317, 1, 'Afyonkarahisar'),
(3318, 1, 'Agri'),
(3319, 1, 'Aksaray'),
(3320, 1, 'Amasya'),
(3321, 1, 'Ankara'),
(3322, 1, 'Antalya'),
(3323, 1, 'Ardahan'),
(3324, 1, 'Artvin'),
(3325, 1, 'Aydin'),
(3326, 1, 'Balikesir'),
(3327, 1, 'Bartin'),
(3328, 1, 'Batman'),
(3329, 1, 'Bayburt'),
(3330, 1, 'Bilecik'),
(3331, 1, 'Bingol'),
(3332, 1, 'Bitlis'),
(3333, 1, 'Bolu'),
(3334, 1, 'Burdur'),
(3335, 1, 'Bursa'),
(3336, 1, 'Canakkale'),
(3337, 1, 'Cankiri'),
(3338, 1, 'Corum'),
(3339, 1, 'Denizli'),
(3340, 1, 'Diyarbakir'),
(3341, 1, 'Duzce'),
(3342, 1, 'Edirne'),
(3343, 1, 'Elazig'),
(3344, 1, 'Erzincan'),
(3345, 1, 'Erzurum'),
(3346, 1, 'Eskisehir'),
(3347, 1, 'Gaziantep'),
(3348, 1, 'Giresun'),
(3349, 1, 'Gumushane'),
(3350, 1, 'Hakkari'),
(3351, 1, 'Hatay'),
(3352, 1, 'Igdir'),
(3353, 1, 'Isparta'),
(3354, 1, 'Istanbul'),
(3355, 1, 'Izmir'),
(3356, 1, 'Kahramanmaras'),
(3357, 1, 'Karabuk'),
(3358, 1, 'Karaman'),
(3359, 1, 'Kars'),
(3360, 1, 'Kastamonu'),
(3361, 1, 'Kayseri'),
(3362, 1, 'Kilis'),
(3363, 1, 'Kirikkale'),
(3364, 1, 'Kirklareli'),
(3365, 1, 'Kirsehir'),
(3366, 1, 'Kocaeli'),
(3367, 1, 'Konya'),
(3368, 1, 'Kutahya'),
(3369, 1, 'Malatya'),
(3370, 1, 'Manisa'),
(3371, 1, 'Mardin'),
(3372, 1, 'Mersin'),
(3373, 1, 'Mugla'),
(3374, 1, 'Mus'),
(3375, 1, 'Nevsehir'),
(3376, 1, 'Nigde'),
(3377, 1, 'Ordu'),
(3378, 1, 'Osmaniye'),
(3379, 1, 'Rize'),
(3380, 1, 'Sakarya'),
(3381, 1, 'Samsun'),
(3382, 1, 'Sanliurfa'),
(3383, 1, 'Siirt'),
(3384, 1, 'Sinop'),
(3385, 1, 'Sirnak'),
(3386, 1, 'Sivas'),
(3387, 1, 'Tekirdag'),
(3388, 1, 'Tokat'),
(3389, 1, 'Trabzon'),
(3390, 1, 'Tunceli'),
(3391, 1, 'Usak'),
(3392, 1, 'Van'),
(3393, 1, 'Yalova'),
(3394, 1, 'Yozgat'),
(3395, 1, 'Zonguldak'),
(3396, 1, 'Ahal Welayaty'),
(3397, 1, 'Balkan Welayaty'),
(3398, 1, 'Dashhowuz Welayaty'),
(3399, 1, 'Lebap Welayaty'),
(3400, 1, 'Mary Welayaty'),
(3401, 1, 'Ambergris Cays'),
(3402, 1, 'Dellis Cay'),
(3403, 1, 'French Cay'),
(3404, 1, 'Little Water Cay'),
(3405, 1, 'Parrot Cay'),
(3406, 1, 'Pine Cay'),
(3407, 1, 'Salt Cay'),
(3408, 1, 'Grand Turk'),
(3409, 1, 'South Caicos'),
(3410, 1, 'East Caicos'),
(3411, 1, 'Middle Caicos'),
(3412, 1, 'North Caicos'),
(3413, 1, 'Providenciales'),
(3414, 1, 'West Caicos'),
(3415, 1, 'Nanumanga'),
(3416, 1, 'Niulakita'),
(3417, 1, 'Niutao'),
(3418, 1, 'Funafuti'),
(3419, 1, 'Nanumea'),
(3420, 1, 'Nui'),
(3421, 1, 'Nukufetau'),
(3422, 1, 'Nukulaelae'),
(3423, 1, 'Vaitupu'),
(3424, 1, 'Kalangala'),
(3425, 1, 'Kampala'),
(3426, 1, 'Kayunga'),
(3427, 1, 'Kiboga'),
(3428, 1, 'Luwero'),
(3429, 1, 'Masaka'),
(3430, 1, 'Mpigi'),
(3431, 1, 'Mubende'),
(3432, 1, 'Mukono'),
(3433, 1, 'Nakasongola'),
(3434, 1, 'Rakai'),
(3435, 1, 'Sembabule'),
(3436, 1, 'Wakiso'),
(3437, 1, 'Bugiri'),
(3438, 1, 'Busia'),
(3439, 1, 'Iganga'),
(3440, 1, 'Jinja'),
(3441, 1, 'Kaberamaido'),
(3442, 1, 'Kamuli'),
(3443, 1, 'Kapchorwa'),
(3444, 1, 'Katakwi'),
(3445, 1, 'Kumi'),
(3446, 1, 'Mayuge'),
(3447, 1, 'Mbale'),
(3448, 1, 'Pallisa'),
(3449, 1, 'Sironko'),
(3450, 1, 'Soroti'),
(3451, 1, 'Tororo'),
(3452, 1, 'Adjumani'),
(3453, 1, 'Apac'),
(3454, 1, 'Arua'),
(3455, 1, 'Gulu'),
(3456, 1, 'Kitgum'),
(3457, 1, 'Kotido'),
(3458, 1, 'Lira'),
(3459, 1, 'Moroto'),
(3460, 1, 'Moyo'),
(3461, 1, 'Nakapiripirit'),
(3462, 1, 'Nebbi'),
(3463, 1, 'Pader'),
(3464, 1, 'Yumbe'),
(3465, 1, 'Bundibugyo'),
(3466, 1, 'Bushenyi'),
(3467, 1, 'Hoima'),
(3468, 1, 'Kabale'),
(3469, 1, 'Kabarole'),
(3470, 1, 'Kamwenge'),
(3471, 1, 'Kanungu'),
(3472, 1, 'Kasese'),
(3473, 1, 'Kibaale'),
(3474, 1, 'Kisoro'),
(3475, 1, 'Kyenjojo'),
(3476, 1, 'Masindi'),
(3477, 1, 'Mbarara'),
(3478, 1, 'Ntungamo'),
(3479, 1, 'Rukungiri'),
(3480, 1, 'Cherkasy'),
(3481, 1, 'Chernihiv'),
(3482, 1, 'Chernivtsi'),
(3483, 1, 'Crimea'),
(3484, 1, 'Dnipro'),
(3485, 1, 'Donets''k'),
(3486, 1, 'Ivano-Frankivs''k'),
(3487, 1, 'Kharkiv'),
(3488, 1, 'Khmel''nyts''kyy'),
(3489, 1, 'Kirovohrad'),
(3490, 1, 'Kyiv'),
(3491, 1, 'Kherson'),
(3492, 1, 'Luhans''k'),
(3493, 1, 'L''viv'),
(3494, 1, 'Mykolaiv'),
(3495, 1, 'Odesa'),
(3496, 1, 'Poltava'),
(3497, 1, 'Rivne'),
(3498, 1, 'Sevastopol'),
(3499, 1, 'Sumy'),
(3500, 1, 'Ternopil'''),
(3501, 1, 'Vinnytsya'),
(3502, 1, 'Volyn'''),
(3503, 1, 'Zakarpattya'),
(3504, 1, 'Zaporizhzhya'),
(3505, 1, 'Zhytomyr'),
(3506, 1, 'Abu Zaby'),
(3507, 1, '''Ajman'),
(3508, 1, 'Al Fujayrah'),
(3509, 1, 'Ash Shariqah'),
(3510, 1, 'Dubayy'),
(3511, 1, 'R''as al Khaymah'),
(3512, 1, 'Umm al Qaywayn'),
(3513, 1, 'Aberdeen'),
(3514, 1, 'Aberdeenshire'),
(3515, 1, 'Anglesey'),
(3516, 1, 'Angus'),
(3517, 1, 'Argyll and Bute'),
(3518, 1, 'Bedfordshire'),
(3519, 1, 'Berkshire'),
(3520, 1, 'Blaenau Gwent'),
(3521, 1, 'Bridgend'),
(3522, 1, 'Bristol'),
(3523, 1, 'Buckinghamshire'),
(3524, 1, 'Caerphilly'),
(3525, 1, 'Cambridgeshire'),
(3526, 1, 'Cardiff'),
(3527, 1, 'Carmarthenshire'),
(3528, 1, 'Ceredigion'),
(3529, 1, 'Cheshire'),
(3530, 1, 'Clackmannanshire'),
(3531, 1, 'Conwy'),
(3532, 1, 'Cornwall'),
(3533, 1, 'Denbighshire'),
(3534, 1, 'Derbyshire'),
(3535, 1, 'Devon'),
(3536, 1, 'Dorset'),
(3537, 1, 'Dumfries and Galloway'),
(3538, 1, 'Dundee'),
(3539, 1, 'Durham'),
(3540, 1, 'East Ayrshire'),
(3541, 1, 'East Dunbartonshire'),
(3542, 1, 'East Lothian'),
(3543, 1, 'East Renfrewshire'),
(3544, 1, 'East Riding of Yorkshire'),
(3545, 1, 'East Sussex'),
(3546, 1, 'Edinburgh'),
(3547, 1, 'Essex'),
(3548, 1, 'Falkirk'),
(3549, 1, 'Fife'),
(3550, 1, 'Flintshire'),
(3551, 1, 'Glasgow'),
(3552, 1, 'Gloucestershire'),
(3553, 1, 'Greater London'),
(3554, 1, 'Greater Manchester'),
(3555, 1, 'Gwynedd'),
(3556, 1, 'Hampshire'),
(3557, 1, 'Herefordshire'),
(3558, 1, 'Hertfordshire'),
(3559, 1, 'Highlands'),
(3560, 1, 'Inverclyde'),
(3561, 1, 'Isle of Wight'),
(3562, 1, 'Kent'),
(3563, 1, 'Lancashire'),
(3564, 1, 'Leicestershire'),
(3565, 1, 'Lincolnshire'),
(3566, 1, 'Merseyside'),
(3567, 1, 'Merthyr Tydfil'),
(3568, 1, 'Midlothian'),
(3569, 1, 'Monmouthshire'),
(3570, 1, 'Moray'),
(3571, 1, 'Neath Port Talbot'),
(3572, 1, 'Newport'),
(3573, 1, 'Norfolk'),
(3574, 1, 'North Ayrshire'),
(3575, 1, 'North Lanarkshire'),
(3576, 1, 'North Yorkshire'),
(3577, 1, 'Northamptonshire'),
(3578, 1, 'Northumberland'),
(3579, 1, 'Nottinghamshire'),
(3580, 1, 'Orkney Islands'),
(3581, 1, 'Oxfordshire'),
(3582, 1, 'Pembrokeshire'),
(3583, 1, 'Perth and Kinross'),
(3584, 1, 'Powys'),
(3585, 1, 'Renfrewshire'),
(3586, 1, 'Rhondda Cynon Taff'),
(3587, 1, 'Rutland'),
(3588, 1, 'Scottish Borders'),
(3589, 1, 'Shetland Islands'),
(3590, 1, 'Shropshire'),
(3591, 1, 'Somerset'),
(3592, 1, 'South Ayrshire'),
(3593, 1, 'South Lanarkshire'),
(3594, 1, 'South Yorkshire'),
(3595, 1, 'Staffordshire'),
(3596, 1, 'Stirling'),
(3597, 1, 'Suffolk'),
(3598, 1, 'Surrey'),
(3599, 1, 'Swansea'),
(3600, 1, 'Torfaen'),
(3601, 1, 'Tyne and Wear'),
(3602, 1, 'Vale of Glamorgan'),
(3603, 1, 'Warwickshire'),
(3604, 1, 'West Dunbartonshire'),
(3605, 1, 'West Lothian'),
(3606, 1, 'West Midlands'),
(3607, 1, 'West Sussex'),
(3608, 1, 'West Yorkshire'),
(3609, 1, 'Western Isles'),
(3610, 1, 'Wiltshire'),
(3611, 1, 'Worcestershire'),
(3612, 1, 'Wrexham'),
(3613, 1, 'Alabama'),
(3614, 1, 'Alaska'),
(3615, 1, 'American Samoa'),
(3616, 1, 'Arizona'),
(3617, 1, 'Arkansas'),
(3618, 1, 'Armed Forces Africa'),
(3619, 1, 'Armed Forces Americas'),
(3620, 1, 'Armed Forces Canada'),
(3621, 1, 'Armed Forces Europe'),
(3622, 1, 'Armed Forces Middle East'),
(3623, 1, 'Armed Forces Pacific'),
(3624, 1, 'California'),
(3625, 1, 'Colorado'),
(3626, 1, 'Connecticut'),
(3627, 1, 'Delaware'),
(3628, 1, 'District of Columbia'),
(3629, 1, 'Federated States Of Micronesia'),
(3630, 1, 'Florida'),
(3631, 1, 'Georgia'),
(3632, 1, 'Guam'),
(3633, 1, 'Hawaii'),
(3634, 1, 'Idaho'),
(3635, 1, 'Illinois'),
(3636, 1, 'Indiana'),
(3637, 1, 'Iowa'),
(3638, 1, 'Kansas'),
(3639, 1, 'Kentucky'),
(3640, 1, 'Louisiana'),
(3641, 1, 'Maine'),
(3642, 1, 'Marshall Islands'),
(3643, 1, 'Maryland'),
(3644, 1, 'Massachusetts'),
(3645, 1, 'Michigan'),
(3646, 1, 'Minnesota'),
(3647, 1, 'Mississippi'),
(3648, 1, 'Missouri'),
(3649, 1, 'Montana'),
(3650, 1, 'Nebraska'),
(3651, 1, 'Nevada'),
(3652, 1, 'New Hampshire'),
(3653, 1, 'New Jersey'),
(3654, 1, 'New Mexico'),
(3655, 1, 'New York'),
(3656, 1, 'North Carolina'),
(3657, 1, 'North Dakota'),
(3658, 1, 'Northern Mariana Islands'),
(3659, 1, 'Ohio'),
(3660, 1, 'Oklahoma'),
(3661, 1, 'Oregon'),
(3662, 1, 'Palau'),
(3663, 1, 'Pennsylvania'),
(3664, 1, 'Puerto Rico'),
(3665, 1, 'Rhode Island'),
(3666, 1, 'South Carolina'),
(3667, 1, 'South Dakota'),
(3668, 1, 'Tennessee'),
(3669, 1, 'Texas'),
(3670, 1, 'Utah'),
(3671, 1, 'Vermont'),
(3672, 1, 'Virgin Islands'),
(3673, 1, 'Virginia'),
(3674, 1, 'Washington'),
(3675, 1, 'West Virginia'),
(3676, 1, 'Wisconsin'),
(3677, 1, 'Wyoming'),
(3678, 1, 'Baker Island'),
(3679, 1, 'Howland Island'),
(3680, 1, 'Jarvis Island'),
(3681, 1, 'Johnston Atoll'),
(3682, 1, 'Kingman Reef'),
(3683, 1, 'Midway Atoll'),
(3684, 1, 'Navassa Island'),
(3685, 1, 'Palmyra Atoll'),
(3686, 1, 'Wake Island'),
(3687, 1, 'Artigas'),
(3688, 1, 'Canelones'),
(3689, 1, 'Cerro Largo'),
(3690, 1, 'Colonia'),
(3691, 1, 'Durazno'),
(3692, 1, 'Flores'),
(3693, 1, 'Florida'),
(3694, 1, 'Lavalleja'),
(3695, 1, 'Maldonado'),
(3696, 1, 'Montevideo'),
(3697, 1, 'Paysandu'),
(3698, 1, 'Rio Negro'),
(3699, 1, 'Rivera'),
(3700, 1, 'Rocha'),
(3701, 1, 'Salto'),
(3702, 1, 'San Jose'),
(3703, 1, 'Soriano'),
(3704, 1, 'Tacuarembo'),
(3705, 1, 'Treinta y Tres'),
(3706, 1, 'Andijon'),
(3707, 1, 'Buxoro'),
(3708, 1, 'Farg''ona'),
(3709, 1, 'Jizzax'),
(3710, 1, 'Namangan'),
(3711, 1, 'Navoiy'),
(3712, 1, 'Qashqadaryo'),
(3713, 1, 'Qoraqalpog''iston Republikasi'),
(3714, 1, 'Samarqand'),
(3715, 1, 'Sirdaryo'),
(3716, 1, 'Surxondaryo'),
(3717, 1, 'Toshkent City'),
(3718, 1, 'Toshkent Region'),
(3719, 1, 'Xorazm'),
(3720, 1, 'Malampa'),
(3721, 1, 'Penama'),
(3722, 1, 'Sanma'),
(3723, 1, 'Shefa'),
(3724, 1, 'Tafea'),
(3725, 1, 'Torba'),
(3726, 1, 'Amazonas'),
(3727, 1, 'Anzoategui'),
(3728, 1, 'Apure'),
(3729, 1, 'Aragua'),
(3730, 1, 'Barinas'),
(3731, 1, 'Bolivar'),
(3732, 1, 'Carabobo'),
(3733, 1, 'Cojedes'),
(3734, 1, 'Delta Amacuro'),
(3735, 1, 'Dependencias Federales'),
(3736, 1, 'Distrito Federal'),
(3737, 1, 'Falcon'),
(3738, 1, 'Guarico'),
(3739, 1, 'Lara'),
(3740, 1, 'Merida'),
(3741, 1, 'Miranda'),
(3742, 1, 'Monagas'),
(3743, 1, 'Nueva Esparta'),
(3744, 1, 'Portuguesa'),
(3745, 1, 'Sucre'),
(3746, 1, 'Tachira'),
(3747, 1, 'Trujillo'),
(3748, 1, 'Vargas'),
(3749, 1, 'Yaracuy'),
(3750, 1, 'Zulia'),
(3751, 1, 'An Giang'),
(3752, 1, 'Bac Giang'),
(3753, 1, 'Bac Kan'),
(3754, 1, 'Bac Lieu'),
(3755, 1, 'Bac Ninh'),
(3756, 1, 'Ba Ria-Vung Tau'),
(3757, 1, 'Ben Tre'),
(3758, 1, 'Binh Dinh'),
(3759, 1, 'Binh Duong'),
(3760, 1, 'Binh Phuoc'),
(3761, 1, 'Binh Thuan'),
(3762, 1, 'Ca Mau'),
(3763, 1, 'Can Tho'),
(3764, 1, 'Cao Bang'),
(3765, 1, 'Dak Lak'),
(3766, 1, 'Dak Nong'),
(3767, 1, 'Da Nang'),
(3768, 1, 'Dien Bien'),
(3769, 1, 'Dong Nai'),
(3770, 1, 'Dong Thap'),
(3771, 1, 'Gia Lai'),
(3772, 1, 'Ha Giang'),
(3773, 1, 'Hai Duong'),
(3774, 1, 'Hai Phong'),
(3775, 1, 'Ha Nam'),
(3776, 1, 'Ha Noi'),
(3777, 1, 'Ha Tay'),
(3778, 1, 'Ha Tinh'),
(3779, 1, 'Hoa Binh'),
(3780, 1, 'Ho Chi Minh City'),
(3781, 1, 'Hau Giang'),
(3782, 1, 'Hung Yen'),
(3783, 1, 'Saint Croix'),
(3784, 1, 'Saint John'),
(3785, 1, 'Saint Thomas'),
(3786, 1, 'Alo'),
(3787, 1, 'Sigave'),
(3788, 1, 'Wallis'),
(3789, 1, 'Abyan'),
(3790, 1, 'Adan'),
(3791, 1, 'Amran'),
(3792, 1, 'Al Bayda'),
(3793, 1, 'Ad Dali'),
(3794, 1, 'Dhamar'),
(3795, 1, 'Hadramawt'),
(3796, 1, 'Hajjah'),
(3797, 1, 'Al Hudaydah'),
(3798, 1, 'Ibb'),
(3799, 1, 'Al Jawf'),
(3800, 1, 'Lahij'),
(3801, 1, 'Ma''rib'),
(3802, 1, 'Al Mahrah'),
(3803, 1, 'Al Mahwit'),
(3804, 1, 'Sa''dah'),
(3805, 1, 'San''a'),
(3806, 1, 'Shabwah'),
(3807, 1, 'Ta''izz'),
(3808, 1, 'Andrijevica'),
(3809, 1, 'Bar'),
(3810, 1, 'Berane'),
(3811, 1, 'Bijelo Polje'),
(3812, 1, 'Bas-Congo'),
(3813, 1, 'Bandundu'),
(3814, 1, 'Equateur'),
(3815, 1, 'Katanga'),
(3816, 1, 'Kasai-Oriental'),
(3817, 1, 'Kinshasa'),
(3818, 1, 'Kasai-Occidental'),
(3819, 1, 'Maniema'),
(3820, 1, 'Nord-Kivu'),
(3821, 1, 'Orientale'),
(3822, 1, 'Sud-Kivu'),
(3823, 1, 'Central'),
(3824, 1, 'Copperbelt'),
(3825, 1, 'Eastern'),
(3826, 1, 'Luapula'),
(3827, 1, 'Lusaka'),
(3828, 1, 'Northern'),
(3829, 1, 'North-Western'),
(3830, 1, 'Southern'),
(3831, 1, 'Western'),
(3832, 1, 'Bulawayo'),
(3833, 1, 'Harare'),
(3834, 1, 'Manicaland'),
(3835, 1, 'Mashonaland Central'),
(3836, 1, 'Mashonaland East'),
(3837, 1, 'Mashonaland West'),
(3838, 1, 'Masvingo'),
(3839, 1, 'Matabeleland North'),
(3840, 1, 'Matabeleland South'),
(3841, 1, 'Midlands'),
(3842, 1, 'Agrigento'),
(3843, 1, 'Alessandria'),
(3844, 1, 'Ancona'),
(3845, 1, 'Aosta'),
(3846, 1, 'Arezzo'),
(3847, 1, 'Ascoli Piceno'),
(3848, 1, 'Asti'),
(3849, 1, 'Avellino'),
(3850, 1, 'Bari'),
(3851, 1, 'Belluno'),
(3852, 1, 'Benevento'),
(3853, 1, 'Bergamo'),
(3854, 1, 'Biella'),
(3855, 1, 'Bologna'),
(3856, 1, 'Bolzano'),
(3857, 1, 'Brescia'),
(3858, 1, 'Brindisi'),
(3859, 1, 'Cagliari'),
(3860, 1, 'Caltanissetta'),
(3861, 1, 'Campobasso'),
(3862, 1, 'Carbonia-Iglesias'),
(3863, 1, 'Caserta'),
(3864, 1, 'Catania'),
(3865, 1, 'Catanzaro'),
(3866, 1, 'Chieti'),
(3867, 1, 'Como'),
(3868, 1, 'Cosenza'),
(3869, 1, 'Cremona'),
(3870, 1, 'Crotone'),
(3871, 1, 'Cuneo'),
(3872, 1, 'Enna'),
(3873, 1, 'Ferrara'),
(3874, 1, 'Firenze'),
(3875, 1, 'Foggia'),
(3876, 1, 'Forli-Cesena'),
(3877, 1, 'Frosinone'),
(3878, 1, 'Genova'),
(3879, 1, 'Gorizia'),
(3880, 1, 'Grosseto'),
(3881, 1, 'Imperia'),
(3882, 1, 'Isernia'),
(3883, 1, 'L&#39;Aquila'),
(3884, 1, 'La Spezia'),
(3885, 1, 'Latina'),
(3886, 1, 'Lecce'),
(3887, 1, 'Lecco'),
(3888, 1, 'Livorno'),
(3889, 1, 'Lodi'),
(3890, 1, 'Lucca'),
(3891, 1, 'Macerata'),
(3892, 1, 'Mantova'),
(3893, 1, 'Massa-Carrara'),
(3894, 1, 'Matera'),
(3895, 1, 'Medio Campidano'),
(3896, 1, 'Messina'),
(3897, 1, 'Milano'),
(3898, 1, 'Modena'),
(3899, 1, 'Napoli'),
(3900, 1, 'Novara'),
(3901, 1, 'Nuoro'),
(3902, 1, 'Ogliastra'),
(3903, 1, 'Olbia-Tempio'),
(3904, 1, 'Oristano'),
(3905, 1, 'Padova'),
(3906, 1, 'Palermo'),
(3907, 1, 'Parma'),
(3908, 1, 'Pavia'),
(3909, 1, 'Perugia'),
(3910, 1, 'Pesaro e Urbino'),
(3911, 1, 'Pescara'),
(3912, 1, 'Piacenza'),
(3913, 1, 'Pisa'),
(3914, 1, 'Pistoia'),
(3915, 1, 'Pordenone'),
(3916, 1, 'Potenza'),
(3917, 1, 'Prato'),
(3918, 1, 'Ragusa'),
(3919, 1, 'Ravenna'),
(3920, 1, 'Reggio Calabria'),
(3921, 1, 'Reggio Emilia'),
(3922, 1, 'Rieti'),
(3923, 1, 'Rimini'),
(3924, 1, 'Roma'),
(3925, 1, 'Rovigo'),
(3926, 1, 'Salerno'),
(3927, 1, 'Sassari'),
(3928, 1, 'Savona'),
(3929, 1, 'Siena'),
(3930, 1, 'Siracusa'),
(3931, 1, 'Sondrio'),
(3932, 1, 'Taranto'),
(3933, 1, 'Teramo'),
(3934, 1, 'Terni'),
(3935, 1, 'Torino'),
(3936, 1, 'Trapani'),
(3937, 1, 'Trento'),
(3938, 1, 'Treviso'),
(3939, 1, 'Trieste'),
(3940, 1, 'Udine'),
(3941, 1, 'Varese'),
(3942, 1, 'Venezia'),
(3943, 1, 'Verbano-Cusio-Ossola'),
(3944, 1, 'Vercelli'),
(3945, 1, 'Verona'),
(3946, 1, 'Vibo Valentia'),
(3947, 1, 'Vicenza'),
(3948, 1, 'Viterbo'),
(3949, 1, 'Antrim'),
(3950, 1, 'Armagh'),
(3951, 1, 'Down'),
(3952, 1, 'Fermanagh'),
(3953, 1, 'Derry'),
(3954, 1, 'Tyrone'),
(3955, 1, 'Mura'),
(3956, 1, 'Drava'),
(3957, 1, 'Carinthia'),
(3958, 1, 'Savinja'),
(3959, 1, 'Central Sava'),
(3960, 1, 'Lower Sava'),
(3961, 1, 'Southeast Slovenia'),
(3962, 1, 'Littoral–Inner Carniola'),
(3963, 1, 'Central Slovenia'),
(3964, 1, 'Upper Carniola'),
(3965, 1, 'Gorizia'),
(3966, 1, 'Coastal–Karst'),
(3967, 1, 'Singapore'),
(3968, 1, 'Metro Manila'),
(3969, 1, 'Budva'),
(3970, 1, 'Cetinje'),
(3971, 1, 'Danilovgrad'),
(3972, 1, 'Gusinje'),
(3973, 1, 'Herceg Novi'),
(3974, 1, 'Kolašin'),
(3975, 1, 'Kotor'),
(3976, 1, 'Mojkovac'),
(3977, 1, 'Nikšić'),
(3978, 1, 'Petnjica'),
(3979, 1, 'Plav'),
(3980, 1, 'Pljevlja'),
(3981, 1, 'Plužine'),
(3982, 1, 'Podgorica'),
(3983, 1, 'Rožaje'),
(3984, 1, 'Šavnik'),
(3985, 1, 'Tivat'),
(3986, 1, 'Tuzi'),
(3987, 1, 'Ulcinj'),
(3988, 1, 'Žabljak'),
(3989, 1, 'Vojvodina'),
(3990, 1, 'Belgrade'),
(3991, 1, 'Šumadija and Western Serbia'),
(3992, 1, 'Southern and Eastern Serbia'),
(3993, 1, 'Kosovo and Metohija'),
(3994, 1, 'Ferizaj'),
(3995, 1, 'Gjakova'),
(3996, 1, 'Gjilan'),
(3997, 1, 'Mitrovica'),
(3998, 1, 'Peja'),
(3999, 1, 'Pristina'),
(4000, 1, 'Prizren'),
(4001, 1, 'Eastern'),
(4002, 1, 'Northeastern'),
(4003, 1, 'Pelagonia'),
(4004, 1, 'Polog'),
(4005, 1, 'Skopje'),
(4006, 1, 'Southeastern'),
(4007, 1, 'Southwestern'),
(4008, 1, 'Vardar');

--
-- Constraints for dumped tables
--

--
-- Constraints for table `[[dbprefix]]fields`
--
ALTER TABLE `[[dbprefix]]fields`
  ADD CONSTRAINT `[[dbprefix]]field_group_fk` FOREIGN KEY (`group_id`) REFERENCES `[[dbprefix]]field_groups` (`group_id`) ON DELETE SET NULL;

--
-- Constraints for table `[[dbprefix]]field_descriptions`
--
ALTER TABLE `[[dbprefix]]field_descriptions`
  ADD CONSTRAINT `[[dbprefix]]fields_fk` FOREIGN KEY (`field_id`) REFERENCES `[[dbprefix]]fields` (`field_id`) ON DELETE CASCADE ON UPDATE CASCADE;

--
-- Constraints for table `[[dbprefix]]field_group_to_form`
--
ALTER TABLE `[[dbprefix]]field_group_to_form`
  ADD CONSTRAINT `[[dbprefix]]field_group_to_form_fk` FOREIGN KEY (`form_id`) REFERENCES `[[dbprefix]]forms` (`form_id`) ON DELETE CASCADE ON UPDATE CASCADE,
  ADD CONSTRAINT `[[dbprefix]]field_group_to_group_fk` FOREIGN KEY (`group_id`) REFERENCES `[[dbprefix]]field_groups` (`group_id`) ON DELETE CASCADE ON UPDATE CASCADE;

--
-- Constraints for table `[[dbprefix]]form_descriptions`
--
ALTER TABLE `[[dbprefix]]form_descriptions`
  ADD CONSTRAINT `[[dbprefix]]form_descriptions_fk` FOREIGN KEY (`form_id`) REFERENCES `[[dbprefix]]forms` (`form_id`) ON DELETE CASCADE ON UPDATE CASCADE;

--
-- Constraints for table `[[dbprefix]]shopping_sessions`
--
ALTER TABLE `[[dbprefix]]shopping_sessions`
  ADD CONSTRAINT `[[dbprefix]]shopping_sessions_customer_fk` FOREIGN KEY (`customer_id`) REFERENCES `[[dbprefix]]customers` (`customer_id`) ON DELETE CASCADE ON UPDATE CASCADE;

/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
